@@ -30,26 +30,28 @@ if [ -z "$BUILD_FROM_TARBALL" ]; then
 fi
 
 if [ "$BUILD_FROM_TARBALL" = "yes" ]; then
-    UPDATE_SOURCES=no
     set_default GNUCASH_DIR "$(wpwd ..\\..)"
     set_default REPOS_DIR $GNUCASH_DIR
     # keep this pointing from BUILD_DIR to REPOS_DIR
     set_default REL_REPOS_DIR ..
-    set_default BUILD_DIR $GNUCASH_DIR\\build
-    set_default INSTALL_DIR $GNUCASH_DIR\\inst
 else
-    # change this to "no" if you are using install.sh from the same repository checkout
-    set_default UPDATE_SOURCES yes
-    # latest revision that should compile, use HEAD or vwxyz
-    set_default SVN_REV "HEAD"
     set_default GNUCASH_DIR $GLOBAL_DIR\\gnucash
-    set_default REPOS_URL "http://svn.gnucash.org/repo/gnucash/trunk"
     set_default REPOS_DIR $GNUCASH_DIR\\repos
     # keep this pointing from BUILD_DIR to REPOS_DIR
     set_default REL_REPOS_DIR ..\\repos
-    set_default BUILD_DIR $GNUCASH_DIR\\build
-    set_default INSTALL_DIR $GNUCASH_DIR\\inst
+
+    set_default REPOS_TYPE "git"
+    if [ "$REPOS_TYPE" = "git" ]; then
+      set_default GNUCASH_SCM_REV "trunk"
+      set_default REPOS_URL "git://github.com/Gnucash/gnucash.git"
+    elif [ "$REPOS_TYPE" = "svn" ]; then
+      # latest revision that should compile, use HEAD or vwxyz
+      set_default GNUCASH_SCM_REV "HEAD"
+      set_default REPOS_URL "http://svn.gnucash.org/repo/gnucash/trunk"
+    fi
 fi
+set_default BUILD_DIR $GNUCASH_DIR\\build
+set_default INSTALL_DIR $GNUCASH_DIR\\inst
 
 set_default WITH_CUTECASH no
 set_default CUTECASH_BUILD_DIR $GNUCASH_DIR\\build-cutecash
@@ -179,8 +181,6 @@ set_default READLINE_DIR $GLOBAL_DIR\\readline
 set_default ACTIVE_PERL_URL "http://downloads.activestate.com/ActivePerl/releases/5.14.4.1405/ActivePerl-5.14.4.1405-MSWin32-x86-296746.zip"
 set_default ACTIVE_PERL_DIR $GLOBAL_DIR\\active-perl
 
-#set_default AUTOCONF_URL "http://ftp.gnu.org/gnu/autoconf/autoconf-2.63.tar.bz2"
-#set_default AUTOMAKE_URL "http://ftp.gnu.org/gnu/automake/automake-1.10.2.tar.bz2"
 set_default AUTOCONF_URL "http://ftp.gnu.org/gnu/autoconf/autoconf-2.63.tar.bz2"
 set_default AUTOMAKE_URL "http://ftp.gnu.org/gnu/automake/automake-1.11.1.tar.bz2"
 set_default LIBTOOL_URL "http://ftp.gnu.org/gnu/libtool/libtool-2.2.6a.tar.gz"
@@ -196,9 +196,6 @@ GUILE_VERSION="1.8.8"
 set_default GUILE_URL "http://ftp.gnu.org/pub/gnu/guile/guile-${GUILE_VERSION}.tar.gz"
 set_default GUILE_DIR $GLOBAL_DIR\\guile
 set_default GUILE_PATCH `pwd`/guile-1.8.8.patch
-#set_default GUILE_URL "http://ftp.gnu.org/pub/gnu/guile/guile-1.6.8.tar.gz"
-set_default SLIB_URL "http://swiss.csail.mit.edu/ftpdir/scm/slib-3b3.zip"
-#set_default GUILE_DIR $GLOBAL_DIR\\guile
 
 set_default OPENSSL_URL "http://www.openssl.org/source/openssl-0.9.8j.tar.gz"
 set_default OPENSSL_DIR $GLOBAL_DIR\\openssl
@@ -214,31 +211,23 @@ set_default EXETYPE_SCRIPT `pwd`/exetype.pl
 set_default EXETYPE_DIR $TOOLS_DIR
 
 XMLSOFT_URL="http://xmlsoft.org/sources/win32"
-set_default LIBXSLT_URL "${XMLSOFT_URL}/libxslt-1.1.26.win32.zip"
-set_default LIBXSLT_LIBXML2_URL "${XMLSOFT_URL}/libxml2-2.7.6.win32.zip"
-set_default LIBXSLT_ICONV_URL "${XMLSOFT_URL}/iconv-1.9.2.win32.zip"
-set_default LIBXSLT_ZLIB_URL "${XMLSOFT_URL}/zlib-1.2.3.win32.zip"
-set_default LIBXSLT_DIR $GLOBAL_DIR\\libxslt
-set_default LIBXSLT_SRC_URL "http://xmlsoft.org/sources/libxslt-1.1.26.tar.gz" # needed for webkit build
-
-XMLSOFT_URL="http://xmlsoft.org/sources/win32"
-XSLT_BASE_URL="http://ftp.acc.umu.se/pub/GNOME/sources/libxslt/1.1"
+#XSLT_BASE_URL="http://ftp.acc.umu.se/pub/GNOME/sources/libxslt/1.1"
 XML2_BASE_URL="ftp://xmlsoft.org/libxml2"
-LIBXSLT_VERSION="1.1.22"
+LIBXSLT_VERSION="1.1.28"
 #LIBXSLT_VERSION=1.1.26
-set_default LIBXSLT_SRC_URL "${XSLT_BASE_URL}/libxslt-${LIBXSLT_VERSION}.tar.bz2"
-set_default LIBXSLT_MAKEFILE_PATCH "`pwd`/libxslt-1.1.22.Makefile.in.patch"
-LIBXML2_VERSION="2.7.7"
+set_default LIBXSLT_SRC_URL "${XML2_BASE_URL}/libxslt-${LIBXSLT_VERSION}.tar.gz"
+#set_default LIBXSLT_MAKEFILE_PATCH "`pwd`/libxslt-1.1.22.Makefile.in.patch"
+LIBXML2_VERSION="2.9.0"
 set_default LIBXML2_SRC_URL "${XML2_BASE_URL}/libxml2-${LIBXML2_VERSION}.tar.gz"
 set_default LIBXSLT_ICONV_URL "${XMLSOFT_URL}/iconv-1.9.2.win32.zip"
 set_default LIBXSLT_ZLIB_URL "${XMLSOFT_URL}/zlib-1.2.3.win32.zip"
 set_default LIBXSLT_DIR $GLOBAL_DIR\\libxslt
 
-set_default ATK_URL                 "$GNOME_WIN32_URL/atk/1.32/atk_1.32.0-1_win32.zip"
-set_default ATK_DEV_URL             "$GNOME_WIN32_URL/atk/1.32/atk-dev_1.32.0-1_win32.zip"
+set_default ATK_URL                 "$GNOME_WIN32_URL/atk/1.32/atk_1.32.0-2_win32.zip"
+set_default ATK_DEV_URL             "$GNOME_WIN32_URL/atk/1.32/atk-dev_1.32.0-2_win32.zip"
 CAIRO_VERSION="1.10.2"
-set_default CAIRO_URL               "$GNOME_WIN32_DEPS_URL/cairo_${CAIRO_VERSION}-1_win32.zip"
-set_default CAIRO_DEV_URL           "$GNOME_WIN32_DEPS_URL/cairo-dev_${CAIRO_VERSION}-1_win32.zip"
+set_default CAIRO_URL               "$GNOME_WIN32_DEPS_URL/cairo_${CAIRO_VERSION}-2_win32.zip"
+set_default CAIRO_DEV_URL           "$GNOME_WIN32_DEPS_URL/cairo-dev_${CAIRO_VERSION}-2_win32.zip"
 set_default EXPAT_URL               "$GNOME_WIN32_DEPS_URL/expat_2.0.1-1_win32.zip"
 set_default EXPAT_DEV_URL           "$GNOME_WIN32_DEPS_URL/expat-dev_2.0.1-1_win32.zip"
 set_default FONTCONFIG_URL          "$GNOME_WIN32_DEPS_URL/fontconfig_2.8.0-2_win32.zip"
@@ -250,36 +239,25 @@ set_default GAIL_DEV_URL            "$GNOME_WIN32_URL/gail/1.22/gail-dev-1.22.0.
 GCONF_VERSION="2.22.0"
 set_default GCONF_URL               "$GNOME_WIN32_URL/GConf/2.22/GConf_${GCONF_VERSION}-3_win32.zip"
 set_default GCONF_DEV_URL           "$GNOME_WIN32_URL/GConf/2.22/GConf-dev_${GCONF_VERSION}-3_win32.zip"
-#GDK_PIXBUF_VERSION=2.22.1
-set_default GDK_PIXBUF_URL          "$GNOME_WIN32_URL/gdk-pixbuf/2.22/gdk-pixbuf_${GCONF_VERSION}-1_win32.zip"
-set_default GDK_PIXBUF_DEV_URL      "$GNOME_WIN32_URL/gdk-pixbuf/2.22/gdk-pixbuf-dev_${GCONF_VERSION}-1_win32.zip"
-set_default GETTEXT_RUNTIME_URL     "$GNOME_WIN32_DEPS_URL/gettext-runtime_0.18.1.1-1_win32.zip"
-set_default GETTEXT_RUNTIME_DEV_URL "$GNOME_WIN32_DEPS_URL/gettext-runtime-dev_0.18.1.1-1_win32.zip"
-set_default GETTEXT_TOOLS_URL       "$GNOME_WIN32_DEPS_URL/gettext-tools-dev_0.18.1.1-1_win32.zip"
-set_default GLIB_URL                "$GNOME_WIN32_URL/glib/2.28/glib_2.28.1-1_win32.zip"
-set_default GLIB_DEV_URL            "$GNOME_WIN32_URL/glib/2.28/glib-dev_2.28.1-1_win32.zip"
-set_default GNOME_VFS_URL           "$GNOME_WIN32_URL/gnome-vfs/2.24/gnome-vfs_2.24.1-1_win32.zip"
-set_default GNOME_VFS_DEV_URL       "$GNOME_WIN32_URL/gnome-vfs/2.24/gnome-vfs-dev_2.24.1-1_win32.zip"
+GDK_PIXBUF_VERSION=2.24.0
+set_default GDK_PIXBUF_URL          "$GNOME_WIN32_URL/gdk-pixbuf/2.24/gdk-pixbuf_${GDK_PIXBUF_VERSION}-1_win32.zip"
+set_default GDK_PIXBUF_DEV_URL      "$GNOME_WIN32_URL/gdk-pixbuf/2.24/gdk-pixbuf-dev_${GDK_PIXBUF_VERSION}-1_win32.zip"
+set_default GETTEXT_RUNTIME_URL     "$GNOME_WIN32_DEPS_URL/gettext-runtime_0.18.1.1-2_win32.zip"
+set_default GETTEXT_RUNTIME_DEV_URL "$GNOME_WIN32_DEPS_URL/gettext-runtime-dev_0.18.1.1-2_win32.zip"
+set_default GETTEXT_TOOLS_URL       "$GNOME_WIN32_DEPS_URL/gettext-tools-dev_0.18.1.1-2_win32.zip"
+set_default GLIB_URL                "$GNOME_WIN32_URL/glib/2.28/glib_2.28.8-1_win32.zip"
+set_default GLIB_DEV_URL            "$GNOME_WIN32_URL/glib/2.28/glib-dev_2.28.8-1_win32.zip"
 GTK_VERSION="2.24.10"
 set_default GTK_URL                 "$GNOME_WIN32_URL/gtk+/2.24/gtk+_${GTK_VERSION}-1_win32.zip"
 set_default GTK_DEV_URL             "$GNOME_WIN32_URL/gtk+/2.24/gtk+-dev_${GTK_VERSION}-1_win32.zip"
 set_default GTK_DOC_URL             "$GNOME_MIRROR/sources/gtk-doc/1.13/gtk-doc-1.13.tar.bz2"
 set_default GTK_PREFS_URL           "$SF_MIRROR/gtk-win/gtk2_prefs-0.4.1.bin-gtk2.10-win32.zip"
 set_default GTK_THEME_URL           "$SF_MIRROR/gtk-win/gtk2-themes-2009-09-07-win32_bin.zip"
-set_default HICOLOR_THEME_URL       "$GNOME_WIN32_DEPS_URL/hicolor-icon-theme_0.10-1_win32.zip"
 set_default INTLTOOL_URL            "$GNOME_WIN32_URL/intltool/0.40/intltool_0.40.4-1_win32.zip"
 set_default LIBART_LGPL_URL         "$GNOME_WIN32_URL/libart_lgpl/2.3/libart-lgpl_2.3.21-1_win32.zip"
 set_default LIBART_LGPL_DEV_URL     "$GNOME_WIN32_URL/libart_lgpl/2.3/libart-lgpl-dev_2.3.21-1_win32.zip"
-set_default LIBBONOBO_URL           "$GNOME_WIN32_URL/libbonobo/2.24/libbonobo_2.24.0-1_win32.zip"
-set_default LIBBONOBO_DEV_URL       "$GNOME_WIN32_URL/libbonobo/2.24/libbonobo-dev_2.24.0-1_win32.zip"
-set_default LIBGLADE_URL            "$GNOME_WIN32_URL/libglade/2.6/libglade_2.6.4-1_win32.zip"
-set_default LIBGLADE_DEV_URL        "$GNOME_WIN32_URL/libglade/2.6/libglade-dev_2.6.4-1_win32.zip"
-set_default LIBGNOME_URL            "$GNOME_WIN32_URL/libgnome/2.24/libgnome_2.24.1-1_win32.zip"
-set_default LIBGNOME_DEV_URL        "$GNOME_WIN32_URL/libgnome/2.24/libgnome-dev_2.24.1-1_win32.zip"
 set_default LIBGNOMECANVAS_URL      "$GNOME_WIN32_URL/libgnomecanvas/2.30/libgnomecanvas_2.30.1-1_win32.zip"
 set_default LIBGNOMECANVAS_DEV_URL  "$GNOME_WIN32_URL/libgnomecanvas/2.30/libgnomecanvas-dev_2.30.1-1_win32.zip"
-set_default LIBGNOMEUI_URL          "$GNOME_WIN32_URL/libgnomeui/2.22/libgnomeui-2.22.1.zip"
-set_default LIBGNOMEUI_DEV_URL      "$GNOME_WIN32_URL/libgnomeui/2.22/libgnomeui-dev-2.22.1.zip"
 set_default LIBICONV_URL            "$GNOME_WIN32_DEPS_URL/libiconv-1.9.1.bin.woe32.zip"
 set_default LIBJPEG_URL             "$SF_MIRROR/gnucash/jpeg_7-1-fixed-win32.zip"
 set_default LIBJPEG_DEV_URL         "$GNOME_WIN32_DEPS_URL/jpeg-dev_7-1_win32.zip"
@@ -291,25 +269,14 @@ set_default LIBXML2_URL             "$GNOME_WIN32_DEPS_URL/libxml2_2.7.7-1_win32
 set_default LIBXML2_DEV_URL         "$GNOME_WIN32_DEPS_URL/libxml2-dev_2.7.7-1_win32.zip"
 set_default ORBIT2_URL              "$GNOME_WIN32_URL/ORBit2/2.14/ORBit2_2.14.16-1_win32.zip"
 set_default ORBIT2_DEV_URL          "$GNOME_WIN32_URL/ORBit2/2.14/ORBit2-dev_2.14.16-1_win32.zip"
-set_default PANGO_URL               "$GNOME_WIN32_URL/pango/1.28/pango_1.28.3-1_win32.zip"
-set_default PANGO_DEV_URL           "$GNOME_WIN32_URL/pango/1.28/pango-dev_1.28.3-1_win32.zip"
+set_default PANGO_URL               "$GNOME_WIN32_URL/pango/1.29/pango_1.29.4-1_win32.zip"
+set_default PANGO_DEV_URL           "$GNOME_WIN32_URL/pango/1.29/pango-dev_1.29.4-1_win32.zip"
 set_default PKG_CONFIG_URL          "$GNOME_WIN32_DEPS_URL/pkg-config_0.25-1_win32.zip"
 set_default PKG_CONFIG_DEV_URL      "$GNOME_WIN32_DEPS_URL/pkg-config-dev_0.25-1_win32.zip"
-set_default POPT_URL                "$GNOME_WIN32_DEPS_URL/popt-1.10.2-tml-20050828.zip"
-set_default POPT_DEV_URL            "$GNOME_WIN32_DEPS_URL/popt-dev-1.10.2-tml-20050828.zip"
 set_default ZLIB_URL                "$GNOME_WIN32_DEPS_URL/zlib_1.2.5-2_win32.zip"
 set_default ZLIB_DEV_URL            "$GNOME_WIN32_DEPS_URL/zlib-dev_1.2.5-2_win32.zip"
 set_default GNOME_DIR $GLOBAL_DIR\\gnome
 
-PIXMAN_VERSION="0.22.0"
-set_default PIXMAN_URL              "http://www.cairographics.org/releases/pixman-${PIXMAN_VERSION}.tar.gz"
-
-set_default LIBBONOBOUI_URL "$GNOME_WIN32_URL/libbonoboui/2.24/libbonoboui_2.24.0-1_win32.zip"
-set_default LIBBONOBOUI_DEV_URL "$GNOME_WIN32_URL/libbonoboui/2.24/libbonoboui-dev_2.24.0-1_win32.zip"
-set_default LIBBONOBOUI_SRC_URL "$GNOME_MIRROR/sources/libbonoboui/2.24/libbonoboui-2.24.2.tar.bz2"
-set_default LIBBONOBOUI_PATCH `pwd`/libbonoboui-2.24.2.patch
-set_default LIBBONOBOUI_DIR $GLOBAL_DIR\\libbonoboui
-
 set_default SWIG_URL "$SF_MIRROR/swig/swigwin-1.3.36.zip"
 set_default SWIG_DIR $GLOBAL_DIR\\swig
 
@@ -317,14 +284,14 @@ set_default PCRE_BIN_URL "$SF_MIRROR/gnuwin32/pcre-7.0-bin.zip"
 set_default PCRE_LIB_URL "$SF_MIRROR/gnuwin32/pcre-7.0-lib.zip"
 set_default PCRE_DIR $GLOBAL_DIR\\pcre
 
-LIBGSF_VERSION="1.14.17"
+LIBGSF_VERSION="1.14.21"
 set_default LIBGSF_URL "$GNOME_MIRROR/sources/libgsf/1.14/libgsf-${LIBGSF_VERSION}.tar.bz2"
 set_default LIBGSF_DIR $GLOBAL_DIR\\libgsf
 
 GOFFICE_VERSION="0.8.17"
 set_default GOFFICE_URL "$GNOME_MIRROR/sources/goffice/0.8/goffice-${GOFFICE_VERSION}.tar.bz2"
 set_default GOFFICE_DIR $GLOBAL_DIR\\goffice
-#set_default GOFFICE_PATCH `pwd`/goffice-0.7.2-patch.diff
+#set_default GOFFICE_PATCH `pwd`/goffice-x.x.x.patch
 
 set_default GLADE_URL "$GNOME_MIRROR/sources/glade3/3.0/glade3-3.1.2.tar.bz2"
 set_default GLADE_DIR $GLOBAL_DIR\\glade
@@ -335,17 +302,30 @@ set_default INNO_DIR $GLOBAL_DIR\\inno
 set_default HH_URL "http://download.microsoft.com/download/0/a/9/0a939ef6-e31c-430f-a3df-dfae7960d564/htmlhelp.exe"
 set_default HH_DIR $GLOBAL_DIR\\hh
 
-set_default WEBKIT_VERSION "1.1.90"
+set_default BUILD_WEBKIT_FROM_SOURCE no
+set_default WEBKIT_VERSION "1.2.7"
 set_default WEBKIT_URL "$SF_MIRROR/gnucash/webkit-${WEBKIT_VERSION}-win32.zip"
-set_default WEBKIT_DIR $GLOBAL_DIR\\webkit-${WEBKIT_VERSION}
+set_default WEBKIT_DIR $GLOBAL_DIR\\webkit
 set_default WEBKIT_SRC_URL "http://www.webkitgtk.org/webkit-1.2.7.tar.gz"
 set_default WEBKIT_PATCH `pwd`/webkit-1.2.7-time.patch
 set_default WEBKIT_PATCH2 `pwd`/webkit-1.2.7-vasprintf.patch
-set_default ENCHANT_URL "$GNOME_WIN32_URL/dependencies/enchant_1.5.0-2_win32.zip"
-set_default ENCHANT_DEV_URL "$GNOME_WIN32_URL/dependencies/enchant-dev_1.5.0-2_win32.zip"
-#set_default LIBSOUP_URL "$GNOME_WIN32_URL/libsoup/2.4/libsoup-2.4.0.zip"
-#set_default LIBSOUP_DEV_URL "$GNOME_WIN32_URL/libsoup/2.4/libsoup-dev-2.4.0.zip"
-set_default LIBSOUP_SRC_URL "$GNOME_MIRROR/sources/libsoup/2.30/libsoup-2.30.1.tar.bz2"
+set_default WEBKIT_CONFIGURE_PATCH `pwd`/webkit-1.2.7-configure.patch
+set_default WEBKIT_DATADIR_PATCH `pwd`/webkit-1.2.7-datadir.patch
+set_default WEBKIT_GCCPATH_PATCH `pwd`/webkit-1.2.7-gccpath.patch
+set_default WEBKIT_MAKEFILE_PATCH `pwd`/webkit-1.2.7-makefile.patch
+set_default WEBKIT_MINGW32_PATCH `pwd`/webkit-1.2.7-mingw32.patch
+set_default WEBKIT_NOSVG_PATCH `pwd`/webkit-1.2.7-nosvg.patch
+set_default WEBKIT_WEBKITENUMTYPES_CPP `pwd`/webkitenumtypes.cpp
+set_default WEBKIT_WEBKITENUMTYPES_H `pwd`/webkitenumtypes.h
+set_default ENCHANT_VERSION "1.5.0"
+set_default ENCHANT_URL "$GNOME_WIN32_URL/dependencies/enchant_${ENCHANT_VERSION}-2_win32.zip"
+set_default ENCHANT_DEV_URL "$GNOME_WIN32_URL/dependencies/enchant-dev_${ENCHANT_VERSION}-2_win32.zip"
+set_default ENCHANT_DIR $GLOBAL_DIR\\enchant
+set_default LIBSOUP_VERSION "2.28.2"
+set_default LIBSOUP_URL "$GNOME_WIN32_URL/libsoup/2.26/libsoup-${LIBSOUP_VERSION}-1_win32.zip"
+set_default LIBSOUP_DEV_URL "$GNOME_WIN32_URL/libsoup/2.26/libsoup-dev-${LIBSOUP_VERSION}-1_win32.zip"
+set_default LIBSOUP_DIR $GLOBAL_DIR\\libsoup
+set_default LIBSOUP_SRC_URL "$GNOME_MIRROR/sources/libsoup/2.28/libsoup-${LIBSOUP_VERSION}.tar.bz2"
 set_default ICU4C_URL "http://download.icu-project.org/files/icu4c/4.4.1/icu4c-4_4_1-Win32-msvc9.zip"
 set_default ICU4C_SRC_URL "http://download.icu-project.org/files/icu4c/4.4.1/icu4c-4_4_1-src.tgz"
 set_default ICU4C_DIR $GLOBAL_DIR\\icu-mingw32
@@ -354,15 +334,18 @@ set_default ICU4C_PATCH `pwd`/icu-crossmingw.patch
 set_default SVN_URL "http://subversion.tigris.org/files/documents/15/47914/svn-win32-1.6.6.zip"
 set_default SVN_DIR $GLOBAL_DIR\\svn
 
+set_default GIT_URL "http://msysgit.googlecode.com/files/Git-1.7.10-preview20120409.exe"
+set_default GIT_DIR $GLOBAL_DIR\\git-1.7.10
+
 # OFX import in gnucash and ofx directconnect support for aqbanking
 set_default OPENSP_URL "$SF_MIRROR/openjade/OpenSP-1.5.2.tar.gz"
 set_default OPENSP_DIR $GLOBAL_DIR\\opensp
-set_default OPENSP_PATCH `pwd`/opensp-1.5.2-patch.diff
+set_default OPENSP_PATCH `pwd`/opensp-1.5.2.patch
 
 LIBOFX_VERSION="0.9.8"
 set_default LIBOFX_URL "$SF_MIRROR/libofx/libofx-${LIBOFX_VERSION}.tar.gz"
 set_default LIBOFX_DIR $GLOBAL_DIR\\libofx
-#set_default LIBOFX_PATCH `pwd`/libofx-0.8.3-patch.diff
+#set_default LIBOFX_PATCH `pwd`/libofx-x.x.x.patch
 
 ## online banking: gwenhywfar+aqbanking
 set_default AQBANKING5 yes
@@ -371,12 +354,12 @@ set_default AQBANKING5 yes
 # needed.
 
 if [ "$AQBANKING5" = "yes" ]; then
-    GWENHYWFAR_VERSION="4.5.0beta"
-    set_default GWENHYWFAR_URL "http://www2.aquamaniac.de/sites/download/download.php?package=01&release=68&file=01&dummy=gwenhywfar-${GWENHYWFAR_VERSION}.tar.gz"
+    GWENHYWFAR_VERSION="4.6.0beta"
+    set_default GWENHYWFAR_URL "http://www2.aquamaniac.de/sites/download/download.php?package=01&release=69&file=01&dummy=gwenhywfar-${GWENHYWFAR_VERSION}.tar.gz"
 else
     GWENHYWFAR_VERSION="3.11.3"
     set_default GWENHYWFAR_URL "http://www2.aquamaniac.de/sites/download/download.php?package=01&release=31&file=01&dummy=gwenhywfar-${GWENHYWFAR_VERSION}.tar.gz"
-    #set_default GWENHYWFAR_PATCH `pwd`/gwenhywfar-3.11.1-patch.diff
+    #set_default GWENHYWFAR_PATCH `pwd`/gwenhywfar-x.x.x.patch
 fi
 set_default GWENHYWFAR_DIR $GLOBAL_DIR\\gwenhywfar
 
@@ -385,13 +368,13 @@ set_default KTOBLZCHECK_URL "$SF_MIRROR/ktoblzcheck/ktoblzcheck-${KTOBLZCHECK_VE
 # ktoblzcheck is being installed into GWENHYWFAR_DIR
 
 if [ "$AQBANKING5" = "yes" ]; then
-    AQBANKING_VERSION="5.0.27beta"
-    set_default AQBANKING_URL "http://www2.aquamaniac.de/sites/download/download.php?package=03&release=97&file=01&dummy=aqbanking-${AQBANKING_VERSION}.tar.gz"
+    AQBANKING_VERSION="5.0.28beta"
+    set_default AQBANKING_URL "http://www2.aquamaniac.de/sites/download/download.php?package=03&release=98&file=01&dummy=aqbanking-${AQBANKING_VERSION}.tar.gz"
     set_default AQBANKING_WITH_QT no
 else
     AQBANKING_VERSION="4.2.4"
     set_default AQBANKING_URL "http://www2.aquamaniac.de/sites/download/download.php?package=03&release=50&file=01&dummy=aqbanking-${AQBANKING_VERSION}.tar.gz"
-    set_default AQBANKING_PATCH `pwd`/aqbanking-4.2.4-r2132-patch.diff
+    set_default AQBANKING_PATCH `pwd`/aqbanking-4.2.4-r2132.patch
     set_default AQBANKING_WITH_QT yes
 fi
 set_default AQBANKING_DIR $GLOBAL_DIR\\aqbanking
@@ -422,9 +405,15 @@ set_default CMAKE_DIR $GLOBAL_DIR\\cmake
 
 set_default DOCBOOK_XSL_URL "$SF_MIRROR/docbook/docbook-xsl-1.76.1.zip"
 set_default DOCBOOK_DTD_URL "http://www.oasis-open.org/docbook/xml/4.1.2/docbkx412.zip"
+if [ "$REPOS_TYPE" = "git" ]; then
+  set_default DOCS_SCM_REV "trunk"
+  set_default DOCS_URL "git://github.com/Gnucash/gnucash-docs.git"
+elif [ "$REPOS_TYPE" = "svn" ]; then
+  # latest revision that should compile, use HEAD or vwxyz
+  set_default DOCS_SCM_REV "HEAD"
+  set_default DOCS_URL "http://svn.gnucash.org/repo/gnucash-docs/trunk"
+fi
 set_default UPDATE_DOCS yes
-set_default DOCS_REV "HEAD"
-set_default DOCS_URL "http://svn.gnucash.org/repo/gnucash-docs/trunk"
 set_default DOCS_DIR $GLOBAL_DIR\\gnucash-docs
 set_default XSLTPROCFLAGS ""
 
