@@ -43,7 +43,7 @@
 
 #include "qof.h"
 #include "guile-mappings.h"
-#include "core-utils/gnc-gconf-utils.h"
+#include "gnc-gconf-utils.h"
 #include "gnc-module/gnc-module.h"
 #include "engine/Account.h"
 #include "engine/Transaction.h"
@@ -51,7 +51,11 @@
 #include "app-utils/gnc-euro.h"
 #include "engine/gnc-hooks.h"
 #include "engine/gnc-session.h"
+#include "engine-helpers.h"
 #include "gnc-locale-utils.h"
+#include "gnc-component-manager.h"
+#include "gnc-features.h"
+#include "gnc-guile-utils.h"
 
 #define KEY_CURRENCY_CHOICE "currency_choice"
 #define KEY_CURRENCY_OTHER  "currency_other"
@@ -85,15 +89,15 @@ gnc_configure_account_separator (void)
 
     string = gnc_gconf_get_string(GCONF_GENERAL, KEY_ACCOUNT_SEPARATOR, NULL);
 
-    if (!string || !*string || safe_strcmp(string, "colon") == 0)
+    if (!string || !*string || g_strcmp0(string, "colon") == 0)
         separator = ":";
-    else if (safe_strcmp(string, "slash") == 0)
+    else if (g_strcmp0(string, "slash") == 0)
         separator = "/";
-    else if (safe_strcmp(string, "backslash") == 0)
+    else if (g_strcmp0(string, "backslash") == 0)
         separator = "\\";
-    else if (safe_strcmp(string, "dash") == 0)
+    else if (g_strcmp0(string, "dash") == 0)
         separator = "-";
-    else if (safe_strcmp(string, "period") == 0)
+    else if (g_strcmp0(string, "period") == 0)
         separator = ".";
     else
         separator = string;
@@ -116,17 +120,17 @@ gnc_configure_reverse_balance (void)
 
     choice = gnc_gconf_get_string(GCONF_GENERAL, KEY_REVERSED_ACCOUNTS, NULL);
 
-    if (safe_strcmp (choice, "none") == 0)
+    if (g_strcmp0 (choice, "none") == 0)
     {
     }
-    else if (safe_strcmp (choice, "income_expense") == 0)
+    else if (g_strcmp0 (choice, "income_expense") == 0)
     {
         reverse_type[ACCT_TYPE_INCOME]  = TRUE;
         reverse_type[ACCT_TYPE_EXPENSE] = TRUE;
     }
     else
     {
-        if (safe_strcmp (choice, "credit") != 0)
+        if (g_strcmp0 (choice, "credit") != 0)
             PERR("bad value '%s'", choice ? choice : "(null)");
         reverse_type[ACCT_TYPE_LIABILITY] = TRUE;
         reverse_type[ACCT_TYPE_PAYABLE]   = TRUE;
@@ -146,18 +150,6 @@ gnc_reverse_balance_init (void)
     reverse_balance_inited = TRUE;
 }
 
-gboolean
-gnc_reverse_balance_type (GNCAccountType type)
-{
-    if ((type < 0) || (type >= NUM_ACCOUNT_TYPES))
-        return FALSE;
-
-    if (!reverse_balance_inited)
-        gnc_reverse_balance_init ();
-
-    return reverse_type[type];
-}
-
 gboolean
 gnc_reverse_balance (const Account *account)
 {
@@ -205,6 +197,25 @@ gnc_get_current_book (void)
     return qof_session_get_book (gnc_get_current_session ());
 }
 
+/* If there is no current session, there is no book and we must be dealing
+ * with a new book. When gnucash is started with --nofile, there is
+ * initially no session (and no book), but by the time we check, one
+ * could have been created (for example, if an empty account tree tab is
+ * opened, a session is created which creates a new, but empty, book).
+ * A session is created and a book is loaded from a backend when gnucash is
+ * started with a file, but selecting 'new file' keeps a session open. So we
+ * need to check as well for a book with no accounts (root with no children). */
+gboolean
+gnc_is_new_book (void)
+{
+    return ((!gnc_current_session_exist() ||
+                            (gnc_current_session_exist() &&
+                                !gnc_account_get_children(
+                                    gnc_book_get_root_account(
+                                        gnc_get_current_book()))))
+                            ? TRUE : FALSE);
+}
+
 #define OPTION_TAXUS_NAME "book/tax_US/name"
 #define OPTION_TAXUS_TYPE "book/tax_US/type"
 
@@ -232,6 +243,26 @@ gnc_get_current_book_tax_type (void)
     return qof_book_get_string_option(gnc_get_current_book(), OPTION_TAXUS_TYPE);
 }
 
+/** Calls gnc_book_option_num_field_source_change to initiate registered
+  * callbacks when num_field_source book option changes so that
+  * registers/reports can update themselves; sets feature flag */
+void
+gnc_book_option_num_field_source_change_cb (gboolean num_action)
+{
+    gnc_suspend_gui_refresh ();
+    if (num_action)
+    {
+    /* Set a feature flag in the book for use of the split action field as number.
+     * This will prevent older GnuCash versions that don't support this feature
+     * from opening this file. */
+        gnc_features_set_used (gnc_get_current_book(),
+                                                GNC_FEATURE_NUM_FIELD_SOURCE);
+    }
+    gnc_book_option_num_field_source_change (num_action);
+    gnc_resume_gui_refresh ();
+    gnc_gui_refresh_all ();
+}
+
 Account *
 gnc_get_current_root_account (void)
 {
@@ -271,190 +302,6 @@ gnc_account_lookup_for_register(const Account *base_account, const char *name)
 }
 
 
-/*
- * This is a wrapper routine around an xaccGetBalanceInCurrency
- * function that handles additional needs of the gui.
- *
- * @param fn        The underlying function in Account.c to call to retrieve
- *                  a specific balance from the account.
- * @param account   The account to retrieve data about.
- * @param recurse   Include all sub-accounts of this account.
- * @param negative  An indication of whether or not the returned value
- *                  is negative.  This can be used by the caller to
- *                  easily decode whether or not to color the output.
- * @param commodity The commodity in which the account balance should
- *                  be returned. If NULL, the value will be returned in
- *                  the commodity of the account. This is normally used
- *                  to specify a currency, which forces the conversion
- *                  of things like stock account values from share
- *                  values to an amount the requested currency.
- */
-gnc_numeric
-gnc_ui_account_get_balance_full (xaccGetBalanceInCurrencyFn fn,
-                                 const Account *account,
-                                 gboolean recurse,
-                                 gboolean *negative,
-                                 const gnc_commodity *commodity)
-{
-    gnc_numeric balance;
-
-    balance = fn(account, commodity, recurse);
-
-    /* reverse sign if needed */
-    if (gnc_reverse_balance (account))
-        balance = gnc_numeric_neg (balance);
-
-    /* Record whether the balance is negative. */
-    if (negative)
-        *negative = gnc_numeric_negative_p(balance);
-
-    return balance;
-}
-
-/*
- * This routine retrives the total balance in an account, possibly
- * including all sub-accounts under the specified account.
- */
-gnc_numeric
-gnc_ui_account_get_balance (const Account *account, gboolean recurse)
-{
-    return gnc_ui_account_get_balance_full (xaccAccountGetBalanceInCurrency,
-                                            account, recurse, NULL, NULL);
-}
-
-/*
- * This routine retrives the total balance in an account converted to
- * a given currency, possibly including all sub-accounts under the
- * specified account.
- */
-gnc_numeric
-gnc_ui_account_get_balance_in_currency (const Account *account,
-                                        const gnc_commodity *currency,
-                                        gboolean recurse)
-{
-    return gnc_ui_account_get_balance_full (xaccAccountGetBalanceInCurrency,
-                                            account, recurse, NULL, currency);
-}
-
-/*
- * This routine retrives the reconciled balance in an account,
- * possibly including all sub-accounts under the specified account.
- */
-gnc_numeric
-gnc_ui_account_get_reconciled_balance (const Account *account,
-                                       gboolean recurse)
-{
-    return gnc_ui_account_get_balance_full (xaccAccountGetReconciledBalanceInCurrency,
-                                            account, recurse, NULL, NULL);
-}
-
-
-/**
- * Wrapper around gnc_ui_account_get_balance_full that converts
- * the resulting number to a character string.  The number is
- * formatted according to the specification of the account currency.
- * The caller is responsible for g_free'ing the returned memory.
- *
- * @param fn        The underlying function in Account.c to call to retrieve
- *                  a specific balance from the account.
- * @param account   The account to retrieve data about.
- * @param recurse   Include all sub-accounts of this account.
- * @param negative  An indication of whether or not the returned value
- *                  is negative.  This can be used by the caller to
- *                  easily decode whether or not to color the output.
- */
-gchar *
-gnc_ui_account_get_print_balance (xaccGetBalanceInCurrencyFn fn,
-                                  const Account *account,
-                                  gboolean recurse,
-                                  gboolean *negative)
-{
-    GNCPrintAmountInfo print_info;
-    gnc_numeric balance;
-
-    balance = gnc_ui_account_get_balance_full(fn, account, recurse,
-              negative, NULL);
-    print_info = gnc_account_print_info(account, TRUE);
-    return g_strdup(xaccPrintAmount(balance, print_info));
-}
-
-
-/**
- * Wrapper around gnc_ui_account_get_balance_full that converts
- * the resulting number to a character string.  The number is
- * formatted according to the specification of the default reporting
- * currency.
- *
- * @param fn        The underlying function in Account.c to call to retrieve
- *                  a specific balance from the account.
- * @param account   The account to retrieve data about.
- * @param recurse   Include all sub-accounts of this account.
- * @param negative  An indication of whether or not the returned value
- *                  is negative.  This can be used by the caller to
- *                  easily decode whether or not to color the output.
- */
-gchar *
-gnc_ui_account_get_print_report_balance (xaccGetBalanceInCurrencyFn fn,
-        const Account *account,
-        gboolean recurse,
-        gboolean *negative)
-{
-    GNCPrintAmountInfo print_info;
-    gnc_numeric balance;
-    gnc_commodity *report_commodity;
-
-    report_commodity = gnc_default_report_currency();
-    balance = gnc_ui_account_get_balance_full(fn, account, recurse,
-              negative, report_commodity);
-    print_info = gnc_commodity_print_info(report_commodity, TRUE);
-    return g_strdup(xaccPrintAmount(balance, print_info));
-}
-
-
-gnc_numeric
-gnc_ui_account_get_balance_as_of_date (Account *account,
-                                       time_t date,
-                                       gboolean include_children)
-{
-    gnc_numeric balance;
-    gnc_commodity *currency;
-
-    if (account == NULL)
-        return gnc_numeric_zero ();
-
-    currency = xaccAccountGetCommodity (account);
-    balance = xaccAccountGetBalanceAsOfDate (account, date);
-
-    if (include_children)
-    {
-        GList *children, *node;
-
-        children = gnc_account_get_descendants(account);
-
-        for (node = children; node; node = node->next)
-        {
-            Account *child;
-            gnc_commodity *child_currency;
-            gnc_numeric child_balance;
-
-            child = node->data;
-            child_currency = xaccAccountGetCommodity (child);
-            child_balance = xaccAccountGetBalanceAsOfDate (child, date);
-            child_balance = xaccAccountConvertBalanceToCurrency (child,
-                            child_balance, child_currency, currency);
-            balance = gnc_numeric_add_fixed (balance, child_balance);
-        }
-
-        g_list_free(children);
-    }
-
-    /* reverse sign if needed */
-    if (gnc_reverse_balance (account))
-        balance = gnc_numeric_neg (balance);
-
-    return balance;
-}
-
 /* Caller is responsible for g_free'ing returned memory */
 char *
 gnc_ui_account_get_tax_info_string (const Account *account)
@@ -464,14 +311,6 @@ gnc_ui_account_get_tax_info_string (const Account *account)
 
     gboolean tax_related = FALSE;
     const char *code;
-    const gchar *tax_type;
-    GNCAccountType atype;
-    SCM category;
-    SCM code_scm;
-    SCM tax_entity_type;
-    const gchar *form, *desc, *copy_txt;
-    gint64 copy_number;
-    SCM scm;
 
     if (!account)
         return NULL;
@@ -498,15 +337,20 @@ gnc_ui_account_get_tax_info_string (const Account *account)
     }
     else  /* with tax code */
     {
-        const gchar *num_code = NULL;
+        const gchar *tax_type;
+        GNCAccountType atype;
+        SCM tax_entity_type;
+        SCM category;
+        gchar *num_code = NULL;
         const gchar *prefix = "N";
+        gchar *return_string = NULL;
 
         tax_type = gnc_get_current_book_tax_type ();
-        if (tax_type == NULL || (safe_strcmp (tax_type, "") == 0))
+        if (tax_type == NULL || (g_strcmp0 (tax_type, "") == 0))
             return g_strdup (_("Tax entity type not specified"));
+
         atype = xaccAccountGetType (account);
-        /*    tax_entity_type = scm_from_locale_string (tax_type); <- requires guile 1.8*/
-        tax_entity_type = scm_makfrom0str (tax_type); /* <-guile 1.6  */
+        tax_entity_type = scm_from_locale_string (tax_type);
 
         if (get_form == SCM_UNDEFINED)
         {
@@ -536,7 +380,8 @@ gnc_ui_account_get_tax_info_string (const Account *account)
 
             g_return_val_if_fail (module, NULL);
 
-            get_form = scm_c_eval_string ("(false-if-exception gnc:txf-get-form)");
+            get_form = scm_c_eval_string
+                       ("(false-if-exception gnc:txf-get-form)");
             get_desc = scm_c_eval_string
                        ("(false-if-exception gnc:txf-get-description)");
         }
@@ -561,89 +406,139 @@ gnc_ui_account_get_tax_info_string (const Account *account)
                                           (atype == ACCT_TYPE_PAYABLE)) ?
                                          "txf-liab-eq-categories" : ""))));
 
-        num_code = g_strdup (code);
-        if (g_str_has_prefix (num_code, prefix))
-            num_code++; /* to lose the leading N */
+        if (g_str_has_prefix (code, prefix))
+        {
+            const gchar *num_code_tmp;
+            num_code_tmp = g_strdup (code);
+            num_code_tmp++; /* to lose the leading N */
+            num_code = g_strdup (num_code_tmp);
+            num_code_tmp--;
+            g_free ((gpointer *) num_code_tmp);
+        }
+        else
+        {
+            num_code = g_strdup (code);
+        }
 
         if (category == SCM_UNDEFINED)
         {
             if (tax_related)
-                return g_strdup_printf
-                       (_("Tax type %s: invalid code %s for account type"),
-                        tax_type, num_code);
+                return_string = g_strdup_printf
+                                (_("Tax type %s: invalid code %s for account type"),
+                                 tax_type, num_code);
             else
-                return g_strdup_printf
-                       (_("Not tax-related; tax type %s: invalid code %s for account type"),
-                        tax_type, num_code);
-        }
-
-        code_scm = scm_str2symbol (code);
-        scm = scm_call_3 (get_form, category, code_scm, tax_entity_type);
-        if (!scm_is_string (scm))
-        {
-            if (tax_related)
-                return g_strdup_printf
-                       (_("Invalid code %s for tax type %s"),
-                        num_code, tax_type);
-            else
-                return g_strdup_printf
-                       (_("Not tax-related; invalid code %s for tax type %s"),
-                        num_code, tax_type);
-        }
-
-        form = scm_to_locale_string (scm);
-        if (!form)
-        {
-            if (tax_related)
-                return g_strdup_printf
-                       (_("No form: code %s, tax type %s"), num_code, tax_type);
-            else
-                return g_strdup_printf
-                       (_("Not tax-related; no form: code %s, tax type %s"),
-                        num_code, tax_type);
-        }
-
-        scm = scm_call_3 (get_desc, category, code_scm, tax_entity_type);
-        if (!scm_is_string (scm))
-        {
-            if (tax_related)
-                return g_strdup_printf
-                       (_("No description: form %s, code %s, tax type %s"),
-                        form, num_code, tax_type);
-            else
-                return g_strdup_printf
-                       (_("Not tax-related; no description: form %s, code %s, tax type %s"),
-                        form, num_code, tax_type);
-        }
-
-        desc = scm_to_locale_string (scm);
-        if (!desc)
-        {
-            if (tax_related)
-                return g_strdup_printf
-                       (_("No description: form %s, code %s, tax type %s"),
-                        form, num_code, tax_type);
-            else
-                return g_strdup_printf
-                       (_("Not tax-related; no description: form %s, code %s, tax type %s"),
-                        form, num_code, tax_type);
-        }
-
-        copy_number = xaccAccountGetTaxUSCopyNumber (account);
-        copy_txt = (copy_number == 1) ? "" : g_strdup_printf ("(%d)",
-                   (gint) copy_number);
-
-        if (tax_related)
-        {
-            if (safe_strcmp (form, "") == 0)
-                return g_strdup_printf ("%s", desc);
-            else
-                return g_strdup_printf ("%s%s: %s", form, copy_txt, desc);
+                return_string = g_strdup_printf
+                                (_("Not tax-related; tax type %s: invalid code %s for account type"),
+                                 tax_type, num_code);
         }
         else
-            return g_strdup_printf
-                   (_("Not tax-related; %s%s: %s (code %s, tax type %s)"),
-                    form, copy_txt, desc, num_code, tax_type);
+        {
+            SCM code_scm;
+            SCM form_scm;
+            code_scm = scm_from_locale_symbol (code);
+            form_scm = scm_call_3 (get_form, category, code_scm, tax_entity_type);
+            if (!scm_is_string (form_scm))
+            {
+                if (tax_related)
+                    return_string =  g_strdup_printf
+                                     (_("Invalid code %s for tax type %s"),
+                                      num_code, tax_type);
+                else
+                    return_string =  g_strdup_printf
+                                     (_("Not tax-related; invalid code %s for tax type %s"),
+                                      num_code, tax_type);
+            }
+            else
+            {
+                gchar *form = NULL;
+
+                /* Note: using scm_to_locale_string directly here instead
+                   of our wrapper gnc_scm_to_locale_string. 'form' should
+                   be freed with 'free' instead of 'g_free'. This will
+                   be taken care of automatically during scm_dynwind_end,
+                   because we inform guile of this memory allocation via
+                   scm_dynwind_free a little further. */
+                form = scm_to_locale_string (form_scm);
+                if (!form)
+                {
+                    if (tax_related)
+                        return_string = g_strdup_printf
+                                        (_("No form: code %s, tax type %s"), num_code,
+                                         tax_type);
+                    else
+                        return_string = g_strdup_printf
+                                        (_("Not tax-related; no form: code %s, tax type %s"),
+                                         num_code, tax_type);
+                }
+                else
+                {
+                    SCM desc_scm;
+
+                    /* Create a dynwind context because we will be calling (scm) functions
+                       that potentially exit non-locally */
+                    scm_dynwind_begin (0);
+                    scm_dynwind_free (form);
+                    desc_scm = scm_call_3 (get_desc, category, code_scm,
+                                           tax_entity_type);
+                    if (!scm_is_string (desc_scm))
+                    {
+                        if (tax_related)
+                            return_string = g_strdup_printf
+                                            (_("No description: form %s, code %s, tax type %s"),
+                                             form, num_code, tax_type);
+                        else
+                            return_string = g_strdup_printf
+                                            (_("Not tax-related; no description: form %s, code %s, tax type %s"),
+                                             form, num_code, tax_type);
+                    }
+                    else
+                    {
+                        gchar *desc = NULL;
+                        desc = gnc_scm_to_locale_string (desc_scm);
+                        if (!desc)
+                        {
+                            if (tax_related)
+                                return_string = g_strdup_printf
+                                                (_("No description: form %s, code %s, tax type %s"),
+                                                 form, num_code, tax_type);
+                            else
+                                return_string = g_strdup_printf
+                                                (_("Not tax-related; no description: form %s, code %s, tax type %s"),
+                                                 form, num_code, tax_type);
+                        }
+                        else
+                        {
+                            gint64 copy_number;
+                            gchar *copy_txt = NULL;
+                            copy_number = xaccAccountGetTaxUSCopyNumber (account);
+                            copy_txt = (copy_number == 1) ?
+                                       g_strdup ("") :
+                                       g_strdup_printf ("(%d)",
+                                                        (gint) copy_number);
+                            if (tax_related)
+                            {
+                                if (g_strcmp0 (form, "") == 0)
+                                    return_string = g_strdup_printf ("%s", desc);
+                                else
+                                    return_string = g_strdup_printf ("%s%s: %s",
+                                                                     form, copy_txt, desc);
+                            }
+                            else
+                            {
+                                return_string = g_strdup_printf
+                                                (_("Not tax-related; %s%s: %s (code %s, tax type %s)"),
+                                                 form, copy_txt, desc, num_code, tax_type);
+                            }
+                            g_free (copy_txt);
+                        }
+                        g_free (desc);
+                    }
+                    scm_dynwind_end ();
+                }
+            }
+        }
+        g_free (num_code);
+        return return_string;
     }
 }
 
@@ -677,12 +572,12 @@ gnc_ui_account_get_tax_info_sub_acct_string (const Account *account)
          * account generally corresponds to a specific line number
          * on a paper form and each form has a unique
          * identification (e.g., Form 1040, Schedule A). */
-        return (sub_acct_tax_number == 0) ? g_strdup ("") :
+        return (sub_acct_tax_number == 0) ? NULL :
                g_strdup_printf (_("(Tax-related subaccounts: %d)"),
                                 sub_acct_tax_number);
     }
     else
-        return g_strdup ("");
+        return NULL;
 }
 
 static const char *
@@ -703,7 +598,7 @@ string_after_colon (const char *msgstr)
  * gnc_get_reconcile_str                                            *
  *   return the i18n'd string for the given reconciled flag         *
  *                                                                  *
- * Args: reconciled_flag - the flag to stringize                    *
+ * Args: reconciled_flag - the flag to convert into a string        *
  * Returns: the i18n'd reconciled string                            *
 \********************************************************************/
 const char *
@@ -751,7 +646,7 @@ gnc_get_reconcile_valid_flags (void)
  * gnc_get_reconcile_flag_order                                     *
  *   return a string containing the reconciled-flag change order    *
  *                                                                  *
- * Args: reconciled_flag - the flag to stringize                    *
+ * Args: reconciled_flag - the flag to convert into a string        *
  * Returns: the i18n'd reconciled string                            *
 \********************************************************************/
 const char *
@@ -870,7 +765,7 @@ gnc_find_or_create_equity_account (Account *root,
 gboolean
 gnc_account_create_opening_balance (Account *account,
                                     gnc_numeric balance,
-                                    time_t date,
+                                    time64 date,
                                     QofBook *book)
 {
     Account *equity_account;
@@ -896,8 +791,8 @@ gnc_account_create_opening_balance (Account *account,
 
     xaccTransBeginEdit (trans);
 
-    xaccTransSetCurrency (trans, xaccAccountGetCommodity (account));
-    xaccTransSetDatePostedSecs (trans, date);
+    xaccTransSetCurrency (trans, gnc_account_or_default_currency (account, NULL));
+    xaccTransSetDatePostedSecsNormalized (trans, date);
     xaccTransSetDescription (trans, _("Opening Balance"));
 
     split = xaccMallocSplit (book);
@@ -925,6 +820,7 @@ gnc_account_create_opening_balance (Account *account,
     return TRUE;
 }
 
+#if 0 /* Not Used */
 static void
 gnc_lconv_set_utf8 (char **p_value, char *default_value)
 {
@@ -968,7 +864,7 @@ gnc_lconv_set_char (char *p_value, char default_value)
     if ((p_value != NULL) && (*p_value == CHAR_MAX))
         *p_value = default_value;
 }
-
+#endif /* Not Used */
 
 gnc_commodity *
 gnc_locale_default_currency_nodefault (void)
@@ -1044,6 +940,33 @@ gnc_default_currency (void)
     return gnc_default_currency_common (user_default_currency, GCONF_GENERAL);
 }
 
+gnc_commodity * gnc_account_or_default_currency(const Account* account, gboolean * currency_from_account_found)
+{
+    gnc_commodity *currency;
+    if (!account)
+    {
+        if (currency_from_account_found)
+            *currency_from_account_found = FALSE;
+        return gnc_default_currency();
+    }
+
+    currency = gnc_account_get_currency_or_parent(account);
+    if (currency)
+    {
+        if (currency_from_account_found)
+            *currency_from_account_found = TRUE;
+    }
+    else
+    {
+        if (currency_from_account_found)
+            *currency_from_account_found = FALSE;
+        currency = gnc_default_currency();
+    }
+    return currency;
+}
+
+
+
 gnc_commodity *
 gnc_default_report_currency (void)
 {
@@ -1305,7 +1228,7 @@ PrintAmountInternal(char *buf, gnc_numeric val, const GNCPrintAmountInfo *info)
         return 0;
     }
 
-    /* Print the absolute value, but remember negativity */
+    /* Print the absolute value, but remember sign */
     value_is_negative = gnc_numeric_negative_p (val);
     val = gnc_numeric_abs (val);
 
@@ -1709,10 +1632,10 @@ static gchar *big_numbers[] =
        thousands. */
     "Million",
     /* Translators: This is the word for the number 10^9, one thousand
-       millions. WATCH OUT: In British english and many other languages
+       millions. WATCH OUT: In British English and many other languages
        this word is used for 10^12 which is one million millions! In
        contrast to this, here in GnuCash this is used in the American
-       english meaning of 10^9.  */
+       English meaning of 10^9.  */
     "Billion",
     /* Translators: This is the word for the number 10^12, one million
        millions. */
@@ -2379,7 +2302,7 @@ gnc_auto_decimal_init (void)
     auto_decimal_enabled =
         gnc_gconf_get_bool(GCONF_GENERAL, "auto_decimal_point", NULL);
     auto_decimal_places =
-        gnc_gconf_get_float(GCONF_GENERAL, "auto_decimal_places", NULL);
+        (int)gnc_gconf_get_float(GCONF_GENERAL, "auto_decimal_places", NULL);
 }
 
 void
@@ -2406,24 +2329,3 @@ gnc_ui_util_init (void)
                                   NULL);
 
 }
-
-/* These implementations are rather lame. */
-#ifndef HAVE_TOWUPPER
-gint32
-towupper (gint32 wc)
-{
-    if (wc > 127)
-        return wc;
-
-    return toupper ((int) wc);
-}
-
-int
-iswlower (gint32 wc)
-{
-    if (wc > 127)
-        return 1;
-
-    return islower ((int) wc);
-}
-#endif
