@@ -4,8 +4,9 @@
 #include <libguile.h>
 #include "guile-mappings.h"
 
-#include "engine-helpers.h"
+#include "engine-helpers-guile.h"
 #include "gnc-module.h"
+#include "gnc-guile-utils.h"
 #include "test-engine-stuff.h"
 #include "test-stuff.h"
 #include "Query.h"
@@ -20,18 +21,16 @@ test_query (Query *q, SCM val2str)
     SCM res_q;
     SCM args = SCM_EOL;
     Query *q2;
-    const gchar * str;
     gchar *str2 = NULL;
 
     scm_q = gnc_query2scm (q);
     args = scm_cons (scm_q, SCM_EOL);
     str_q = scm_apply (val2str, args, SCM_EOL);
 
-    args = scm_cons (scm_makfrom0str ("'"), scm_cons (str_q, SCM_EOL));
+    args = scm_cons (scm_from_locale_string ("'"), scm_cons (str_q, SCM_EOL));
     str_q = scm_string_append (args);
 
-    str = scm_to_locale_string (str_q);
-    if (str) str2 = g_strdup(str);
+    str2 = gnc_scm_to_locale_string (str_q);
     if (str2)
     {
         res_q = scm_c_eval_string (str2);
@@ -50,14 +49,14 @@ test_query (Query *q, SCM val2str)
         scm_q = gnc_query2scm (q2);
         scm_display (scm_q, SCM_UNDEFINED);
         scm_newline (SCM_UNDEFINED);
-        if (str2) g_free(str2);
+        g_free(str2);
         exit (1);
     }
     else
     {
         success ("queries match");
     }
-    if (str2) g_free(str2);
+    g_free(str2);
     if (q2) qof_query_destroy (q2);
 }
 
@@ -76,7 +75,6 @@ run_tests (void)
         q = get_random_query ();
         test_query (q, val2str);
         qof_query_destroy (q);
-        printf("%d ", i);
         fflush(stdout);
     }
 
@@ -84,16 +82,15 @@ run_tests (void)
         q = get_random_query ();
         test_query (q, val2str);
         qof_query_destroy (q);
-        printf("%d ", i);
         fflush(stdout);
     }
 
-    printf("\n");
 }
 
 static void
 main_helper (void *closure, int argc, char **argv)
 {
+    gnc_module_system_init ();
     gnc_module_load("gnucash/engine", 0);
     gnc_module_load("gnucash/app-utils", 0);
 
