@@ -46,7 +46,6 @@
 #include "SX-book.h"
 #include "Recurrence.h"
 
-#include "gnc-gconf-utils.h"
 #include "gnc-uri-utils.h"
 #include "gnc-filepath-utils.h"
 #include "gnc-locale-utils.h"
@@ -58,7 +57,7 @@
 #endif
 
 #ifdef G_OS_WIN32
-#include <Winsock2.h>
+#include <winsock2.h>
 #define GETPID() GetCurrentProcessId()
 #else
 #include <limits.h>
@@ -227,8 +226,6 @@ create_tables_cb( const gchar* type, gpointer data_p, gpointer be_p )
 static void
 sqlite3_error_fn( dbi_conn conn, /*@ unused @*/ void* user_data )
 {
-    GncDbiBackend *be = (GncDbiBackend*)user_data;
-    GncDbiSqlConnection *dbi_conn = (GncDbiSqlConnection*)be->sql_be.conn;
     const gchar* msg;
 
     (void)dbi_conn_error( conn, &msg );
@@ -264,6 +261,7 @@ gnc_dbi_sqlite3_session_begin( QofBackend *qbe, QofSession *session,
     {
         qof_backend_set_error( qbe, ERR_FILEIO_FILE_NOT_FOUND );
         qof_backend_set_message(qbe, "Sqlite3 file %s not found", filepath);
+        PWARN ("Sqlite3 file %s not found", filepath);
         goto exit;
     }
 
@@ -271,6 +269,7 @@ gnc_dbi_sqlite3_session_begin( QofBackend *qbe, QofSession *session,
     {
         qof_backend_set_error (qbe, ERR_BACKEND_STORE_EXISTS);
         msg = "Might clobber, no force";
+        PWARN ("%s", msg);
         goto exit;
     }
 
@@ -322,22 +321,22 @@ gnc_dbi_sqlite3_session_begin( QofBackend *qbe, QofSession *session,
     }
 
     dbi_test_result = conn_test_dbi_library( be->conn );
-    switch( dbi_test_result )
+    switch ( dbi_test_result )
     {
-        case GNC_DBI_PASS:
-            break;
+    case GNC_DBI_PASS:
+        break;
 
-        case GNC_DBI_FAIL_SETUP:
-            qof_backend_set_error( qbe, ERR_SQL_DBI_UNTESTABLE );
-            qof_backend_set_message( qbe,
-                    "SQLite3: Failed to setup for large number test" );
-            break;
+    case GNC_DBI_FAIL_SETUP:
+        qof_backend_set_error( qbe, ERR_SQL_DBI_UNTESTABLE );
+        qof_backend_set_message( qbe,
+                                 "SQLite3: Failed to setup for large number test" );
+        break;
 
-        case GNC_DBI_FAIL_TEST:
-            qof_backend_set_error( qbe, ERR_SQL_BAD_DBI );
-            qof_backend_set_message( qbe,
-                    "SQLite3 DBI library fails large number test" );
-            break;
+    case GNC_DBI_FAIL_TEST:
+        qof_backend_set_error( qbe, ERR_SQL_BAD_DBI );
+        qof_backend_set_message( qbe,
+                                 "SQLite3 DBI library fails large number test" );
+        break;
     }
     if ( dbi_test_result != GNC_DBI_PASS )
     {
@@ -667,7 +666,8 @@ gnc_dbi_lock_database ( QofBackend* qbe, gboolean ignore_lock )
         result = NULL;
     }
     return FALSE;
-}static void
+}
+static void
 gnc_dbi_unlock( QofBackend *qbe )
 {
     GncDbiBackend *qe = (GncDbiBackend*)qbe;
@@ -810,22 +810,22 @@ gnc_dbi_mysql_session_begin( QofBackend* qbe, QofSession *session,
     if ( result == 0 )
     {
         dbi_test_result = conn_test_dbi_library( be->conn );
-        switch( dbi_test_result )
+        switch ( dbi_test_result )
         {
-            case GNC_DBI_PASS:
-                break;
+        case GNC_DBI_PASS:
+            break;
 
-            case GNC_DBI_FAIL_SETUP:
-                qof_backend_set_error( qbe, ERR_SQL_DBI_UNTESTABLE );
-                qof_backend_set_message( qbe,
-                        "DBI library large number test incomplete" );
-                break;
+        case GNC_DBI_FAIL_SETUP:
+            qof_backend_set_error( qbe, ERR_SQL_DBI_UNTESTABLE );
+            qof_backend_set_message( qbe,
+                                     "DBI library large number test incomplete" );
+            break;
 
-            case GNC_DBI_FAIL_TEST:
-                qof_backend_set_error( qbe, ERR_SQL_BAD_DBI );
-                qof_backend_set_message( qbe,
-                        "DBI library fails large number test" );
-                break;
+        case GNC_DBI_FAIL_TEST:
+            qof_backend_set_error( qbe, ERR_SQL_BAD_DBI );
+            qof_backend_set_message( qbe,
+                                     "DBI library fails large number test" );
+            break;
         }
         if ( GNC_DBI_PASS != dbi_test_result )
         {
@@ -898,22 +898,22 @@ gnc_dbi_mysql_session_begin( QofBackend* qbe, QofSession *session,
                 goto exit;
             }
             dbi_test_result = conn_test_dbi_library( be->conn );
-            switch( dbi_test_result )
+            switch ( dbi_test_result )
             {
-                case GNC_DBI_PASS:
-                    break;
+            case GNC_DBI_PASS:
+                break;
 
-                case GNC_DBI_FAIL_SETUP:
-                    qof_backend_set_error( qbe, ERR_SQL_DBI_UNTESTABLE );
-                    qof_backend_set_message( qbe,
-                            "MySql: Failed to setup for large number test" );
-                    break;
+            case GNC_DBI_FAIL_SETUP:
+                qof_backend_set_error( qbe, ERR_SQL_DBI_UNTESTABLE );
+                qof_backend_set_message( qbe,
+                                         "MySql: Failed to setup for large number test" );
+                break;
 
-                case GNC_DBI_FAIL_TEST:
-                    qof_backend_set_error( qbe, ERR_SQL_BAD_DBI );
-                    qof_backend_set_message( qbe,
-                            "MySql DBI library fails large number test" );
-                    break;
+            case GNC_DBI_FAIL_TEST:
+                qof_backend_set_error( qbe, ERR_SQL_BAD_DBI );
+                qof_backend_set_message( qbe,
+                                         "MySql DBI library fails large number test" );
+                break;
             }
             if ( dbi_test_result != GNC_DBI_PASS )
             {
@@ -1138,20 +1138,20 @@ gnc_dbi_postgres_session_begin( QofBackend *qbe, QofSession *session,
         dbi_test_result = conn_test_dbi_library( be->conn );
         switch ( dbi_test_result )
         {
-            case GNC_DBI_PASS:
-                break;
+        case GNC_DBI_PASS:
+            break;
 
-            case GNC_DBI_FAIL_SETUP:
-                qof_backend_set_error( qbe, ERR_SQL_DBI_UNTESTABLE );
-                qof_backend_set_message( qbe,
-                        "Postgresql: Failed to setup for large number test" );
-                break;
+        case GNC_DBI_FAIL_SETUP:
+            qof_backend_set_error( qbe, ERR_SQL_DBI_UNTESTABLE );
+            qof_backend_set_message( qbe,
+                                     "Postgresql: Failed to setup for large number test" );
+            break;
 
-            case GNC_DBI_FAIL_TEST:
-                qof_backend_set_error( qbe, ERR_SQL_BAD_DBI );
-                qof_backend_set_message( qbe,
-                        "Postgresql DBI library fails large number test" );
-                break;
+        case GNC_DBI_FAIL_TEST:
+            qof_backend_set_error( qbe, ERR_SQL_BAD_DBI );
+            qof_backend_set_message( qbe,
+                                     "Postgresql DBI library fails large number test" );
+            break;
         }
         if ( dbi_test_result != GNC_DBI_PASS )
         {
@@ -1225,22 +1225,22 @@ gnc_dbi_postgres_session_begin( QofBackend *qbe, QofSession *session,
                 goto exit;
             }
             dbi_test_result = conn_test_dbi_library( be->conn );
-            switch( dbi_test_result )
+            switch ( dbi_test_result )
             {
-                case GNC_DBI_PASS:
-                    break;
+            case GNC_DBI_PASS:
+                break;
 
-                case GNC_DBI_FAIL_SETUP:
-                    qof_backend_set_error( qbe, ERR_SQL_DBI_UNTESTABLE );
-                    qof_backend_set_message( qbe,
-                            "DBI library large number test incomplete" );
-                    break;
+            case GNC_DBI_FAIL_SETUP:
+                qof_backend_set_error( qbe, ERR_SQL_DBI_UNTESTABLE );
+                qof_backend_set_message( qbe,
+                                         "DBI library large number test incomplete" );
+                break;
 
-                case GNC_DBI_FAIL_TEST:
-                    qof_backend_set_error( qbe, ERR_SQL_BAD_DBI );
-                    qof_backend_set_message( qbe,
-                            "DBI library fails large number test" );
-                    break;
+            case GNC_DBI_FAIL_TEST:
+                qof_backend_set_error( qbe, ERR_SQL_BAD_DBI );
+                qof_backend_set_message( qbe,
+                                         "DBI library fails large number test" );
+                break;
             }
             if ( GNC_DBI_PASS != dbi_test_result )
             {
@@ -1456,6 +1456,7 @@ conn_table_manage_backup (GncDbiSqlConnection *conn,
     case drop_backup:
         result = dbi_conn_queryf( conn->conn, "DROP TABLE %s",
                                   new_name );
+        break;
     default:
         break;
     }
@@ -1525,7 +1526,7 @@ conn_table_operation( GncSqlConnection *sql_conn, GSList *table_name_list,
                     if ( result )
                         break;
                 }
-                /* Note fall-through */
+                /* Fall through */
             case backup:
             case drop_backup:
                 result = conn_table_manage_backup( conn, table_name, op );
@@ -1555,6 +1556,7 @@ conn_table_operation( GncSqlConnection *sql_conn, GSList *table_name_list,
     return result;
 }
 
+#if 0 /* Not Used */
 /**
  * Really a bit of an understatement. More like "delete everything in
  * storage and replace with what's in memory".
@@ -1572,7 +1574,6 @@ gnc_dbi_sync_all( QofBackend* qbe, /*@ dependent @*/ QofBook *book )
     GncDbiSqlConnection *conn = (GncDbiSqlConnection*)(((GncSqlBackend*)be)->conn);
     GSList* table_name_list;
     const gchar* dbname;
-    gint status;
 
     g_return_if_fail( be != NULL );
     g_return_if_fail( book != NULL );
@@ -1596,6 +1597,7 @@ gnc_dbi_sync_all( QofBackend* qbe, /*@ dependent @*/ QofBook *book )
 
     LEAVE( "book=%p", book );
 }
+#endif
 
 /**
  * Safely resave a database by renaming all of its tables, recreating
@@ -1613,7 +1615,6 @@ gnc_dbi_safe_sync_all( QofBackend *qbe, QofBook *book )
     GncDbiSqlConnection *conn = (GncDbiSqlConnection*)(((GncSqlBackend*)be)->conn);
     GSList *table_list, *index_list, *iter;
     const gchar* dbname = NULL;
-    gint status;
 
     g_return_if_fail( be != NULL );
     g_return_if_fail( book != NULL );
@@ -1722,8 +1723,8 @@ init_sql_backend( GncDbiBackend* dbi_be )
     be->events_pending = NULL;
     be->process_events = NULL;
 
-/* The SQL/DBI backend doesn't need to be synced until it is
- * configured for multiuser access. */
+    /* The SQL/DBI backend doesn't need to be synced until it is
+     * configured for multiuser access. */
     be->sync = gnc_dbi_safe_sync_all;
     be->safe_sync = gnc_dbi_safe_sync_all;
     be->load_config = NULL;
@@ -1738,7 +1739,7 @@ init_sql_backend( GncDbiBackend* dbi_be )
     gnc_sql_init( &dbi_be->sql_be );
 
     dbi_be->sql_be.conn = NULL;
-    dbi_be->sql_be.primary_book = NULL;
+    dbi_be->sql_be.book = NULL;
 }
 
 static QofBackend*
@@ -1797,7 +1798,7 @@ gnc_dbi_check_sqlite3_file( const gchar *uri )
 {
     FILE* f;
     gchar buf[50];
-    size_t chars_read;
+    G_GNUC_UNUSED size_t chars_read;
     gint status;
     gchar *filename;
 
@@ -2007,8 +2008,7 @@ row_get_value_at_col_name( GncSqlRow* row, const gchar* col_name )
     gushort type;
     guint attrs;
     GValue* value;
-    time_t time;
-    struct tm tm_struct;
+    time64 time;
 
     type = dbi_result_get_field_type( dbi_row->result, col_name );
     attrs = dbi_result_get_field_attribs( dbi_row->result, col_name );
@@ -2054,20 +2054,21 @@ row_get_value_at_col_name( GncSqlRow* row, const gchar* col_name )
 	   creates a string that GDate can't parse. */
 	if (time >= 0)
 	  {
-	    (void)gmtime_r( &time, &tm_struct );
-	    (void)g_value_init( value, G_TYPE_STRING );
-	    g_value_take_string( value,
-				 g_strdup_printf( "%d%02d%02d%02d%02d%02d",
-						  1900 + tm_struct.tm_year,
-						  tm_struct.tm_mon + 1,
-						  tm_struct.tm_mday,
-						  tm_struct.tm_hour,
-						  tm_struct.tm_min,
-						  tm_struct.tm_sec ) );
+            struct tm *tm_struct = gnc_gmtime (&time);
+            (void)g_value_init (value, G_TYPE_STRING);
+            g_value_take_string (value,
+                                 g_strdup_printf ("%d%02d%02d%02d%02d%02d",
+                                                  1900 + tm_struct->tm_year,
+						  tm_struct->tm_mon + 1,
+						  tm_struct->tm_mday,
+                                                  tm_struct->tm_hour,
+						  tm_struct->tm_min,
+						  tm_struct->tm_sec));
+	    gnc_tm_free (tm_struct);
 	  }
 	else
 	  g_value_take_string (value, "19691231235959");
-        
+
         break;
     default:
         PERR( "Field %s: unknown DBI_TYPE: %d\n", col_name, type );
@@ -2347,6 +2348,7 @@ conn_create_statement_from_sql( /*@ observer @*/ GncSqlConnection* conn, const g
     return create_dbi_statement( conn, sql );
 }
 
+#if 0 /* Not Used */
 static GValue*
 create_gvalue_from_string( /*@ only @*/ gchar* s )
 {
@@ -2360,6 +2362,7 @@ create_gvalue_from_string( /*@ only @*/ gchar* s )
 
     return s_gval;
 }
+#endif
 
 static gboolean
 conn_does_table_exist( GncSqlConnection* conn, const gchar* table_name )
@@ -2523,7 +2526,6 @@ add_columns_ddl( GncSqlConnection* conn,
 {
     GString* ddl;
     const GList* list_node;
-    const GncSqlColumnTableEntry* table_row;
     guint col_num;
     GncDbiSqlConnection* dbi_conn = (GncDbiSqlConnection*)conn;
 
@@ -2861,7 +2863,6 @@ conn_create_index( /*@ unused @*/ GncSqlConnection* conn, /*@ unused @*/ const g
     GncDbiSqlConnection* dbi_conn = (GncDbiSqlConnection*)conn;
     gchar* ddl;
     dbi_result result;
-    gint status;
 
     g_return_val_if_fail( conn != NULL, FALSE );
     g_return_val_if_fail( index_name != NULL, FALSE );
@@ -2898,7 +2899,6 @@ conn_add_columns_to_table( /*@ unused @*/ GncSqlConnection* conn, /*@ unused @*/
     GncDbiSqlConnection* dbi_conn = (GncDbiSqlConnection*)conn;
     gchar* ddl;
     dbi_result result;
-    gint status;
 
     g_return_val_if_fail( conn != NULL, FALSE );
     g_return_val_if_fail( table_name != NULL, FALSE );
@@ -2956,7 +2956,6 @@ conn_get_table_list( dbi_conn conn, const gchar* dbname )
     while ( dbi_result_next_row( tables ) != 0 )
     {
         const gchar* table_name;
-        dbi_result result;
 
         table_name = dbi_result_get_string_idx( tables, 1 );
         list = g_slist_prepend( list, strdup( table_name ) );
@@ -3080,7 +3079,7 @@ conn_test_dbi_library( dbi_conn conn )
         PWARN("Test_DBI_Library: Failed to retrieve test row into table: %s",
               errmsg );
         result = dbi_conn_query( conn, "DROP TABLE numtest" );
-	gnc_pop_locale( LC_NUMERIC );
+        gnc_pop_locale( LC_NUMERIC );
         return GNC_DBI_FAIL_SETUP;
     }
     while ( dbi_result_next_row( result ))
