@@ -46,8 +46,6 @@
 #include "gncTaxTable.h"
 #include "gncInvoice.h"
 
-#include "gnc-gconf-utils.h"
-
 #include "gnc-backend-sql.h"
 
 #include "gnc-account-sql.h"
@@ -74,7 +72,7 @@
 #include "gnc-tax-table-sql.h"
 #include "gnc-vendor-sql.h"
 
-#include "gnc-main.h"
+#include "gnc-core-prefs.h"
 
 #if defined( S_SPLINT_S )
 #include "splint-defs.h"
@@ -229,8 +227,8 @@ gnc_sql_load( GncSqlBackend* be, /*@ dependent @*/ QofBook *book, QofBackendLoad
 
     if ( loadType == LOAD_TYPE_INITIAL_LOAD )
     {
-        g_assert( be->primary_book == NULL );
-        be->primary_book = book;
+        g_assert( be->book == NULL );
+        be->book = book;
 
         /* Load any initial stuff. Some of this needs to happen in a certain order */
         for ( i = 0; fixed_load_order[i] != NULL; i++ )
@@ -288,7 +286,7 @@ compare_namespaces(gconstpointer a, gconstpointer b)
     const gchar *sa = (const gchar *) a;
     const gchar *sb = (const gchar *) b;
 
-    return( safe_strcmp( sa, sb ) );
+    return( g_strcmp0( sa, sb ) );
 }
 
 static gint
@@ -297,7 +295,7 @@ compare_commodity_ids(gconstpointer a, gconstpointer b)
     const gnc_commodity *ca = (const gnc_commodity *) a;
     const gnc_commodity *cb = (const gnc_commodity *) b;
 
-    return( safe_strcmp( gnc_commodity_get_mnemonic( ca ),
+    return( g_strcmp0( gnc_commodity_get_mnemonic( ca ),
     gnc_commodity_get_mnemonic( cb ) ) );
 }
 
@@ -369,11 +367,11 @@ write_accounts( GncSqlBackend* be )
     g_return_val_if_fail( be != NULL, FALSE );
 
     update_progress( be );
-    is_ok = write_account_tree( be, gnc_book_get_root_account( be->primary_book ) );
+    is_ok = write_account_tree( be, gnc_book_get_root_account( be->book ) );
     if ( is_ok )
     {
         update_progress( be );
-        is_ok = write_account_tree( be, gnc_book_get_template_root( be->primary_book ) );
+        is_ok = write_account_tree( be, gnc_book_get_template_root( be->book ) );
     }
 
     return is_ok;
@@ -410,7 +408,7 @@ write_transactions( GncSqlBackend* be )
     data.be = be;
     data.is_ok = TRUE;
     (void)xaccAccountTreeForEachTransaction(
-        gnc_book_get_root_account( be->primary_book ), write_tx, &data );
+        gnc_book_get_root_account( be->book ), write_tx, &data );
     update_progress( be );
     return data.is_ok;
 }
@@ -425,7 +423,7 @@ write_template_transactions( GncSqlBackend* be )
 
     data.is_ok = TRUE;
     data.be = be;
-    ra = gnc_book_get_template_root( be->primary_book );
+    ra = gnc_book_get_template_root( be->book );
     if ( gnc_account_n_descendants( ra ) > 0 )
     {
         (void)xaccAccountTreeForEachTransaction( ra, write_tx, &data );
@@ -444,7 +442,7 @@ write_schedXactions( GncSqlBackend* be )
 
     g_return_val_if_fail( be != NULL, FALSE );
 
-    schedXactions = gnc_book_get_schedxactions( be->primary_book )->sx_list;
+    schedXactions = gnc_book_get_schedxactions( be->book )->sx_list;
 
     for ( ; schedXactions != NULL && is_ok; schedXactions = schedXactions->next )
     {
@@ -494,10 +492,10 @@ gnc_sql_sync_all( GncSqlBackend* be, /*@ dependent @*/ QofBook *book )
     g_return_if_fail( be != NULL );
     g_return_if_fail( book != NULL );
 
-    ENTER( "book=%p, primary=%p", book, be->primary_book );
+    ENTER( "book=%p, be->book=%p", book, be->book );
     update_progress( be );
     (void)reset_version_info( be );
-    gnc_sql_set_table_version( be, "Gnucash", gnc_get_long_version() );
+    gnc_sql_set_table_version( be, "Gnucash", gnc_core_prefs_get_long_version() );
     gnc_sql_set_table_version( be, "Gnucash-Resave", GNUCASH_RESAVE_VERSION );
 
     /* Create new tables */
@@ -505,7 +503,7 @@ gnc_sql_sync_all( GncSqlBackend* be, /*@ dependent @*/ QofBook *book )
     qof_object_foreach_backend( GNC_SQL_BACKEND, create_tables_cb, be );
 
     /* Save all contents */
-    be->primary_book = book;
+    be->book = book;
     be->obj_total = 0;
     be->obj_total += 1 + gnc_account_n_descendants( gnc_book_get_root_account( book ) );
     be->obj_total += gnc_book_count_transactions( book );
@@ -618,7 +616,7 @@ gnc_sql_commit_edit( GncSqlBackend *be, QofInstance *inst )
     g_return_if_fail( be != NULL );
     g_return_if_fail( inst != NULL );
 
-    if ( qof_book_is_readonly( be->primary_book ) )
+    if ( qof_book_is_readonly( be->book ) )
     {
         qof_backend_set_error( (QofBackend*)be, ERR_BACKEND_READONLY );
         (void)gnc_sql_connection_rollback_transaction( be->conn );
@@ -635,8 +633,8 @@ gnc_sql_commit_edit( GncSqlBackend *be, QofInstance *inst )
     // The engine has a PriceDB object but it isn't in the database
     if ( strcmp( inst->e_type, "PriceDB" ) == 0 )
     {
-        qof_book_mark_session_saved( be->primary_book );
         qof_instance_mark_clean( inst );
+        qof_book_mark_session_saved( be->book );
         return;
     }
 
@@ -676,7 +674,7 @@ gnc_sql_commit_edit( GncSqlBackend *be, QofInstance *inst )
         (void)gnc_sql_connection_rollback_transaction( be->conn );
 
         // Don't let unknown items still mark the book as being dirty
-        qof_book_mark_session_saved( be->primary_book );
+        qof_book_mark_session_saved( be->book );
         qof_instance_mark_clean(inst);
         LEAVE( "Rolled back - unknown object type" );
         return;
@@ -693,7 +691,7 @@ gnc_sql_commit_edit( GncSqlBackend *be, QofInstance *inst )
 
     (void)gnc_sql_connection_commit_transaction( be->conn );
 
-    qof_book_mark_session_saved( be->primary_book );
+    qof_book_mark_session_saved( be->book );
     qof_instance_mark_clean(inst);
 
     LEAVE( "" );
@@ -806,7 +804,7 @@ handle_and_term( QofQueryTerm* pTerm, GString* sql )
     }
     else if ( strcmp( pPredData->type_name, "numeric" ) == 0 )
     {
-        query_numeric_t pData = (query_numeric_t)pPredData;
+        /* query_numeric_t pData = (query_numeric_t)pPredData; */
 
         g_string_append( sql, "numeric" );
     }
@@ -923,14 +921,12 @@ gchar*
 gnc_sql_compile_query_to_sql( GncSqlBackend* be, QofQuery* query )
 {
     QofIdType searchObj;
-    GList* bookList;
     GString* sql;
 
     g_return_val_if_fail( be != NULL, NULL );
     g_return_val_if_fail( query != NULL, NULL );
 
     searchObj = qof_query_get_search_for( query );
-    bookList = qof_query_get_books( query );
 
     /* Convert search object type to table name */
     sql = g_string_new( "" );
@@ -1074,7 +1070,7 @@ gnc_sql_run_query( QofBackend* pBEnd, gpointer pQuery )
 //    }
 
     // Mark the book as clean
-    qof_instance_mark_clean( QOF_INSTANCE(be->primary_book) );
+    qof_instance_mark_clean( QOF_INSTANCE(be->book) );
 
 //    DEBUG( "%s\n", (gchar*)pQueryInfo->pCompiledQuery );
 
@@ -1551,7 +1547,6 @@ load_int64( const GncSqlBackend* be, GncSqlRow* row,
 
     g_return_if_fail( be != NULL );
     g_return_if_fail( row != NULL );
-    g_return_if_fail( setter != NULL );
     g_return_if_fail( table_row != NULL );
     g_return_if_fail( table_row->gobj_param_name != NULL || setter != NULL );
 
@@ -1801,7 +1796,6 @@ add_gvalue_guid_to_slist( const GncSqlBackend* be, QofIdTypeConst obj_name,
     GncGUID* guid = NULL;
     gchar guid_buf[GUID_ENCODING_LENGTH+1];
     GValue* value;
-    gboolean free_guid = FALSE;
 
     g_return_if_fail( be != NULL );
     g_return_if_fail( obj_name != NULL );
@@ -1813,7 +1807,6 @@ add_gvalue_guid_to_slist( const GncSqlBackend* be, QofIdTypeConst obj_name,
     if ( table_row->gobj_param_name != NULL )
     {
         g_object_get( pObject, table_row->gobj_param_name, &guid, NULL );
-        free_guid = TRUE;
     }
     else
     {
@@ -1832,12 +1825,6 @@ add_gvalue_guid_to_slist( const GncSqlBackend* be, QofIdTypeConst obj_name,
 
     (*pList) = g_slist_append( (*pList), value );
 
-#if 0
-    if ( free_guid )
-    {
-        g_free( guid );
-    }
-#endif
 }
 
 static GncSqlColumnTypeHandler guid_handler
@@ -1911,19 +1898,19 @@ typedef void (*TimespecSetterFunc)( const gpointer, Timespec );
 gchar*
 gnc_sql_convert_timespec_to_string( const GncSqlBackend* be, Timespec ts )
 {
-    time_t time;
+    time64 time;
     struct tm* tm;
     gint year;
     gchar* datebuf;
 
-    time = timespecToTime_t( ts );
-    tm = gmtime( &time );
+    time = timespecToTime64( ts );
+    tm = gnc_gmtime( &time );
 
-    if ( tm->tm_year < 60 ) year = tm->tm_year + 2000;
-    else year = tm->tm_year + 1900;
+    year = tm->tm_year + 1900;
 
     datebuf = g_strdup_printf( be->timespec_format,
                                year, tm->tm_mon + 1, tm->tm_mday, tm->tm_hour, tm->tm_min, tm->tm_sec );
+    gnc_tm_free (tm);
     return datebuf;
 }
 
@@ -3277,9 +3264,7 @@ gnc_sql_init_version_info( GncSqlBackend* be )
     }
     else
     {
-        gboolean ok;
-
-        ok = do_create_table( be, VERSION_TABLE_NAME, version_table );
+        do_create_table( be, VERSION_TABLE_NAME, version_table );
     }
 }
 
