@@ -89,7 +89,6 @@ static const GncSqlColumnTableEntry tx_col_table[] =
 
 static /*@ dependent @*//*@ null @*/ gpointer get_split_reconcile_state( gpointer pObject );
 static void set_split_reconcile_state( gpointer pObject, /*@ null @*/ gpointer pValue );
-static void set_split_reconcile_date( gpointer pObject, Timespec ts );
 static void set_split_lot( gpointer pObject, /*@ null @*/ gpointer pLot );
 
 #define SPLIT_MAX_MEMO_LEN 2048
@@ -168,7 +167,7 @@ set_split_reconcile_state( gpointer pObject, /*@ null @*/ gpointer pValue )
 
     xaccSplitSetReconcile( GNC_SPLIT(pObject), s[0] );
 }
-
+#if 0 /* Not Used */
 static void
 set_split_reconcile_date( gpointer pObject, Timespec ts )
 {
@@ -177,6 +176,7 @@ set_split_reconcile_date( gpointer pObject, Timespec ts )
 
     xaccSplitSetDateReconciledTS( GNC_SPLIT(pObject), &ts );
 }
+#endif
 
 static void
 set_split_lot( gpointer pObject, /*@ null @*/ gpointer pLot )
@@ -210,10 +210,10 @@ load_single_split( GncSqlBackend* be, GncSqlRow* row )
     if ( guid == NULL ) return NULL;
     split_guid = *guid;
 
-    pSplit = xaccSplitLookup( &split_guid, be->primary_book );
+    pSplit = xaccSplitLookup( &split_guid, be->book );
     if ( pSplit == NULL )
     {
-        pSplit = xaccMallocSplit( be->primary_book );
+        pSplit = xaccMallocSplit( be->book );
     }
 
     /* If the split is dirty, don't overwrite it */
@@ -222,7 +222,7 @@ load_single_split( GncSqlBackend* be, GncSqlRow* row )
         gnc_sql_load_object( be, row, GNC_ID_SPLIT, pSplit, split_col_table );
     }
 
-    /*# -ifempty */g_assert( pSplit == xaccSplitLookup( &split_guid, be->primary_book ) );
+    /*# -ifempty */g_assert( pSplit == xaccSplitLookup( &split_guid, be->book ) );
 
     return pSplit;
 }
@@ -287,17 +287,17 @@ load_single_tx( GncSqlBackend* be, GncSqlRow* row )
     tx_guid = *guid;
 
     // Don't overwrite the transaction if it's already been loaded (and possibly modified).
-    pTx = xaccTransLookup( &tx_guid, be->primary_book );
+    pTx = xaccTransLookup( &tx_guid, be->book );
     if ( pTx != NULL )
     {
         return NULL;
     }
 
-    pTx = xaccMallocTransaction( be->primary_book );
+    pTx = xaccMallocTransaction( be->book );
     xaccTransBeginEdit( pTx );
     gnc_sql_load_object( be, row, GNC_ID_TRANS, pTx, tx_col_table );
 
-    g_assert( pTx == xaccTransLookup( &tx_guid, be->primary_book ) );
+    g_assert( pTx == xaccTransLookup( &tx_guid, be->book ) );
 
     return pTx;
 }
@@ -319,6 +319,7 @@ typedef struct
     gnc_numeric end_reconciled_bal;
 } full_acct_balances_t;
 
+#if 0 /* Not Used */
 /**
  * Saves the start/end balances for an account.
  *
@@ -364,7 +365,7 @@ save_account_balances( Account* acc, gpointer pData )
     g_free( pstart_r );
     g_free( pend_r );
 }
-
+#endif
 /**
  * Executes a transaction query statement and loads the transactions and all
  * of the splits.
@@ -387,11 +388,11 @@ query_transactions( GncSqlBackend* be, GncSqlStatement* stmt )
         GList* node;
         GncSqlRow* row;
         Transaction* tx;
+#if LOAD_TRANSACTIONS_AS_NEEDED
         GSList* bal_list = NULL;
         GSList* nextbal;
-        Account* root = gnc_book_get_root_account( be->primary_book );
+        Account* root = gnc_book_get_root_account( be->book );
 
-#if LOAD_TRANSACTIONS_AS_NEEDED
         qof_event_suspend();
         xaccAccountBeginEdit( root );
 
@@ -776,8 +777,8 @@ save_transaction( GncSqlBackend* be, Transaction* pTx, gboolean do_save_splits )
     }
     if (! is_ok )
     {
-        gchar *message1 = "Transaction %s dated %s in account %s not saved due to %s.%s";
-        gchar *message2 = "\nDatabase may be corrupted, check your data carefully.";
+        G_GNUC_UNUSED gchar *message1 = "Transaction %s dated %s in account %s not saved due to %s.%s";
+        G_GNUC_UNUSED gchar *message2 = "\nDatabase may be corrupted, check your data carefully.";
         Split* split = xaccTransGetSplit( pTx, 0);
         Account *acc = xaccSplitGetAccount( split );
         /* FIXME: This needs to be implemented
@@ -819,6 +820,7 @@ commit_transaction( GncSqlBackend* be, QofInstance* inst )
 }
 
 /* ================================================================= */
+#if 0 /* Not Used */
 static /*@ dependent @*//*@ null @*/ const GncGUID*
 get_guid_from_query( QofQuery* pQuery )
 {
@@ -849,7 +851,7 @@ get_guid_from_query( QofQuery* pQuery )
         return NULL;
     }
 }
-
+#endif
 /**
  * Loads all transactions for an account.
  *
@@ -946,19 +948,16 @@ convert_query_comparison_to_sql( QofQueryPredData* pPredData, gboolean isInverte
 static void
 convert_query_term_to_sql( const GncSqlBackend* be, const gchar* fieldName, QofQueryTerm* pTerm, GString* sql )
 {
-    GSList* pParamPath;
     QofQueryPredData* pPredData;
     gboolean isInverted;
-    GSList* name;
 
     g_return_if_fail( pTerm != NULL );
     g_return_if_fail( sql != NULL );
 
-    pParamPath = qof_query_term_get_param_path( pTerm );
     pPredData = qof_query_term_get_pred_data( pTerm );
     isInverted = qof_query_term_is_inverted( pTerm );
 
-    if ( safe_strcmp( pPredData->type_name, QOF_TYPE_GUID ) == 0 )
+    if ( g_strcmp0( pPredData->type_name, QOF_TYPE_GUID ) == 0 )
     {
         query_guid_t guid_data = (query_guid_t)pPredData;
         GList* guid_entry;
@@ -993,7 +992,7 @@ convert_query_term_to_sql( const GncSqlBackend* be, const gchar* fieldName, QofQ
         g_string_append( sql, "))" );
 
     }
-    else if ( safe_strcmp( pPredData->type_name, QOF_TYPE_CHAR ) == 0 )
+    else if ( g_strcmp0( pPredData->type_name, QOF_TYPE_CHAR ) == 0 )
     {
         query_char_t char_data = (query_char_t)pPredData;
         int i;
@@ -1025,7 +1024,7 @@ convert_query_term_to_sql( const GncSqlBackend* be, const gchar* fieldName, QofQ
         }
 
     }
-    else if ( safe_strcmp( pPredData->type_name, QOF_TYPE_STRING ) == 0 )
+    else if ( g_strcmp0( pPredData->type_name, QOF_TYPE_STRING ) == 0 )
     {
         query_string_t string_data = (query_string_t)pPredData;
         sqlEscape* escape = sqlEscape_new();
@@ -1078,7 +1077,7 @@ convert_query_term_to_sql( const GncSqlBackend* be, const gchar* fieldName, QofQ
             g_string_append_printf( sql, "%f", d );
 
         }
-        else if ( safe_strcmp( pPredData->type_name, QOF_TYPE_DATE ) == 0 )
+        else if ( g_strcmp0( pPredData->type_name, QOF_TYPE_DATE ) == 0 )
         {
             query_date_t date_data = (query_date_t)pPredData;
             gchar* datebuf;
@@ -1130,11 +1129,11 @@ typedef struct
     gboolean has_been_run;
 } split_query_info_t;
 
-static /*@ null @*/ gpointer
+#define TX_GUID_CHECK 0
+
+G_GNUC_UNUSED static /*@ null @*/ gpointer
 compile_split_query( GncSqlBackend* be, QofQuery* query )
 {
-    const GncGUID* acct_guid;
-    gchar guid_buf[GUID_ENCODING_LENGTH+1];
     split_query_info_t* query_info = NULL;
     gchar* query_sql;
 
@@ -1157,8 +1156,9 @@ compile_split_query( GncSqlBackend* be, QofQuery* query )
             GList* andterms = (GList*)orTerm->data;
             GList* andTerm;
             gboolean need_AND = FALSE;
+#if TX_GUID_CHECK
             gboolean has_tx_guid_check = FALSE;
-
+#endif
             if ( need_OR )
             {
                 g_string_append( sql, " OR " );
@@ -1198,7 +1198,7 @@ compile_split_query( GncSqlBackend* be, QofQuery* query )
                 }
                 else if ( strcmp( paramPath->data, SPLIT_TRANS ) == 0 )
                 {
-#if 0
+#if TX_GUID_CHECK
                     if ( !has_tx_guid_check )
                     {
                         g_string_append( sql, "(splits.tx_guid = transactions.guid) AND " );
@@ -1290,7 +1290,7 @@ done_compiling_query:
     return query_info;
 }
 
-static void
+G_GNUC_UNUSED static void
 run_split_query( GncSqlBackend* be, gpointer pQuery )
 {
     split_query_info_t* query_info = (split_query_info_t*)pQuery;
@@ -1307,7 +1307,7 @@ run_split_query( GncSqlBackend* be, gpointer pQuery )
     }
 }
 
-static void
+G_GNUC_UNUSED static void
 free_split_query( GncSqlBackend* be, gpointer pQuery )
 {
     g_return_if_fail( be != NULL );
@@ -1335,7 +1335,7 @@ set_acct_bal_account_from_guid( gpointer pObject, gpointer pValue )
     g_return_if_fail( pObject != NULL );
     g_return_if_fail( pValue != NULL );
 
-    bal->acct = xaccAccountLookup( guid, bal->be->primary_book );
+    bal->acct = xaccAccountLookup( guid, bal->be->book );
 }
 
 static void
@@ -1370,7 +1370,7 @@ static const GncSqlColumnTableEntry acct_balances_col_table[] =
     /*@ +full_init_block @*/
 };
 
-static /*@ null @*/ single_acct_balance_t*
+G_GNUC_UNUSED static /*@ null @*/ single_acct_balance_t*
 load_single_acct_balances( const GncSqlBackend* be, GncSqlRow* row )
 {
     single_acct_balance_t* bal = NULL;
@@ -1498,7 +1498,7 @@ load_tx_guid( const GncSqlBackend* be, GncSqlRow* row,
     if ( guid_str != NULL )
     {
         (void)string_to_guid( guid_str, &guid );
-        tx = xaccTransLookup( &guid, be->primary_book );
+        tx = xaccTransLookup( &guid, be->book );
 
         // If the transaction is not found, try loading it
         if ( tx == NULL )
@@ -1511,7 +1511,7 @@ load_tx_guid( const GncSqlBackend* be, GncSqlRow* row,
             stmt = gnc_sql_create_statement_from_sql( (GncSqlBackend*)be, buf );
             g_free( buf );
             query_transactions( (GncSqlBackend*)be, stmt );
-            tx = xaccTransLookup( &guid, be->primary_book );
+            tx = xaccTransLookup( &guid, be->book );
         }
 
         if ( tx != NULL )
