@@ -28,6 +28,7 @@
 
 #include "gnc-plugin.h"
 #include "dialog-invoice.h"
+#include "gnc-ledger-display.h"
 #include "gnc-plugin-page-invoice.h"
 
 #include "dialog-account.h"
@@ -55,10 +56,6 @@ static void gnc_plugin_page_invoice_window_changed (GncPluginPage *plugin_page,
 
 static void gnc_plugin_page_invoice_summarybar_position_changed(GConfEntry *entry, gpointer user_data);
 
-void gnc_plugin_page_invoice_start_toggle_cb(GtkToggleButton *toggle, gpointer data);
-void gnc_plugin_page_invoice_end_toggle_cb(GtkToggleButton *toggle, gpointer data);
-void gnc_plugin_page_invoice_today_cb(GtkButton *buttontoggle, gpointer data);
-
 /* Command callbacks */
 static void gnc_plugin_page_invoice_cmd_new_invoice (GtkAction *action, GncPluginPageInvoice *plugin_page);
 static void gnc_plugin_page_invoice_cmd_new_account (GtkAction *action, GncPluginPageInvoice *plugin_page);
@@ -208,15 +205,25 @@ static guint gnc_plugin_page_invoice_n_actions = G_N_ELEMENTS (gnc_plugin_page_i
 
 static GtkRadioActionEntry radio_entries [] =
 {
-    { "SortStandardAction", NULL, N_("_Standard"), NULL, N_("Keep normal invoice order"), BY_STANDARD },
-    { "SortDateAction", NULL, N_("_Date"), NULL, N_("Sort by date"), BY_DATE },
-    { "SortDateEntryAction", NULL, N_("Date of _Entry"), NULL, N_("Sort by the date of entry"), BY_DATE_ENTERED },
-    { "SortQuantityAction", NULL, N_("_Quantity"), NULL, N_("Sort by quantity"), BY_QTY },
-    { "SortPriceAction", NULL, N_("_Price"), NULL, N_("Sort by price"), BY_PRICE },
-    { "SortDescriptionAction", NULL, N_("Descri_ption"), NULL, N_("Sort by description"), BY_DESC },
+    { "SortStandardAction", NULL, N_("_Standard"), NULL, N_("Keep normal invoice order"), INVSORT_BY_STANDARD },
+    { "SortDateAction", NULL, N_("_Date"), NULL, N_("Sort by date"), INVSORT_BY_DATE },
+    { "SortDateEntryAction", NULL, N_("Date of _Entry"), NULL, N_("Sort by the date of entry"), INVSORT_BY_DATE_ENTERED },
+    { "SortQuantityAction", NULL, N_("_Quantity"), NULL, N_("Sort by quantity"), INVSORT_BY_QTY },
+    { "SortPriceAction", NULL, N_("_Price"), NULL, N_("Sort by price"), INVSORT_BY_PRICE },
+    { "SortDescriptionAction", NULL, N_("Descri_ption"), NULL, N_("Sort by description"), INVSORT_BY_DESC },
 };
 static guint n_radio_entries = G_N_ELEMENTS (radio_entries);
 
+static const gchar *invoice_book_readwrite_actions[] =
+{
+    // Only insert actions here which are not yet in posted_actions and unposted_actions!
+    "FileNewAccountAction",
+    "EditDuplicateInvoiceAction",
+    "BusinessNewInvoiceAction",
+    "ToolsProcessPaymentAction",
+    NULL
+};
+
 static const gchar *posted_actions[] =
 {
     NULL
@@ -364,13 +371,10 @@ gnc_plugin_page_invoice_class_init (GncPluginPageInvoiceClass *klass)
 static void
 gnc_plugin_page_invoice_init (GncPluginPageInvoice *plugin_page)
 {
-    GncPluginPageInvoicePrivate *priv;
     GncPluginPage *parent;
     GtkActionGroup *action_group;
     gboolean use_new;
 
-    priv = GNC_PLUGIN_PAGE_INVOICE_GET_PRIVATE(plugin_page);
-
     /* Init parent declared variables */
     parent = GNC_PLUGIN_PAGE(plugin_page);
     use_new = gnc_gconf_get_bool(GCONF_SECTION_INVOICE, KEY_USE_NEW, NULL);
@@ -402,15 +406,9 @@ gnc_plugin_page_invoice_init (GncPluginPageInvoice *plugin_page)
 static void
 gnc_plugin_page_invoice_finalize (GObject *object)
 {
-    GncPluginPageInvoice *page;
-    GncPluginPageInvoicePrivate *priv;
-
     g_return_if_fail (GNC_IS_PLUGIN_PAGE_INVOICE (object));
 
     ENTER("object %p", object);
-    page = GNC_PLUGIN_PAGE_INVOICE (object);
-    priv = GNC_PLUGIN_PAGE_INVOICE_GET_PRIVATE(page);
-
     G_OBJECT_CLASS (parent_class)->finalize (object);
     LEAVE(" ");
 }
@@ -420,9 +418,17 @@ void
 gnc_plugin_page_invoice_update_menus (GncPluginPage *page, gboolean is_posted, gboolean can_unpost)
 {
     GtkActionGroup *action_group;
+    gboolean is_readonly = qof_book_is_readonly(gnc_get_current_book());
 
     g_return_if_fail(GNC_IS_PLUGIN_PAGE_INVOICE(page));
 
+    if (is_readonly)
+    {
+        // Are we readonly? Then don't allow any actions.
+        is_posted = TRUE;
+        can_unpost = FALSE;
+    }
+
     action_group = gnc_plugin_page_get_action_group(page);
     gnc_plugin_update_actions (action_group, posted_actions,
                                "sensitive", is_posted);
@@ -430,6 +436,8 @@ gnc_plugin_page_invoice_update_menus (GncPluginPage *page, gboolean is_posted, g
                                "sensitive", !is_posted);
     gnc_plugin_update_actions (action_group, can_unpost_actions,
                                "sensitive", can_unpost);
+    gnc_plugin_update_actions (action_group, invoice_book_readwrite_actions,
+                               "sensitive", !is_readonly);
 }
 
 
