@@ -103,7 +103,7 @@ gnc_entry_ledger_get_account_by_name (GncEntryLedger *ledger, BasicCell * bcell,
         account_types = g_list_prepend (account_types, (gpointer)ACCT_TYPE_CREDIT);
         account_types = g_list_prepend (account_types, (gpointer)ACCT_TYPE_ASSET);
         account_types = g_list_prepend (account_types, (gpointer)ACCT_TYPE_LIABILITY);
-        if ( ledger->is_invoice )
+        if ( ledger->is_cust_doc )
             account_types = g_list_prepend (account_types, (gpointer)ACCT_TYPE_INCOME);
         else
             account_types = g_list_prepend (account_types, (gpointer)ACCT_TYPE_EXPENSE);
@@ -161,7 +161,7 @@ GncTaxTable * gnc_entry_ledger_get_taxtable (GncEntryLedger *ledger,
 
     /* If it has not changed, pull in the table from the entry */
     entry = gnc_entry_ledger_get_current_entry (ledger);
-    if (ledger->is_invoice)
+    if (ledger->is_cust_doc)
         return gncEntryGetInvTaxTable (entry);
     else
         return gncEntryGetBillTaxTable (entry);
@@ -298,14 +298,28 @@ GncEntryLedger * gnc_entry_ledger_new (QofBook *book, GncEntryLedgerType type)
     case GNCENTRY_ORDER_VIEWER:
     case GNCENTRY_INVOICE_ENTRY:
     case GNCENTRY_INVOICE_VIEWER:
-        ledger->is_invoice = TRUE;
+        ledger->is_cust_doc = TRUE;
+        ledger->is_credit_note = FALSE;
         break;
     case GNCENTRY_BILL_ENTRY:
     case GNCENTRY_BILL_VIEWER:
     case GNCENTRY_EXPVOUCHER_ENTRY:
     case GNCENTRY_EXPVOUCHER_VIEWER:
     case GNCENTRY_NUM_REGISTER_TYPES:
-        ledger->is_invoice = FALSE;
+        ledger->is_cust_doc = FALSE;
+        ledger->is_credit_note = FALSE;
+        break;
+    case GNCENTRY_CUST_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_CUST_CREDIT_NOTE_VIEWER:
+        ledger->is_cust_doc = TRUE;
+        ledger->is_credit_note = TRUE;
+        break;
+    case GNCENTRY_VEND_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_VEND_CREDIT_NOTE_VIEWER:
+    case GNCENTRY_EMPL_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_EMPL_CREDIT_NOTE_VIEWER:
+        ledger->is_cust_doc = FALSE;
+        ledger->is_credit_note = TRUE;
         break;
     }
 
@@ -313,9 +327,9 @@ GncEntryLedger * gnc_entry_ledger_new (QofBook *book, GncEntryLedgerType type)
     ledger->blank_entry_edited = FALSE;
 
     {
-        Timespec ts = { 0, 0 };
-        ts.tv_sec = time (NULL);
-        ledger->last_date_entered = timespecCanonicalDayTime (ts);
+        GDate *today = gnc_g_date_new_today();
+        ledger->last_date_entered = *today;
+        g_date_free(today);
     }
 
     {
@@ -364,6 +378,10 @@ GncEntryLedger * gnc_entry_ledger_new (QofBook *book, GncEntryLedgerType type)
 
     /* Initialize Display */
     gnc_entry_ledger_display_init (ledger);
+    if (qof_book_is_readonly(ledger->book))
+    {
+        gnc_entry_ledger_set_readonly(ledger, TRUE);
+    }
     return ledger;
 }
 
@@ -420,7 +438,7 @@ static void create_invoice_query (GncEntryLedger *ledger)
      *
      * 1. book AND
      * 2.   ( Entry->I-TYPE == ledger->invoice
-     * #if I-TYPE == Invoice (entry only)
+     * #if I-TYPE == Invoice/Cust Credit Note (entry only)
      *        OR
      * 3.     ( Entry->Invoice == NULL AND
      *          ( Entry->Billable == TRUE AND
@@ -444,12 +462,18 @@ static void create_invoice_query (GncEntryLedger *ledger)
     {
     case GNCENTRY_INVOICE_ENTRY:
     case GNCENTRY_INVOICE_VIEWER:
+    case GNCENTRY_CUST_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_CUST_CREDIT_NOTE_VIEWER:
         type = ENTRY_INVOICE;
         break;
     case GNCENTRY_BILL_ENTRY:
     case GNCENTRY_BILL_VIEWER:
     case GNCENTRY_EXPVOUCHER_ENTRY:
     case GNCENTRY_EXPVOUCHER_VIEWER:
+    case GNCENTRY_VEND_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_VEND_CREDIT_NOTE_VIEWER:
+    case GNCENTRY_EMPL_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_EMPL_CREDIT_NOTE_VIEWER:
         type = ENTRY_BILL;
         break;
     default:
@@ -463,7 +487,8 @@ static void create_invoice_query (GncEntryLedger *ledger)
                               gncInvoiceGetGUID (ledger->invoice), QOF_QUERY_OR);
 
     /* Term 3 */
-    if (ledger->type == GNCENTRY_INVOICE_ENTRY &&
+    if ((ledger->type == GNCENTRY_INVOICE_ENTRY ||
+            ledger->type == GNCENTRY_CUST_CREDIT_NOTE_ENTRY) &&
             gncOwnerGetEndGUID (gncInvoiceGetOwner (ledger->invoice)) != NULL)
     {
 
@@ -533,7 +558,7 @@ void gnc_entry_ledger_set_default_invoice (GncEntryLedger *ledger,
      * to understand why.
      */
     if (gncInvoiceGetOwnerType (invoice) == GNC_OWNER_VENDOR)
-        ledger->last_date_entered = gncInvoiceGetDateOpened (invoice);
+        ledger->last_date_entered = timespec_to_gdate(gncInvoiceGetDateOpened (invoice));
 
     if (!ledger->query && invoice)
         create_invoice_query (ledger);
@@ -582,6 +607,7 @@ gboolean gnc_entry_ledger_find_entry (GncEntryLedger *ledger, GncEntry *entry,
 void gnc_entry_ledger_set_readonly (GncEntryLedger *ledger, gboolean readonly)
 {
     if (!ledger) return;
+    if (!readonly && qof_book_is_readonly(ledger->book)) return;
 
     /* reset the ledger type appropriately */
     if (readonly)
@@ -603,8 +629,20 @@ void gnc_entry_ledger_set_readonly (GncEntryLedger *ledger, gboolean readonly)
             ledger->type = GNCENTRY_EXPVOUCHER_VIEWER;
             create_invoice_query (ledger);
             break;
+        case GNCENTRY_CUST_CREDIT_NOTE_ENTRY:
+            ledger->type = GNCENTRY_CUST_CREDIT_NOTE_VIEWER;
+            create_invoice_query (ledger);
+            break;
+        case GNCENTRY_VEND_CREDIT_NOTE_ENTRY:
+            ledger->type = GNCENTRY_VEND_CREDIT_NOTE_VIEWER;
+            create_invoice_query (ledger);
+            break;
+        case GNCENTRY_EMPL_CREDIT_NOTE_ENTRY:
+            ledger->type = GNCENTRY_EMPL_CREDIT_NOTE_VIEWER;
+            create_invoice_query (ledger);
+            break;
         default:
-            return;			/* Nothing to do */
+            return;        /* Nothing to do */
         }
     }
     else
@@ -626,8 +664,20 @@ void gnc_entry_ledger_set_readonly (GncEntryLedger *ledger, gboolean readonly)
             ledger->type = GNCENTRY_EXPVOUCHER_ENTRY;
             create_invoice_query (ledger);
             break;
+        case GNCENTRY_CUST_CREDIT_NOTE_VIEWER:
+            ledger->type = GNCENTRY_CUST_CREDIT_NOTE_ENTRY;
+            create_invoice_query (ledger);
+            break;
+        case GNCENTRY_VEND_CREDIT_NOTE_VIEWER:
+            ledger->type = GNCENTRY_VEND_CREDIT_NOTE_ENTRY;
+            create_invoice_query (ledger);
+            break;
+        case GNCENTRY_EMPL_CREDIT_NOTE_VIEWER:
+            ledger->type = GNCENTRY_EMPL_CREDIT_NOTE_ENTRY;
+            create_invoice_query (ledger);
+            break;
         default:
-            return;			/* Nothing to do */
+            return;        /* Nothing to do */
         }
     }
 
@@ -881,8 +931,8 @@ gnc_entry_ledger_duplicate_current_entry (GncEntryLedger *ledger)
         GncEntry * new_entry;
 
         new_entry = gncEntryCreate (ledger->book);
-        gncEntryCopy (entry, new_entry);
-        gncEntrySetDate (new_entry, ledger->last_date_entered);
+        gncEntryCopy (entry, new_entry, TRUE);
+        gncEntrySetDateGDate (new_entry, &ledger->last_date_entered);
 
         /* We also must set a new DateEntered on the new entry
          * because otherwise the ordering is not deterministic */
@@ -959,10 +1009,26 @@ void gnc_entry_ledger_move_current_entry_updown (GncEntryLedger *ledger,
      * up the current sort ordering from here, so I cowardly refuse to
      * tweak the EntryDate in this case. */
     {
-        Timespec t1 = gncEntryGetDate(current),
-                 t2 = gncEntryGetDate(target);
-        if (!timespec_equal(&t1, &t2))
+        Timespec t1, t2;
+        GDate d1 = gncEntryGetDateGDate(current),
+              d2 = gncEntryGetDateGDate(target);
+        if (g_date_compare(&d1, &d2) != 0)
             return;
+
+        /* Special treatment if the equality doesn't hold if we access the
+        dates as timespec. See the comment in gncEntrySetDateGDate() for the
+        reason: Some code used the timespec at noon for the EntryDate, other
+        code used the timespec at the start of day. */
+        t1 = gncEntryGetDate(current);
+        t2 = gncEntryGetDate(target);
+        if (!timespec_equal(&t1, &t2))
+        {
+            /* Timespecs are not equal, even though the GDates were equal? Then
+            we set the GDates again. This will force the timespecs to be equal
+            as well. */
+            gncEntrySetDateGDate(current, &d1);
+            gncEntrySetDateGDate(target, &d2);
+        }
     }
 
     /*g_warning("Ok, current desc='%s' target desc='%s'",
