@@ -35,10 +35,16 @@ typedef enum
     GNCENTRY_ORDER_VIEWER,
     GNCENTRY_INVOICE_ENTRY,
     GNCENTRY_INVOICE_VIEWER,
+    GNCENTRY_CUST_CREDIT_NOTE_ENTRY,
+    GNCENTRY_CUST_CREDIT_NOTE_VIEWER,
     GNCENTRY_BILL_ENTRY,
     GNCENTRY_BILL_VIEWER,
+    GNCENTRY_VEND_CREDIT_NOTE_ENTRY,
+    GNCENTRY_VEND_CREDIT_NOTE_VIEWER,
     GNCENTRY_EXPVOUCHER_ENTRY,
     GNCENTRY_EXPVOUCHER_VIEWER,
+    GNCENTRY_EMPL_CREDIT_NOTE_ENTRY,
+    GNCENTRY_EMPL_CREDIT_NOTE_VIEWER,
     GNCENTRY_NUM_REGISTER_TYPES
 } GncEntryLedgerType;
 
