@@ -25,7 +25,6 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <libguile.h>
 
 #include "Account.h"
 #include "account-quickfill.h"
@@ -35,7 +34,7 @@
 #include "gnc-ui-util.h"
 #include "recncell.h"
 
-#include "business-options.h"
+#include "business-helpers.h"
 
 #include "gncEntry.h"
 #include "gncEntryLedger.h"
@@ -54,8 +53,9 @@ const char * gnc_entry_ledger_type_string_getter (char flag)
     case '2':
         return _("%");
     default:
-        return "?";
+        break;
     };
+    return "?";
 }
 
 const char * gnc_entry_ledger_how_string_getter (char flag)
@@ -69,8 +69,9 @@ const char * gnc_entry_ledger_how_string_getter (char flag)
     case '3':
         return _(">");
     default:
-        return "?";
+        break;
     };
+        return "?";
 }
 
 static void load_discount_type_cells (GncEntryLedger *ledger)
@@ -108,7 +109,7 @@ static void load_discount_how_cells (GncEntryLedger *ledger)
 static void load_payment_type_cells (GncEntryLedger *ledger)
 {
     ComboCell *cell;
-    GncOwner *owner;
+    const GncOwner *owner;
     GncEmployee *employee;
 
     cell = (ComboCell *) gnc_table_layout_get_cell (ledger->table->layout,
@@ -207,6 +208,8 @@ load_xfer_type_cells (GncEntryLedger *ledger)
     case GNCENTRY_ORDER_VIEWER:
     case GNCENTRY_INVOICE_ENTRY:
     case GNCENTRY_INVOICE_VIEWER:
+    case GNCENTRY_CUST_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_CUST_CREDIT_NOTE_VIEWER:
         qf = gnc_get_shared_account_name_quickfill (root, IKEY,
                 skip_expense_acct_cb, NULL);
         store = gnc_get_shared_account_name_list_store (root, IKEY,
@@ -217,6 +220,10 @@ load_xfer_type_cells (GncEntryLedger *ledger)
     case GNCENTRY_BILL_VIEWER:
     case GNCENTRY_EXPVOUCHER_ENTRY:
     case GNCENTRY_EXPVOUCHER_VIEWER:
+    case GNCENTRY_VEND_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_VEND_CREDIT_NOTE_VIEWER:
+    case GNCENTRY_EMPL_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_EMPL_CREDIT_NOTE_VIEWER:
     case GNCENTRY_NUM_REGISTER_TYPES:
         qf = gnc_get_shared_account_name_quickfill (root, EKEY,
                 skip_income_acct_cb, NULL);
@@ -284,10 +291,13 @@ load_description_cell (GncEntryLedger *ledger)
     {
     case GNCENTRY_INVOICE_ENTRY:
     case GNCENTRY_INVOICE_VIEWER:
+    case GNCENTRY_CUST_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_CUST_CREDIT_NOTE_VIEWER:
         shared_quickfill = gnc_get_shared_entry_desc_quickfill(ledger->book, DESC_QF_KEY_INVOICES, TRUE);
         break;
     default:
         shared_quickfill = gnc_get_shared_entry_desc_quickfill(ledger->book, DESC_QF_KEY_BILLS, FALSE);
+        break;
     };
 
     cell = (QuickFillCell *)
@@ -306,7 +316,7 @@ void gnc_entry_ledger_load_xfer_cells (GncEntryLedger *ledger)
 /* XXX (FIXME): This should be in a config file! */
 /* Copy GncEntry information from the list to the rows of the Ledger. */
 /* XXX This code is a cut-n-paste job from the SplitRegister code;
- * the split-regsiter should be generalized to the point where a cut-n-paste
+ * the split-register should be generalized to the point where a cut-n-paste
  * like this isn't required, and this should be trashed.
  */
 void gnc_entry_ledger_load (GncEntryLedger *ledger, GList *entry_list)
@@ -319,7 +329,6 @@ void gnc_entry_ledger_load (GncEntryLedger *ledger, GList *entry_list)
     CellBlock *cursor_header, *cursor;
     VirtualCellLocation vcell_loc;
     VirtualLocation save_loc;
-    time_t present;
     gboolean start_primary_color = TRUE;
 
     int new_entry_row = -1;
@@ -344,11 +353,14 @@ void gnc_entry_ledger_load (GncEntryLedger *ledger, GList *entry_list)
         case GNCENTRY_INVOICE_ENTRY:
         case GNCENTRY_BILL_ENTRY:
         case GNCENTRY_EXPVOUCHER_ENTRY:
+        case GNCENTRY_CUST_CREDIT_NOTE_ENTRY:
+        case GNCENTRY_VEND_CREDIT_NOTE_ENTRY:
+        case GNCENTRY_EMPL_CREDIT_NOTE_ENTRY:
 
             gnc_suspend_gui_refresh ();
 
             blank_entry = gncEntryCreate (ledger->book);
-            gncEntrySetDate (blank_entry, ledger->last_date_entered);
+            gncEntrySetDateGDate (blank_entry, &ledger->last_date_entered);
             ledger->blank_entry_guid = *gncEntryGetGUID (blank_entry);
 
             gnc_resume_gui_refresh ();
@@ -356,15 +368,13 @@ void gnc_entry_ledger_load (GncEntryLedger *ledger, GList *entry_list)
             /* The rest of this does not apply to expense vouchers */
             if (ledger->type != GNCENTRY_EXPVOUCHER_ENTRY)
             {
-                GncOwner *owner = gncInvoiceGetOwner (ledger->invoice);
+                const GncOwner *owner = gncOwnerGetEndOwner (gncInvoiceGetOwner (ledger->invoice));
                 GncTaxTable *table = NULL;
                 GncTaxIncluded taxincluded_p = GNC_TAXINCLUDED_USEGLOBAL;
                 gboolean taxincluded = FALSE;
                 gnc_numeric discount = gnc_numeric_zero ();
-                GNCOptionDB *odb;
 
                 /* Determine the TaxIncluded and Discount values */
-                owner = gncOwnerGetEndOwner (owner);
                 switch (gncOwnerGetType (owner))
                 {
                 case GNC_OWNER_CUSTOMER:
@@ -400,26 +410,19 @@ void gnc_entry_ledger_load (GncEntryLedger *ledger, GList *entry_list)
                 }
 
                 /* Compute the proper taxtable */
-                odb = gnc_option_db_new_for_type (GNC_ID_BOOK);
-                gnc_option_db_load_from_kvp (odb, qof_book_get_slots (ledger->book));
-
                 switch (gncOwnerGetType (owner))
                 {
                 case GNC_OWNER_CUSTOMER:
-                    table = gnc_option_db_lookup_taxtable_option (odb,
-                            "Business",
-                            "Default Customer TaxTable",
-                            NULL);
+                    table = gnc_business_get_default_tax_table (ledger->book,
+                            GNC_OWNER_CUSTOMER);
 
                     if (gncCustomerGetTaxTableOverride (owner->owner.customer))
                         table = gncCustomerGetTaxTable (owner->owner.customer);
                     break;
 
                 case GNC_OWNER_VENDOR:
-                    table = gnc_option_db_lookup_taxtable_option (odb,
-                            "Business",
-                            "Default Vendor TaxTable",
-                            NULL);
+                    table = gnc_business_get_default_tax_table (ledger->book,
+                            GNC_OWNER_VENDOR);
 
                     if (gncVendorGetTaxTableOverride (owner->owner.vendor))
                         table = gncVendorGetTaxTable (owner->owner.vendor);
@@ -429,9 +432,7 @@ void gnc_entry_ledger_load (GncEntryLedger *ledger, GList *entry_list)
                     break;
                 }
 
-                gnc_option_db_destroy (odb);
-
-                if (ledger->is_invoice)
+                if (ledger->is_cust_doc)
                 {
                     gncEntrySetInvTaxTable (blank_entry, table);
                     gncEntrySetInvTaxIncluded (blank_entry, taxincluded);
@@ -507,7 +508,7 @@ void gnc_entry_ledger_load (GncEntryLedger *ledger, GList *entry_list)
     vcell_loc.virt_row++;
 
     /* get the current time and reset the dividing row */
-    present = gnc_timet_get_today_end ();
+    table->model->dividing_row_upper = -1;
     table->model->dividing_row = -1;
     cursor = gnc_table_layout_get_cursor (table->layout, "cursor");
 
