@@ -28,7 +28,7 @@
 
 #include "Account.h"
 #include "gnc-ui-util.h"
-#include "qof.h"	/* for safe_strcmp */
+#include "qof.h"	/* for g_strcmp0 */
 
 #include "datecell.h"
 #include "checkboxcell.h"
@@ -292,7 +292,7 @@ static const char * get_pric_entry (VirtualLocation virt_loc,
     gnc_numeric price;
 
     entry = gnc_entry_ledger_get_entry (ledger, virt_loc.vcell_loc);
-    if (ledger->is_invoice)
+    if (ledger->is_cust_doc)
         price = gncEntryGetInvPrice (entry);
     else
         price = gncEntryGetBillPrice (entry);
@@ -313,7 +313,7 @@ static const char * get_qty_entry (VirtualLocation virt_loc,
     gnc_numeric qty;
 
     entry = gnc_entry_ledger_get_entry (ledger, virt_loc.vcell_loc);
-    qty = gncEntryGetQuantity (entry);
+    qty = gncEntryGetDocQuantity (entry, ledger->is_credit_note);
 
     if (gnc_numeric_zero_p (qty))
         return NULL;
@@ -331,7 +331,7 @@ static const char * get_taxable_entry (VirtualLocation virt_loc,
     gboolean taxable;
 
     entry = gnc_entry_ledger_get_entry (ledger, virt_loc.vcell_loc);
-    if (ledger->is_invoice)
+    if (ledger->is_cust_doc)
         taxable = gncEntryGetInvTaxable (entry);
     else
         taxable = gncEntryGetBillTaxable (entry);
@@ -384,7 +384,7 @@ static const char * get_taxtable_entry (VirtualLocation virt_loc,
     }
 
     entry = gnc_entry_ledger_get_entry (ledger, virt_loc.vcell_loc);
-    if (ledger->is_invoice)
+    if (ledger->is_cust_doc)
         table = gncEntryGetInvTaxTable (entry);
     else
         table = gncEntryGetBillTaxTable (entry);
@@ -412,7 +412,7 @@ static const char * get_taxincluded_entry (VirtualLocation virt_loc,
     }
 
     entry = gnc_entry_ledger_get_entry (ledger, virt_loc.vcell_loc);
-    if (ledger->is_invoice)
+    if (ledger->is_cust_doc)
         taxincluded = gncEntryGetInvTaxIncluded (entry);
     else
         taxincluded = gncEntryGetBillTaxIncluded (entry);
@@ -451,6 +451,9 @@ static const char * get_value_entry (VirtualLocation virt_loc,
     if (virt_cell_loc_equal (ledger->table->current_cursor_loc.vcell_loc,
                              virt_loc.vcell_loc))
     {
+        /* Sign attention: this function works with values as seen
+         * on-screen in the ledger, so they are always in the proper sign.
+         */
         gnc_entry_ledger_compute_value (ledger, &value, NULL);
     }
     else
@@ -460,8 +463,12 @@ static const char * get_value_entry (VirtualLocation virt_loc,
         if (entry == gnc_entry_ledger_get_blank_entry (ledger))
             return NULL;
 
-        value = gncEntryReturnValue (entry, ledger->is_invoice);
+        /* Ledger should display values with the same sign as on the document
+         * so get the document value instead of the internal value here.
+         */
+        value = gncEntryGetDocValue (entry, TRUE, ledger->is_cust_doc, ledger->is_credit_note);
     }
+
     return xaccPrintAmount (value, gnc_default_print_info (FALSE));
 }
 
@@ -477,6 +484,9 @@ static const char * get_taxval_entry (VirtualLocation virt_loc,
     if (virt_cell_loc_equal (ledger->table->current_cursor_loc.vcell_loc,
                              virt_loc.vcell_loc))
     {
+        /* Sign attention: this function works with values as seen
+         * on-screen in the ledger, so they are always in the proper sign.
+         */
         gnc_entry_ledger_compute_value (ledger, NULL, &value);
     }
     else
@@ -486,7 +496,10 @@ static const char * get_taxval_entry (VirtualLocation virt_loc,
         if (entry == gnc_entry_ledger_get_blank_entry (ledger))
             return NULL;
 
-        value = gncEntryReturnTaxValue (entry, ledger->is_invoice);
+        /* Ledger should display values with the same sign as on the document
+         * so get the document value instead of the internal value here.
+         */
+        value = gncEntryGetDocTaxValue (entry, TRUE, ledger->is_cust_doc, ledger->is_credit_note);
     }
 
     return xaccPrintAmount (value, gnc_default_print_info (FALSE));
@@ -564,9 +577,9 @@ static char * get_date_help (VirtualLocation virt_loc, gpointer user_data)
     GncEntryLedger *ledger = user_data;
     BasicCell *cell;
     char string[1024];
-    struct tm *tm;
+    struct tm tm;
     Timespec ts;
-    time_t tt;
+    time64 tt;
 
     cell = gnc_table_get_cell (ledger->table, virt_loc);
     if (!cell)
@@ -577,8 +590,8 @@ static char * get_date_help (VirtualLocation virt_loc, gpointer user_data)
 
     gnc_date_cell_get_date ((DateCell *) cell, &ts);
     tt = ts.tv_sec;
-    tm = localtime (&tt);
-    qof_strftime (string, sizeof(string), "%A %d %B %Y", tm);
+    gnc_localtime_r (&tt, &tm);
+    qof_strftime (string, sizeof(string), "%A %d %B %Y", &tm);
 
     return g_strdup (string);
 }
@@ -735,12 +748,22 @@ static char * get_inv_help (VirtualLocation virt_loc, gpointer user_data)
     case GNCENTRY_BILL_VIEWER:
     case GNCENTRY_EXPVOUCHER_ENTRY:
     case GNCENTRY_EXPVOUCHER_VIEWER:
-        help = _("Is this entry Invoiced?");
+        help = _("Is this entry invoiced?");
+        break;
+    case GNCENTRY_VEND_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_VEND_CREDIT_NOTE_VIEWER:
+    case GNCENTRY_EMPL_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_EMPL_CREDIT_NOTE_VIEWER:
+        help = _("Is this entry credited?");
         break;
     case GNCENTRY_INVOICE_ENTRY:
     case GNCENTRY_INVOICE_VIEWER:
         help = _("Include this entry on this invoice?");
         break;
+    case GNCENTRY_CUST_CREDIT_NOTE_ENTRY:
+    case GNCENTRY_CUST_CREDIT_NOTE_VIEWER:
+        help = _("Include this entry on this credit note?");
+        break;
     default:
         help = _("Unknown EntryLedger Type");
     }
@@ -812,7 +835,7 @@ static CellIOFlags get_standard_io_flags (VirtualLocation virt_loc,
         if (gncEntryGetInvoice (entry) != NULL)
             return XACC_CELL_ALLOW_SHADOW;
     }
-    /* FALLTHROUGH */
+    /* FALL THROUGH */
     default:
         return XACC_CELL_ALLOW_ALL;
     }
@@ -833,8 +856,9 @@ static CellIOFlags get_inv_io_flags (VirtualLocation virt_loc,
     switch (ledger->type)
     {
     case GNCENTRY_INVOICE_ENTRY:
+    case GNCENTRY_CUST_CREDIT_NOTE_ENTRY:
     {
-        /* This cell should be mutably IFF this entry is attached to
+        /* This cell should be immutable IFF this entry is attached to
          * a bill, order, or something else.
          */
         GncEntry * entry = gnc_entry_ledger_get_entry (ledger, virt_loc.vcell_loc);
@@ -843,7 +867,7 @@ static CellIOFlags get_inv_io_flags (VirtualLocation virt_loc,
             return XACC_CELL_ALLOW_ALL | XACC_CELL_ALLOW_EXACT_ONLY;
 
     }
-    /* FALLTHROUGH */
+    /* FALL THROUGH */
     default:
         return XACC_CELL_ALLOW_SHADOW;
     }
@@ -887,7 +911,7 @@ static CellIOFlags get_qty_io_flags (VirtualLocation virt_loc, gpointer user_dat
     CellIOFlags flags = get_standard_io_flags (virt_loc, user_data);
 
     /* If this isn't an invoice, or the flags are already read-only ... */
-    if (!ledger->is_invoice || flags == XACC_CELL_ALLOW_SHADOW)
+    if (!ledger->is_cust_doc || flags == XACC_CELL_ALLOW_SHADOW)
         return flags;
 
     /* ok, if this is an invoice ledger AND this entry is attached to a
@@ -989,15 +1013,15 @@ static void gnc_entry_ledger_save_cells (gpointer save_data,
                                            ENTRY_DATE_CELL, TRUE))
     {
         BasicCell *cell;
-        Timespec ts;
+        GDate date;
 
         cell = gnc_table_layout_get_cell (ledger->table->layout, ENTRY_DATE_CELL);
 
         /* commit any pending changes */
         gnc_date_cell_commit ((DateCell *) cell);
 
-        gnc_date_cell_get_date ((DateCell *) cell, &ts);
-        gncEntrySetDate (entry, ts);
+        gnc_date_cell_get_date_gdate ((DateCell *) cell, &date);
+        gncEntrySetDateGDate (entry, &date);
     }
 
     if (gnc_table_layout_get_cell_changed (ledger->table->layout,
@@ -1047,7 +1071,9 @@ static void gnc_entry_ledger_save_cells (gpointer save_data,
         gnc_numeric amount;
 
         if (gnc_entry_ledger_get_numeric (ledger, ENTRY_QTY_CELL, &amount))
-            gncEntrySetQuantity (entry, amount);
+        {
+            gncEntrySetDocQuantity (entry, amount, ledger->is_credit_note);
+        }
     }
 
     if (gnc_table_layout_get_cell_changed (ledger->table->layout,
@@ -1066,9 +1092,9 @@ static void gnc_entry_ledger_save_cells (gpointer save_data,
 
         value = gnc_table_layout_get_cell_value (ledger->table->layout,
                 ENTRY_PAYMENT_CELL);
-        if (!safe_strcmp (value, _("Cash")))
+        if (!g_strcmp0 (value, _("Cash")))
             gncEntrySetBillPayment (entry, GNC_PAYMENT_CASH);
-        else if (!safe_strcmp (value, _("Charge")))
+        else if (!g_strcmp0 (value, _("Charge")))
             gncEntrySetBillPayment (entry, GNC_PAYMENT_CARD);
         else
             g_warning ("Invalid Payment cell: %s", value ? value : "(null)");
@@ -1081,7 +1107,7 @@ static void gnc_entry_ledger_save_cells (gpointer save_data,
 
         if (gnc_entry_ledger_get_numeric (ledger, ENTRY_PRIC_CELL, &amount))
         {
-            if (ledger->is_invoice)
+            if (ledger->is_cust_doc)
                 gncEntrySetInvPrice (entry, amount);
             else
                 gncEntrySetBillPrice (entry, amount);
@@ -1094,7 +1120,7 @@ static void gnc_entry_ledger_save_cells (gpointer save_data,
         gboolean taxable;
 
         taxable = gnc_entry_ledger_get_checkmark (ledger, ENTRY_TAXABLE_CELL);
-        if (ledger->is_invoice)
+        if (ledger->is_cust_doc)
             gncEntrySetInvTaxable (entry, taxable);
         else
             gncEntrySetBillTaxable (entry, taxable);
@@ -1109,7 +1135,7 @@ static void gnc_entry_ledger_save_cells (gpointer save_data,
         table = gnc_entry_ledger_get_taxtable (ledger, ENTRY_TAXTABLE_CELL);
         if (table)
         {
-            if (ledger->is_invoice)
+            if (ledger->is_cust_doc)
                 gncEntrySetInvTaxTable (entry, table);
             else
                 gncEntrySetBillTaxTable (entry, table);
@@ -1123,13 +1149,14 @@ static void gnc_entry_ledger_save_cells (gpointer save_data,
 
         taxincluded = gnc_entry_ledger_get_checkmark (ledger,
                       ENTRY_TAXINCLUDED_CELL);
-        if (ledger->is_invoice)
+        if (ledger->is_cust_doc)
             gncEntrySetInvTaxIncluded (entry, taxincluded);
         else
             gncEntrySetBillTaxIncluded (entry, taxincluded);
     }
 
-    if (ledger->type == GNCENTRY_INVOICE_ENTRY)
+    if (ledger->type == GNCENTRY_INVOICE_ENTRY ||
+            ledger->type == GNCENTRY_CUST_CREDIT_NOTE_ENTRY)
     {
         gboolean inv_value;
 
@@ -1221,6 +1248,9 @@ static void gnc_entry_ledger_model_new_handlers (TableModel *model,
     case GNCENTRY_INVOICE_VIEWER:
     case GNCENTRY_BILL_VIEWER:
     case GNCENTRY_EXPVOUCHER_VIEWER:
+    case GNCENTRY_CUST_CREDIT_NOTE_VIEWER:
+    case GNCENTRY_VEND_CREDIT_NOTE_VIEWER:
+    case GNCENTRY_EMPL_CREDIT_NOTE_VIEWER:
         /* make this table read-only */
         gnc_table_model_set_read_only (model, TRUE);
         break;
