@@ -35,14 +35,11 @@
 #include "SchedXaction.h"
 #include "Transaction.h"
 #include "gnc-engine.h"
+#include "engine-helpers.h"
 
 #undef G_LOG_DOMAIN
 #define G_LOG_DOMAIN "gnc.engine.sx"
 
-/* Local Prototypes *****/
-
-void sxprivtransactionListMapDelete( gpointer data, gpointer user_data );
-
 enum
 {
     PROP_0,
@@ -787,28 +784,6 @@ gint gnc_sx_get_num_occur_daterange(const SchedXaction *sx, const GDate* start_d
     return result;
 }
 
-
-KvpValue *
-xaccSchedXactionGetSlot( const SchedXaction *sx, const char *slot )
-{
-    if (!sx) return NULL;
-
-    return kvp_frame_get_slot(sx->inst.kvp_data, slot);
-}
-
-void
-xaccSchedXactionSetSlot( SchedXaction *sx,
-                         const char *slot,
-                         const KvpValue *value )
-{
-    if (!sx) return;
-
-    gnc_sx_begin_edit(sx);
-    kvp_frame_set_slot( sx->inst.kvp_data, slot, value );
-    qof_instance_set_dirty(&sx->inst);
-    gnc_sx_commit_edit(sx);
-}
-
 gboolean
 xaccSchedXactionGetEnabled( const SchedXaction *sx )
 {
@@ -1065,10 +1040,11 @@ pack_split_info (TTSplitInfo *s_info, Account *parent_acct,
     xaccSplitSetMemo(split,
                      gnc_ttsplitinfo_get_memo(s_info));
 
-    xaccSplitSetAction(split,
+    /* Set split-action with gnc_set_num_action which is the same as
+     * xaccSplitSetAction with these arguments */
+    gnc_set_num_action(NULL, split, NULL,
                        gnc_ttsplitinfo_get_action(s_info));
 
-
     xaccAccountInsertSplit(parent_acct,
                            split);
 
@@ -1137,10 +1113,12 @@ xaccSchedXactionSetTemplateTrans(SchedXaction *sx, GList *t_t_list,
         xaccTransSetDescription(new_trans,
                                 gnc_ttinfo_get_description(tti));
 
-        xaccTransSetDatePostedSecs(new_trans, time(NULL));
+        xaccTransSetDatePostedSecsNormalized(new_trans, gnc_time (NULL));
 
-        xaccTransSetNum(new_trans,
-                        gnc_ttinfo_get_num(tti));
+        /* Set tran-num with gnc_set_num_action which is the same as
+         * xaccTransSetNum with these arguments */
+        gnc_set_num_action(new_trans, NULL,
+                        gnc_ttinfo_get_num(tti), NULL);
         xaccTransSetCurrency( new_trans,
                               gnc_ttinfo_get_currency(tti) );
 
@@ -1186,18 +1164,6 @@ gnc_sx_incr_temporal_state(const SchedXaction *sx, SXTmpStateData *stateData )
     tsd->num_inst += 1;
 }
 
-void
-gnc_sx_revert_to_temporal_state( SchedXaction *sx, SXTmpStateData *stateData )
-{
-    SXTmpStateData *tsd = (SXTmpStateData*)stateData;
-    gnc_sx_begin_edit(sx);
-    sx->last_date        = tsd->last_date;
-    sx->num_occurances_remain = tsd->num_occur_rem;
-    sx->instance_num     = tsd->num_inst;
-    qof_instance_set_dirty(&sx->inst);
-    gnc_sx_commit_edit(sx);
-}
-
 void
 gnc_sx_destroy_temporal_state( SXTmpStateData *stateData )
 {
