@@ -39,6 +39,7 @@
 #endif
 
 #include "qof.h"
+#include "qofbook.h"
 #include "Split.h"
 #include "AccountP.h"
 #include "Scrub.h"
@@ -431,6 +432,39 @@ xaccSplitClone (const Split *s)
     return split;
 }
 
+
+/*################## Added for Reg2 #################*/
+
+/* This is really a helper for xaccTransCopyOnto. It doesn't reparent
+   the 'to' split to from's transaction, because xaccTransCopyOnto is
+   responsible for parenting the split to the correct transaction.
+   Also, from's parent transaction may not even be a valid
+   transaction, so this function may not modify anything about 'from'
+   or from's transaction.
+*/
+void
+xaccSplitCopyOnto(const Split *from_split, Split *to_split)
+{
+   if (!from_split || !to_split) return;
+   xaccTransBeginEdit (to_split->parent);
+
+   xaccSplitSetMemo(to_split, xaccSplitGetMemo(from_split));
+   xaccSplitSetAction(to_split, xaccSplitGetAction(from_split));
+   xaccSplitSetAmount(to_split, xaccSplitGetAmount(from_split));
+   xaccSplitSetValue(to_split, xaccSplitGetValue(from_split));
+   /* Setting the account is okay here because, even though the from
+      split might not really belong to the account it claims to,
+      setting the account won't cause any event involving from. */
+   xaccSplitSetAccount(to_split, xaccSplitGetAccount(from_split));
+   /* N.B. Don't set parent. */
+
+   qof_instance_set_dirty(QOF_INSTANCE(to_split));
+   xaccTransCommitEdit(to_split->parent);
+}
+
+/*################## Added for Reg2 #################*/
+
+
 #ifdef DUMP_FUNCTIONS
 void
 xaccSplitDump (const Split *split, const char *tag)
@@ -523,7 +557,7 @@ xaccSplitEqualCheckBal (const char *tag, gnc_numeric a, gnc_numeric b)
     str_a = gnc_numeric_to_string (a);
     str_b = gnc_numeric_to_string (b);
 
-    PWARN ("%sbalances differ: %s vs %s", tag, str_a, str_b);
+    PINFO ("%sbalances differ: %s vs %s", tag, str_a, str_b);
 
     g_free (str_a);
     g_free (str_b);
@@ -546,7 +580,7 @@ xaccSplitEqual(const Split *sa, const Split *sb,
 
     if (!sa || !sb)
     {
-        PWARN ("one is NULL");
+        PINFO ("one is NULL");
         return FALSE;
     }
 
@@ -558,22 +592,22 @@ xaccSplitEqual(const Split *sa, const Split *sb,
     {
         if (qof_instance_guid_compare(sa, sb) != 0)
         {
-            PWARN ("GUIDs differ");
+            PINFO ("GUIDs differ");
             return FALSE;
         }
     }
 
     /* If the same book, since these strings are cached we can just use pointer equality */
-    if ((same_book && sa->memo != sb->memo) || (!same_book && safe_strcmp(sa->memo, sb->memo) != 0))
+    if ((same_book && sa->memo != sb->memo) || (!same_book && g_strcmp0(sa->memo, sb->memo) != 0))
     {
-        PWARN ("memos differ: (%p)%s vs (%p)%s",
+        PINFO ("memos differ: (%p)%s vs (%p)%s",
                sa->memo, sa->memo, sb->memo, sb->memo);
         return FALSE;
     }
 
-    if ((same_book && sa->action != sb->action) || (!same_book && safe_strcmp(sa->action, sb->action) != 0))
+    if ((same_book && sa->action != sb->action) || (!same_book && g_strcmp0(sa->action, sb->action) != 0))
     {
-        PWARN ("actions differ: %s vs %s", sa->action, sb->action);
+        PINFO ("actions differ: %s vs %s", sa->action, sb->action);
         return FALSE;
     }
 
@@ -585,7 +619,7 @@ xaccSplitEqual(const Split *sa, const Split *sb,
         frame_a = kvp_frame_to_string (sa->inst.kvp_data);
         frame_b = kvp_frame_to_string (sb->inst.kvp_data);
 
-        PWARN ("kvp frames differ:\n%s\n\nvs\n\n%s", frame_a, frame_b);
+        PINFO ("kvp frames differ:\n%s\n\nvs\n\n%s", frame_a, frame_b);
 
         g_free (frame_a);
         g_free (frame_b);
@@ -595,13 +629,13 @@ xaccSplitEqual(const Split *sa, const Split *sb,
 
     if (sa->reconciled != sb->reconciled)
     {
-        PWARN ("reconcile flags differ: %c vs %c", sa->reconciled, sb->reconciled);
+        PINFO ("reconcile flags differ: %c vs %c", sa->reconciled, sb->reconciled);
         return FALSE;
     }
 
     if (timespec_cmp(&(sa->date_reconciled), &(sb->date_reconciled)))
     {
-        PWARN ("reconciled date differs");
+        PINFO ("reconciled date differs");
         return FALSE;
     }
 
@@ -613,7 +647,7 @@ xaccSplitEqual(const Split *sa, const Split *sb,
         str_a = gnc_numeric_to_string (xaccSplitGetAmount (sa));
         str_b = gnc_numeric_to_string (xaccSplitGetAmount (sb));
 
-        PWARN ("amounts differ: %s vs %s", str_a, str_b);
+        PINFO ("amounts differ: %s vs %s", str_a, str_b);
 
         g_free (str_a);
         g_free (str_b);
@@ -629,7 +663,7 @@ xaccSplitEqual(const Split *sa, const Split *sb,
         str_a = gnc_numeric_to_string (xaccSplitGetValue (sa));
         str_b = gnc_numeric_to_string (xaccSplitGetValue (sb));
 
-        PWARN ("values differ: %s vs %s", str_a, str_b);
+        PINFO ("values differ: %s vs %s", str_a, str_b);
 
         g_free (str_a);
         g_free (str_b);
@@ -652,35 +686,36 @@ xaccSplitEqual(const Split *sa, const Split *sb,
     if (!xaccTransEqual(sa->parent, sb->parent, check_guids, check_txn_splits,
                         check_balances, FALSE))
     {
-        PWARN ("transactions differ");
+        PINFO ("transactions differ");
         return FALSE;
     }
 
     return TRUE;
 }
 
-static void
-add_keys_to_list(gpointer key, gpointer val, gpointer list)
-{
-    *(GList **)list = g_list_prepend(*(GList **)list, key);
-}
 
+/*################## Added for Reg2 #################*/
+/********************************************************************
+ * xaccSplitListGetUniqueTransactions
+ ********************************************************************/
 GList *
 xaccSplitListGetUniqueTransactions(const GList *splits)
 {
-    const GList *node;
+    const GList *snode;
     GList *transList = NULL;
-    GHashTable *transHash = g_hash_table_new(g_direct_hash, g_direct_equal);
 
-    for (node = splits; node; node = node->next)
+    for(snode = splits; snode; snode = snode->next)
     {
-        Transaction *trans = xaccSplitGetParent((Split *)(node->data));
-        g_hash_table_insert(transHash, trans, trans);
+        Transaction *trans = xaccSplitGetParent((Split *)(snode->data));
+
+        GList *item = g_list_find (transList, trans);
+        if (item == NULL)
+            transList = g_list_append (transList, trans);
     }
-    g_hash_table_foreach(transHash, add_keys_to_list, &transList);
-    g_hash_table_destroy(transHash);
     return transList;
 }
+/*################## Added for Reg2 #################*/
+
 
 /********************************************************************
  * Account funcs
@@ -731,7 +766,7 @@ xaccSplitCommitEdit(Split *s)
     orig_acc = s->orig_acc;
 
     if (GNC_IS_ACCOUNT(s->acc))
-        acc=s->acc;
+        acc = s->acc;
 
     /* Remove from lot (but only if it hasn't been moved to
        new lot already) */
@@ -920,7 +955,7 @@ xaccSplitGetSlots (const Split * s)
 {
     return qof_instance_get_slots(QOF_INSTANCE(s));
 }
-
+/* Used for testing only: _get_random_split in test-engine-stuff.c */
 void
 xaccSplitSetSlots_nc(Split *s, KvpFrame *frm)
 {
@@ -934,25 +969,6 @@ xaccSplitSetSlots_nc(Split *s, KvpFrame *frm)
 /********************************************************************\
 \********************************************************************/
 
-void
-DxaccSplitSetSharePriceAndAmount (Split *s, double price, double amt)
-{
-    if (!s) return;
-    ENTER (" ");
-    xaccTransBeginEdit (s->parent);
-
-    s->amount = double_to_gnc_numeric(amt, get_commodity_denom(s),
-                                      GNC_HOW_RND_ROUND_HALF_UP);
-    s->value  = double_to_gnc_numeric(price * amt, get_currency_denom(s),
-                                      GNC_HOW_RND_ROUND_HALF_UP);
-
-    SET_GAINS_A_VDIRTY(s);
-    mark_split (s);
-    qof_instance_set_dirty(QOF_INSTANCE(s));
-    xaccTransCommitEdit(s->parent);
-    LEAVE("");
-}
-
 void
 xaccSplitSetSharePriceAndAmount (Split *s, gnc_numeric price, gnc_numeric amt)
 {
@@ -999,41 +1015,6 @@ xaccSplitSetSharePrice (Split *s, gnc_numeric price)
     LEAVE ("");
 }
 
-void
-DxaccSplitSetShareAmount (Split *s, double damt)
-{
-    gnc_numeric old_price, old_amt;
-    int commodity_denom = get_commodity_denom(s);
-    gnc_numeric amt = double_to_gnc_numeric(damt, commodity_denom,
-                                            GNC_HOW_RND_ROUND_HALF_UP);
-    if (!s) return;
-    ENTER (" ");
-    xaccTransBeginEdit (s->parent);
-
-    old_amt = xaccSplitGetAmount (s);
-    if (!gnc_numeric_zero_p(old_amt))
-    {
-        old_price = gnc_numeric_div(xaccSplitGetValue (s),
-                                    old_amt, GNC_DENOM_AUTO,
-                                    GNC_HOW_DENOM_REDUCE);
-    }
-    else
-    {
-        old_price = gnc_numeric_create(1, 1);
-    }
-
-    s->amount = gnc_numeric_convert(amt, commodity_denom,
-                                    GNC_HOW_RND_NEVER);
-    s->value  = gnc_numeric_mul(s->amount, old_price,
-                                get_currency_denom(s), GNC_HOW_RND_ROUND_HALF_UP);
-
-    SET_GAINS_A_VDIRTY(s);
-    mark_split (s);
-    qof_instance_set_dirty(QOF_INSTANCE(s));
-    xaccTransCommitEdit(s->parent);
-    LEAVE ("");
-}
-
 static void
 qofSplitSetAmount (Split *split, gnc_numeric amt)
 {
@@ -1206,69 +1187,6 @@ xaccSplitGetBaseValue (const Split *s, const gnc_commodity * base_currency)
 /********************************************************************\
 \********************************************************************/
 
-gnc_numeric
-xaccSplitsComputeValue (GList *splits, const Split * skip_me,
-                        const gnc_commodity * base_currency)
-{
-    GList *node;
-    gnc_numeric value = gnc_numeric_zero();
-
-    g_return_val_if_fail (base_currency, value);
-
-    ENTER (" currency=%s", gnc_commodity_get_mnemonic (base_currency));
-
-    for (node = splits; node; node = node->next)
-    {
-        const Split *s = node->data;
-        const gnc_commodity *currency;
-        const gnc_commodity *commodity;
-
-        if (s == skip_me) continue;
-
-        /* value = gnc_numeric_add(value, xaccSplitGetBaseValue(s, base_currency),
-           GNC_DENOM_AUTO, GNC_HOW_DENOM_LCD); */
-
-        /* The split-editor often sends us 'temp' splits whose account
-         * hasn't yet been set.  Be lenient, and assume an implied base
-         * currency. If there's a problem later, the scrub routines will
-         * pick it up.
-         */
-        commodity = s->acc ? xaccAccountGetCommodity (s->acc) : base_currency;
-        currency = xaccTransGetCurrency (s->parent);
-
-
-        if (gnc_commodity_equiv(currency, base_currency))
-        {
-            value = gnc_numeric_add(value, xaccSplitGetValue(s),
-                                    GNC_DENOM_AUTO, GNC_HOW_DENOM_LCD);
-        }
-        else if (gnc_commodity_equiv(commodity, base_currency))
-        {
-            value = gnc_numeric_add(value, xaccSplitGetAmount(s),
-                                    GNC_DENOM_AUTO, GNC_HOW_DENOM_LCD);
-        }
-        else
-        {
-            PERR ("inconsistent currencies\n"
-                  "\tbase = '%s', curr='%s', sec='%s'\n",
-                  gnc_commodity_get_printname(base_currency),
-                  gnc_commodity_get_printname(currency),
-                  gnc_commodity_get_printname(commodity));
-            g_return_val_if_fail (FALSE, value);
-        }
-    }
-
-    /* Note that just because the currencies are equivalent
-     * doesn't mean the denominators are the same! */
-    value = gnc_numeric_convert(value,
-                                gnc_commodity_get_fraction (base_currency),
-                                GNC_HOW_RND_ROUND_HALF_UP);
-
-    LEAVE (" total=%" G_GINT64_FORMAT "/%" G_GINT64_FORMAT,
-           value.num, value.denom);
-    return value;
-}
-
 gnc_numeric
 xaccSplitConvertAmount (const Split *split, const Account * account)
 {
@@ -1375,13 +1293,22 @@ xaccSplitOrder (const Split *sa, const Split *sb)
     int retval;
     int comp;
     char *da, *db;
+    gboolean action_for_num;
 
     if (sa == sb) return 0;
     /* nothing is always less than something */
-    if (!sa && sb) return -1;
-    if (sa && !sb) return +1;
+    if (!sa) return -1;
+    if (!sb) return +1;
 
-    retval = xaccTransOrder (sa->parent, sb->parent);
+    /* sort in transaction order, but use split action rather than trans num
+     * according to book option */
+    action_for_num = qof_book_use_split_action_for_num_field
+                                                        (xaccSplitGetBook (sa));
+    if (action_for_num)
+        retval = xaccTransOrder_num_action (sa->parent, sa->action,
+                                            sb->parent, sb->action);
+    else
+        retval = xaccTransOrder (sa->parent, sb->parent);
     if (retval) return retval;
 
     /* otherwise, sort on memo strings */
@@ -1428,14 +1355,14 @@ xaccSplitOrderDateOnly (const Split *sa, const Split *sb)
 
     if (sa == sb) return 0;
     /* nothing is always less than something */
-    if (!sa && sb) return -1;
-    if (sa && !sb) return +1;
+    if (!sa) return -1;
+    if (!sb) return +1;
 
     ta = sa->parent;
     tb = sb->parent;
-    if ( ta && !tb ) return -1;
-    if ( !ta && tb ) return +1;
     if ( !ta && !tb ) return 0;
+    if ( !tb ) return -1;
+    if ( !ta ) return +1;
 
     /* if dates differ, return */
     DATE_CMP(ta, tb, date_posted);
@@ -1444,7 +1371,6 @@ xaccSplitOrderDateOnly (const Split *sa, const Split *sb)
     return -1;
 }
 
-
 static gboolean
 get_corr_account_split(const Split *sa, const Split **retval)
 {
@@ -1570,7 +1496,7 @@ xaccSplitCompareAccountCodes(const Split *sa, const Split *sb)
     aa = sa->acc;
     ab = sb->acc;
 
-    return safe_strcmp(xaccAccountGetName(aa), xaccAccountGetName(ab));
+    return g_strcmp0(xaccAccountGetCode(aa), xaccAccountGetCode(ab));
 }
 
 int
@@ -1588,7 +1514,7 @@ xaccSplitCompareOtherAccountFullNames(const Split *sa, const Split *sb)
 
     ca = xaccSplitGetCorrAccountFullName(sa);
     cb = xaccSplitGetCorrAccountFullName(sb);
-    retval = safe_strcmp(ca, cb);
+    retval = g_strcmp0(ca, cb);
     g_free(ca);
     g_free(cb);
     return retval;
@@ -1604,7 +1530,7 @@ xaccSplitCompareOtherAccountCodes(const Split *sa, const Split *sb)
 
     ca = xaccSplitGetCorrAccountCode(sa);
     cb = xaccSplitGetCorrAccountCode(sb);
-    return safe_strcmp(ca, cb);
+    return g_strcmp0(ca, cb);
 }
 
 static void
@@ -1662,6 +1588,7 @@ qofSplitSetReconcile (Split *split, char recn)
         break;
     default:
         PERR("Bad reconciled flag");
+        break;
     }
 }
 
@@ -1685,13 +1612,14 @@ xaccSplitSetReconcile (Split *split, char recn)
         break;
     default:
         PERR("Bad reconciled flag");
+        break;
     }
     xaccTransCommitEdit(split->parent);
 
 }
 
 void
-xaccSplitSetDateReconciledSecs (Split *split, time_t secs)
+xaccSplitSetDateReconciledSecs (Split *split, time64 secs)
 {
     if (!split) return;
     xaccTransBeginEdit (split->parent);
@@ -1729,6 +1657,14 @@ xaccSplitRetDateReconciledTS (const Split * split)
     return split ? split->date_reconciled : ts;
 }
 
+/*################## Added for Reg2 #################*/
+time64
+xaccSplitGetDateReconciled (const Split * split)
+{
+    return split ? split->date_reconciled.tv_sec : 0;
+}
+/*################## Added for Reg2 #################*/
+
 /********************************************************************\
 \********************************************************************/
 
@@ -1974,12 +1910,6 @@ xaccSplitGetOtherSplit (const Split *split)
 /********************************************************************\
 \********************************************************************/
 
-gboolean
-xaccIsPeerSplit (const Split *sa, const Split *sb)
-{
-    return (sa && sb && (sa->parent == sb->parent));
-}
-
 gnc_numeric
 xaccSplitVoidFormerAmount(const Split *split)
 {
@@ -2197,5 +2127,17 @@ gboolean xaccSplitRegister (void)
     return qof_object_register (&split_object_def);
 }
 
+SplitTestFunctions*
+_utest_split_fill_functions (void)
+{
+    SplitTestFunctions *func = g_new (SplitTestFunctions, 1);
+
+    func->xaccSplitEqualCheckBal = xaccSplitEqualCheckBal;
+    func->get_currency_denom = get_currency_denom;
+    func->get_commodity_denom = get_commodity_denom;
+    func->get_corr_account_split = get_corr_account_split;
+    return func;
+}
+
 /************************ END OF ************************************\
 \************************* FILE *************************************/
