@@ -65,6 +65,7 @@ ToDo:
 #include "TransactionP.h"
 #include "cap-gains.h"
 #include "gnc-engine.h"
+#include "engine-helpers.h"
 #include "gnc-lot.h"
 #include "policy.h"
 #include "policy-p.h"
@@ -464,7 +465,7 @@ xaccSplitAssignToLot (Split *split, GNCLot *lot)
     /* If we are here, then (cmp == +1 iff (amt > baln)) and we need
      * to split up the split into pieces. Do it. */
     {
-        time_t now = time(0);
+        time64 now = gnc_time (NULL);
         Split * new_split;
         gnc_numeric amt_a, amt_b, amt_tot;
         gnc_numeric val_a, val_b, val_tot;
@@ -532,7 +533,10 @@ xaccSplitAssignToLot (Split *split, GNCLot *lot)
 
         /* Copy most of the split attributes */
         xaccSplitSetMemo (new_split, xaccSplitGetMemo (split));
-        xaccSplitSetAction (new_split, xaccSplitGetAction (split));
+        /* Set split-action with gnc_set_num_action which is the same as
+         * xaccSplitSetAction with these arguments; use gnc_get_num_action to get
+         * split-action which is the same as xaccSplitGetAction */
+        gnc_set_num_action(NULL, new_split, NULL, gnc_get_num_action(NULL, split));
         xaccSplitSetReconcile (new_split, xaccSplitGetReconcile (split));
         ts = xaccSplitRetDateReconciledTS (split);
         xaccSplitSetDateReconciledTS (new_split, &ts);
@@ -732,7 +736,7 @@ xaccSplitComputeCapGains(Split *split, Account *gain_acc)
         return;
     }
 
-    if (safe_strcmp ("stock-split", xaccSplitGetType (split)) == 0)
+    if (g_strcmp0 ("stock-split", xaccSplitGetType (split)) == 0)
     {
         LEAVE ("Stock split split, returning.");
         return;
@@ -1015,7 +1019,7 @@ xaccSplitComputeCapGains(Split *split, Account *gain_acc)
             /* Common to both */
             ts = xaccTransRetDatePostedTS (split->parent);
             xaccTransSetDatePostedTS (trans, &ts);
-            xaccTransSetDateEnteredSecs (trans, time(0));
+            xaccTransSetDateEnteredSecs (trans, gnc_time (NULL));
 
             xaccSplitSetAmount (lot_split, zero);
             xaccSplitSetValue (lot_split, value);
