@@ -66,8 +66,6 @@ struct _book_info
     GList *         tables;          /* visible tables */
 };
 
-static GncTaxTableEntry * CloneTaxEntry (const GncTaxTableEntry*, QofBook *);
-
 static QofLogModule log_module = GNC_MOD_BUSINESS;
 
 /* =============================================================== */
@@ -105,7 +103,7 @@ gncTaxIncludedTypeToString (GncTaxIncluded type)
 }
 #undef GNC_RETURN_ENUM_AS_STRING
 #define GNC_RETURN_ON_MATCH(s,x) \
-  if(safe_strcmp((s), (str)) == 0) { *type = x; return(TRUE); }
+  if(g_strcmp0((s), (str)) == 0) { *type = x; return(TRUE); }
 gboolean
 gncAmountStringToType (const char *str, GncAmountType *type)
 {
@@ -138,7 +136,7 @@ gncTaxIncludedStringToType (const char *str, GncTaxIncluded *type)
 #define SET_STR(obj, member, str) { \
         char * tmp; \
         \
-        if (!safe_strcmp (member, str)) return; \
+        if (!g_strcmp0 (member, str)) return; \
         gncTaxTableBeginEdit (obj); \
         tmp = CACHE_INSERT (str); \
         CACHE_REMOVE (member); \
@@ -165,7 +163,7 @@ maybe_resort_list (GncTaxTable *table)
 static inline void
 mod_table (GncTaxTable *table)
 {
-    timespecFromTime_t (&table->modtime, time(NULL));
+    timespecFromTime64 (&table->modtime, gnc_time (NULL));
 }
 
 static inline void addObj (GncTaxTable *table)
@@ -209,7 +207,9 @@ gncTaxTableRemoveChild (GncTaxTable *table, const GncTaxTable *child)
 enum
 {
     PROP_0,
-    PROP_NAME
+    PROP_NAME,
+    PROP_INVISIBLE,
+    PROP_REFCOUNT
 };
 
 /* GObject Initialization */
@@ -248,6 +248,12 @@ gnc_taxtable_get_property (GObject         *object,
     case PROP_NAME:
         g_value_set_string(value, tt->name);
         break;
+    case PROP_INVISIBLE:
+    	g_value_set_boolean(value, tt->invisible);
+    	break;
+    case PROP_REFCOUNT:
+    	g_value_set_uint64(value, tt->refcount);
+    	break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -270,6 +276,15 @@ gnc_taxtable_set_property (GObject         *object,
     case PROP_NAME:
         gncTaxTableSetName(tt, g_value_get_string(value));
         break;
+    case PROP_INVISIBLE:
+    	if (g_value_get_boolean(value))
+    	{
+            gncTaxTableMakeInvisible(tt);
+    	}
+    	break;
+    case PROP_REFCOUNT:
+    	gncTaxTableSetRefcount(tt, g_value_get_uint64(value));
+    	break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -362,6 +377,27 @@ gnc_taxtable_class_init (GncTaxTableClass *klass)
                           "tax table mnemonic.",
                           NULL,
                           G_PARAM_READWRITE));
+
+    g_object_class_install_property
+    (gobject_class,
+     PROP_INVISIBLE,
+     g_param_spec_boolean ("invisible",
+                           "Invisible",
+                           "TRUE if the tax table is invisible.  FALSE if visible.",
+                           FALSE,
+                           G_PARAM_READWRITE));
+
+    g_object_class_install_property
+    (gobject_class,
+     PROP_REFCOUNT,
+     g_param_spec_uint64("ref-count",
+                         "Reference count",
+                         "The ref-count property contains number of times this tax table "
+                         "is referenced.",
+                         0,           /* min */
+                         G_MAXUINT64, /* max */
+                         0,           /* default */
+                         G_PARAM_READWRITE));
 }
 
 /* Create/Destroy Functions */
@@ -379,73 +415,6 @@ gncTaxTableCreate (QofBook *book)
     return table;
 }
 
-
-GncTaxTable *
-gncCloneTaxTable (GncTaxTable *from, QofBook *book)
-{
-    GList *node;
-    GncTaxTable *table;
-    if (!book) return NULL;
-
-    table = g_object_new (GNC_TYPE_TAXTABLE, NULL);
-    qof_instance_init_data (&table->inst, _GNC_MOD_NAME, book);
-    qof_instance_gemini (&table->inst, &from->inst);
-
-    table->name = CACHE_INSERT (from->name);
-    table->modtime = from->modtime;
-    table->invisible = from->invisible;
-
-    table->refcount = 0;
-
-    /* Make copies of parents and children. Note that this can be
-     * a recursive copy ... treat as doubly-linked list. */
-    if (from->child)
-    {
-        table->child = gncTaxTableObtainTwin (from->child, book);
-        table->child->parent = table;
-    }
-    if (from->parent)
-    {
-        table->parent = gncTaxTableObtainTwin (from->parent, book);
-        table->parent->child = table;
-    }
-    for (node = g_list_last(from->children); node; node = node->next)
-    {
-        GncTaxTable *tbl = node->data;
-        tbl = gncTaxTableObtainTwin (tbl, book);
-        tbl->parent = table;
-        table->children = g_list_prepend(table->children, tbl);
-    }
-
-    /* Copy tax entries, preserving the order in the list */
-    table->entries = NULL;
-    for (node = g_list_last(from->entries); node; node = node->prev)
-    {
-        GncTaxTableEntry *ent = node->data;
-        ent = CloneTaxEntry (ent, book);
-        table->entries = g_list_prepend (table->entries, ent);
-    }
-
-    addObj (table);
-    qof_event_gen (&table->inst, QOF_EVENT_CREATE, NULL);
-    return table;
-}
-
-GncTaxTable *
-gncTaxTableObtainTwin (const GncTaxTable *from, QofBook *book)
-{
-    GncTaxTable *table;
-    if (!from) return NULL;
-
-    table = (GncTaxTable *) qof_instance_lookup_twin (QOF_INSTANCE(from), book);
-    if (!table)
-    {
-        table = gncCloneTaxTable (table, book);
-    }
-    return table;
-}
-
-
 void
 gncTaxTableDestroy (GncTaxTable *table)
 {
@@ -507,25 +476,6 @@ void gncTaxTableEntryDestroy (GncTaxTableEntry *entry)
     g_free (entry);
 }
 
-/** Makes a clone. The account is from the appriate book.
- *  Note that the table is left blank (for performance reasons
- *  we set it above, when cloning the table).
- */
-static GncTaxTableEntry *
-CloneTaxEntry (const GncTaxTableEntry*from, QofBook *book)
-{
-    QofInstance *acc;
-    GncTaxTableEntry *entry;
-    entry = g_new0 (GncTaxTableEntry, 1);
-
-    entry->type = from->type;
-    entry->amount = from->amount;
-
-    acc = qof_instance_lookup_twin (QOF_INSTANCE(from->account), book);
-    entry->account = (Account *) acc;
-    return entry;
-}
-
 /* =============================================================== */
 /* Set Functions */
 
@@ -707,7 +657,7 @@ GncTaxTable *gncTaxTableLookupByName (QofBook *book, const char *name)
     for ( ; list; list = list->next)
     {
         GncTaxTable *table = list->data;
-        if (!safe_strcmp (table->name, name))
+        if (!g_strcmp0 (table->name, name))
             return list->data;
     }
     return NULL;
@@ -824,6 +774,8 @@ gnc_numeric gncTaxTableEntryGetAmount (const GncTaxTableEntry *entry)
     return entry->amount;
 }
 
+/* This is a semi-private function (meaning that it's not declared in
+ * the header) used for SQL Backend testing. */
 GncTaxTable* gncTaxTableEntryGetTable( const GncTaxTableEntry* entry )
 {
     if (!entry) return NULL;
@@ -841,7 +793,7 @@ int gncTaxTableEntryCompare (const GncTaxTableEntry *a, const GncTaxTableEntry *
 
     name_a = gnc_account_get_full_name (a->account);
     name_b = gnc_account_get_full_name (b->account);
-    retval = safe_strcmp(name_a, name_b);
+    retval = g_strcmp0(name_a, name_b);
     g_free(name_a);
     g_free(name_b);
 
@@ -856,7 +808,7 @@ int gncTaxTableCompare (const GncTaxTable *a, const GncTaxTable *b)
     if (!a && !b) return 0;
     if (!a) return -1;
     if (!b) return 1;
-    return safe_strcmp (a->name, b->name);
+    return g_strcmp0 (a->name, b->name);
 }
 
 gboolean gncTaxTableEntryEqual(const GncTaxTableEntry *a, const GncTaxTableEntry *b)
@@ -893,7 +845,7 @@ gboolean gncTaxTableEqual(const GncTaxTable *a, const GncTaxTable *b)
     g_return_val_if_fail(GNC_IS_TAXTABLE(a), FALSE);
     g_return_val_if_fail(GNC_IS_TAXTABLE(b), FALSE);
 
-    if (safe_strcmp(a->name, b->name) != 0)
+    if (g_strcmp0(a->name, b->name) != 0)
     {
         PWARN("Names differ: %s vs %s", a->name, b->name);
         return FALSE;
