@@ -23,18 +23,14 @@
 
 #include "config.h"
 
-#include <gnome.h>
 #include <glib/gi18n.h>
-#include <libguile.h>
 #include <gconf/gconf.h>
 #ifdef HAVE_X11_XLIB_H
 # include <X11/Xlib.h>
 #endif
 #include <libxml/xmlIO.h>
 
-//#include "gnc-html-graph-gog.h"
-
-#include "druid-gconf-setup.h"
+#include "assistant-gconf-setup.h"
 #include "gnc-gconf-utils.h"
 #include "gnc-gnome-utils.h"
 //#include "gnc-html.h"
@@ -54,6 +50,7 @@
 #include "dialog-totd.h"
 #include "gnc-ui-util.h"
 #include "gnc-session.h"
+#include "qofbookslots.h"
 #ifdef G_OS_WIN32
 #    include "gnc-help-utils.h"
 #endif
@@ -62,7 +59,6 @@
 #endif
 
 static QofLogModule log_module = GNC_MOD_GUI;
-static GnomeProgram *gnucash_program = NULL;
 static int gnome_is_running = FALSE;
 static int gnome_is_terminating = FALSE;
 static int gnome_is_initialized = FALSE;
@@ -70,12 +66,52 @@ static int gnome_is_initialized = FALSE;
 
 #define ACCEL_MAP_NAME "accelerator-map"
 
+static void gnc_book_options_help_cb (GNCOptionWin *win, gpointer dat);
+
 static void
 gnc_global_options_help_cb (GNCOptionWin *win, gpointer dat)
 {
     gnc_gnome_help (HF_HELP, HL_GLOBPREFS);
 }
 
+static void
+gnc_book_options_help_cb (GNCOptionWin *win, gpointer dat)
+{
+    gnc_gnome_help (HF_HELP, HL_BOOK_OPTIONS);
+}
+
+void
+gnc_options_dialog_set_book_options_help_cb (GNCOptionWin *win)
+{
+    gnc_options_dialog_set_help_cb(win,
+                                (GNCOptionWinCallback)gnc_book_options_help_cb,
+                                NULL);
+}
+
+void
+gnc_options_dialog_set_new_book_option_values (GNCOptionDB *odb)
+{
+    GNCOption *num_source_option;
+    GtkWidget *num_source_is_split_action_button;
+    gboolean num_source_is_split_action;
+
+    if (!odb) return;
+    num_source_is_split_action = gnc_gconf_get_bool(GCONF_GENERAL,
+                                                    KEY_NUM_SOURCE,
+                                                    NULL);
+    if (num_source_is_split_action)
+    {
+        num_source_option = gnc_option_db_get_option_by_name(odb,
+                                                 OPTION_SECTION_ACCOUNTS,
+                                                 OPTION_NAME_NUM_FIELD_SOURCE);
+        num_source_is_split_action_button =
+                                gnc_option_get_gtk_widget (num_source_option);
+        gtk_toggle_button_set_active
+                    (GTK_TOGGLE_BUTTON (num_source_is_split_action_button),
+                        num_source_is_split_action);
+    }
+}
+
 static void
 gnc_commodity_help_cb (void)
 {
@@ -170,74 +206,7 @@ gnc_configure_date_completion (void)
     }
 }
 
-char *
-gnc_gnome_locate_pixmap (const char *name)
-{
-    char *fullname;
-
-    g_return_val_if_fail (name != NULL, NULL);
-
-    fullname = gnome_program_locate_file (gnucash_program,
-                                          GNOME_FILE_DOMAIN_APP_PIXMAP,
-                                          name, TRUE, NULL);
-    if (fullname == NULL)
-    {
-        PERR ("Could not locate pixmap/pixbuf file %s", name);
-        return NULL;
-    }
-
-    return fullname;
-}
-
-char *
-gnc_gnome_locate_file (GnomeFileDomain domain, const char *name)
-{
-    char *fullname;
-
-    g_return_val_if_fail(name, NULL);
-    fullname = gnome_program_locate_file(gnucash_program,
-                                         domain, name, TRUE, NULL);
-    if (!fullname)
-        PERR ("Could not locate file %s", name);
-    return fullname;
-}
-
-char *
-gnc_gnome_locate_data_file (const char *name)
-{
-    char *fullname;
-
-    g_return_val_if_fail (name != NULL, NULL);
-
-    fullname = gnome_program_locate_file (gnucash_program,
-                                          GNOME_FILE_DOMAIN_APP_DATADIR,
-                                          name, TRUE, NULL);
-
-    if (fullname == NULL)
-    {
-        PERR ("Could not locate file %s", name);
-        return NULL;
-    }
-
-    return fullname;
-}
-
-char *
-gnc_gnome_locate_ui_file (const char *name)
-{
-    char *partial;
-    char *fullname;
-
-    g_return_val_if_fail (name != NULL, NULL);
-
-    partial = g_strdup_printf("ui/%s", name);
-    fullname = gnc_gnome_locate_data_file(partial);
-    g_free(partial);
-
-    return fullname;
-}
-
-static void
+void
 gnc_gtk_add_rc_file (void)
 {
     const gchar *var;
@@ -252,80 +221,6 @@ gnc_gtk_add_rc_file (void)
     }
 }
 
-void
-gnc_gnome_init (int argc, char **argv, const char * version)
-{
-    GError *error = NULL;
-    gchar *prefix = gnc_path_get_prefix ();
-    gchar *pkgsysconfdir = gnc_path_get_pkgsysconfdir ();
-    gchar *pkgdatadir = gnc_path_get_pkgdatadir ();
-    gchar *pkglibdir = gnc_path_get_pkglibdir ();
-
-    gnc_gtk_add_rc_file();
-    gnucash_program = gnome_program_init(
-                          "gnucash", version, LIBGNOMEUI_MODULE,
-                          argc, argv,
-                          GNOME_PARAM_APP_PREFIX, prefix,
-                          GNOME_PARAM_APP_SYSCONFDIR, pkgsysconfdir,
-                          GNOME_PARAM_APP_DATADIR, pkgdatadir,
-                          GNOME_PARAM_APP_LIBDIR, pkglibdir,
-                          GNOME_PARAM_NONE);
-    g_free (prefix);
-    g_free (pkgsysconfdir);
-    g_free (pkgdatadir);
-    g_free (pkglibdir);
-
-#ifdef G_OS_WIN32
-    /* workaround for bug #421792 */
-    xmlCleanupInputCallbacks();
-#endif
-
-    /* initialization required for gtkhtml */
-    gtk_widget_set_default_colormap (gdk_rgb_get_colormap ());
-
-    /* use custom icon */
-    {
-        int idx;
-        char *icon_filenames[] = {"gnucash-icon-16x16.png",
-                                  "gnucash-icon-32x32.png",
-                                  "gnucash-icon-48x48.png",
-                                  NULL
-                                 };
-        GList *icons = NULL;
-        char *fullname, *name_iter;
-
-        for (idx = 0; icon_filenames[idx] != NULL; idx++)
-        {
-            GdkPixbuf *buf = NULL;
-
-            fullname = gnc_gnome_locate_pixmap(icon_filenames[idx]);
-            if (fullname == NULL)
-            {
-                g_warning("couldn't find icon file [%s]", icon_filenames[idx]);
-                continue;
-            }
-
-            buf = gnc_gnome_get_gdkpixbuf(fullname);
-            if (buf == NULL)
-            {
-                g_warning("error loading image from [%s]", fullname);
-                g_free(fullname);
-                continue;
-            }
-            g_free(fullname);
-            icons = g_list_append(icons, buf);
-        }
-
-        gtk_window_set_default_icon_list(icons);
-        g_list_foreach(icons, (GFunc)g_object_unref, NULL);
-        g_list_free(icons);
-    }
-
-    druid_gconf_install_check_schemas();
-
-    return;
-}
-
 #ifdef MAC_INTEGRATION
 
 /* Don't be alarmed if this function looks strange to you: It's
@@ -375,7 +270,7 @@ subdir = [[[subdir lowercaseString] componentsSeparatedByString: @" "]
 if (![[NSFileManager defaultManager] fileExistsAtPath: docs_dir])
         {
             const gchar *message =
-                _("GnuCash could not find the files for the help documentation.  "
+                _("GnuCash could not find the files for the help documentation. "
                   "This is likely because the 'gnucash-docs' package is not installed");
             gnc_error_dialog(NULL, "%s at %s", message, [docs_dir UTF8String]);
             [pool release];
@@ -468,7 +363,7 @@ url = [NSURL fileURLWithPath: [[NSBundle mainBundle]
     else
     {
         const gchar *message =
-            _("GnuCash could not find the files for the help documentation.  "
+            _("GnuCash could not find the files for the help documentation. "
               "This is likely because the 'gnucash-docs' package is not installed.");
         gnc_error_dialog(NULL, "%s", message);
     }
@@ -513,15 +408,24 @@ void
 gnc_gnome_help (const char *file_name, const char *anchor)
 {
     GError *error = NULL;
+    gchar *uri = NULL;
+    gboolean success;
 
-    DEBUG ("Attempting to opening help file %s", file_name);
-    if (gnome_help_display (file_name, anchor, &error))
+    if (anchor)
+        uri = g_strconcat ("ghelp:", file_name, "?", anchor, NULL);
+    else
+        uri = g_strconcat ("ghelp:", file_name, NULL);
+
+    DEBUG ("Attempting to opening help uri %s", uri);
+    success = gtk_show_uri (NULL, uri, gtk_get_current_event_time (), &error);
+    g_free (uri);
+    if (success)
         return;
 
     g_assert(error != NULL);
     {
         const gchar *message =
-            _("GnuCash could not find the files for the help documentation.  "
+            _("GnuCash could not find the files for the help documentation. "
               "This is likely because the 'gnucash-docs' package is not installed.");
         gnc_error_dialog(NULL, "%s", message);
     }
@@ -547,7 +451,7 @@ gnc_gnome_get_pixmap (const char *name)
 
     g_return_val_if_fail (name != NULL, NULL);
 
-    fullname = gnc_gnome_locate_pixmap (name);
+    fullname = gnc_filepath_locate_pixmap (name);
     if (fullname == NULL)
         return NULL;
 
@@ -579,7 +483,7 @@ gnc_gnome_get_gdkpixbuf (const char *name)
 
     g_return_val_if_fail (name != NULL, NULL);
 
-    fullname = gnc_gnome_locate_pixmap (name);
+    fullname = gnc_filepath_locate_pixmap (name);
     if (fullname == NULL)
         return NULL;
 
@@ -680,16 +584,57 @@ gnc_gui_init(void)
 {
     static GncMainWindow *main_window;
     gchar *map;
+#ifdef MAC_INTEGRATION
     gchar *data_dir;
+#endif
+    int idx;
+    char *icon_filenames[] = {"gnucash-icon-16x16.png",
+                              "gnucash-icon-32x32.png",
+                              "gnucash-icon-48x48.png",
+                              NULL
+                             };
+    GList *icons = NULL;
+    char *fullname;
+
+    ENTER ("");
 
     if (gnome_is_initialized)
-    {
         return main_window;
+
+    /* use custom icon */
+    for (idx = 0; icon_filenames[idx] != NULL; idx++)
+    {
+        GdkPixbuf *buf = NULL;
+
+        fullname = gnc_filepath_locate_pixmap(icon_filenames[idx]);
+        if (fullname == NULL)
+        {
+            g_warning("couldn't find icon file [%s]", icon_filenames[idx]);
+            continue;
+        }
+
+        buf = gnc_gnome_get_gdkpixbuf(fullname);
+        if (buf == NULL)
+        {
+            g_warning("error loading image from [%s]", fullname);
+            g_free(fullname);
+            continue;
+        }
+        g_free(fullname);
+        icons = g_list_append(icons, buf);
     }
 
+    gtk_window_set_default_icon_list(icons);
+    g_list_foreach(icons, (GFunc)g_object_unref, NULL);
+    g_list_free(icons);
+
+    /* initialization required for gtkhtml (is it also needed for webkit?) */
+    gtk_widget_set_default_colormap (gdk_rgb_get_colormap ());
+
     g_set_application_name(PACKAGE_NAME);
 
     gnc_show_splash_screen();
+    assistant_gconf_install_check_schemas();
 
     gnome_is_initialized = TRUE;
 
@@ -729,6 +674,7 @@ gnc_gui_init(void)
     gnc_load_stock_icons();
     gnc_totd_dialog(GTK_WINDOW(main_window), TRUE);
 
+    LEAVE ("");
     return main_window;
 }
 
