@@ -22,7 +22,6 @@
 
 #include "config.h"
 
-#include <gnome.h>
 #include <glib/gi18n.h>
 
 #include "dialog-utils.h"
@@ -75,6 +74,9 @@ gnc_ok_cancel_dialog(GtkWidget *parent,
     g_free(buffer);
     va_end(args);
 
+    if (parent == NULL)
+        gtk_window_set_skip_taskbar_hint(GTK_WINDOW(dialog), FALSE);
+
     gtk_dialog_set_default_response (GTK_DIALOG(dialog), default_result);
     result = gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_destroy (dialog);
@@ -120,6 +122,9 @@ gnc_verify_dialog(GtkWidget *parent, gboolean yes_is_default,
     g_free(buffer);
     va_end(args);
 
+    if (parent == NULL)
+        gtk_window_set_skip_taskbar_hint(GTK_WINDOW(dialog), FALSE);
+
     gtk_dialog_set_default_response(GTK_DIALOG(dialog),
                                     (yes_is_default ? GTK_RESPONSE_YES : GTK_RESPONSE_NO));
     result = gtk_dialog_run(GTK_DIALOG(dialog));
@@ -159,6 +164,9 @@ gnc_info_dialog(GtkWidget *parent, const gchar *format, ...)
                                      buffer);
     va_end(args);
 
+    if (parent == NULL)
+        gtk_window_set_skip_taskbar_hint(GTK_WINDOW(dialog), FALSE);
+
     gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_destroy (dialog);
 }
@@ -194,6 +202,9 @@ gnc_warning_dialog_common(GtkWidget *parent, const gchar *format, va_list args)
                                      buffer);
     g_free(buffer);
 
+    if (parent == NULL)
+        gtk_window_set_skip_taskbar_hint(GTK_WINDOW(dialog), FALSE);
+
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
 }
@@ -238,6 +249,9 @@ gnc_error_dialog_common(GtkWidget *parent, const gchar *format, va_list args)
                                      buffer);
     g_free(buffer);
 
+    if (parent == NULL)
+        gtk_window_set_skip_taskbar_hint(GTK_WINDOW(dialog), FALSE);
+
     gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_destroy (dialog);
 }
@@ -333,7 +347,6 @@ gnc_choose_radio_option_dialog(GtkWidget *parent,
                                           GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                           button_name, GTK_RESPONSE_OK,
                                           NULL);
-    gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
 
     /* default to ok */
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
