@@ -617,15 +617,9 @@ gnc_plugin_file_history_init (GncPluginFileHistory *plugin)
 static void
 gnc_plugin_file_history_finalize (GObject *object)
 {
-    GncPluginFileHistory *plugin;
-    GncPluginFileHistoryPrivate *priv;
-
     g_return_if_fail (GNC_IS_PLUGIN_FILE_HISTORY (object));
 
     ENTER("plugin %p", object);
-    plugin = GNC_PLUGIN_FILE_HISTORY (object);
-    priv = GNC_PLUGIN_FILE_HISTORY_GET_PRIVATE (plugin);
-
     G_OBJECT_CLASS (parent_class)->finalize (object);
     LEAVE("");
 }
@@ -725,7 +719,7 @@ gnc_plugin_file_history_cmd_open_file (GtkAction *action,
     filename = g_object_get_data(G_OBJECT(action), FILENAME_STRING);
     gnc_window_set_progressbar_window (GNC_WINDOW(data->window));
     /* also opens new account page */
-    gnc_file_open_file (filename);
+    gnc_file_open_file (filename, /*open_readonly*/ FALSE);
     gnc_window_set_progressbar_window (NULL);
 }
 
