@@ -39,6 +39,7 @@
 
 #include "gnc-plugin.h"
 #include "gnc-engine.h"
+#include "gnc-filepath-utils.h"
 #include "gnc-gconf-utils.h"
 #include "gnc-gnome-utils.h"
 #include "gnc-gobject-utils.h"
@@ -141,14 +142,8 @@ gnc_plugin_init (GncPlugin *plugin_page, GncPluginClass *klass)
 static void
 gnc_plugin_finalize (GObject *object)
 {
-    GncPlugin *plugin;
-    GncPluginPrivate *priv;
-
     g_return_if_fail (GNC_IS_PLUGIN (object));
 
-    plugin = GNC_PLUGIN (object);
-    priv = GNC_PLUGIN_GET_PRIVATE (plugin);
-
     gnc_gobject_tracking_forget(object);
     G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -353,7 +348,16 @@ gnc_plugin_update_actions (GtkActionGroup *action_group,
     for (i = 0; action_names[i]; i++)
     {
         action = gtk_action_group_get_action (action_group, action_names[i]);
-        g_object_set_property (G_OBJECT(action), property_name, &gvalue);
+        if (action)
+        {
+            g_object_set_property (G_OBJECT(action), property_name, &gvalue);
+        }
+        else
+        {
+            g_warning("No such action with name '%s' in action group %s (size %d)",
+                      action_names[i], gtk_action_group_get_name(action_group),
+                      g_list_length(gtk_action_group_list_actions(action_group)));
+        }
     }
 }
 
@@ -378,7 +382,7 @@ gnc_plugin_add_actions (GtkUIManager *ui_merge,
           ui_merge, action_group, filename);
     gtk_ui_manager_insert_action_group (ui_merge, action_group, 0);
 
-    pathname = gnc_gnome_locate_ui_file (filename);
+    pathname = gnc_filepath_locate_ui_file (filename);
     if (pathname == NULL)
     {
         LEAVE("fail");
