@@ -209,19 +209,6 @@ gboolean gnc_tree_model_commodity_get_iter_from_commodity (GncTreeModelCommodity
         gnc_commodity *commodity,
         GtkTreeIter *iter);
 
-/** Convert a commodity namespace pointer into a GtkTreePath.
- *
- *  @param model A pointer to the commodity tree model.
- *
- *  @param namespace A pointer to the gnucash commodity namespace.
- *
- *  @return A pointer to a GtkTreePath describing the location of this
- *  namespace.  This pointer must be freed by the caller when no
- *  longer needed.  This routine will return NULL if the namespace
- *  does not exist in the tree. */
-GtkTreePath *gnc_tree_model_commodity_get_path_from_namespace (GncTreeModelCommodity *model,
-        gnc_commodity_namespace *namespace);
-
 /** Convert a commodity pointer into a GtkTreePath.
  *
  *  @param model A pointer to the commodity tree model.
