@@ -1,26 +1,26 @@
-/********************************************************************\
- * gnc-tree-view-account.c -- GtkTreeView implementation to display *
- *                            accounts in a GtkTreeView.            *
+/**********************************************************************\
+ * gnc-tree-view-account.c -- GtkTreeView implementation to display   *
+ *                            accounts in a GtkTreeView.              *
  * Copyright (C) 2003,2005,2006 David Hampton <hampton@employees.org> *
- *                                                                  *
- * This program is free software; you can redistribute it and/or    *
- * modify it under the terms of the GNU General Public License as   *
- * published by the Free Software Foundation; either version 2 of   *
- * the License, or (at your option) any later version.              *
- *                                                                  *
- * This program is distributed in the hope that it will be useful,  *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
- * GNU General Public License for more details.                     *
- *                                                                  *
- * You should have received a copy of the GNU General Public License*
- * along with this program; if not, contact:                        *
- *                                                                  *
- * Free Software Foundation           Voice:  +1-617-542-5942       *
- * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
- * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
- *                                                                  *
-\********************************************************************/
+ *                                                                    *
+ * This program is free software; you can redistribute it and/or      *
+ * modify it under the terms of the GNU General Public License as     *
+ * published by the Free Software Foundation; either version 2 of     *
+ * the License, or (at your option) any later version.                *
+ *                                                                    *
+ * This program is distributed in the hope that it will be useful,    *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of     *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      *
+ * GNU General Public License for more details.                       *
+ *                                                                    *
+ * You should have received a copy of the GNU General Public License  *
+ * along with this program; if not, contact:                          *
+ *                                                                    *
+ * Free Software Foundation           Voice:  +1-617-542-5942         *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652         *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                     *
+ *                                                                    *
+\**********************************************************************/
 
 #include "config.h"
 
@@ -40,10 +40,11 @@
 #include "gnc-engine.h"
 #include "gnc-glib-utils.h"
 #include "gnc-gobject-utils.h"
+#include "gnc-gconf-utils.h"
 #include "gnc-hooks.h"
 #include "gnc-session.h"
 #include "gnc-icons.h"
-#include "gnc-ui-util.h"
+#include "gnc-ui-balances.h"
 #include "dialog-utils.h"
 #include "window-main-summarybar.h"
 
@@ -77,13 +78,22 @@ static void tax_info_data_func (GtkTreeViewColumn *col,
                                 GtkTreeIter       *iter,
                                 gpointer           view);
 
+static void acc_color_data_func (GtkTreeViewColumn *col,
+                                GtkCellRenderer   *renderer,
+                                GtkTreeModel      *model,
+                                GtkTreeIter       *iter,
+                                gpointer           view);
+
+static void gnc_tree_view_account_color_update (GConfEntry *entry, gpointer user_data);
+
+
 typedef struct GncTreeViewAccountPrivate
 {
     AccountViewInfo avi;
 
     gnc_tree_view_account_filter_func filter_fn;
     gpointer                          filter_data;
-    GtkFunction                       filter_destroy;
+    GSourceFunc                       filter_destroy;
 
     GtkTreeViewColumn *name_column;
     GtkTreeViewColumn *code_column;
@@ -95,6 +105,9 @@ typedef struct GncTreeViewAccountPrivate
     GtkTreeViewColumn *future_min_report_column;
     GtkTreeViewColumn *total_report_column;
     GtkTreeViewColumn *notes_column;
+
+    gboolean show_account_color;
+
 } GncTreeViewAccountPrivate;
 
 #define GNC_TREE_VIEW_ACCOUNT_GET_PRIVATE(o)  \
@@ -175,6 +188,11 @@ gnc_tree_view_account_init (GncTreeViewAccount *view)
     GncTreeViewAccountPrivate *priv;
 
     priv = GNC_TREE_VIEW_ACCOUNT_GET_PRIVATE(view);
+
+    gnc_gconf_general_register_cb("show_account_color",
+                                  gnc_tree_view_account_color_update,
+                                  view);
+
     gnc_init_account_view_info(&priv->avi);
 }
 
@@ -191,6 +209,10 @@ gnc_tree_view_account_finalize (GObject *object)
     account_view = GNC_TREE_VIEW_ACCOUNT (object);
 
     priv = GNC_TREE_VIEW_ACCOUNT_GET_PRIVATE(account_view);
+
+    gnc_gconf_general_remove_cb("show_account_color",
+                                gnc_tree_view_account_color_update,
+                                account_view);
     if (priv->filter_destroy)
     {
         priv->filter_destroy(priv->filter_data);
@@ -428,7 +450,7 @@ sort_by_xxx_period_value (GtkTreeModel *f_model,
                           gboolean recurse)
 {
     Account *acct1, *acct2;
-    time_t t1, t2;
+    time64 t1, t2;
     gnc_numeric b1, b2;
     gint result;
 
@@ -506,13 +528,13 @@ tax_info_data_func (GtkTreeViewColumn *col,
                            GNC_TREE_MODEL_ACCOUNT_COL_TAX_INFO_SUB_ACCT,
                            &tax_info_sub_acct,
                            -1);
-        if ((safe_strcmp (tax_info_sub_acct, "") == 0) ||
+        if ((g_strcmp0 (tax_info_sub_acct, "") == 0) ||
                 (tax_info_sub_acct == NULL))
             g_object_set(renderer, "text",
                          (tax_info == NULL ? "" : tax_info), NULL);
         else
         {
-            if ((safe_strcmp (tax_info, "") == 0) ||
+            if ((g_strcmp0 (tax_info, "") == 0) ||
                     (tax_info == NULL))
                 g_object_set(renderer, "text",
                              (tax_info_sub_acct == NULL ? "" : tax_info_sub_acct),
@@ -534,6 +556,106 @@ tax_info_data_func (GtkTreeViewColumn *col,
     gtk_tree_path_free(path);
 }
 
+/************************************************************/
+/*                acc_color data function                   */
+/************************************************************/
+/*
+ * The account-color column in the account tree view is obtained
+ * from the GNC_TREE_MODEL_ACCOUNT_COL_COLOR_ACCOUNT which is
+ * checked for a valid color string to set the background color
+ * of the cell.
+ */
+static void
+update_cell_renderers (GList *renderers, gchar *account_color)
+{
+    GtkCellRenderer *cell;
+    GList *node;
+
+    /* Update the cell background in the list of renderers */
+    for (node = renderers; node; node = node->next)
+    {
+        cell = node->data;
+        g_object_set (cell, "cell-background", account_color, NULL);
+    }
+}
+
+/* Colorizes a cell in the account tree view if
+ * - a color is assigned to the given account
+ * - the user enabled account colorization in the preferences
+ * Only the account color column is special: it will always
+ * be colored if a valid color was set, regardless of the
+ * preference setting.
+ */
+static void
+acc_color_data_func (GtkTreeViewColumn *col,
+                    GtkCellRenderer   *renderer,
+                    GtkTreeModel      *model,
+                    GtkTreeIter       *iter,
+                    gpointer           view)
+{
+    GncTreeViewAccountPrivate *priv;
+    gchar                     *acc_color = NULL, *acc_cond_color = NULL;
+    gchar                     *item;
+    GdkColor                   color;
+    gchar                     *column_name;
+    GList                     *renderers;
+
+    gtk_tree_model_get(model,
+                       iter,
+                       GNC_TREE_MODEL_ACCOUNT_COL_COLOR_ACCOUNT,
+                       &item,
+                       -1);
+
+    /* Check if color was set for the account */
+    if ((item) && (*item != '\0'))
+        acc_color = g_strstrip(g_strdup(item));
+    g_free (item);
+
+    /* Test if the color string represents a valid color */
+    if (acc_color && (!gdk_color_parse(acc_color, &color)))
+    {
+        g_free (acc_color);
+        acc_color = NULL;
+    }
+
+    /* Determine whether columns other than the
+     * Account Color column should be colored. */
+    priv = GNC_TREE_VIEW_ACCOUNT_GET_PRIVATE(view);
+    if (priv->show_account_color)
+        acc_cond_color = acc_color;
+
+    column_name = g_object_get_data(G_OBJECT(col), PREF_NAME);
+    renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (col));
+
+    /* Account Color column is always colored, other columns only conditionally. */
+    if (g_strcmp0(column_name, "account-color") == 0)
+        update_cell_renderers (renderers, acc_color);
+    else
+        update_cell_renderers (renderers, acc_cond_color);
+
+    g_list_free (renderers);
+    g_free (acc_color);
+}
+
+/** Tell the GncTreeViewAccount code to show or not show the
+ *  Account name column with background in the account color.
+ *
+ *  @internal
+ */
+static void
+gnc_tree_view_account_color_update (GConfEntry *entry, gpointer user_data)
+{
+    GncTreeViewAccountPrivate *priv;
+    GncTreeViewAccount *view;
+    GConfValue *value;
+
+    g_return_if_fail(GNC_IS_TREE_VIEW_ACCOUNT(user_data));
+    view = user_data;
+    priv = GNC_TREE_VIEW_ACCOUNT_GET_PRIVATE(view);
+    value = gconf_entry_get_value(entry);
+    priv->show_account_color = gconf_value_get_bool(value);
+}
+
 /************************************************************/
 /*                    New View Creation                     */
 /************************************************************/
@@ -552,7 +674,7 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
     GtkTreePath *virtual_root_path = NULL;
     const gchar *sample_type, *sample_commodity;
     GncTreeViewAccountPrivate *priv;
-    GtkTreeViewColumn *tax_info_column;
+    GtkTreeViewColumn *tax_info_column, *acc_color_column;
     GtkCellRenderer *renderer;
 
     ENTER(" ");
@@ -562,6 +684,9 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
 
     priv = GNC_TREE_VIEW_ACCOUNT_GET_PRIVATE(GNC_TREE_VIEW_ACCOUNT (view));
 
+    /* Get the show_account_color value from gconf */
+    priv->show_account_color = gnc_gconf_get_bool(GCONF_GENERAL, "show_account_color", NULL);
+
     /* Create/get a pointer to the existing model for this set of books. */
     model = gnc_tree_model_account_new (root);
 
@@ -593,10 +718,20 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
                                     GNC_TREE_MODEL_ACCOUNT_COL_NAME,
                                     GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                     sort_by_string);
+
+    renderer = gnc_tree_view_column_get_renderer(priv->name_column);
+
+    gtk_tree_view_column_set_cell_data_func(priv->name_column,
+                                            renderer,
+                                            acc_color_data_func,
+                                            GTK_TREE_VIEW(view),
+                                            NULL);
+
     gnc_tree_view_add_text_column(view, _("Type"), "type", NULL, sample_type,
                                   GNC_TREE_MODEL_ACCOUNT_COL_TYPE,
                                   GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                   sort_by_string);
+
     gnc_tree_view_add_text_column(view, _("Commodity"), "commodity", NULL,
                                   sample_commodity,
                                   GNC_TREE_MODEL_ACCOUNT_COL_COMMODITY,
@@ -614,11 +749,13 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
                                     GNC_TREE_MODEL_ACCOUNT_COL_DESCRIPTION,
                                     GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                     sort_by_string);
+
     gnc_tree_view_add_numeric_column(view, _("Last Num"), "lastnum", "12345",
                                      GNC_TREE_MODEL_ACCOUNT_COL_LASTNUM,
                                      GNC_TREE_VIEW_COLUMN_COLOR_NONE,
                                      GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                      sort_by_string);
+
     gnc_tree_view_add_numeric_column(view, _("Present"), "present",
                                      SAMPLE_ACCOUNT_VALUE,
                                      GNC_TREE_MODEL_ACCOUNT_COL_PRESENT,
@@ -632,6 +769,7 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
                                        GNC_TREE_MODEL_ACCOUNT_COL_COLOR_PRESENT,
                                        GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                        sort_by_present_value);
+
     gnc_tree_view_add_numeric_column(view, _("Balance"), "balance",
                                      SAMPLE_ACCOUNT_VALUE,
                                      GNC_TREE_MODEL_ACCOUNT_COL_BALANCE,
@@ -652,6 +790,7 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
                                      GNC_TREE_MODEL_ACCOUNT_COL_COLOR_BALANCE_PERIOD,
                                      GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                      sort_by_balance_period_value);
+
     gnc_tree_view_add_numeric_column(view, _("Cleared"), "cleared",
                                      SAMPLE_ACCOUNT_VALUE,
                                      GNC_TREE_MODEL_ACCOUNT_COL_CLEARED,
@@ -665,6 +804,7 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
                                        GNC_TREE_MODEL_ACCOUNT_COL_COLOR_CLEARED,
                                        GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                        sort_by_cleared_value);
+
     gnc_tree_view_add_numeric_column(view, _("Reconciled"), "reconciled",
                                      SAMPLE_ACCOUNT_VALUE,
                                      GNC_TREE_MODEL_ACCOUNT_COL_RECONCILED,
@@ -678,11 +818,13 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
                                        GNC_TREE_MODEL_ACCOUNT_COL_COLOR_RECONCILED,
                                        GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                        sort_by_reconciled_value);
+
     gnc_tree_view_add_text_column(view, _("Last Reconcile Date"), "last-recon-date", NULL,
                                   "Last Reconcile Date",
                                   GNC_TREE_MODEL_ACCOUNT_COL_RECONCILED_DATE,
                                   GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                   sort_by_string);
+
     gnc_tree_view_add_numeric_column(view, _("Future Minimum"), "future_min",
                                      SAMPLE_ACCOUNT_VALUE,
                                      GNC_TREE_MODEL_ACCOUNT_COL_FUTURE_MIN,
@@ -696,6 +838,7 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
                                         GNC_TREE_MODEL_ACCOUNT_COL_COLOR_FUTURE_MIN,
                                         GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                         sort_by_future_min_value);
+
     gnc_tree_view_add_numeric_column(view, _("Total"), "total",
                                      SAMPLE_ACCOUNT_VALUE,
                                      GNC_TREE_MODEL_ACCOUNT_COL_TOTAL,
@@ -709,12 +852,33 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
                                        GNC_TREE_MODEL_ACCOUNT_COL_COLOR_TOTAL,
                                        GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                        sort_by_total_value);
+
     gnc_tree_view_add_numeric_column(view, _("Total (Period)"), "total-period",
                                      SAMPLE_ACCOUNT_VALUE,
                                      GNC_TREE_MODEL_ACCOUNT_COL_TOTAL_PERIOD,
                                      GNC_TREE_MODEL_ACCOUNT_COL_COLOR_TOTAL_PERIOD,
                                      GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                      sort_by_total_period_value);
+
+    /* Translators: The C is the column title and stands for Color, this should be one character */
+    acc_color_column
+    = gnc_tree_view_add_text_column(view, _("C"), "account-color", NULL,
+                                    "xx",
+                                    GNC_TREE_VIEW_COLUMN_DATA_NONE,
+                                    GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
+                                    NULL);
+
+    renderer = gnc_tree_view_column_get_renderer(acc_color_column);
+
+    /* Add the full title to the object for menu creation */
+    g_object_set_data_full(G_OBJECT(acc_color_column), REAL_TITLE,
+                           g_strdup(_("Account Color")), g_free);
+
+    gtk_tree_view_column_set_cell_data_func(acc_color_column,
+                                            renderer,
+                                            acc_color_data_func,
+                                            GTK_TREE_VIEW(view),
+                                            NULL);
     priv->notes_column
     = gnc_tree_view_add_text_column(view, _("Notes"), "notes", NULL,
                                     "Sample account notes.",
@@ -727,12 +891,14 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
                                     GNC_TREE_MODEL_ACCOUNT_COL_TAX_INFO,
                                     GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                     sort_by_string);
+
     renderer = gnc_tree_view_column_get_renderer(tax_info_column);
     gtk_tree_view_column_set_cell_data_func(tax_info_column,
                                             renderer,
                                             tax_info_data_func,
                                             GTK_TREE_VIEW(view),
                                             NULL);
+
     gnc_tree_view_add_toggle_column(view, _("Placeholder"),
                                     /* Translators: This string has a context prefix; the translation
                                     	must only contain the part after the | character. */
@@ -743,7 +909,7 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
                                     sort_by_placeholder,
                                     gnc_tree_view_account_placeholder_toggled);
 
-    /* Update column titles to use the curreny name. */
+    /* Update column titles to use the currency name. */
     gtva_update_column_names(view);
 
     /* By default only the first column is visible. */
@@ -989,7 +1155,7 @@ void
 gnc_tree_view_account_set_filter (GncTreeViewAccount *view,
                                   gnc_tree_view_account_filter_func func,
                                   gpointer data,
-                                  GtkFunction destroy)
+                                  GSourceFunc destroy)
 {
     GncTreeViewAccountPrivate *priv;
 
@@ -1026,20 +1192,6 @@ gnc_tree_view_account_refilter (GncTreeViewAccount *view)
     gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (f_model));
 }
 
-gboolean
-gnc_tree_view_account_filter_by_type_selection(Account* acct, gpointer data)
-{
-    GNCAccountType acct_type;
-    guint sel_bits = GPOINTER_TO_UINT(data);
-
-    g_return_val_if_fail(GNC_IS_ACCOUNT(acct), FALSE);
-    acct_type = xaccAccountGetType(acct);
-
-    /* Because of some silly '== TRUE' comparisons in treemodelfilter,
-       we have to return exactly TRUE */
-    return (sel_bits & (1 << acct_type)) ? TRUE : FALSE;
-}
-
 gboolean
 gnc_tree_view_account_filter_by_view_info(Account* acct, gpointer data)
 {
@@ -1485,14 +1637,12 @@ gnc_tree_view_account_expand_to_account (GncTreeViewAccount *view,
 Account *
 gnc_tree_view_account_get_cursor_account (GncTreeViewAccount *view)
 {
-    GtkTreeModel *s_model;
     GtkTreePath *s_path;
     Account *account;
 
     ENTER("view %p", view);
     g_return_val_if_fail (GNC_IS_TREE_VIEW_ACCOUNT (view), NULL);
 
-    s_model = gtk_tree_view_get_model (GTK_TREE_VIEW(view));
     gtk_tree_view_get_cursor (GTK_TREE_VIEW(view), &s_path, NULL);
     if (!s_path)
     {
@@ -1772,7 +1922,8 @@ gnc_plugin_page_account_tree_filter_accounts (Account *account,
  *
  *  @param button The GtkCheckButton that was toggled.
  *
- *  @param fd A pointer to the account filter dialog struct. */
+ *  @param fd A pointer to the account filter dialog struct.
+ */
 void
 gppat_filter_show_hidden_toggled_cb (GtkToggleButton *button,
                                      AccountFilterDialog *fd)
@@ -1790,7 +1941,8 @@ gppat_filter_show_hidden_toggled_cb (GtkToggleButton *button,
  *
  *  @param button The GtkCheckButton that was toggled.
  *
- *  @param fd A pointer to the account filter dialog struct. */
+ *  @param fd A pointer to the account filter dialog struct.
+ */
 void
 gppat_filter_show_zero_toggled_cb (GtkToggleButton *button,
                                    AccountFilterDialog *fd)
@@ -1809,7 +1961,8 @@ gppat_filter_show_zero_toggled_cb (GtkToggleButton *button,
  *
  *  @param button The button that was clicked.
  *
- *  @param fd A pointer to the account filter dialog struct. */
+ *  @param fd A pointer to the account filter dialog struct.
+ */
 void
 gppat_filter_clear_all_cb (GtkWidget *button,
                            AccountFilterDialog *fd)
@@ -1848,7 +2001,7 @@ gppat_filter_select_all_cb (GtkWidget *button,
  *
  *  @param button The button that was clicked.
  *
- *  @param fd A pointer to the account filter dialog struct. */
+ *  @param fd A pointer to the account filter dialog struct.*/
 void
 gppat_filter_select_default_cb (GtkWidget *button,
                                 AccountFilterDialog *fd)
@@ -1922,19 +2075,18 @@ gppat_filter_visible_toggled_cb (GtkCellRendererToggle *renderer,
  *
  *  @param response The response code from closing the dialog.
  *
- *  @param fd A pointer to the account filter dialog struct. */
+ *  @param fd A pointer to the account filter dialog struct.
+ */
 void
 gppat_filter_response_cb (GtkWidget *dialog,
                           gint       response,
                           AccountFilterDialog *fd)
 {
-    GtkWidget *view;
     gpointer gptemp;
 
     g_return_if_fail(GTK_IS_DIALOG(dialog));
 
     ENTER("dialog %p, response %d", dialog, response);
-    view = gnc_glade_lookup_widget(dialog, FILTER_TREE_VIEW);
 
     if (response != GTK_RESPONSE_OK)
     {
@@ -1959,7 +2111,7 @@ account_filter_dialog_create(AccountFilterDialog *fd, GncPluginPage *page)
     GtkWidget *dialog, *button;
     GtkTreeView *view;
     GtkCellRenderer *renderer;
-    GladeXML *xml;
+    GtkBuilder *builder;
     gchar *title;
 
     ENTER("(fd %p, page %p)", fd, page);
@@ -1972,8 +2124,9 @@ account_filter_dialog_create(AccountFilterDialog *fd, GncPluginPage *page)
     }
 
     /* Create the dialog */
-    xml = gnc_glade_xml_new ("account.glade", "Filter By");
-    dialog = glade_xml_get_widget (xml, "Filter By");
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-account.glade", "Filter By");
+    dialog = GTK_WIDGET(gtk_builder_get_object (builder, "Filter By"));
     fd->dialog = dialog;
     gtk_window_set_transient_for(GTK_WINDOW(dialog),
                                  GTK_WINDOW(GNC_PLUGIN_PAGE(page)->window));
@@ -1989,15 +2142,15 @@ account_filter_dialog_create(AccountFilterDialog *fd, GncPluginPage *page)
     fd->original_show_zero_total = fd->show_zero_total;
 
     /* Update the dialog widgets for the current state */
-    button = glade_xml_get_widget (xml, "show_hidden");
+    button = GTK_WIDGET(gtk_builder_get_object (builder, "show_hidden"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),
                                  fd->show_hidden);
-    button = glade_xml_get_widget (xml, "show_zero");
+    button = GTK_WIDGET(gtk_builder_get_object (builder, "show_zero"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),
                                  fd->show_zero_total);
 
     /* Set up the tree view and model */
-    view = GTK_TREE_VIEW(glade_xml_get_widget (xml, FILTER_TREE_VIEW));
+    view = GTK_TREE_VIEW(gtk_builder_get_object (builder, FILTER_TREE_VIEW));
 
     fd->model = gnc_tree_model_account_types_filter_using_mask
                 (~(1 << ACCT_TYPE_ROOT));
@@ -2020,8 +2173,8 @@ account_filter_dialog_create(AccountFilterDialog *fd, GncPluginPage *page)
      "text", GNC_TREE_MODEL_ACCOUNT_TYPES_COL_NAME, NULL);
 
     /* Wire up the rest of the callbacks */
-    glade_xml_signal_autoconnect_full(xml, gnc_glade_autoconnect_full_func,
-                                      fd);
+    gtk_builder_connect_signals(builder, fd);
+    g_object_unref(G_OBJECT(builder));
 
     /* Show it */
     gtk_widget_show_all(dialog);
@@ -2292,24 +2445,24 @@ gnc_tree_view_account_name_edited_cb(Account *account, GtkTreeViewColumn *col, c
 void
 gnc_tree_view_account_code_edited_cb(Account *account, GtkTreeViewColumn *col, const gchar *new_code)
 {
-    if (safe_strcmp(xaccAccountGetCode(account), new_code) == 0)
-	return;
+    if (g_strcmp0(xaccAccountGetCode(account), new_code) == 0)
+        return;
     xaccAccountSetCode(account, new_code);
 }
 
 void
 gnc_tree_view_account_description_edited_cb(Account *account, GtkTreeViewColumn *col, const gchar *new_desc)
 {
-    if (safe_strcmp(xaccAccountGetDescription(account), new_desc) == 0)
-	return;
+    if (g_strcmp0(xaccAccountGetDescription(account), new_desc) == 0)
+        return;
     xaccAccountSetDescription(account, new_desc);
 }
 
 void
 gnc_tree_view_account_notes_edited_cb(Account *account, GtkTreeViewColumn *col, const gchar *new_notes)
 {
-    if (safe_strcmp(xaccAccountGetNotes(account), new_notes) == 0)
-	return;
+    if (g_strcmp0(xaccAccountGetNotes(account), new_notes) == 0)
+        return;
     xaccAccountSetNotes(account, new_notes);
 }
 
@@ -2323,7 +2476,7 @@ gtva_set_column_editor(GncTreeViewAccount *view,
 
     // look for the first text-renderer; on the 0th column of the account tree,
     // there are two renderers: pixbuf and text.  So find the text one.
-    for (renderers_orig = renderers = gtk_tree_view_column_get_cell_renderers(column);
+    for (renderers_orig = renderers = gtk_cell_layout_get_cells(GTK_CELL_LAYOUT(column));
             renderers && !GTK_IS_CELL_RENDERER_TEXT(renderers->data);
             renderers = renderers->next);
     renderer = GTK_CELL_RENDERER(renderers->data);
