@@ -124,16 +124,10 @@ gnc_tree_view_commodity_init (GncTreeViewCommodity *view)
 static void
 gnc_tree_view_commodity_finalize (GObject *object)
 {
-    GncTreeViewCommodity *view;
-    GncTreeViewCommodityPrivate *priv;
-
     g_return_if_fail (object != NULL);
     g_return_if_fail (GNC_IS_TREE_VIEW_COMMODITY (object));
 
     ENTER("view %p", object);
-    view = GNC_TREE_VIEW_COMMODITY (object);
-    priv = GNC_TREE_VIEW_COMMODITY_GET_PRIVATE (view);
-
     if (G_OBJECT_CLASS (parent_class)->finalize)
         (* G_OBJECT_CLASS (parent_class)->finalize) (object);
     LEAVE(" ");
@@ -142,13 +136,10 @@ gnc_tree_view_commodity_finalize (GObject *object)
 static void
 gnc_tree_view_commodity_destroy (GtkObject *object)
 {
-    GncTreeViewCommodity *view;
-
     g_return_if_fail (object != NULL);
     g_return_if_fail (GNC_IS_TREE_VIEW_COMMODITY (object));
 
     ENTER("view %p", object);
-    view = GNC_TREE_VIEW_COMMODITY (object);
 
     if (GTK_OBJECT_CLASS (parent_class)->destroy)
         (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
@@ -487,50 +478,7 @@ gnc_tree_view_commodity_new (QofBook *book,
     g_free(path_string);				\
   }
 
-#if 0
-static GtkTreePath *
-gnc_tree_view_commodity_get_path_from_commodity (GncTreeViewCommodity *view,
-        gnc_commodity *commodity)
-{
-    GtkTreeModel *model, *f_model, *s_model;
-    GtkTreePath *path, *f_path, *s_path;
-
-    ENTER("view %p, commodity %p (%s)", view, commodity, gnc_commodity_get_name(commodity));
-
-    if (commodity == NULL)
-    {
-        LEAVE("no commodity");
-        return NULL;
-    }
-
-    /* Reach down to the real model and get a path for this commodity */
-    s_model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
-    f_model = gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(s_model));
-    model = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER(f_model));
-    path = gnc_tree_model_commodity_get_path_from_commodity (GNC_TREE_MODEL_COMMODITY(model), commodity);
-    if (path == NULL)
-    {
-        LEAVE("no path");
-        return NULL;
-    }
-
-    /* convert back to a filtered path */
-    f_path = gtk_tree_model_filter_convert_child_path_to_path (GTK_TREE_MODEL_FILTER (f_model), path);
-    gtk_tree_path_free(path);
-    if (!f_path)
-    {
-        LEAVE("no filter path");
-        return NULL;
-    }
-
-    /* convert back to a sorted path */
-    s_path = gtk_tree_model_filter_convert_child_path_to_path (GTK_TREE_MODEL_SORT (s_model), f_path);
-    gtk_tree_path_free(f_path);
-    debug_path(LEAVE, s_path);
-    return s_path;
-}
-#endif
-
+#if 0 /* Not Used */
 static gboolean
 gnc_tree_view_commodity_get_iter_from_commodity (GncTreeViewCommodity *view,
         gnc_commodity *commodity,
@@ -563,98 +511,7 @@ gnc_tree_view_commodity_get_iter_from_commodity (GncTreeViewCommodity *view,
     LEAVE(" ");
     return TRUE;
 }
-
-gint
-gnc_tree_view_commodity_count_children (GncTreeViewCommodity *view,
-                                        gnc_commodity *commodity)
-{
-    GtkTreeModel *s_model;
-    GtkTreeIter s_iter;
-    gint num_children;
-
-    ENTER("view %p, commodity %p (%s)", view, commodity, gnc_commodity_get_mnemonic(commodity));
-
-    if (commodity == NULL)
-    {
-        LEAVE("no commodity");
-        return 0;
-    }
-
-    if (!gnc_tree_view_commodity_get_iter_from_commodity (view, commodity, &s_iter))
-    {
-        LEAVE("view_get_iter_from_commodity failed");
-        return 0;
-    }
-
-    /* Any children? */
-    s_model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
-    num_children = gtk_tree_model_iter_n_children(s_model, &s_iter);
-    LEAVE("%d children", num_children);
-    return num_children;
-}
-
-
-gnc_commodity *
-gnc_tree_view_commodity_get_commodity_from_column (GtkTreeViewColumn *column,
-        GtkTreeModel *s_model,
-        GtkTreeIter  *s_iter)
-{
-    GtkTreeModel *model, *f_model;
-    GtkTreeIter iter, f_iter;
-    gnc_commodity *commodity;
-
-    g_return_val_if_fail (GTK_IS_TREE_VIEW_COLUMN(column), NULL);
-    g_return_val_if_fail (GTK_IS_TREE_MODEL_SORT(s_model), NULL);
-    g_return_val_if_fail (s_iter != NULL, NULL);
-
-    ENTER("column %p, model %p, iter %p", column, s_model, s_iter);
-    gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT(s_model),
-            &f_iter,
-            s_iter);
-    f_model = gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(s_model));
-    gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER(f_model),
-            &iter,
-            &f_iter);
-    model = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER(f_model));
-    commodity = gnc_tree_model_commodity_get_commodity (GNC_TREE_MODEL_COMMODITY(model), &iter);
-    LEAVE("commodity %p (%s)", commodity, gnc_commodity_get_mnemonic (commodity));
-    return commodity;
-}
-
-/************************************************************/
-/*            Commodity Tree View Filter Functions            */
-/************************************************************/
-
-/*
- * Set the list of columns that will be visible in an commodity tree view.
- */
-void
-gnc_tree_view_commodity_configure_columns (GncTreeViewCommodity *view,
-        GSList *column_names)
-{
-    GtkTreeViewColumn *column;
-    GSList *node;
-    int i;
-
-    ENTER(" ");
-
-    for (i = 1; i < GNC_TREE_MODEL_COMMODITY_NUM_COLUMNS; i++)
-    {
-        column = gtk_tree_view_get_column (GTK_TREE_VIEW(view), i);
-        gtk_tree_view_column_set_visible (column, FALSE);
-    }
-
-    for (node = column_names; node != NULL; node = node->next)
-    {
-        for (i = 0; i < GNC_TREE_MODEL_COMMODITY_NUM_COLUMNS; i++)
-        {
-            column = gtk_tree_view_get_column (GTK_TREE_VIEW(view), i);
-            gtk_tree_view_column_set_visible (column, TRUE);
-        }
-    }
-
-    LEAVE(" ");
-}
+#endif /* Not Used */
 
 /************************************************************/
 /*          Commodity Tree View Visibility Filter           */
@@ -665,7 +522,7 @@ typedef struct
     gnc_tree_view_commodity_ns_filter_func user_ns_fn;
     gnc_tree_view_commodity_cm_filter_func user_cm_fn;
     gpointer                               user_data;
-    GtkDestroyNotify                       user_destroy;
+    GDestroyNotify                         user_destroy;
 } filter_user_data;
 
 static void
@@ -723,7 +580,7 @@ gnc_tree_view_commodity_set_filter (GncTreeViewCommodity *view,
                                     gnc_tree_view_commodity_ns_filter_func ns_func,
                                     gnc_tree_view_commodity_cm_filter_func cm_func,
                                     gpointer data,
-                                    GtkDestroyNotify destroy)
+                                    GDestroyNotify destroy)
 {
     GtkTreeModel *f_model, *s_model;
     filter_user_data *fd = data;
@@ -775,54 +632,6 @@ gnc_tree_view_commodity_refilter (GncTreeViewCommodity *view)
 /*           Commodity Tree View Get/Set Functions            */
 /************************************************************/
 
-/*
- * Retrieve the selected commodity from an commodity tree view.  The
- * commodity tree must be in single selection mode.
- */
-gnc_commodity *
-gnc_tree_view_commodity_get_commodity_from_path (GncTreeViewCommodity *view,
-        GtkTreePath *s_path)
-{
-    GtkTreeModel *model, *f_model, *s_model;
-    GtkTreePath *path, *f_path;
-    GtkTreeIter iter;
-    gnc_commodity *commodity;
-
-    g_return_val_if_fail (GNC_IS_TREE_VIEW_COMMODITY (view), NULL);
-    g_return_val_if_fail (s_path != NULL, NULL);
-
-    ENTER("view %p", view);
-    s_model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
-    f_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT (s_model), s_path);
-    if (!f_path)
-    {
-        LEAVE("no filter path");
-        return NULL;
-    }
-
-    f_model = gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(s_model));
-    path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER (f_model), f_path);
-    gtk_tree_path_free(f_path);
-    if (!path)
-    {
-        LEAVE("no path");
-        return NULL;
-    }
-
-    model = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER(f_model));
-    if (!gtk_tree_model_get_iter (model, &iter, path))
-    {
-        LEAVE("no iter");
-        return NULL;
-    }
-
-    commodity = gnc_tree_model_commodity_get_commodity (GNC_TREE_MODEL_COMMODITY(model),
-                &iter);
-    gtk_tree_path_free(path);
-    LEAVE("commodity %p (%s)", commodity, gnc_commodity_get_mnemonic (commodity));
-    return commodity;
-}
-
 /*
  * Retrieve the selected commodity from an commodity tree view.  The
  * commodity tree must be in single selection mode.
@@ -861,79 +670,8 @@ gnc_tree_view_commodity_get_selected_commodity (GncTreeViewCommodity *view)
     return commodity;
 }
 
-/*
- * Selects a single commodity in the commodity tree view.  The commodity
- * tree must be in single selection mode.
- */
-void
-gnc_tree_view_commodity_set_selected_commodity (GncTreeViewCommodity *view,
-        gnc_commodity *commodity)
-{
-    GtkTreeModel *model, *f_model, *s_model;
-    GtkTreePath *path, *f_path, *s_path, *parent_path;
-    GtkTreeSelection *selection;
-
-    ENTER("view %p, commodity %p (%s)", view,
-          commodity, gnc_commodity_get_mnemonic (commodity));
-
-    /* Clear any existing selection. */
-    selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
-    gtk_tree_selection_unselect_all (selection);
-
-    if (commodity == NULL)
-    {
-        LEAVE("");
-        return;
-    }
-
-    s_model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
-    f_model = gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(s_model));
-    model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (f_model));
-
-    path = gnc_tree_model_commodity_get_path_from_commodity (GNC_TREE_MODEL_COMMODITY(model), commodity);
-    if (path == NULL)
-    {
-        LEAVE("get_path_from_commodity failed");
-        return;
-    }
-    debug_path(DEBUG, path);
-
-    f_path = gtk_tree_model_filter_convert_child_path_to_path (GTK_TREE_MODEL_FILTER (f_model),
-             path);
-    gtk_tree_path_free(path);
-    if (f_path == NULL)
-    {
-        LEAVE("no filter path");
-        return;
-    }
-    debug_path(DEBUG, f_path);
-
-    s_path = gtk_tree_model_sort_convert_child_path_to_path (GTK_TREE_MODEL_SORT (s_model),
-             f_path);
-    gtk_tree_path_free(f_path);
-    if (s_path == NULL)
-    {
-        LEAVE("no sort path");
-        return;
-    }
-
-    /* gtk_tree_view requires that a row be visible before it can be selected */
-    parent_path = gtk_tree_path_copy (s_path);
-    if (gtk_tree_path_up (parent_path))
-    {
-        /* This function is misnamed.  It expands the actual item
-         * specified, not the path to the item specified. I.E. It expands
-         * one level too many, thus the get of the parent. */
-        gtk_tree_view_expand_to_path(GTK_TREE_VIEW(view), parent_path);
-    }
-    gtk_tree_path_free(parent_path);
-
-    gtk_tree_selection_select_path (selection, s_path);
-    gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW(view), s_path, NULL, FALSE, 0.0, 0.0);
-    debug_path(LEAVE, s_path);
-    gtk_tree_path_free(s_path);
-}
 
+#if 0 /* Not Used */
 /*
  * This helper function is called once for each row in the tree view
  * that is currently selected.  Its task is to an the corresponding
@@ -962,121 +700,4 @@ get_selected_commodities_helper (GtkTreeModel *s_model,
                 &iter);
     *return_list = g_list_append(*return_list, commodity);
 }
-
-/*
- * Given an commodity tree view, return a list of the selected commodities. The
- * commodity tree must be in multiple selection mode.
- *
- * Note: It is the responsibility of the caller to free the returned
- * list.
- */
-GList *
-gnc_tree_view_commodity_get_selected_commodities (GncTreeViewCommodity *view)
-{
-    GtkTreeSelection *selection;
-    GList *return_list = NULL;
-
-    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(view));
-    gtk_tree_selection_selected_foreach(selection, get_selected_commodities_helper, &return_list);
-    return return_list;
-}
-
-/*
- * Given an commodity tree view and a list of commodities, select those
- * commodities in the tree view.
- */
-void
-gnc_tree_view_commodity_set_selected_commodities (GncTreeViewCommodity *view,
-        GList *commodity_list,
-        gboolean show_last)
-{
-    GtkTreeModel *model, *f_model, *s_model;
-    GtkTreePath *path, *f_path, *s_path, *parent_path;
-    GtkTreeSelection *selection;
-    GList *element;
-    gnc_commodity *commodity;
-
-    s_model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
-    f_model = gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(s_model));
-    model = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER(f_model));
-
-    /* Clear any existing selection. */
-    selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
-    gtk_tree_selection_unselect_all (selection);
-    gtk_tree_view_collapse_all (GTK_TREE_VIEW(view));
-
-    /* Now go select what the user requested. */
-    for (element = commodity_list; element; )
-    {
-        commodity = element->data;
-        element = g_list_next(element);
-
-        path = gnc_tree_model_commodity_get_path_from_commodity (GNC_TREE_MODEL_COMMODITY(model), commodity);
-        if (path == NULL)
-        {
-            /*
-             * Oops.  Someone must have deleted this commodity and not cleaned
-             * up all references to it.
-             */
-            continue;
-        }
-
-        f_path = gtk_tree_model_filter_convert_child_path_to_path (GTK_TREE_MODEL_FILTER (f_model),
-                 path);
-        gtk_tree_path_free(path);
-        if (f_path == NULL)
-            continue;
-
-        s_path = gtk_tree_model_sort_convert_child_path_to_path (GTK_TREE_MODEL_SORT (s_model),
-                 f_path);
-        gtk_tree_path_free(f_path);
-        if (s_path == NULL)
-            continue;
-
-        /* gtk_tree_view requires that a row be visible before it can be selected */
-        parent_path = gtk_tree_path_copy (s_path);
-        if (gtk_tree_path_up (parent_path))
-        {
-            /* This function is misnamed.  It expands the actual item
-             * specified, not the path to the item specified. I.E. It
-             * expands one level too many, thus the get of the parent. */
-            gtk_tree_view_expand_to_path(GTK_TREE_VIEW(view), parent_path);
-        }
-        gtk_tree_path_free(parent_path);
-
-        gtk_tree_selection_select_path (selection, s_path);
-        if (show_last && (element == NULL))
-            gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW(view), s_path, NULL, FALSE, 0.0, 0.0);
-        gtk_tree_path_free(s_path);
-    }
-}
-
-#ifdef NEEDED
-/*
- * Retrieve the commodity currently under the cursor.
- */
-gnc_commodity *
-gnc_tree_view_commodity_get_cursor_account (GncTreeViewCommodity *view)
-{
-    GtkTreeModel *s_model;
-    GtkTreePath *s_path;
-    gnc_commodity *commodity;
-
-    g_return_val_if_fail (GNC_IS_TREE_VIEW_COMMODITY (view), NULL);
-
-    ENTER("view %p", view);
-    s_model = gtk_tree_view_get_model (GTK_TREE_VIEW(view));
-    gtk_tree_view_get_cursor (GTK_TREE_VIEW(view), &s_path, NULL);
-    if (s_path)
-    {
-        account = gnc_tree_view_commodity_get_account_from_path (view, s_path);
-        gtk_tree_path_free(s_path);
-    }
-    else
-    {
-        account = NULL;
-    }
-    LEAVE("account %p (%s)", account, gnc_commodity_get_mnemonic (account));
-    return account;
-}
-#endif
+#endif /* Not Used */
