@@ -43,22 +43,7 @@
 #include "gnc-gconf-utils.h"
 #include "gnc-gnome-utils.h"
 #include "gnc-gobject-utils.h"
-
-/* The column id refers to a specific column in the tree model.  It is
- * also attached to the side of the tree column to allow lookup of a
- * GtkTreeViewColumn when passed a column id from the underlying
- * model. By convention, negative column numbers are used when the
- * visible column has no association with the underlying model.*/
-#define MODEL_COLUMN "model_column"
-
-/* For checkbox columns, this contains the real title for the column. */
-#define REAL_TITLE  "real_title"
-
-/* The name of this column as it should appear in gconf.  This is
- * attached to the column when it is created, and used to map back and
- * forth to gconf keys.  The actual gconf keys are built from these
- * strings. */
-#define PREF_NAME  "pref-name"
+#include "gnc-cell-renderer-date.h"
 
 /* The actual gconf key for a particular column visibility.  This is
  * attached to the menu items that are in the column selection menu.
@@ -117,8 +102,6 @@ static void gnc_tree_view_select_column_cb (GtkTreeViewColumn *column,
 
 typedef struct GncTreeViewPrivate
 {
-    GtkTooltips       *title_tips;
-
     /*  Spacer column */
     GtkTreeViewColumn *spacer_column;
     GtkTreeViewColumn *selection_column;
@@ -128,6 +111,9 @@ typedef struct GncTreeViewPrivate
     GtkWidget         *column_menu;
     gboolean           show_column_menu;
 
+    /* Sort callback model */
+    GtkTreeModel      *sort_model;
+
     /* Gconf related values */
     gchar             *gconf_section;
     gboolean           seen_gconf_visibility;
@@ -252,6 +238,7 @@ gnc_tree_view_init (GncTreeView *view, GncTreeViewClass *klass)
     priv = GNC_TREE_VIEW_GET_PRIVATE(view);
     priv->column_menu = NULL;
     priv->show_column_menu = FALSE;
+    priv->sort_model = NULL;
     priv->gconf_section = NULL;
     priv->seen_gconf_visibility = FALSE;
     priv->columns_changed_cb_id = 0;
@@ -276,6 +263,8 @@ gnc_tree_view_init (GncTreeView *view, GncTreeViewClass *klass)
                  (gchar *)NULL);
     priv->spacer_column = column;
 
+    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
+
     /* Create the last column which contains the column selection
      * widget.  gnc_tree_view_add_text_column will do most of the
      * work. */
@@ -295,6 +284,8 @@ gnc_tree_view_init (GncTreeView *view, GncTreeViewClass *klass)
                      G_CALLBACK (gnc_tree_view_select_column_cb),
                      view);
     priv->column_menu_column = column;
+
+    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
 }
 
 /** Finalize the GncTreeView object.  This function is called from the
@@ -310,18 +301,12 @@ gnc_tree_view_init (GncTreeView *view, GncTreeViewClass *klass)
 static void
 gnc_tree_view_finalize (GObject *object)
 {
-    GncTreeView *view;
-    GncTreeViewPrivate *priv;
-
     ENTER("view %p", object);
     g_return_if_fail (object != NULL);
     g_return_if_fail (GNC_IS_TREE_VIEW (object));
 
     gnc_gobject_tracking_forget(object);
 
-    view = GNC_TREE_VIEW (object);
-    priv = GNC_TREE_VIEW_GET_PRIVATE (view);
-
     if (G_OBJECT_CLASS (parent_class)->finalize)
         G_OBJECT_CLASS (parent_class)->finalize (object);
     LEAVE(" ");
@@ -357,7 +342,7 @@ gnc_tree_view_destroy (GtkObject *object)
     if (priv->column_menu)
     {
         DEBUG("removing column selection menu");
-        gtk_widget_unref(priv->column_menu);
+        g_object_unref(priv->column_menu);
         priv->column_menu = NULL;
     }
 
@@ -758,7 +743,6 @@ gtk_tree_view_size_allocate_cb (GtkWidget *widget,
     GList *column_list;
 
     g_return_if_fail(GNC_IS_TREE_VIEW(widget));
-
     view = GNC_TREE_VIEW(widget);
     column_list = gtk_tree_view_get_columns(GTK_TREE_VIEW(view));
     g_list_foreach(column_list, (GFunc)gtk_tree_view_size_allocate_helper, view);
@@ -977,6 +961,7 @@ gnc_tree_view_set_sort_column (GncTreeView *view,
     if (!gtk_tree_sortable_get_sort_column_id(GTK_TREE_SORTABLE(s_model),
             &current, &order))
         order = GTK_SORT_ASCENDING;
+
     g_signal_handler_block(s_model, priv->sort_column_changed_cb_id);
     gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(s_model),
                                          model_column, order);
@@ -1076,6 +1061,7 @@ gnc_tree_view_gconf_changed (GConfClient *client,
     priv = GNC_TREE_VIEW_GET_PRIVATE(view);
     key = gconf_entry_get_key(entry);
     value = gconf_entry_get_value(entry);
+
     if (!value)
     {
         /* Values can be unset */
@@ -1102,7 +1088,7 @@ gnc_tree_view_gconf_changed (GConfClient *client,
         /* Make a copy of the local part of the key so it can be split
          * into column name and key type */
         known = FALSE;
-        column_name = strdup(local);
+        column_name = g_strdup(local);
         type_name = strrchr(column_name, '_');
         *type_name++ = '\0';
 
@@ -1398,7 +1384,6 @@ gnc_tree_view_create_menu_item (GtkTreeViewColumn *column,
     GncTreeViewPrivate *priv;
     GtkWidget *widget;
     const gchar *column_name, *pref_name;
-    gulong id;
     gchar *key;
 
     // ENTER("view %p, column %p", view, column);
@@ -1438,8 +1423,8 @@ gnc_tree_view_create_menu_item (GtkTreeViewColumn *column,
     }
 
     /* Set up the callback  */
-    id = g_signal_connect(widget, "toggled",
-                          (GCallback)gnc_tree_view_menu_item_toggled, view);
+    g_signal_connect(widget, "toggled",
+		     (GCallback)gnc_tree_view_menu_item_toggled, view);
 
     /* Store data on the widget for callbacks */
     key = g_strdup_printf("%s_%s", pref_name, GCONF_KEY_VISIBLE);
@@ -1472,7 +1457,7 @@ gnc_tree_view_build_column_menu (GncTreeView *view)
     /* Destroy any old menu */
     if (priv->column_menu)
     {
-        gtk_widget_unref(priv->column_menu);
+        g_object_unref(priv->column_menu);
         priv->column_menu = NULL;
     }
 
@@ -1558,7 +1543,7 @@ gnc_tree_view_select_column_cb (GtkTreeViewColumn *column,
                                 GncTreeView *view)
 {
     GncTreeViewPrivate *priv;
-    GtkWidget *widget, *menu;
+    GtkWidget *menu;
 
     g_return_if_fail(GTK_IS_TREE_VIEW_COLUMN(column));
     g_return_if_fail(GNC_IS_TREE_VIEW(view));
@@ -1577,7 +1562,6 @@ gnc_tree_view_select_column_cb (GtkTreeViewColumn *column,
     gtk_widget_show_all(menu);
 
     /* Pop the menu up at the button */
-    widget = gtk_tree_view_column_get_widget(column);
     gtk_menu_popup(GTK_MENU(priv->column_menu), NULL, GTK_WIDGET(menu),
                    NULL, NULL, 0, gtk_get_current_event_time());
 }
@@ -1626,11 +1610,71 @@ void gnc_tree_view_expand_columns (GncTreeView *view,
     va_end (args);
 
     gtk_tree_view_column_set_visible (priv->spacer_column, !hide_spacer);
-    gtk_tree_view_column_set_visible (priv->selection_column, !hide_spacer);
 
     LEAVE(" ");
 }
 
+
+/* Links the cell backgrounds of the two control columns to the model or
+   cell data function */
+static void
+update_control_cell_renderers_background (GncTreeView *view, GtkTreeViewColumn *col, gint column, GtkTreeCellDataFunc func )
+{
+    GList *renderers;
+    GtkCellRenderer *cell;
+    GList *node;
+
+    renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (col));
+
+    /* Update the cell background in the list of renderers */
+    for (node = renderers; node; node = node->next)
+    {
+        cell = node->data;
+        if (func == NULL)
+            gtk_tree_view_column_add_attribute (col, cell, "cell-background", column);
+        else
+            gtk_tree_view_column_set_cell_data_func (col, cell, func, view, NULL);
+    }
+    g_list_free (renderers);
+}
+
+
+/* This function links the cell backgrounds of the two control columns to a column
+   in the model that has color strings or a cell data function */
+void
+gnc_tree_view_set_control_column_background (GncTreeView *view, gint column, GtkTreeCellDataFunc func )
+{
+    GncTreeViewPrivate *priv;
+
+    g_return_if_fail (GNC_IS_TREE_VIEW (view));
+
+    ENTER("view %p, column %d, func %p", view, column, func);
+    priv = GNC_TREE_VIEW_GET_PRIVATE (view);
+
+    update_control_cell_renderers_background (view, priv->spacer_column, column, func);
+    update_control_cell_renderers_background (view, priv->selection_column, column, func);
+
+    LEAVE(" ");
+}
+
+
+/* This allows the columns to be setup without the model connected */
+//FIXME I think this should be specified as a parameter to the add columns functions...
+void
+gnc_tree_view_set_sort_user_data (GncTreeView *view, GtkTreeModel *s_model)
+{
+    GncTreeViewPrivate *priv;
+
+    g_return_if_fail (GNC_IS_TREE_VIEW (view));
+
+    ENTER("view %p, sort_model %p", view, s_model);
+    priv = GNC_TREE_VIEW_GET_PRIVATE (view);
+
+    priv->sort_model = s_model;
+    LEAVE(" ");
+}
+
+
 /** This function is called to set the "show-column-menu" property on
  *  this view.  This function has no visible effect if the
  *  "gconf-section" property has not been set.
@@ -1864,9 +1908,23 @@ gnc_tree_view_column_properties (GncTreeView *view,
         if (column_sort_fn)
         {
             gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE(s_model),
-                                             data_column, column_sort_fn,
-                                             GINT_TO_POINTER(data_column),
-                                             NULL /* destroy fn */);
+                                         data_column, column_sort_fn,
+                                         GINT_TO_POINTER(data_column),
+                                         NULL /* destroy fn */);
+        }
+    }
+
+    // Used in registers, sort model not connected to view yet
+    priv = GNC_TREE_VIEW_GET_PRIVATE(view);
+    if (priv->sort_model != NULL)
+    {
+        gtk_tree_view_column_set_sort_column_id (column, data_column);
+        if (column_sort_fn)
+        {
+            gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE(priv->sort_model),
+                                         data_column, column_sort_fn,
+                                         view,
+                                         NULL /* destroy fn */);
         }
     }
 
@@ -1897,13 +1955,11 @@ gnc_tree_view_add_toggle_column (GncTreeView *view,
                                  GtkTreeIterCompareFunc column_sort_fn,
                                  renderer_toggled toggle_edited_cb)
 {
-    GncTreeViewPrivate *priv;
     GtkTreeViewColumn *column;
     GtkCellRenderer *renderer;
 
     g_return_val_if_fail (GNC_IS_TREE_VIEW(view), NULL);
 
-    priv = GNC_TREE_VIEW_GET_PRIVATE(view);
     renderer = gtk_cell_renderer_toggle_new ();
     column =
         gtk_tree_view_column_new_with_attributes (column_short_title,
@@ -1929,9 +1985,7 @@ gnc_tree_view_add_toggle_column (GncTreeView *view,
     gnc_tree_view_append_column (view, column);
 
     /* Also add the full title to the object as a tooltip */
-    if (!priv->title_tips)
-        priv->title_tips = gtk_tooltips_new();
-    gtk_tooltips_set_tip(priv->title_tips, column->button, column_title, NULL);
+    gtk_widget_set_tooltip_text(column->button, column_title);
 
     return column;
 }
@@ -2001,6 +2055,73 @@ gnc_tree_view_add_text_column (GncTreeView *view,
     return column;
 }
 
+
+
+/** This function adds a new date column to a GncTreeView base view.
+ *  It takes all the parameters necessary to hook a GtkTreeModel
+ *  column to a GtkTreeViewColumn.  If the tree has a gconf section
+ *  associated with it, this function also wires up the column so that
+ *  its visibility and width are remembered.
+ *
+ *  Parameters are defined in gnc-tree-view.h
+ */
+GtkTreeViewColumn *
+gnc_tree_view_add_date_column (GncTreeView *view,
+                                   const gchar *column_title,
+                                   const gchar *pref_name,
+                                   const gchar *stock_icon_name,
+                                   const gchar *sizing_text,
+                                   gint model_data_column,
+                                   gint model_visibility_column,
+                                   GtkTreeIterCompareFunc column_sort_fn)
+{
+  GtkTreeViewColumn *column;
+  GtkCellRenderer *renderer;
+  PangoLayout* layout;
+  int default_width, title_width;
+
+  g_return_val_if_fail (GNC_IS_TREE_VIEW(view), NULL);
+
+  column = gtk_tree_view_column_new ();
+  gtk_tree_view_column_set_title (column, column_title);
+
+  /* Set up an icon renderer if requested */
+  if (stock_icon_name) {
+    renderer = gtk_cell_renderer_pixbuf_new ();
+    g_object_set (renderer, "stock-id", stock_icon_name, NULL);
+    gtk_tree_view_column_pack_start (column, renderer, FALSE);
+  }
+
+  /* Set up a text renderer and attributes */
+  renderer = gnc_cell_renderer_date_new(TRUE);
+  gtk_tree_view_column_pack_start (column, renderer, TRUE);
+
+  /* Set renderer attributes controlled by the model */
+  if (model_data_column != GNC_TREE_VIEW_COLUMN_DATA_NONE)
+    gtk_tree_view_column_add_attribute (column, renderer,
+					"text", model_data_column);
+  if (model_visibility_column != GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS)
+    gtk_tree_view_column_add_attribute (column, renderer,
+					"visible", model_visibility_column);
+
+  /* Default size is the larger of the column title and the sizing text */
+  layout = gtk_widget_create_pango_layout (GTK_WIDGET(view), column_title);
+  pango_layout_get_pixel_size(layout, &title_width, NULL);
+  g_object_unref(layout);
+  layout = gtk_widget_create_pango_layout (GTK_WIDGET(view), sizing_text);
+  pango_layout_get_pixel_size(layout, &default_width, NULL);
+  g_object_unref(layout);
+  default_width = MAX(default_width, title_width);
+  if (default_width)
+    default_width += 10; /* padding on either side */
+  gnc_tree_view_column_properties (view, column, pref_name, model_data_column,
+				   default_width, TRUE, column_sort_fn);
+
+  gnc_tree_view_append_column (view, column);
+  return column;
+}
+
+
 GtkTreeViewColumn *
 gnc_tree_view_add_combo_column (GncTreeView *view,
                                 const gchar *column_title,
@@ -2069,7 +2190,7 @@ gnc_tree_view_column_get_renderer(GtkTreeViewColumn *column)
     g_return_val_if_fail(GTK_TREE_VIEW_COLUMN(column), NULL);
 
     /* Get the list of one renderer */
-    renderers = gtk_tree_view_column_get_cell_renderers(column);
+    renderers = gtk_cell_layout_get_cells(GTK_CELL_LAYOUT(column));
     if (g_list_length(renderers) > 0)
         cr = GTK_CELL_RENDERER(renderers->data);
     g_list_free(renderers);
@@ -2223,6 +2344,12 @@ gnc_tree_view_keynav(GncTreeView *view, GtkTreeViewColumn **col,
             else
             {
                 gtk_tree_path_next(path);
+                if (!gnc_tree_view_path_is_valid(view, path) && depth > 2)
+                {
+                    gtk_tree_path_prev(path);
+                    gtk_tree_path_up(path);
+                    gtk_tree_path_next(path);
+                }
                 if (!gnc_tree_view_path_is_valid(view, path) && depth > 1)
                 {
                     gtk_tree_path_prev(path);
