@@ -32,8 +32,8 @@
 #ifndef __GNC_TREE_VIEW_H
 #define __GNC_TREE_VIEW_H
 
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtktreeview.h>
+#include <gtk/gtk.h>
+#include "gnc-cell-renderer-date.h"
 
 G_BEGIN_DECLS
 
@@ -68,6 +68,22 @@ GType gnc_tree_view_get_type (void);
    g_object_set_data(col, ATTRIBUTE_NAME, value);
 */
 
+/* The column id refers to a specific column in the tree model.  It is
+ * also attached to the side of the tree column to allow lookup of a
+ * GtkTreeViewColumn when passed a column id from the underlying
+ * model. By convention, negative column numbers are used when the
+ * visible column has no association with the underlying model.*/
+#define MODEL_COLUMN "model_column"
+
+/* For checkbox columns, this contains the real title for the column. */
+#define REAL_TITLE  "real_title"
+
+/* The name of this column as it should appear in gconf.  This is
+ * attached to the column when it is created, and used to map back and
+ * forth to gconf keys.  The actual gconf keys are built from these
+ * strings. */
+#define PREF_NAME  "pref-name"
+
 /* A column with this attribute set cannot be hidden from view. Valid
    values: GINT_TO_POINTER(0) and GINT_TO_POINTER(1) */
 #define ALWAYS_VISIBLE  "always-visible"
@@ -209,6 +225,22 @@ gnc_tree_view_add_combo_column (GncTreeView *view,
                                 gint combo_model_text_column,
                                 GtkTreeIterCompareFunc column_sort_fn);
 
+
+/** This function adds a new date column to a GncTreeView base
+ *  view.  The parameters it takes in common with
+ *  gnc_tree_view_add_text_column() behave the same as there.
+ */
+GtkTreeViewColumn *
+gnc_tree_view_add_date_column (GncTreeView *view,
+                                   const gchar *column_title,
+                                   const gchar *pref_name,
+                                   const gchar *stock_icon_name,
+                                   const gchar *sizing_text,
+                                   gint model_data_column,
+                                   gint model_visibility_column,
+                                   GtkTreeIterCompareFunc column_sort_fn);
+
+
 /** This function adds a new numeric column to a GncTreeView base
  *  view.  It takes all the parameters necessary to hook a
  *  GtkTreeModel column to a GtkTreeViewColumn.  If the tree has a
@@ -351,10 +383,40 @@ void gnc_tree_view_set_gconf_section (GncTreeView *view,
  */
 const gchar *gnc_tree_view_get_gconf_section (GncTreeView *view);
 
+/** This function set the columns that will be allocated the free space
+ *  in the view.
+ *
+ *  @param view The tree view.
+ *
+ *  @param list of column names.
+ */
 void gnc_tree_view_expand_columns (GncTreeView *view,
                                    gchar *first_column_name,
                                    ...);
 
+/** This function links the cell backgrounds of the two control columns
+ *  to a column in the model that has color strings or a cell data function
+ *  that sets the "cell-background" property.
+ *
+ *  @param view The tree view.
+ *
+ *  @param column The column in the model containing color strings.
+ *
+ *  @param func This is a cell data function that sets the "cell-background".
+ */
+void
+gnc_tree_view_set_control_column_background (GncTreeView *view, gint column,
+                                             GtkTreeCellDataFunc func);
+
+/** This allows the columns to be setup without the model connected
+ *
+ *  @param view The tree view.
+ *
+ *  @param sort model.
+ */
+void
+gnc_tree_view_set_sort_user_data (GncTreeView *view, GtkTreeModel *s_model);
+
 /** This function is called to set the "show-column-menu" property on
  *  this view.  This function has no visible effect if the
  *  "gconf-section" property has not been set.
