@@ -87,8 +87,8 @@ typedef struct
     gboolean euro;
     gboolean grand_total;
     gboolean non_currency;
-    time_t start_date;
-    time_t end_date;
+    time64 start_date;
+    time64 end_date;
 } GNCSummarybarOptions;
 
 /**
@@ -196,11 +196,11 @@ gnc_ui_accounts_recurse (Account *parent, GList **currency_list,
         case ACCT_TYPE_PAYABLE:
         case ACCT_TYPE_RECEIVABLE:
             end_amount = xaccAccountGetBalanceAsOfDate(account, options.end_date);
-            timespecFromTime_t(&end_timespec, options.end_date);
+            timespecFromTime64(&end_timespec, options.end_date);
             end_amount_default_currency =
                 xaccAccountConvertBalanceToCurrencyAsOfDate
                 (account, end_amount, account_currency, options.default_currency,
-                 timespecToTime_t(timespecCanonicalDayTime(end_timespec)));
+                 timespecToTime64(timespecCanonicalDayTime(end_timespec)));
 
             if (!non_currency || options.non_currency)
             {
@@ -240,17 +240,17 @@ gnc_ui_accounts_recurse (Account *parent, GList **currency_list,
         case ACCT_TYPE_INCOME:
         case ACCT_TYPE_EXPENSE:
             start_amount = xaccAccountGetBalanceAsOfDate(account, options.start_date);
-            timespecFromTime_t(&start_timespec, options.start_date);
+            timespecFromTime64(&start_timespec, options.start_date);
             start_amount_default_currency =
                 xaccAccountConvertBalanceToCurrencyAsOfDate
                 (account, start_amount, account_currency, options.default_currency,
-                 timespecToTime_t(timespecCanonicalDayTime(start_timespec)));
+                 timespecToTime64(timespecCanonicalDayTime(start_timespec)));
             end_amount = xaccAccountGetBalanceAsOfDate(account, options.end_date);
-            timespecFromTime_t(&end_timespec, options.end_date);
+            timespecFromTime64(&end_timespec, options.end_date);
             end_amount_default_currency =
                 xaccAccountConvertBalanceToCurrencyAsOfDate
                 (account, end_amount, account_currency, options.default_currency,
-                 timespecToTime_t(timespecCanonicalDayTime(end_timespec)));
+                 timespecToTime64(timespecCanonicalDayTime(end_timespec)));
 
             if (!non_currency || options.non_currency)
             {
@@ -385,7 +385,13 @@ gnc_main_window_summary_refresh (GNCMainSummary * summary)
     GList *current;
     GNCSummarybarOptions options;
 
-    options.default_currency = gnc_default_report_currency ();
+
+    root = gnc_get_current_root_account ();
+    options.default_currency = xaccAccountGetCommodity(root);
+    if (options.default_currency == NULL)
+    {
+        options.default_currency = gnc_default_currency ();
+    }
 
     options.euro = gnc_gconf_get_bool(GCONF_GENERAL, KEY_ENABLE_EURO, NULL);
     options.grand_total =
@@ -407,7 +413,6 @@ gnc_main_window_summary_refresh (GNCMainSummary * summary)
     gnc_ui_get_currency_accumulator (&currency_list, options.default_currency,
                                      TOTAL_SINGLE);
 
-    root = gnc_get_current_root_account ();
     gnc_ui_accounts_recurse(root, &currency_list, options);
 
     {
