@@ -24,19 +24,20 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libguile.h>
 
 #include "dialog-new-user.h"
 #include "dialog-utils.h"
-#include "druid-hierarchy.h"
 #include "dialog-file-access.h"
+#include "assistant-hierarchy.h"
 #include "gnc-engine.h"
 #include "gnc-gconf-utils.h"
 #include "gnc-hooks.h"
 #include "gnc-ui.h"
+#include "gnc-file.h"
 #include "gnc-main-window.h"
 #include "gnc-plugin-page-account-tree.h"
 #include "gnc-session.h"
+#include "app-utils/gnc-ui-util.h" // for gnc_get_current_book
 
 #define GCONF_SECTION "dialogs/new_user"
 #define FIRST_STARTUP "first_startup"
@@ -44,16 +45,16 @@
 /* This static indicates the debugging module that this .o belongs to.  */
 static QofLogModule log_module = GNC_MOD_GUI;
 
-/* function to open a qif import druid */
-static void (*qifImportDruidFcn)(void) = NULL;
+/* function to open a qif import assistant */
+static void (*qifImportAssistantFcn)(void) = NULL;
 
 static void gnc_ui_new_user_cancel_dialog (void);
 
 void
-gnc_new_user_dialog_register_qif_druid (void (*cb_fcn)(void))
+gnc_new_user_dialog_register_qif_assistant (void (*cb_fcn)(void))
 {
-    g_return_if_fail (qifImportDruidFcn == NULL);
-    qifImportDruidFcn = cb_fcn;
+    g_return_if_fail (qifImportAssistantFcn == NULL);
+    qifImportAssistantFcn = cb_fcn;
 }
 
 void
@@ -63,7 +64,7 @@ gnc_set_first_startup (gboolean first_startup)
 }
 
 static void
-after_hierarchy_druid(void)
+after_hierarchy_assistant(void)
 {
     GncPluginPage *page;
 
@@ -72,6 +73,7 @@ after_hierarchy_druid(void)
 
     page = gnc_plugin_page_account_tree_new();
     gnc_main_window_open_page(NULL, page);
+    qof_book_mark_session_dirty(gnc_get_current_book());
     gnc_ui_file_access_for_save_as();
 }
 
@@ -82,22 +84,23 @@ gnc_ui_new_user_dialog (void)
     GtkWidget *new_accounts_button;
     GtkWidget *import_qif_button;
     GtkWidget *tutorial_button;
-    GladeXML  *xml;
+    GtkBuilder  *builder;
     gint result;
 
     ENTER(" ");
-    xml = gnc_glade_xml_new ("newuser.glade", "New User Dialog");
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-new-user.glade", "New User Dialog");
 
-    dialog = glade_xml_get_widget (xml, "New User Dialog");
+    dialog = GTK_WIDGET(gtk_builder_get_object (builder, "New User Dialog"));
 
-    new_accounts_button = glade_xml_get_widget (xml, "new_accounts_button");
-    import_qif_button = glade_xml_get_widget (xml, "import_qif_button");
-    tutorial_button = glade_xml_get_widget (xml, "tutorial_button");
+    new_accounts_button = GTK_WIDGET(gtk_builder_get_object (builder, "new_accounts_button"));
+    import_qif_button = GTK_WIDGET(gtk_builder_get_object (builder, "import_qif_button"));
+    tutorial_button = GTK_WIDGET(gtk_builder_get_object (builder, "tutorial_button"));
 
     /* Set the sensitivity of the qif-import button based on the availability
-     * of the qif-import druid.
+     * of the qif-import assistant.
      */
-    gtk_widget_set_sensitive (import_qif_button, (qifImportDruidFcn != NULL));
+    gtk_widget_set_sensitive (import_qif_button, (qifImportAssistantFcn != NULL));
 
     result = gtk_dialog_run (GTK_DIALOG (dialog));
     switch (result)
@@ -109,27 +112,27 @@ gnc_ui_new_user_dialog (void)
     case GTK_RESPONSE_OK:
         if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (new_accounts_button)))
         {
-            gnc_ui_hierarchy_druid_with_callback(TRUE, after_hierarchy_druid);
-            break;
+            gnc_ui_hierarchy_assistant_with_callback(TRUE, after_hierarchy_assistant);
         }
-        else if ((qifImportDruidFcn != NULL)
+        else if ((qifImportAssistantFcn != NULL)
                  && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (import_qif_button)))
         {
-            qifImportDruidFcn();
+            qifImportAssistantFcn();
             gncp_new_user_finish ();
-            break;
         }
         else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (tutorial_button)))
         {
             gnc_gnome_help (HF_GUIDE, NULL);
             gncp_new_user_finish ();
-            break;
         }
+        break;
     default:
         g_print ("DEBUG: Response: %d", result);
         g_assert_not_reached ();
+        break;
     }
 
+    g_object_unref(G_OBJECT(builder));
     gtk_widget_destroy (dialog);
     LEAVE(" ");
 }
@@ -138,13 +141,14 @@ static void
 gnc_ui_new_user_cancel_dialog (void)
 {
     GtkWidget *dialog;
-    GladeXML  *xml;
+    GtkBuilder  *builder;
     gint result;
     gboolean keepshowing;
 
-    xml = gnc_glade_xml_new ("newuser.glade", "New User Cancel Dialog");
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-new-user.glade", "New User Cancel Dialog");
 
-    dialog = glade_xml_get_widget (xml, "New User Cancel Dialog");
+    dialog = GTK_WIDGET(gtk_builder_get_object (builder, "New User Cancel Dialog"));
 
     result = gtk_dialog_run (GTK_DIALOG (dialog));
     keepshowing = (result == GTK_RESPONSE_YES);
@@ -152,6 +156,7 @@ gnc_ui_new_user_cancel_dialog (void)
     gnc_set_first_startup (keepshowing);
     gncp_new_user_finish ();
 
+    g_object_unref(G_OBJECT(builder));
     gtk_widget_destroy(dialog);
 }
 
