@@ -3,6 +3,7 @@
  * Copyright (C) 2001 Gnumatic, Inc.                                *
  * Author: Dave Peticolas <dave@krondo.com>                         *
  * Copyright (C) 2003,2005 David Hampton                            *
+ * Copyright (C) 2011 Robert Fewell                                 *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
@@ -45,7 +46,7 @@
 #include "gnc-ui.h"
 #include "gnc-ui-util.h"
 #include "guile-util.h"
-#include "engine-helpers.h"
+#include "engine-helpers-guile.h"
 #include "swig-runtime.h"
 
 
@@ -98,6 +99,7 @@ gnc_prices_dialog_window_destroy_cb (GtkObject *object, gpointer data)
     LEAVE(" ");
 }
 
+
 void
 gnc_prices_dialog_close_cb (GtkDialog *dialog, gpointer data)
 {
@@ -108,6 +110,7 @@ gnc_prices_dialog_close_cb (GtkDialog *dialog, gpointer data)
     LEAVE(" ");
 }
 
+
 void
 gnc_prices_dialog_response (GtkDialog *dialog, gint response_id, gpointer data)
 {
@@ -118,6 +121,7 @@ gnc_prices_dialog_response (GtkDialog *dialog, gint response_id, gpointer data)
     LEAVE(" ");
 }
 
+
 void
 gnc_prices_dialog_edit_clicked (GtkWidget *widget, gpointer data)
 {
@@ -144,12 +148,14 @@ gnc_prices_dialog_edit_clicked (GtkWidget *widget, gpointer data)
     LEAVE(" ");
 }
 
+
 static void
 remove_helper(GNCPrice *price, GNCPriceDB *pdb)
 {
     gnc_pricedb_remove_price (pdb, price);
 }
 
+
 void
 gnc_prices_dialog_remove_clicked (GtkWidget *widget, gpointer data)
 {
@@ -174,7 +180,7 @@ gnc_prices_dialog_remove_clicked (GtkWidget *widget, gpointer data)
         message = g_strdup_printf
                   (/* Translators: %d is the number of prices. This
 	  is a ngettext(3) message. */
-                      ngettext("Are you sure you want to delete the %d selected price?",
+                      ngettext("Are you sure you want to delete the selected price?",
                                "Are you sure you want to delete the %d selected prices?",
                                length),
                       length);
@@ -207,22 +213,33 @@ gnc_prices_dialog_remove_clicked (GtkWidget *widget, gpointer data)
     LEAVE(" ");
 }
 
+
 void
 gnc_prices_dialog_remove_old_clicked (GtkWidget *widget, gpointer data)
 {
     PricesDialog *pdb_dialog = data;
-    GladeXML *xml;
-    GtkWidget *dialog, *button, *date, *label;
+    GtkBuilder *builder;
+    GtkWidget *dialog, *button, *date, *label, *box;
     gint result;
     gboolean delete_user, delete_last;
 
     ENTER(" ");
-    xml = gnc_glade_xml_new ("price.glade", "Deletion Date");
-    dialog = glade_xml_get_widget (xml, "Deletion Date");
-    date = glade_xml_get_widget (xml, "date");
-    label = glade_xml_get_widget (xml, "date_label");
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-price.glade", "Deletion Date");
+
+    dialog = GTK_WIDGET(gtk_builder_get_object (builder, "Deletion Date"));
+
+    box = GTK_WIDGET(gtk_builder_get_object (builder, "date_hbox"));
+    date = gnc_date_edit_new (time (NULL), FALSE, FALSE);
+
+    gtk_box_pack_start (GTK_BOX (box), date, TRUE, TRUE, 0);
+    gtk_widget_show (date);
+    gtk_entry_set_activates_default(GTK_ENTRY(GNC_DATE_EDIT(date)->date_entry), TRUE);
+    label = GTK_WIDGET(gtk_builder_get_object (builder, "date_label"));
     gnc_date_make_mnemonic_target (GNC_DATE_EDIT(date), label);
-    glade_xml_signal_autoconnect_full(xml, gnc_glade_autoconnect_full_func, pdb_dialog);
+
+    gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, pdb_dialog);
+
     gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (pdb_dialog->dialog));
 
     result = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -234,9 +251,9 @@ gnc_prices_dialog_remove_old_clicked (GtkWidget *widget, gpointer data)
         ts.tv_sec = gnc_date_edit_get_date (GNC_DATE_EDIT (date));
         ts.tv_nsec = 0;
 
-        button = glade_xml_get_widget (xml, "delete_manual");
+        button = GTK_WIDGET(gtk_builder_get_object (builder, "delete_manual"));
         delete_user = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
-        button = glade_xml_get_widget (xml, "delete_last");
+        button = GTK_WIDGET(gtk_builder_get_object (builder, "delete_last"));
         delete_last = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
 
         gnc_pricedb_remove_old_prices(pdb_dialog->price_db, ts,
@@ -247,6 +264,7 @@ gnc_prices_dialog_remove_old_clicked (GtkWidget *widget, gpointer data)
     LEAVE(" ");
 }
 
+
 void
 gnc_prices_dialog_add_clicked (GtkWidget *widget, gpointer data)
 {
@@ -266,6 +284,7 @@ gnc_prices_dialog_add_clicked (GtkWidget *widget, gpointer data)
     LEAVE(" ");
 }
 
+
 void
 gnc_prices_dialog_get_quotes_clicked (GtkWidget *widget, gpointer data)
 {
@@ -335,7 +354,7 @@ gnc_price_dialog_filter_ns_func (gnc_commodity_namespace *namespace,
 
     /* Never show the template list */
     name = gnc_commodity_namespace_get_name (namespace);
-    if (safe_strcmp (name, "template") == 0)
+    if (g_strcmp0 (name, "template") == 0)
         return FALSE;
 
     /* See if this namespace has commodities */
@@ -354,6 +373,7 @@ gnc_price_dialog_filter_ns_func (gnc_commodity_namespace *namespace,
     return FALSE;
 }
 
+
 static gboolean
 gnc_price_dialog_filter_cm_func (gnc_commodity *commodity,
                                  gpointer data)
@@ -364,6 +384,7 @@ gnc_price_dialog_filter_cm_func (gnc_commodity *commodity,
     return gnc_pricedb_has_prices(pdb_dialog->price_db, commodity, NULL);
 }
 
+
 static void
 row_activated_cb (GtkTreeView *view, GtkTreePath *path,
                   GtkTreeViewColumn *column, gpointer data)
@@ -391,26 +412,26 @@ row_activated_cb (GtkTreeView *view, GtkTreePath *path,
     }
 }
 
+
 static void
 gnc_prices_dialog_create (GtkWidget * parent, PricesDialog *pdb_dialog)
 {
     GtkWidget *dialog, *scrolled_window;
-    GladeXML *xml;
+    GtkBuilder *builder;
     GtkTreeView *view;
     GtkTreeSelection *selection;
 
     ENTER(" ");
-    xml = gnc_glade_xml_new ("price.glade", "Prices Dialog");
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-price.glade", "Prices Dialog");
 
-    dialog = glade_xml_get_widget (xml, "Prices Dialog");
+    dialog = GTK_WIDGET(gtk_builder_get_object (builder, "Prices Dialog"));
     pdb_dialog->dialog = dialog;
 
     pdb_dialog->session = gnc_get_current_session();
     pdb_dialog->book = qof_session_get_book(pdb_dialog->session);
     pdb_dialog->price_db = gnc_pricedb_get_db(pdb_dialog->book);
 
-    glade_xml_signal_autoconnect_full(xml, gnc_glade_autoconnect_full_func, pdb_dialog);
-
     /* parent */
     if (parent != NULL)
         gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (parent));
@@ -419,7 +440,7 @@ gnc_prices_dialog_create (GtkWidget * parent, PricesDialog *pdb_dialog)
     gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
 
     /* price tree */
-    scrolled_window = glade_xml_get_widget (xml, "price_list_window");
+    scrolled_window = GTK_WIDGET(gtk_builder_get_object (builder, "price_list_window"));
     view = gnc_tree_view_price_new(pdb_dialog->book,
                                    "gconf-section", GCONF_SECTION,
                                    "show-column-menu", TRUE,
@@ -444,23 +465,28 @@ gnc_prices_dialog_create (GtkWidget * parent, PricesDialog *pdb_dialog)
     {
         GtkWidget *button;
 
-        button = glade_xml_get_widget (xml, "edit_button");
+        button = GTK_WIDGET(gtk_builder_get_object (builder, "edit_button"));
         pdb_dialog->edit_button = button;
 
-        button = glade_xml_get_widget (xml, "remove_button");
+        button = GTK_WIDGET(gtk_builder_get_object (builder, "remove_button"));
         pdb_dialog->remove_button = button;
 
         if (!gnc_quote_source_fq_installed())
         {
-            button = glade_xml_get_widget (xml, "get_quotes_button");
+            button = GTK_WIDGET(gtk_builder_get_object (builder, "get_quotes_button"));
             gtk_widget_set_sensitive(button, FALSE);
         }
     }
 
+    gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, pdb_dialog);
+
+    g_object_unref(G_OBJECT(builder));
+
     gnc_restore_window_size(GCONF_SECTION, GTK_WINDOW(pdb_dialog->dialog));
     LEAVE(" ");
 }
 
+
 static void
 close_handler (gpointer user_data)
 {
@@ -473,6 +499,7 @@ close_handler (gpointer user_data)
     LEAVE(" ");
 }
 
+
 static void
 refresh_handler (GHashTable *changes, gpointer user_data)
 {
@@ -480,6 +507,7 @@ refresh_handler (GHashTable *changes, gpointer user_data)
     LEAVE(" ");
 }
 
+
 static gboolean
 show_handler (const char *class, gint component_id,
               gpointer user_data, gpointer iter_data)
@@ -498,6 +526,7 @@ show_handler (const char *class, gint component_id,
     return(TRUE);
 }
 
+
 /********************************************************************\
  * gnc_prices_dialog                                                *
  *   opens up a window showing all price information                *
