@@ -4,6 +4,7 @@
  * Copyright (C) 2001 Robert Merkel <rgmerk@mira.net>               *
  * Copyright (C) 2001 Joshua Sled <jsled@asynchronous.org>          *
  * Copyright (c) 2006 David Hampton <hampton@employees.org>         *
+ * Copyright (c) 2011 Robert Fewell                                 *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
@@ -25,6 +26,7 @@
 
 #include "config.h"
 
+#include <gnc-gdate-utils.h>
 #include "dialog-sx-editor.h"
 #include "dialog-sx-from-trans.h"
 #include "dialog-utils.h"
@@ -33,6 +35,7 @@
 #include "gnc-dense-cal-store.h"
 #include "gnc-dense-cal.h"
 #include "gnc-engine.h"
+#include "engine-helpers.h"
 #include "gnc-gconf-utils.h"
 #include "gnc-ui-util.h"
 #include "gnc-ui.h"
@@ -45,23 +48,6 @@
 #include <gtk/gtk.h>
 #include <stdlib.h>
 
-#define SX_GLADE_FILE "sched-xact.glade"
-#define SXFTD_DIALOG_GLADE_NAME "sx_from_real_trans"
-#define SXFTD_OK_BUTTON "ok_button"
-#define SXFTD_ADVANCED_BUTTON "advanced_button"
-#define SXFTD_CANCEL_BUTTON "cancel_button"
-#define SXFTD_NEVER_END_BUTTON "never_end_button"
-#define SXFTD_END_ON_DATE_BUTTON "end_on_date_button"
-#define SXFTD_N_OCCURRENCES_BUTTON "n_occurrences_button"
-#define SXFTD_PARAM_TABLE "param_table"
-#define SXFTD_NAME_ENTRY "name_entry"
-#define SXFTD_N_OCCURRENCES_ENTRY "n_occurrences_entry"
-#define SXFTD_FREQ_COMBO_BOX "freq_combo_box"
-/* #define SXFTD_END_DATE_EDIT "end_date_edit" */
-#define SXFTD_START_DATE_EDIT "start_date_edit"
-#define SXFTD_EX_CAL_FRAME "ex_cal_frame"
-#define SXFTD_END_DATE_BOX "end_date_hbox"
-
 #define SXFTD_ERRNO_UNBALANCED_XACTION 3
 #define SXFTD_ERRNO_OPEN_XACTION -3
 
@@ -70,11 +56,11 @@
 
 #define SXFTD_RESPONSE_ADVANCED 100 /* 'Advanced' button response code */
 
-static QofLogModule log_module = GNC_MOD_GUI_SX;
-
 #undef G_LOG_DOMAIN
 #define G_LOG_DOMAIN GNC_MOD_GUI_SX
 
+static QofLogModule log_module = GNC_MOD_GUI_SX;
+
 static void sxftd_freq_combo_changed( GtkWidget *w, gpointer user_data );
 static void gnc_sx_trans_window_response_cb(GtkDialog *dialog, gint response, gpointer data);
 
@@ -91,8 +77,16 @@ typedef enum { FREQ_DAILY = 0,  /* I know the =0 is redundant, but I'm using
 
 typedef struct
 {
-    GladeXML *gxml;
+    GtkBuilder *builder;
     GtkWidget *dialog;
+    GtkEntry *name;
+    GtkComboBox *freq_combo;
+
+    GtkToggleButton *ne_but;
+    GtkToggleButton *ed_but;
+    GtkToggleButton *oc_but;
+    GtkEntry *n_occurences;
+
     Transaction *trans;
     SchedXaction *sx;
 
@@ -131,11 +125,11 @@ sxfti_attach_callbacks(SXFromTransInfo *sxfti)
     {
         /* Whenever any of the controls change, we want to update the
          * calendar. */
-        { SXFTD_NEVER_END_BUTTON,     "clicked",      sxftd_update_excal_adapt },
-        { SXFTD_END_ON_DATE_BUTTON,   "clicked",      sxftd_update_excal_adapt },
-        { SXFTD_N_OCCURRENCES_BUTTON, "clicked",      sxftd_update_excal_adapt },
-        { SXFTD_N_OCCURRENCES_ENTRY,  "changed",      sxftd_update_excal_adapt },
-        { NULL,                  NULL,      NULL }
+        { "never_end_button",     "clicked",      sxftd_update_excal_adapt },
+        { "end_on_date_button",   "clicked",      sxftd_update_excal_adapt },
+        { "n_occurrences_button", "clicked",      sxftd_update_excal_adapt },
+        { "n_occurrences_entry",  "changed",      sxftd_update_excal_adapt },
+        { NULL,                   NULL,           NULL }
     };
 
     int i;
@@ -143,7 +137,7 @@ sxfti_attach_callbacks(SXFromTransInfo *sxfti)
     GtkWidget *w;
     for (i = 0; callbacks[i].name != NULL; i++)
     {
-        w = glade_xml_get_widget(sxfti->gxml, callbacks[i].name);
+        w = GTK_WIDGET(gtk_builder_get_object(sxfti->builder, callbacks[i].name));
 
         g_signal_connect (GTK_OBJECT(w), callbacks[i].signal,
                           G_CALLBACK(callbacks[i].handlerFn),
@@ -160,38 +154,33 @@ static getEndTuple
 sxftd_get_end_info(SXFromTransInfo *sxfti)
 {
     getEndTuple retval;
-    GtkWidget *w;
 
     retval.type = BAD_END;
     g_date_clear( &(retval.end_date), 1 );
     retval.n_occurrences = 0;
 
-    w = glade_xml_get_widget(sxfti->gxml, SXFTD_NEVER_END_BUTTON);
-    if (gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(w)))
+    if (gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(sxfti->ne_but)))
     {
         retval.type = NEVER_END;
         return retval;
     }
 
-    w = glade_xml_get_widget(sxfti->gxml, SXFTD_END_ON_DATE_BUTTON);
-    if (gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(w)))
+    if (gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(sxfti->ed_but)))
     {
-        time_t end_tt;
+        time64 end_tt;
         retval.type = END_ON_DATE;
         g_date_clear( &(retval.end_date), 1 );
         end_tt = gnc_date_edit_get_date(sxfti->endDateGDE);
-        g_date_set_time_t( &(retval.end_date), end_tt);
+        gnc_gdate_set_time64( &(retval.end_date), end_tt);
         return retval;
     }
 
-    w = glade_xml_get_widget(sxfti->gxml, SXFTD_N_OCCURRENCES_BUTTON);
-    if (gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(w) ))
+    if (gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(sxfti->oc_but) ))
     {
         gchar *text, *endptr;
         guint n_occs;
-        w = glade_xml_get_widget(sxfti->gxml, SXFTD_N_OCCURRENCES_ENTRY);
-        text = gtk_editable_get_chars(GTK_EDITABLE(w), 0, -1);
 
+        text = gtk_editable_get_chars(GTK_EDITABLE(sxfti->n_occurences), 0, -1);
         if (text == NULL || strlen(text) == 0)
         {
             n_occs = 0;
@@ -204,17 +193,12 @@ sxftd_get_end_info(SXFromTransInfo *sxfti)
                 n_occs = -1;
             }
         }
-
         g_free(text);
 
-        if (n_occs > 0)
-        {
-            retval.type = END_AFTER_N_OCCS;
-            retval.n_occurrences = n_occs;
-            return retval;
-        }
+        retval.type = END_AFTER_N_OCCS;
+        retval.n_occurrences = n_occs;
+        return retval;
     }
-
     return retval;
 }
 
@@ -236,14 +220,14 @@ sxftd_add_template_trans(SXFromTransInfo *sxfti)
     runningBalance = gnc_numeric_zero();
 
     gnc_ttinfo_set_description(tti, xaccTransGetDescription(tr));
-    gnc_ttinfo_set_num(tti, xaccTransGetNum(tr));
+    gnc_ttinfo_set_num(tti, gnc_get_num_action(tr, NULL));
     gnc_ttinfo_set_currency(tti, xaccTransGetCurrency(tr));
 
     for (splits = xaccTransGetSplitList(tr); splits; splits = splits->next)
     {
         sp = splits->data;
         ttsi = gnc_ttsplitinfo_malloc();
-        gnc_ttsplitinfo_set_action(ttsi, xaccSplitGetAction(sp));
+        gnc_ttsplitinfo_set_action(ttsi, gnc_get_num_action(NULL, sp));
         split_value = xaccSplitGetValue(sp);
         gnc_ttsplitinfo_set_memo(ttsi, xaccSplitGetMemo(sp));
 
@@ -294,16 +278,16 @@ sxftd_add_template_trans(SXFromTransInfo *sxfti)
     return 0;
 }
 
+
 static void
 sxftd_update_schedule( SXFromTransInfo *sxfti, GDate *date, GList **recurrences)
 {
     gint index;
-    GtkWidget *w;
 
     /* Note that we make the start date the *NEXT* instance, not the
      * present one. */
-    w = glade_xml_get_widget(sxfti->gxml, SXFTD_FREQ_COMBO_BOX);
-    index = gtk_combo_box_get_active(GTK_COMBO_BOX(w));
+
+    index = gtk_combo_box_get_active(GTK_COMBO_BOX(sxfti->freq_combo));
 
     switch (index)
     {
@@ -346,6 +330,7 @@ sxftd_update_schedule( SXFromTransInfo *sxfti, GDate *date, GList **recurrences)
     }
 }
 
+
 static gint
 sxftd_init( SXFromTransInfo *sxfti )
 {
@@ -353,7 +338,7 @@ sxftd_init( SXFromTransInfo *sxfti )
     const char *transName;
     gint pos;
     GList *schedule = NULL;
-    time_t start_tt;
+    time64 start_tt;
     struct tm *tmpTm;
     GDate date, nextDate;
 
@@ -370,13 +355,30 @@ sxftd_init( SXFromTransInfo *sxfti )
         return SXFTD_ERRNO_OPEN_XACTION;
     }
 
+    /* Setup Widgets */
+    {
+        sxfti->ne_but = GTK_TOGGLE_BUTTON(gtk_builder_get_object(sxfti->builder, "never_end_button"));
+        sxfti->ed_but = GTK_TOGGLE_BUTTON(gtk_builder_get_object(sxfti->builder, "end_on_date_button"));
+        sxfti->oc_but = GTK_TOGGLE_BUTTON(gtk_builder_get_object(sxfti->builder, "n_occurrences_button"));
+        sxfti->n_occurences = GTK_ENTRY(gtk_builder_get_object(sxfti->builder, "n_occurrences_entry"));
+    }
+
+    /* Get the name from the transaction, try that as the initial SX name. */
+    transName = xaccTransGetDescription( sxfti->trans );
+    xaccSchedXactionSetName( sxfti->sx, transName );
+
+    sxfti->name = GTK_ENTRY(gtk_builder_get_object(sxfti->builder, "name_entry" ));
+    pos = 0;
+    gtk_editable_insert_text( GTK_EDITABLE(sxfti->name), transName,
+                              (strlen(transName) * sizeof(char)), &pos );
+
     sxfti_attach_callbacks(sxfti);
 
     /* Setup the example calendar and related data structures. */
     {
         int num_marks = SXFTD_EXCAL_NUM_MONTHS * 31;
 
-        w = GTK_WIDGET(glade_xml_get_widget( sxfti->gxml, SXFTD_EX_CAL_FRAME ));
+        w = GTK_WIDGET(gtk_builder_get_object(sxfti->builder, "ex_cal_frame" ));
         sxfti->dense_cal_model = gnc_dense_cal_store_new(num_marks);
         sxfti->example_cal = GNC_DENSE_CAL(gnc_dense_cal_new_with_model(GNC_DENSE_CAL_MODEL(sxfti->dense_cal_model)));
         g_object_ref_sink(sxfti->example_cal);
@@ -389,11 +391,10 @@ sxftd_init( SXFromTransInfo *sxfti )
 
     /* Setup the start and end dates as GNCDateEdits */
     {
-        GtkWidget *paramTable = glade_xml_get_widget( sxfti->gxml,
-                                SXFTD_PARAM_TABLE );
+        GtkWidget *paramTable = GTK_WIDGET(gtk_builder_get_object(sxfti->builder, "param_table" ));
         sxfti->startDateGDE =
-            GNC_DATE_EDIT( gnc_date_edit_new( time( NULL ),
-                                              FALSE, FALSE ) );
+            GNC_DATE_EDIT( gnc_date_edit_new (gnc_time (NULL),
+                                              FALSE, FALSE));
         gtk_table_attach( GTK_TABLE(paramTable),
                           GTK_WIDGET( sxfti->startDateGDE ),
                           1, 2, 2, 3,
@@ -405,49 +406,34 @@ sxftd_init( SXFromTransInfo *sxfti )
                           sxfti );
     }
     {
-        GtkWidget *endDateBox = glade_xml_get_widget( sxfti->gxml,
-                                SXFTD_END_DATE_BOX );
+        GtkWidget *endDateBox = GTK_WIDGET(gtk_builder_get_object(sxfti->builder, "end_date_hbox" ));
         sxfti->endDateGDE =
-            GNC_DATE_EDIT( gnc_date_edit_new( time( NULL ),
-                                              FALSE, FALSE ) );
+            GNC_DATE_EDIT( gnc_date_edit_new (gnc_time (NULL),
+                                              FALSE, FALSE));
         gtk_box_pack_start( GTK_BOX( endDateBox ),
                             GTK_WIDGET( sxfti->endDateGDE ),
-                            FALSE, TRUE, 0 );
+                            TRUE, TRUE, 0 );
         g_signal_connect( sxfti->endDateGDE, "date-changed",
                           G_CALLBACK( sxftd_update_excal_adapt ),
                           sxfti );
     }
 
-    /* Get the name from the transaction, try that as the initial SX name. */
-    transName = xaccTransGetDescription( sxfti->trans );
-    xaccSchedXactionSetName( sxfti->sx, transName );
-
     /* Setup the initial start date for user display/confirmation */
     /* compute good initial date. */
     start_tt = xaccTransGetDate( sxfti->trans );
-    g_date_set_time_t( &date, start_tt );
-    w = glade_xml_get_widget(sxfti->gxml,
-                             SXFTD_FREQ_COMBO_BOX);
-    gtk_combo_box_set_active(GTK_COMBO_BOX(w), 0);
-    g_signal_connect( w, "changed",
+    gnc_gdate_set_time64( &date, start_tt );
+    sxfti->freq_combo = GTK_COMBO_BOX(gtk_builder_get_object(sxfti->builder, "freq_combo_box"));
+    gtk_combo_box_set_active(GTK_COMBO_BOX(sxfti->freq_combo), 0);
+    g_signal_connect( sxfti->freq_combo, "changed",
                       G_CALLBACK(sxftd_freq_combo_changed),
                       sxfti );
     sxftd_update_schedule( sxfti, &date, &schedule);
     recurrenceListNextInstance(schedule, &date, &nextDate);
     recurrenceListFree(&schedule);
-
-    tmpTm = g_new0( struct tm, 1 );
-    g_date_to_struct_tm( &nextDate, tmpTm );
-    start_tt = mktime( tmpTm );
-    g_free( tmpTm );
+    start_tt = gnc_time64_get_day_start_gdate (&nextDate);
     gnc_date_edit_set_time( sxfti->startDateGDE, start_tt );
 
-    w = glade_xml_get_widget( sxfti->gxml, SXFTD_NAME_ENTRY );
-    pos = 0;
-    gtk_editable_insert_text( GTK_EDITABLE(w), transName,
-                              (strlen(transName) * sizeof(char)), &pos );
-
-    g_signal_connect( GTK_OBJECT(w), "destroy",
+    g_signal_connect( GTK_OBJECT(sxfti->name), "destroy",
                       G_CALLBACK(sxftd_destroy),
                       sxfti );
 
@@ -456,10 +442,10 @@ sxftd_init( SXFromTransInfo *sxfti )
     return 0;
 }
 
+
 static guint
 sxftd_compute_sx(SXFromTransInfo *sxfti)
 {
-    GtkWidget *w;
     gchar *name;
     GDate date;
     GList *schedule = NULL;
@@ -469,12 +455,12 @@ sxftd_compute_sx(SXFromTransInfo *sxfti)
     SchedXaction *sx = sxfti->sx;
 
     /* get the name */
-    w = glade_xml_get_widget(sxfti->gxml, SXFTD_NAME_ENTRY);
-    name = gtk_editable_get_chars(GTK_EDITABLE(w), 0, -1);
+    name = gtk_editable_get_chars(GTK_EDITABLE(sxfti->name), 0, -1);
+
     xaccSchedXactionSetName(sx, name);
     g_free(name);
 
-    g_date_set_time_t( &date, gnc_date_edit_get_date( sxfti->startDateGDE ) );
+    gnc_gdate_set_time64( &date, gnc_date_edit_get_date( sxfti->startDateGDE ) );
 
     sxftd_update_schedule(sxfti, &date, &schedule);
     if (sxftd_errno == 0)
@@ -536,6 +522,7 @@ sxftd_compute_sx(SXFromTransInfo *sxfti)
     return sxftd_errno;
 }
 
+
 static void
 sxftd_close(SXFromTransInfo *sxfti, gboolean delete_sx)
 {
@@ -549,6 +536,7 @@ sxftd_close(SXFromTransInfo *sxfti, gboolean delete_sx)
     gtk_widget_destroy (GTK_WIDGET (sxfti->dialog));
 }
 
+
 static void
 sxftd_ok_clicked(SXFromTransInfo *sxfti)
 {
@@ -578,6 +566,7 @@ sxftd_ok_clicked(SXFromTransInfo *sxfti)
     return;
 }
 
+
 /**
  * Update start date... right now we always base this off the transaction
  * start date, but ideally we want to respect what the user has in the field,
@@ -588,36 +577,31 @@ sxftd_freq_combo_changed( GtkWidget *w, gpointer user_data )
 {
     SXFromTransInfo *sxfti = (SXFromTransInfo*)user_data;
     GDate date, nextDate;
-    time_t tmp_tt;
+    time64 tmp_tt;
     struct tm *tmpTm;
     GList *schedule = NULL;
 
     tmp_tt = xaccTransGetDate( sxfti->trans );
-    g_date_set_time_t( &date, tmp_tt );
+    gnc_gdate_set_time64 (&date, tmp_tt);
 
     g_date_clear(&nextDate, 1);
     sxftd_update_schedule(sxfti, &date, &schedule);
     recurrenceListNextInstance(schedule, &date, &nextDate);
-
-    tmpTm = g_new0( struct tm, 1 );
-    g_date_to_struct_tm( &nextDate, tmpTm );
-    tmp_tt = mktime( tmpTm );
-    g_free( tmpTm );
+    tmp_tt = gnc_time64_get_day_start_gdate (&nextDate);
     gnc_date_edit_set_time( sxfti->startDateGDE, tmp_tt );
 
     recurrenceListFree(&schedule);
     sxftd_update_example_cal( sxfti );
 }
 
+
 static void
 sxftd_advanced_clicked(SXFromTransInfo *sxfti)
 {
     guint sx_error = sxftd_compute_sx(sxfti);
-    GncSxEditorDialog *adv_edit_dlg;
     GMainContext *context;
 
-    if ( sx_error != 0
-            && sx_error != SXFTD_ERRNO_UNBALANCED_XACTION )
+    if ( sx_error != 0 && sx_error != SXFTD_ERRNO_UNBALANCED_XACTION )
     {
         // unbalanced-xaction is "okay", since this is also checked for by
         // the advanced editor.
@@ -629,14 +613,13 @@ sxftd_advanced_clicked(SXFromTransInfo *sxfti)
     context = g_main_context_default();
     while (g_main_context_iteration(context, FALSE));
 
-    adv_edit_dlg =
-        gnc_ui_scheduled_xaction_editor_dialog_create(sxfti->sx,
-                TRUE /* newSX */);
+    gnc_ui_scheduled_xaction_editor_dialog_create(sxfti->sx, TRUE /* newSX */);
     /* close ourself, since advanced editing entails us, and there are sync
      * issues otherwise. */
     sxftd_close(sxfti, FALSE);
 }
 
+
 static void
 sxftd_destroy( GtkWidget *w, gpointer user_data )
 {
@@ -652,11 +635,10 @@ sxftd_destroy( GtkWidget *w, gpointer user_data )
     g_object_unref(G_OBJECT(sxfti->dense_cal_model));
     g_object_unref(G_OBJECT(sxfti->example_cal));
 
-    /* FIXME: do we need to clean up the GladeXML pointer? */
-
     g_free(sxfti);
 }
 
+
 static void
 gnc_sx_trans_window_response_cb (GtkDialog *dialog,
                                  gint response,
@@ -685,6 +667,7 @@ gnc_sx_trans_window_response_cb (GtkDialog *dialog,
     LEAVE(" ");
 }
 
+
 /**
  * Update the example calendar; make sure to take into account the end
  * specification.
@@ -693,7 +676,7 @@ static void
 sxftd_update_example_cal( SXFromTransInfo *sxfti )
 {
     struct tm *tmpTm;
-    time_t tmp_tt;
+    time64 tmp_tt;
     GDate date, startDate, nextDate;
     GList *schedule = NULL;
     getEndTuple get;
@@ -701,13 +684,7 @@ sxftd_update_example_cal( SXFromTransInfo *sxfti )
     get = sxftd_get_end_info( sxfti );
 
     tmp_tt = gnc_date_edit_get_date( sxfti->startDateGDE );
-    tmpTm = g_new0( struct tm, 1 );
-    *tmpTm = *localtime( &tmp_tt );
-    g_date_clear(&date, 1);
-    g_date_set_day( &date, tmpTm->tm_mday );
-    g_date_set_month( &date, tmpTm->tm_mon + 1 );
-    g_date_set_year( &date, tmpTm->tm_year + 1900 );
-    g_free( tmpTm );
+    gnc_gdate_set_time64 (&date, tmp_tt);
 
     sxftd_update_schedule(sxfti, &date, &schedule);
 
@@ -719,11 +696,10 @@ sxftd_update_example_cal( SXFromTransInfo *sxfti )
     recurrenceListNextInstance(schedule, &date, &nextDate);
 
     {
-        GtkWidget *w;
         gchar *name;
         /* get the name */
-        w = glade_xml_get_widget(sxfti->gxml, SXFTD_NAME_ENTRY);
-        name = gtk_editable_get_chars(GTK_EDITABLE(w), 0, -1);
+        name = NULL;
+        name = gtk_editable_get_chars(GTK_EDITABLE(sxfti->name), 0, -1);
         gnc_dense_cal_store_update_name(sxfti->dense_cal_model, name);
         g_free(name);
     }
@@ -735,6 +711,10 @@ sxftd_update_example_cal( SXFromTransInfo *sxfti )
         g_free(schedule_desc);
     }
 
+    /* Set End date sensitivity */
+    gtk_widget_set_sensitive( GTK_WIDGET(sxfti->endDateGDE), (get.type == END_ON_DATE) );
+    gtk_widget_set_sensitive( GTK_WIDGET(sxfti->n_occurences), (get.type == END_AFTER_N_OCCS) );
+
     switch (get.type)
     {
     case NEVER_END:
@@ -757,9 +737,10 @@ sxftd_update_example_cal( SXFromTransInfo *sxfti )
     recurrenceListFree(&schedule);
 }
 
-/**
- * Callback to update the calendar
- **/
+
+/***********************************
+ * Callback to update the calendar *
+ **********************************/
 static void
 sxftd_update_excal_adapt( GObject *o, gpointer ud )
 {
@@ -767,18 +748,27 @@ sxftd_update_excal_adapt( GObject *o, gpointer ud )
     sxftd_update_example_cal( sxfti );
 }
 
+
+/*********************
+ * Create the dialog *
+ ********************/
 void
 gnc_sx_create_from_trans( Transaction *trans )
 {
     int errno;
     SXFromTransInfo *sxfti = g_new0( SXFromTransInfo, 1);
+    GtkBuilder *builder;
+    GtkWidget *dialog;
 
-    sxfti->gxml = gnc_glade_xml_new(SX_GLADE_FILE,
-                                    SXFTD_DIALOG_GLADE_NAME);
+    builder = gtk_builder_new();
 
-    sxfti->dialog = glade_xml_get_widget(sxfti->gxml,
-                                         SXFTD_DIALOG_GLADE_NAME);
+    gnc_builder_add_from_file  (builder , "dialog-sx.glade", "freq_liststore");
 
+    gnc_builder_add_from_file  (builder , "dialog-sx.glade", "sx_from_real_trans");
+    dialog = GTK_WIDGET(gtk_builder_get_object (builder, "sx_from_real_trans"));
+
+    sxfti->builder = builder;
+    sxfti->dialog = dialog;
     sxfti->trans = trans;
 
     sxfti->sx = xaccSchedXactionMalloc(gnc_get_current_book ());
@@ -802,4 +792,7 @@ gnc_sx_create_from_trans( Transaction *trans )
     }
 
     gtk_widget_show_all(GTK_WIDGET(sxfti->dialog));
+
+    gtk_builder_connect_signals(builder, sxfti);
+    g_object_unref(G_OBJECT(builder));
 }
