@@ -30,6 +30,8 @@
 #include <glib/gi18n.h>
 #include <libguile.h>
 #include "guile-mappings.h"
+#include "guile-util.h"
+#include "gnc-guile-utils.h"
 
 #include "Account.h"
 #include "gnc-ui-util.h"
@@ -41,7 +43,6 @@
 #include "qof.h"
 #include "gnc-ui.h"
 
-
 #define DIALOG_TAX_INFO_CM_CLASS "dialog-tax-info"
 #define GCONF_SECTION "dialogs/tax_info"
 #define PANED_POSITION "paned_position"
@@ -94,6 +95,7 @@ typedef struct
 typedef struct
 {
     GtkWidget * dialog;
+    GtkWidget * paned;
 
     GtkWidget * entity_name_display;
     GtkWidget * entity_name_entry;
@@ -107,13 +109,19 @@ typedef struct
     GtkWidget * liab_eq_radio;
     GtkWidget * account_treeview;
     GtkWidget * select_button;
+    GtkWidget * num_acct_label;
 
     GtkWidget * txf_info;
     GtkWidget * tax_related_button;
+    GtkWidget * txf_vbox;
     GtkWidget * txf_category_view;
     GtkWidget * txf_help_text;
+    GtkWidget * help_scroll;
+    GtkWidget * payer_vbox;
+    GtkWidget * pns_vbox;
     GtkWidget * current_account_button;
     GtkWidget * parent_account_button;
+    GtkWidget * copy_vbox;
     GtkWidget * copy_spin_button;
 
     GList * entity_type_infos;
@@ -135,7 +143,6 @@ typedef struct
     GNCAccountType account_type;
 } TaxInfoDialog;
 
-
 static void
 initialize_getters (void)
 {
@@ -229,15 +236,14 @@ load_txf_info (gint acct_category, TaxInfoDialog *ti_dialog)
     SCM codes;
 
     if (ti_dialog->tax_type == NULL ||
-            (safe_strcmp (ti_dialog->tax_type, "") == 0))
+            (g_strcmp0 (ti_dialog->tax_type, "") == 0))
     {
         destroy_txf_infos (infos);
         return NULL;
     }
     else
     {
-        /*     tax_entity_type = scm_from_locale_string (ti_dialog->tax_type); <- Req's guile 1.8 */
-        tax_entity_type = scm_makfrom0str (ti_dialog->tax_type); /* <-guile 1.6  */
+        tax_entity_type = scm_from_locale_string (ti_dialog->tax_type);
     }
 
     switch (acct_category)
@@ -276,14 +282,15 @@ load_txf_info (gint acct_category, TaxInfoDialog *ti_dialog)
     {
         TXFInfo *txf_info;
         SCM code_scm;
-        const gchar *str;
         const gchar *last_yr = _("Last Valid Year: ");
         const gchar *form_line = _("Form Line Data: ");
         const gchar *code_line_word = _("Code");
         const gchar *code_line_colon = ": ";
-        const gchar *num_code = NULL;
         const gchar *prefix = "N";
+        gchar *str = NULL;
+        gchar *num_code = NULL;
         gchar *form_line_data = NULL;
+        gchar *help_text = NULL;
         SCM scm;
         gint year;
         gboolean cpy;
@@ -293,103 +300,142 @@ load_txf_info (gint acct_category, TaxInfoDialog *ti_dialog)
 
         scm = scm_call_3 (getters.payer_name_source, category, code_scm,
                           tax_entity_type);
-        str = SCM_SYMBOL_CHARS (scm);
-        if (safe_strcmp (str, "not-impl") == 0)
+        if (scm_is_symbol(scm))
+            str = gnc_scm_symbol_to_locale_string (scm);
+        else
+            str = g_strdup ("");
+        if (g_strcmp0 (str, "not-impl") == 0)
         {
+            g_free (str);
             continue;
         }
 
         txf_info = g_new0 (TXFInfo, 1);
 
-        if (safe_strcmp (str, "none") == 0)
+        if (g_strcmp0 (str, "none") == 0)
             txf_info->payer_name_source = NULL;
         else
             txf_info->payer_name_source = g_strdup (str);
+        g_free (str);
 
-        str = scm_is_symbol(code_scm) ? SCM_SYMBOL_CHARS(code_scm) : "";
+        if (scm_is_symbol(code_scm))
+            str = gnc_scm_symbol_to_locale_string (code_scm);
+        else
+            str = g_strdup ("");
         txf_info->code = g_strdup (str);
-        num_code = g_strdup (str);
-        if (g_str_has_prefix (num_code, prefix))
-            num_code++; /* to lose the leading N */
+        if (g_str_has_prefix (str, prefix))
+        {
+            const gchar *num_code_tmp;
+            num_code_tmp = g_strdup (str);
+            num_code_tmp++; /* to lose the leading N */
+            num_code = g_strdup (num_code_tmp);
+            num_code_tmp--;
+            g_free ((gpointer *) num_code_tmp);
+        }
+        else
+            num_code = g_strdup (str);
+        g_free (str);
 
         scm = scm_call_3 (getters.form, category, code_scm, tax_entity_type);
-        str = scm_is_string(scm) ? scm_to_locale_string(scm) : "";
-        txf_info->form = g_strdup (str);
+        if (scm_is_string(scm))
+            txf_info->form = gnc_scm_to_locale_string(scm);
+        else
+            txf_info->form = g_strdup ("");
 
         scm = scm_call_3 (getters.description, category, code_scm, tax_entity_type);
-        str = scm_is_string(scm) ? scm_to_locale_string(scm) : "";
-        txf_info->description = g_strdup (str);
+        if (scm_is_string(scm))
+            txf_info->description = gnc_scm_to_locale_string(scm);
+        else
+            txf_info->description = g_strdup ("");
 
         scm = scm_call_2 (getters.help, category, code_scm);
-        str = scm_is_string(scm) ? scm_to_locale_string(scm) : "";
+        if (scm_is_string(scm))
+            help_text = gnc_scm_to_locale_string(scm);
+        else
+            help_text = g_strdup ("");
+
         scm = scm_call_3 (getters.last_year, category, code_scm, tax_entity_type);
-        /*    year = scm_is_bool (scm) ? 0 : scm_to_int(scm); <- Req's guile 1.8 */
-        year = scm_is_bool (scm) ? 0 : SCM_INUM(scm); /* <-guile 1.6  */
+        year = scm_is_bool (scm) ? 0 : scm_to_int(scm);
         scm = scm_call_3 (getters.line_data, category, code_scm, tax_entity_type);
         if (scm_is_list (scm))
         {
-            const gchar *until = _("now");
+            const gchar *now = _("now");
+            gchar *until;
 
+            until = (gchar *) now;
             form_line_data = g_strconcat ("\n", "\n", form_line, NULL);
             while (!scm_is_null (scm))
             {
                 SCM year_scm;
                 gint line_year;
-                const gchar *line;
-                gchar *temp;
+                gchar *line = NULL;
+                gchar *temp = NULL;
+                gchar *temp2 = NULL;
 
                 year_scm  = SCM_CAR (scm);
                 scm       = SCM_CDR (scm);
 
-                /*        line_year = scm_is_bool (SCM_CAR (year_scm)) ? 0 :
-                                          scm_to_int (SCM_CAR (year_scm)); <- Req's guile 1.8 */
                 line_year = scm_is_bool (SCM_CAR (year_scm)) ? 0 :
-                            SCM_INUM (SCM_CAR (year_scm)); /* <-guile 1.6  */
-                line = scm_is_string((SCM_CAR (SCM_CDR (year_scm))))
-                       ? scm_to_locale_string((SCM_CAR (SCM_CDR (year_scm)))) : "";
-                temp = g_strconcat (form_line_data, "\n",
-                                    g_strdup_printf ("%d", line_year), " - ", until,
-                                    "   ", line, NULL);
+                            scm_to_int (SCM_CAR (year_scm));
+                if (scm_is_string((SCM_CAR (SCM_CDR (year_scm)))))
+                    line = gnc_scm_to_locale_string((SCM_CAR (SCM_CDR
+                                                     (year_scm))));
+                else
+                    line = g_strdup ("");
+                temp2 = g_strdup_printf ("%d", line_year);
+                temp = g_strconcat (form_line_data, "\n", temp2, " - ",
+                                    until, "   ", line, NULL);
+                if (until != now)
+                    g_free (until);
                 until = g_strdup_printf ("%d", (line_year - 1));
-                g_free(form_line_data);
+                g_free (form_line_data);
                 form_line_data = g_strdup (temp);
-                g_free(temp);
+                g_free (line);
+                g_free (temp);
+                g_free (temp2);
             }
+            if (g_strcmp0 (until, now) != 0)
+                g_free (until);
         }
         if (year != 0)
         {
+            gchar *temp = g_strdup_printf("%d", year);
             if (form_line_data != NULL)
-                txf_info->help = g_strconcat (last_yr, g_strdup_printf ("%d", year),
-                                              "\n", "\n", str, "\n", "\n",
-                                              code_line_word, code_line_colon, num_code,
+                txf_info->help = g_strconcat (last_yr, temp, "\n", "\n",
+                                              help_text, "\n", "\n",
+                                              code_line_word,
+                                              code_line_colon, num_code,
                                               form_line_data, NULL);
             else
-                txf_info->help = g_strconcat (last_yr, g_strdup_printf ("%d", year),
-                                              "\n", "\n", str, "\n", "\n",
-                                              code_line_word, code_line_colon, num_code, NULL);
+                txf_info->help = g_strconcat (last_yr, temp, "\n", "\n",
+                                              help_text, "\n", "\n",
+                                              code_line_word,
+                                              code_line_colon, num_code, NULL);
+            g_free (temp);
         }
         else
         {
             if (form_line_data != NULL)
-                txf_info->help = g_strconcat (str, "\n", "\n",
-                                              code_line_word, code_line_colon, num_code,
+                txf_info->help = g_strconcat (help_text, "\n", "\n",
+                                              code_line_word,
+                                              code_line_colon, num_code,
                                               form_line_data, NULL);
             else
-                txf_info->help = g_strconcat (str, "\n", "\n",
-                                              code_line_word, code_line_colon, num_code, NULL);
+                txf_info->help = g_strconcat (help_text, "\n", "\n",
+                                              code_line_word,
+                                              code_line_colon, num_code, NULL);
         }
 
-        if (form_line_data != NULL)
-            g_free(form_line_data);
+        g_free (num_code);
+        g_free (help_text);
+        g_free (form_line_data);
 
         scm = scm_call_3 (getters.copy, category, code_scm, tax_entity_type);
-        /*    cpy = scm_is_bool (scm) ? (scm_is_false (scm) ? FALSE : TRUE): FALSE; <- Req's guile 1.8 */
-        cpy = scm_is_bool (scm) ? (scm_is_false (scm) ? FALSE : TRUE) : FALSE; /* <-guile 1.6  */
+        cpy = scm_is_bool (scm) ? (scm_is_false (scm) ? FALSE : TRUE) : FALSE;
         txf_info->copy = cpy;
 
         infos = g_list_prepend (infos, txf_info);
     }
-
     return g_list_reverse (infos);
 }
 
@@ -424,7 +470,7 @@ load_tax_entity_type_list (TaxInfoDialog *ti_dialog)
     {
         TaxTypeInfo *tax_type_info;
         SCM type_scm;
-        const gchar *str;
+        gchar *str = NULL;
         SCM scm;
 
         type_scm  = SCM_CAR (tax_types);
@@ -434,28 +480,34 @@ load_tax_entity_type_list (TaxInfoDialog *ti_dialog)
 
         tax_type_info = g_new0 (TaxTypeInfo, 1);
 
-        str = scm_is_symbol(type_scm) ? SCM_SYMBOL_CHARS(type_scm) : "";
-        tax_type_info->type_code = g_strdup (str);
+        if (scm_is_symbol(type_scm))
+            tax_type_info->type_code = gnc_scm_symbol_to_locale_string (type_scm);
+        else
+            tax_type_info->type_code = g_strdup ("");
 
         scm = scm_call_1 (getters.tax_entity_type, type_scm);
-        str = scm_is_string(scm) ? scm_to_locale_string (scm) : "";
-        tax_type_info->type = g_strdup (str);
+        if (scm_is_string(scm))
+            tax_type_info->type = gnc_scm_to_locale_string(scm);
+        else
+            tax_type_info->type = g_strdup ("");
 
         scm = scm_call_1 (getters.tax_entity_desc, type_scm);
-        str = scm_is_string(scm) ? scm_to_locale_string (scm) : "";
-        tax_type_info->description = g_strdup (str);
+        if (scm_is_string(scm))
+            tax_type_info->description = gnc_scm_to_locale_string(scm);
+        else
+            tax_type_info->description = g_strdup ("");
 
-        tax_type_info->combo_box_entry = g_strconcat(tax_type_info->type, " - ",
+        tax_type_info->combo_box_entry = g_strconcat(tax_type_info->type,
+                                         " - ",
                                          tax_type_info->description, NULL);
         /* save combo text for current tax type code */
-        if (safe_strcmp (ti_dialog->tax_type, tax_type_info->type_code) == 0)
-            ti_dialog->tax_type_combo_text = g_strdup (tax_type_info->combo_box_entry);
+        if (g_strcmp0 (ti_dialog->tax_type, tax_type_info->type_code) == 0)
+            ti_dialog->tax_type_combo_text = tax_type_info->combo_box_entry;
         /* the last will be default */
-        ti_dialog->default_tax_type = g_strdup (tax_type_info->combo_box_entry);
+        ti_dialog->default_tax_type = tax_type_info->combo_box_entry;
 
         types = g_list_prepend (types, tax_type_info);
     }
-
     ti_dialog->entity_type_infos = g_list_reverse (types);
 }
 
@@ -544,7 +596,7 @@ txf_infos_find_code (GList *infos, const char *code)
     {
         TXFInfo *info = infos->data;
 
-        if (safe_strcmp (code, info->code) == 0)
+        if (g_strcmp0 (code, info->code) == 0)
             return info;
     }
 
@@ -592,7 +644,7 @@ account_to_gui (TaxInfoDialog *ti_dialog, Account *account)
     gtk_tree_path_free(path);
 
     str = xaccAccountGetTaxUSPayerNameSource (account);
-    if (safe_strcmp (str, "parent") == 0)
+    if (g_strcmp0 (str, "parent") == 0)
         gtk_toggle_button_set_active
         (GTK_TOGGLE_BUTTON (ti_dialog->parent_account_button), TRUE);
     else
@@ -676,17 +728,18 @@ gui_to_accounts (TaxInfoDialog *ti_dialog)
 
         xaccAccountCommitEdit (account);
     }
+    g_list_free (accounts);
 }
 
 static void
-identity_edit_destroy_cb (GtkObject *object, gpointer data)
+identity_edit_destroy_cb (GtkDialog *dialog, gpointer data)
 {
     TaxInfoDialog *ti_dialog = data;
 
     ti_dialog->entity_name_entry = NULL;
     ti_dialog->entity_type_combo = NULL;
 
-    gtk_object_destroy (object);
+    gtk_widget_destroy(GTK_WIDGET(dialog));
 }
 
 static void
@@ -807,7 +860,6 @@ gnc_tax_info_update_accounts (TaxInfoDialog *ti_dialog)
     GncTreeViewAccount *tree;
     GtkTreeSelection* selection;
     GtkWidget *label;
-    GtkWidget *vbox;
     int num_accounts;
     char *string;
 
@@ -815,14 +867,13 @@ gnc_tax_info_update_accounts (TaxInfoDialog *ti_dialog)
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(tree));
     num_accounts = gtk_tree_selection_count_selected_rows (selection);
 
-    label = gnc_glade_lookup_widget (ti_dialog->dialog, "num_accounts_label");
-    vbox = gnc_glade_lookup_widget (ti_dialog->dialog, "tax_info_vbox");
+    label = ti_dialog->num_acct_label;
 
     string = g_strdup_printf ("%d", num_accounts);
     gtk_label_set_text (GTK_LABEL (label), string);
     g_free (string);
 
-    gtk_widget_set_sensitive (vbox, num_accounts > 0);
+    gtk_widget_set_sensitive (ti_dialog->txf_info, num_accounts > 0);
 
     return num_accounts;
 }
@@ -835,14 +886,14 @@ gnc_tax_info_acct_type_cb (GtkWidget *w, gpointer data)
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)))
     {
-        button_name = gtk_widget_get_name (w);
-        if (safe_strcmp (button_name, "income_radio") == 0)
+        button_name = gtk_buildable_get_name(GTK_BUILDABLE(w));
+        if (g_strcmp0 (button_name, "income_radio") == 0)
             ti_dialog->account_type = ACCT_TYPE_INCOME;
-        else if (safe_strcmp (button_name, "expense_radio") == 0)
+        else if (g_strcmp0 (button_name, "expense_radio") == 0)
             ti_dialog->account_type = ACCT_TYPE_EXPENSE;
-        else if (safe_strcmp (button_name, "asset_radio") == 0)
+        else if (g_strcmp0 (button_name, "asset_radio") == 0)
             ti_dialog->account_type = ACCT_TYPE_ASSET;
-        else if (safe_strcmp (button_name, "liab_eq_radio") == 0)
+        else if (g_strcmp0 (button_name, "liab_eq_radio") == 0)
             ti_dialog->account_type = ACCT_TYPE_LIABILITY;
         else
             return;
@@ -903,7 +954,6 @@ txf_code_select_row_cb (GtkTreeSelection *selection,
     gint *indices;
     TXFInfo *txf_info;
     GtkAdjustment *adj;
-    GtkWidget *scroll;
     GtkWidget *vbox;
     GtkTextBuffer *tb;
     const char *text;
@@ -920,14 +970,10 @@ txf_code_select_row_cb (GtkTreeSelection *selection,
     text = (txf_info && txf_info->help) ? txf_info->help : "";
     gtk_text_buffer_set_text (tb, text, -1);
 
-    scroll = gnc_glade_lookup_widget (GTK_WIDGET (ti_dialog->dialog),
-                                      "help_scroll");
-
-    adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (scroll));
+    adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (ti_dialog->help_scroll));
     gtk_adjustment_set_value (adj, 0.0);
 
-    vbox = gnc_glade_lookup_widget (GTK_WIDGET (ti_dialog->dialog),
-                                    "payer_name_source_vbox");
+    vbox = ti_dialog->payer_vbox;
 
     if (txf_info && txf_info->payer_name_source)
     {
@@ -951,8 +997,7 @@ txf_code_select_row_cb (GtkTreeSelection *selection,
         (GTK_TOGGLE_BUTTON (ti_dialog->current_account_button), TRUE);
     }
 
-    vbox = gnc_glade_lookup_widget (GTK_WIDGET (ti_dialog->dialog),
-                                    "copy_number_vbox");
+    vbox = ti_dialog->copy_vbox;
 
     if (txf_info && txf_info->copy)
     {
@@ -970,21 +1015,19 @@ static void
 set_focus_sensitivity (TaxInfoDialog *ti_dialog)
 {
     if ((ti_dialog->tax_type == NULL) ||
-            (safe_strcmp (ti_dialog->tax_type, "Other") == 0) ||
-            (safe_strcmp (ti_dialog->tax_type, "") == 0))
+            (g_strcmp0 (ti_dialog->tax_type, "Other") == 0) ||
+            (g_strcmp0 (ti_dialog->tax_type, "") == 0))
     {
         gtk_widget_grab_focus (ti_dialog->tax_identity_edit_button);
         gtk_widget_set_sensitive (ti_dialog->acct_info, FALSE);
         gtk_widget_set_sensitive (ti_dialog->txf_info, FALSE);
-        gtk_widget_hide (ti_dialog->txf_help_text); /* doesn't go insensitive!? */
+        gtk_widget_hide (ti_dialog->txf_help_text); /* textview doesn't go insensitive!? */
     }
     else if (ti_dialog->tax_type_changed)
     {
         gtk_widget_set_sensitive (ti_dialog->acct_info, TRUE);
         gtk_widget_set_sensitive (ti_dialog->txf_info, TRUE);
-        gtk_widget_show (ti_dialog->txf_help_text);
         gtk_widget_grab_focus (ti_dialog->account_treeview);
-
     }
     else
     {
@@ -1022,11 +1065,11 @@ identity_edit_response_cb (GtkDialog *dialog, gint response, gpointer data)
             if (selected_type)
             {
                 entry_type = selected_type->type_code;
-                if (!(safe_strcmp (ti_dialog->tax_type, entry_type) == 0))
+                if (!(g_strcmp0 (ti_dialog->tax_type, entry_type) == 0))
                 {
                     ti_dialog->tax_type_changed = TRUE;
                     gnc_set_current_book_tax_type (entry_type);
-                    ti_dialog->tax_type = g_strdup (entry_type);
+                    ti_dialog->tax_type = entry_type;
                     if (entry_type != NULL)
                     {
                         gtk_label_set_text (GTK_LABEL (ti_dialog->entity_type_display),
@@ -1037,9 +1080,17 @@ identity_edit_response_cb (GtkDialog *dialog, gint response, gpointer data)
                         gtk_label_set_text (GTK_LABEL (ti_dialog->entity_type_display),
                                             ti_dialog->default_tax_type);
                     }
+                    if (ti_dialog->income_txf_infos != NULL)
+                        destroy_txf_infos (ti_dialog->income_txf_infos);
                     ti_dialog->income_txf_infos = load_txf_info (INCOME, ti_dialog);
+                    if (ti_dialog->expense_txf_infos != NULL)
+                        destroy_txf_infos (ti_dialog->expense_txf_infos);
                     ti_dialog->expense_txf_infos = load_txf_info (EXPENSE, ti_dialog);
+                    if (ti_dialog->asset_txf_infos != NULL)
+                        destroy_txf_infos (ti_dialog->asset_txf_infos);
                     ti_dialog->asset_txf_infos = load_txf_info (ASSET, ti_dialog);
+                    if (ti_dialog->liab_eq_txf_infos != NULL)
+                        destroy_txf_infos (ti_dialog->liab_eq_txf_infos);
                     ti_dialog->liab_eq_txf_infos = load_txf_info (LIAB_EQ, ti_dialog);
                     gtk_toggle_button_set_active
                     (GTK_TOGGLE_BUTTON(ti_dialog->expense_radio), TRUE);
@@ -1051,7 +1102,7 @@ identity_edit_response_cb (GtkDialog *dialog, gint response, gpointer data)
                 }
             }
         }
-        if (!(safe_strcmp (ti_dialog->tax_name, entry_name) == 0))
+        if (!(g_strcmp0 (ti_dialog->tax_name, entry_name) == 0))
         {
             gnc_set_current_book_tax_name (entry_name);
             ti_dialog->tax_name = g_strdup (entry_name);
@@ -1061,7 +1112,7 @@ identity_edit_response_cb (GtkDialog *dialog, gint response, gpointer data)
         set_focus_sensitivity (ti_dialog);
         ti_dialog->tax_type_changed = FALSE;
     }
-    identity_edit_destroy_cb (GTK_OBJECT (dialog), ti_dialog);
+    identity_edit_destroy_cb (GTK_DIALOG (dialog), ti_dialog);
 }
 
 static void
@@ -1070,7 +1121,7 @@ identity_edit_clicked_cb (GtkButton *button,
 {
     TaxInfoDialog *ti_dialog = user_data;
     GtkWidget *dialog;
-    /*  GtkWidget *content_area;  <- requires GTK 2.14 */
+    GtkWidget *content_area;
     GtkWidget *name_entry;
     GtkWidget *label;
     GtkWidget *alignment;
@@ -1092,10 +1143,12 @@ identity_edit_clicked_cb (GtkButton *button,
                                           GTK_STOCK_APPLY,
                                           GTK_RESPONSE_APPLY,
                                           NULL);
-    /*  content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog)); <- requires GTK 2.14 */
+
+    content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
     name_entry = gtk_entry_new();
     ti_dialog->entity_name_entry = name_entry;
-    gtk_entry_set_text (GTK_ENTRY (name_entry), ti_dialog->tax_name);
+    if (!(g_strcmp0 (ti_dialog->tax_name, NULL) == 0))
+        gtk_entry_set_text (GTK_ENTRY (name_entry), ti_dialog->tax_name);
     label = gtk_label_new (_("Name"));
     gtk_misc_set_alignment (GTK_MISC (label), 1.00, 0.50);
     alignment = gtk_alignment_new(1.00, 0.50, 1.00, 0.00);
@@ -1116,7 +1169,7 @@ identity_edit_clicked_cb (GtkButton *button,
 
         gtk_list_store_append(store, &iter);
         gtk_list_store_set(store, &iter, 0, tax_type_info->combo_box_entry, -1);
-        if (safe_strcmp (ti_dialog->tax_type, tax_type_info->type_code) == 0)
+        if (g_strcmp0 (ti_dialog->tax_type, tax_type_info->type_code) == 0)
             current_item = item;
         item++;
     }
@@ -1152,8 +1205,7 @@ identity_edit_clicked_cb (GtkButton *button,
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 6, 6, 4, 4);
     gtk_container_add (GTK_CONTAINER (alignment), label);
     gtk_table_attach_defaults (GTK_TABLE (table), alignment, 0, 2, 2, 3);
-    /*  gtk_container_add (GTK_CONTAINER (content_area), table);  <- requires GTK 2.14 */
-    gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), table);
+    gtk_container_add (GTK_CONTAINER (content_area), table);
     gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_APPLY);
     g_signal_connect (G_OBJECT (dialog), "response",
                       G_CALLBACK (identity_edit_response_cb), ti_dialog);
@@ -1173,14 +1225,17 @@ tax_related_toggled_cb (GtkToggleButton *togglebutton,
 
     on = gtk_toggle_button_get_active (togglebutton);
 
-    vbox = gnc_glade_lookup_widget (GTK_WIDGET (togglebutton),
-                                    "txf_categories_vbox");
-    hbox = gnc_glade_lookup_widget (GTK_WIDGET (togglebutton),
-                                    "pns_copy_hbox");
+    vbox = ti_dialog->txf_vbox;
+    hbox = ti_dialog->pns_vbox;
     gtk_widget_set_sensitive (vbox, on);
 
     gtk_widget_set_sensitive (hbox, on);
 
+    if (on == FALSE)
+        gtk_widget_hide (ti_dialog->txf_help_text); /* textview doesn't go insensitive!? */
+    else
+        gtk_widget_show (ti_dialog->txf_help_text);
+
     gnc_tax_info_set_changed (ti_dialog, TRUE);
 }
 
@@ -1206,17 +1261,17 @@ static void
 gnc_tax_info_dialog_create (GtkWidget * parent, TaxInfoDialog *ti_dialog)
 {
     GtkWidget *dialog;
-    GtkObject *tido;
-    GladeXML  *xml;
+    GtkBuilder  *builder;
     GtkTreeView *tree_view;
     GtkTreeSelection *selection;
     GtkWidget *label;
 
-    xml = gnc_glade_xml_new ("tax.glade", "Tax Information Dialog");
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-tax-info.glade", "copy_spin_adj");
+    gnc_builder_add_from_file (builder, "dialog-tax-info.glade", "Tax Information Dialog");
 
-    dialog = glade_xml_get_widget (xml, "Tax Information Dialog");
+    dialog = GTK_WIDGET(gtk_builder_get_object (builder, "Tax Information Dialog"));
     ti_dialog->dialog = dialog;
-    tido = GTK_OBJECT (dialog);
 
     initialize_getters ();
 
@@ -1242,20 +1297,20 @@ gnc_tax_info_dialog_create (GtkWidget * parent, TaxInfoDialog *ti_dialog)
         ti_dialog->tax_name = gnc_get_current_book_tax_name();
         ti_dialog->tax_type = gnc_get_current_book_tax_type();
 
-        label = glade_xml_get_widget (xml, "entity_name");
+        label = GTK_WIDGET(gtk_builder_get_object (builder, "entity_name"));
         ti_dialog->entity_name_display = label;
         gtk_label_set_text (GTK_LABEL (label), ti_dialog->tax_name);
         ti_dialog->entity_name_entry = NULL;
 
         load_tax_entity_type_list (ti_dialog); /* initialize tax_type_combo_text */
 
-        label = glade_xml_get_widget (xml, "entity_type");
+        label = GTK_WIDGET(gtk_builder_get_object (builder, "entity_type"));
         ti_dialog->entity_type_display = label;
         if (ti_dialog->tax_type != NULL)
             gtk_label_set_text (GTK_LABEL (label), ti_dialog->tax_type_combo_text);
         ti_dialog->entity_type_combo = NULL;
 
-        edit_button = glade_xml_get_widget (xml, "identity_edit_button");
+        edit_button = GTK_WIDGET(gtk_builder_get_object (builder, "identity_edit_button"));
         ti_dialog->tax_identity_edit_button = edit_button;
         g_signal_connect (G_OBJECT (edit_button), "clicked",
                           G_CALLBACK (identity_edit_clicked_cb), ti_dialog);
@@ -1275,18 +1330,18 @@ gnc_tax_info_dialog_create (GtkWidget * parent, TaxInfoDialog *ti_dialog)
         GtkWidget *button;
         GtkWidget *text;
 
-        ti_dialog->txf_info = glade_xml_get_widget (xml, "tax_info_vbox");
-        button = glade_xml_get_widget (xml, "tax_related_button");
+        ti_dialog->txf_info = GTK_WIDGET(gtk_builder_get_object (builder, "tax_info_vbox"));
+        button = GTK_WIDGET(gtk_builder_get_object (builder, "tax_related_button"));
         ti_dialog->tax_related_button = button;
 
         g_signal_connect (G_OBJECT (button), "toggled",
                           G_CALLBACK  (tax_related_toggled_cb), ti_dialog);
 
-        text = glade_xml_get_widget (xml, "txf_help_text");
+        text = GTK_WIDGET(gtk_builder_get_object (builder, "txf_help_text"));
         gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(text), GTK_WRAP_WORD);
         ti_dialog->txf_help_text = text;
 
-        tree_view = GTK_TREE_VIEW(glade_xml_get_widget(xml, "txf_category_view"));
+        tree_view = GTK_TREE_VIEW(gtk_builder_get_object (builder, "txf_category_view"));
         store =  gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
         gtk_tree_view_set_model(tree_view, GTK_TREE_MODEL(store));
         g_object_unref(store);
@@ -1304,20 +1359,26 @@ gnc_tax_info_dialog_create (GtkWidget * parent, TaxInfoDialog *ti_dialog)
         g_signal_connect (G_OBJECT (selection), "changed",
                           G_CALLBACK  (txf_code_select_row_cb), ti_dialog);
 
-        label = glade_xml_get_widget(xml, "txf_category_label");
+        label = GTK_WIDGET(gtk_builder_get_object (builder, "txf_category_label"));
         gtk_label_set_mnemonic_widget(GTK_LABEL(label), GTK_WIDGET(tree_view));
 
-        button = glade_xml_get_widget (xml, "current_account_button");
+        button = GTK_WIDGET(gtk_builder_get_object (builder, "current_account_button"));
         ti_dialog->current_account_button = button;
 
-        button = glade_xml_get_widget (xml, "parent_account_button");
+        button = GTK_WIDGET(gtk_builder_get_object (builder, "parent_account_button"));
         ti_dialog->parent_account_button = button;
 
+        ti_dialog->help_scroll = GTK_WIDGET(gtk_builder_get_object (builder, "help_scroll"));
+        ti_dialog->payer_vbox = GTK_WIDGET(gtk_builder_get_object (builder, "payer_name_source_vbox"));
+        ti_dialog->copy_vbox = GTK_WIDGET(gtk_builder_get_object (builder, "copy_number_vbox"));
+        ti_dialog->txf_vbox = GTK_WIDGET(gtk_builder_get_object (builder, "txf_categories_vbox"));
+        ti_dialog->pns_vbox = GTK_WIDGET(gtk_builder_get_object (builder, "pns_copy_hbox"));
+
         g_signal_connect (G_OBJECT (button), "toggled",
                           G_CALLBACK  (current_account_toggled_cb),
                           ti_dialog);
 
-        button = glade_xml_get_widget (xml, "copy_spin_button");
+        button = GTK_WIDGET(gtk_builder_get_object (builder, "copy_spin_button"));
         ti_dialog->copy_spin_button = button;
 
         g_signal_connect (G_OBJECT (button), "value-changed",
@@ -1327,10 +1388,12 @@ gnc_tax_info_dialog_create (GtkWidget * parent, TaxInfoDialog *ti_dialog)
 
     /* account tree */
     {
-        GtkWidget *income_radio, *expense_radio, *asset_radio, *liab_eq_radio, *box;
+        GtkWidget *income_radio, *expense_radio, *asset_radio,
+                  *liab_eq_radio, *box;
+
+        ti_dialog->acct_info = GTK_WIDGET(gtk_builder_get_object (builder, "acct_info_vbox"));
+        ti_dialog->num_acct_label = GTK_WIDGET(gtk_builder_get_object (builder, "num_accounts_label"));
 
-        ti_dialog->acct_info = glade_xml_get_widget (xml, "acct_info_vbox");
-        box = glade_xml_get_widget (xml, "account_scroll");
         tree_view = gnc_tree_view_account_new (FALSE);
         gnc_tree_view_account_set_filter (GNC_TREE_VIEW_ACCOUNT(tree_view),
                                           gnc_tax_info_dialog_account_filter_func,
@@ -1344,20 +1407,22 @@ gnc_tax_info_dialog_create (GtkWidget * parent, TaxInfoDialog *ti_dialog)
                           ti_dialog);
 
         gtk_widget_show (ti_dialog->account_treeview);
+        box = GTK_WIDGET(gtk_builder_get_object (builder, "account_scroll"));
         gtk_container_add (GTK_CONTAINER (box), ti_dialog->account_treeview);
 
-        label = glade_xml_get_widget(xml, "accounts_label");
+        label = GTK_WIDGET(gtk_builder_get_object (builder, "accounts_label"));
         gtk_label_set_mnemonic_widget(GTK_LABEL(label), GTK_WIDGET(tree_view));
 
-        income_radio = glade_xml_get_widget (xml, "income_radio");
-        expense_radio = glade_xml_get_widget (xml, "expense_radio");
+        income_radio = GTK_WIDGET(gtk_builder_get_object (builder, "income_radio"));
+        expense_radio = GTK_WIDGET(gtk_builder_get_object (builder, "expense_radio"));
         ti_dialog->expense_radio = expense_radio;
-        asset_radio = glade_xml_get_widget (xml, "asset_radio");
+        asset_radio = GTK_WIDGET(gtk_builder_get_object (builder, "asset_radio"));
         ti_dialog->asset_radio = asset_radio;
-        liab_eq_radio = glade_xml_get_widget (xml, "liab_eq_radio");
+        liab_eq_radio = GTK_WIDGET(gtk_builder_get_object (builder, "liab_eq_radio"));
         ti_dialog->liab_eq_radio = liab_eq_radio;
-        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(expense_radio), TRUE);
         ti_dialog->account_type = ACCT_TYPE_EXPENSE;
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(expense_radio), TRUE);
+
         g_signal_connect (G_OBJECT (income_radio), "toggled",
                           G_CALLBACK  (gnc_tax_info_acct_type_cb),
                           ti_dialog);
@@ -1376,7 +1441,7 @@ gnc_tax_info_dialog_create (GtkWidget * parent, TaxInfoDialog *ti_dialog)
     {
         GtkWidget *button;
 
-        button = glade_xml_get_widget (xml, "select_subaccounts_button");
+        button = GTK_WIDGET(gtk_builder_get_object (builder, "select_subaccounts_button"));
         ti_dialog->select_button = button;
 
         g_signal_connect (G_OBJECT (button), "clicked",
@@ -1394,12 +1459,14 @@ gnc_tax_info_dialog_create (GtkWidget * parent, TaxInfoDialog *ti_dialog)
 
     gnc_restore_window_size(GCONF_SECTION, GTK_WINDOW(ti_dialog->dialog));
 
+    ti_dialog->paned = GTK_WIDGET(gtk_builder_get_object (builder, "paned"));
+
     if (gnc_gconf_get_bool(GCONF_GENERAL, KEY_SAVE_GEOMETRY, NULL))
     {
-        GtkWidget *paned = glade_xml_get_widget(xml, "paned");
         gint position = gnc_gconf_get_int(GCONF_SECTION, PANED_POSITION, NULL);
-        gtk_paned_set_position(GTK_PANED(paned), position);
+        gtk_paned_set_position(GTK_PANED(ti_dialog->paned), position);
     }
+    g_object_unref (builder);
 }
 
 static void
@@ -1409,9 +1476,8 @@ close_handler (gpointer user_data)
 
     if (gnc_gconf_get_bool(GCONF_GENERAL, KEY_SAVE_GEOMETRY, NULL))
     {
-        GtkWidget *paned = gnc_glade_lookup_widget(ti_dialog->dialog, "paned");
         gnc_gconf_set_int(GCONF_SECTION, PANED_POSITION,
-                          gtk_paned_get_position(GTK_PANED(paned)), NULL);
+                          gtk_paned_get_position(GTK_PANED(ti_dialog->paned)), NULL);
     }
 
     gnc_save_window_size(GCONF_SECTION, GTK_WINDOW(ti_dialog->dialog));
