@@ -38,6 +38,7 @@
 #include <glib/gi18n.h>
 #include "gnc-plugin-page-account-tree.h"
 #include "gnc-plugin-page-register.h"
+#include "gnc-plugin-page-register2.h"
 
 #include "Scrub.h"
 #include "Scrub3.h"
@@ -45,7 +46,7 @@
 #include "dialog-account.h"
 #include "dialog-transfer.h"
 #include "dialog-utils.h"
-#include "druid-hierarchy.h"
+#include "assistant-hierarchy.h"
 #include "gnc-account-sel.h"
 #include "gnc-component-manager.h"
 #include "gnc-engine.h"
@@ -60,7 +61,7 @@
 #include "gnc-tree-model-account-types.h"
 #include "gnc-ui.h"
 #include "gnc-ui-util.h"
-#include "lot-viewer.h"
+#include "dialog-lot-viewer.h"
 #include "window-reconcile.h"
 #include "window-autoclear.h"
 #include "window-main-summarybar.h"
@@ -72,8 +73,12 @@ static QofLogModule log_module = GNC_MOD_GUI;
 #define PLUGIN_PAGE_ACCT_TREE_CM_CLASS "plugin-page-acct-tree"
 #define GCONF_SECTION "window/pages/account_tree"
 
-#define DELETE_DIALOG_FILTER  "filter"
-#define DELETE_DIALOG_ACCOUNT "account"
+#define DELETE_DIALOG_FILTER       "filter"
+#define DELETE_DIALOG_ACCOUNT      "account"
+#define DELETE_DIALOG_TRANS_MAS    "trans_mas"
+#define DELETE_DIALOG_SA_MAS       "sa_mas"
+#define DELETE_DIALOG_SA_TRANS_MAS "sa_trans_mas"
+#define DELETE_DIALOG_OK_BUTTON    "deletebutton"
 
 enum
 {
@@ -101,6 +106,7 @@ static GObjectClass *parent_class = NULL;
 static void gnc_plugin_page_account_tree_class_init (GncPluginPageAccountTreeClass *klass);
 static void gnc_plugin_page_account_tree_init (GncPluginPageAccountTree *plugin_page);
 static void gnc_plugin_page_account_tree_finalize (GObject *object);
+static void gnc_plugin_page_account_tree_selected (GObject *object, gpointer user_data);
 
 static GtkWidget *gnc_plugin_page_account_tree_create_widget (GncPluginPage *plugin_page);
 static void gnc_plugin_page_account_tree_destroy_widget (GncPluginPage *plugin_page);
@@ -120,8 +126,8 @@ static void gnc_plugin_page_account_tree_double_click_cb (GtkTreeView        *tr
 
 static void gnc_plugin_page_account_tree_selection_changed_cb (GtkTreeSelection *selection,
         GncPluginPageAccountTree *page);
-void gppat_populate_tmas_list(GtkToggleButton *dmrb, gpointer tmas);
-void gppat_set_insensitive_iff_rb_active(GtkToggleButton *b, GtkWidget *widget);
+void gppat_populate_trans_mas_list(GtkToggleButton *sa_mrb, GtkWidget *dialog);
+void gppat_set_insensitive_iff_rb_active(GtkWidget *widget, GtkToggleButton *b);
 
 /* Command callbacks */
 static void gnc_plugin_page_account_tree_cmd_new_account (GtkAction *action, GncPluginPageAccountTree *plugin_page);
@@ -141,6 +147,9 @@ static void gnc_plugin_page_account_tree_cmd_scrub (GtkAction *action, GncPlugin
 static void gnc_plugin_page_account_tree_cmd_scrub_sub (GtkAction *action, GncPluginPageAccountTree *page);
 static void gnc_plugin_page_account_tree_cmd_scrub_all (GtkAction *action, GncPluginPageAccountTree *page);
 
+/* Command callback for new Register Test */
+static void gnc_plugin_page_account_tree_cmd_open2_account (GtkAction *action, GncPluginPageAccountTree *page);
+static void gnc_plugin_page_account_tree_cmd_open2_subaccounts (GtkAction *action, GncPluginPageAccountTree *page);
 
 static guint plugin_page_signals[LAST_SIGNAL] = { 0 };
 
@@ -157,18 +166,28 @@ static GtkActionEntry gnc_plugin_page_account_tree_actions [] =
         G_CALLBACK (gnc_plugin_page_account_tree_cmd_new_account)
     },
     {
-        "FileAddAccountHierarchyDruidAction", GNC_STOCK_NEW_ACCOUNT, N_("New Account _Hierarchy..."), NULL,
+        "FileAddAccountHierarchyAssistantAction", GNC_STOCK_NEW_ACCOUNT, N_("New Account _Hierarchy..."), NULL,
         N_("Extend the current book by merging with new account type categories"),
         G_CALLBACK (gnc_plugin_page_account_tree_cmd_file_new_hierarchy)
     },
     {
-        "FileOpenAccountAction", GNC_STOCK_OPEN_ACCOUNT, N_("Open _Account"), NULL,
+        "FileOpenAccount2Action", GNC_STOCK_OPEN_ACCOUNT, N_("Open _Account"), NULL,
         N_("Open the selected account"),
+        G_CALLBACK (gnc_plugin_page_account_tree_cmd_open2_account)
+    },
+    {
+        "FileOpenAccountAction", GNC_STOCK_OPEN_ACCOUNT, N_("Open _Old Style Register Account"), NULL,
+        N_("Open the old style register selected account"),
         G_CALLBACK (gnc_plugin_page_account_tree_cmd_open_account)
     },
     {
-        "FileOpenSubaccountsAction", GNC_STOCK_OPEN_ACCOUNT, N_("Open _Subaccounts"), NULL,
+        "FileOpenSubaccounts2Action", GNC_STOCK_OPEN_ACCOUNT, N_("Open _SubAccounts"), NULL,
         N_("Open the selected account and all its subaccounts"),
+        G_CALLBACK (gnc_plugin_page_account_tree_cmd_open2_subaccounts)
+    },
+    {
+        "FileOpenSubaccountsAction", GNC_STOCK_OPEN_ACCOUNT, N_("Open Old St_yle Subaccounts"), NULL,
+        N_("Open the old style register selected account and all its subaccounts"),
         G_CALLBACK (gnc_plugin_page_account_tree_cmd_open_subaccounts)
     },
 
@@ -243,25 +262,51 @@ static guint gnc_plugin_page_account_tree_n_actions = G_N_ELEMENTS (gnc_plugin_p
 
 
 /** Actions that require an account to be selected before they are
- *  enabled. */
-static const gchar *actions_requiring_account[] =
+ *  enabled, and the book is in read-write mode. */
+static const gchar *actions_requiring_account_rw[] =
 {
-    "FileOpenAccountAction",
-    "FileOpenSubaccountsAction",
     "EditEditAccountAction",
     "EditDeleteAccountAction",
     "ActionsReconcileAction",
     "ActionsAutoClearAction",
+    NULL
+};
+
+/** Actions that require an account to be selected before they are
+ *  enabled. Those actions can be selected even if the book is in readonly mode. */
+static const gchar *actions_requiring_account_always[] =
+{
+    "FileOpenAccountAction",
+    "FileOpenAccount2Action",
+    "FileOpenSubaccountsAction",
     "ActionsLotsAction",
     NULL
 };
 
+/* This is the list of actions which are switched inactive in a read-only book. */
+static const gchar* readonly_inactive_actions[] =
+{
+    "FileNewAccountAction",
+    "FileAddAccountHierarchyAssistantAction",
+    "EditEditAccountAction",
+    "EditDeleteAccountAction",
+    "EditRenumberSubaccountsAction",
+    "ActionsTransferAction",
+    "ActionsReconcileAction",
+    "ActionsAutoClearAction",
+    "ActionsStockSplitAction",
+    "ScrubAction",
+    "ScrubSubAction",
+    "ScrubAllAction",
+    NULL
+};
 
 /** Short labels for use on the toolbar buttons. */
 static action_toolbar_labels toolbar_labels[] =
 {
-    { "FileOpenAccountAction", 	    N_("Open") },
-    { "EditEditAccountAction", 	    N_("Edit") },
+    { "FileOpenAccountAction", 	            N_("Open") },
+    { "FileOpenAccount2Action", 	    N_("Open2") },
+    { "EditEditAccountAction", 	            N_("Edit") },
     { "FileNewAccountAction",    	    N_("New") },
     { "EditDeleteAccountAction", 	    N_("Delete") },
     { NULL, NULL },
@@ -355,8 +400,10 @@ gnc_plugin_page_account_tree_init (GncPluginPageAccountTree *plugin_page)
     g_object_set(G_OBJECT(plugin_page),
                  "page-name",      _("Accounts"),
                  "page-uri",       "default:",
-                 "ui-description", "gnc-plugin-page-account-tree-ui.xml",
+                 "ui-description", "gnc-plugin-page-account-tree2-ui.xml",
                  NULL);
+    g_signal_connect (G_OBJECT (plugin_page), "selected",
+                      G_CALLBACK (gnc_plugin_page_account_tree_selected), plugin_page);
 
     /* change me when the system supports multiple books */
     gnc_plugin_page_add_book(parent, gnc_get_current_book());
@@ -380,7 +427,7 @@ gnc_plugin_page_account_tree_init (GncPluginPageAccountTree *plugin_page)
                                  plugin_page);
     gnc_plugin_init_short_names (action_group, toolbar_labels);
 
-    /* Visisble types */
+    /* Visible types */
     priv->fd.visible_types = -1; /* Start with all types */
     priv->fd.show_hidden = FALSE;
     priv->fd.show_zero_total = TRUE;
@@ -446,11 +493,7 @@ gnc_plugin_page_account_refresh_cb (GHashTable *changes, gpointer user_data)
 static void
 gnc_plugin_page_account_tree_close_cb (gpointer user_data)
 {
-    GncPluginPage *plugin_page;
-    GncPluginPageAccountTree *page;
-
-    plugin_page = GNC_PLUGIN_PAGE(user_data);
-    page = GNC_PLUGIN_PAGE_ACCOUNT_TREE (plugin_page);
+    GncPluginPage *plugin_page = GNC_PLUGIN_PAGE(user_data);
     gnc_main_window_close_page(plugin_page);
 }
 
@@ -574,6 +617,35 @@ gnc_plugin_page_account_tree_destroy_widget (GncPluginPage *plugin_page)
     LEAVE("widget destroyed");
 }
 
+static void update_inactive_actions(GncPluginPage *plugin_page)
+{
+    GtkActionGroup *action_group;
+    gboolean is_sensitive = !qof_book_is_readonly(gnc_get_current_book());
+
+    // We are readonly - so we have to switch particular actions to inactive.
+    g_return_if_fail(plugin_page);
+    g_return_if_fail(GNC_IS_PLUGIN_PAGE(plugin_page));
+
+    /* Get the action group */
+    action_group = gnc_plugin_page_get_action_group(plugin_page);
+    g_return_if_fail(GTK_IS_ACTION_GROUP (action_group));
+
+    /* Set the action's sensitivity */
+    gnc_plugin_update_actions (action_group, readonly_inactive_actions,
+                               "sensitive", is_sensitive);
+}
+
+/**
+ * Called when this page is selected.
+ *
+ * Update the toolbar button sensitivity. */
+static void gnc_plugin_page_account_tree_selected (GObject *object, gpointer user_data)
+{
+    GncPluginPage *plugin_page = GNC_PLUGIN_PAGE (object);
+    g_return_if_fail (GNC_IS_PLUGIN_PAGE (plugin_page));
+    update_inactive_actions(plugin_page);
+}
+
 /** Save enough information about this account tree page that it can
  *  be recreated next time the user starts gnucash.
  *
@@ -689,12 +761,11 @@ gnc_plugin_page_account_tree_button_press_cb (GtkWidget *widget,
         GdkEventButton *event,
         GncPluginPage *page)
 {
-    gboolean result;
 
     g_return_val_if_fail(GNC_IS_PLUGIN_PAGE(page), FALSE);
 
     ENTER("widget %p, event %p, page %p", widget, event, page);
-    result = gnc_main_window_button_press_cb(widget, event, page);
+    gnc_main_window_button_press_cb(widget, event, page);
     LEAVE(" ");
 
     /* Always return FALSE.  This will let the tree view callback run as
@@ -709,30 +780,67 @@ gppat_open_account_common (GncPluginPageAccountTree *page,
                            Account *account,
                            gboolean include_subs)
 {
-    GncPluginPageAccountTreePrivate *priv;
     GtkWidget *window;
     GncPluginPage *new_page;
 
     if (account == NULL)
         return;
 
-    priv = GNC_PLUGIN_PAGE_ACCOUNT_TREE_GET_PRIVATE(page);
     window = GNC_PLUGIN_PAGE (page)->window;
     new_page = gnc_plugin_page_register_new (account, include_subs);
     gnc_main_window_open_page (GNC_MAIN_WINDOW(window), new_page);
 }
 
+/*################## Added for Reg2 #################*/
+/*        New Register Common                        */
 static void
-gnc_plugin_page_account_tree_double_click_cb (GtkTreeView        *treeview,
-        GtkTreePath        *path,
-        GtkTreeViewColumn  *col,
-        GncPluginPageAccountTree *page)
+gppat_open2_account_common (GncPluginPageAccountTree *page,
+                           Account *account,
+                           gboolean include_subs)
 {
-    Account *account;
+    GtkWidget *window;
+    GncPluginPage *new_page;
+
+    if (account == NULL)
+        return;
+
+    window = GNC_PLUGIN_PAGE (page)->window;
+    new_page = gnc_plugin_page_register2_new (account, include_subs);
+    gnc_main_window_open_page (GNC_MAIN_WINDOW(window), new_page);
+}
+/*################## Added for Reg2 #################*/
+
+static void
+gnc_plugin_page_account_tree_double_click_cb (GtkTreeView *treeview,
+                                              GtkTreePath        *path,
+                                              GtkTreeViewColumn  *col,
+                                              GncPluginPageAccountTree *page)
+{
+    GtkTreeModel *model;
+    GtkTreeIter iter;
 
     g_return_if_fail (GNC_IS_PLUGIN_PAGE_ACCOUNT_TREE (page));
-    account = gnc_tree_view_account_get_account_from_path (GNC_TREE_VIEW_ACCOUNT(treeview), path);
-    gppat_open_account_common (page, account, FALSE);
+    g_return_if_fail (treeview);
+
+    model = gtk_tree_view_get_model(treeview);
+    if (gtk_tree_model_get_iter(model, &iter, path))
+    {
+        if (gtk_tree_model_iter_has_child(model, &iter))
+        {
+            /* There are children,
+             * just expand or collapse the row. */
+            if (gtk_tree_view_row_expanded(treeview, path))
+                gtk_tree_view_collapse_row(treeview, path);
+            else
+                gtk_tree_view_expand_row(treeview, path, FALSE);
+        }
+        else
+        {
+            /* It's an account without any children, so open its register */
+            Account *account = gnc_tree_view_account_get_account_from_path (GNC_TREE_VIEW_ACCOUNT(treeview), path);
+            gppat_open2_account_common (page, account, FALSE);
+        }
+    }
 }
 
 static void
@@ -745,6 +853,7 @@ gnc_plugin_page_account_tree_selection_changed_cb (GtkTreeSelection *selection,
     Account *account = NULL;
     gboolean sensitive;
     gboolean subaccounts;
+    gboolean is_readwrite = !qof_book_is_readonly(gnc_get_current_book());
 
     g_return_if_fail(GNC_IS_PLUGIN_PAGE_ACCOUNT_TREE(page));
 
@@ -765,15 +874,19 @@ gnc_plugin_page_account_tree_selection_changed_cb (GtkTreeSelection *selection,
     }
 
     action_group = gnc_plugin_page_get_action_group(GNC_PLUGIN_PAGE(page));
-    gnc_plugin_update_actions (action_group, actions_requiring_account,
+    gnc_plugin_update_actions (action_group, actions_requiring_account_rw,
+                               "sensitive", is_readwrite && sensitive);
+    gnc_plugin_update_actions (action_group, actions_requiring_account_always,
                                "sensitive", sensitive);
     g_signal_emit (page, plugin_page_signals[ACCOUNT_SELECTED], 0, account);
 
     action = gtk_action_group_get_action (action_group, "EditRenumberSubaccountsAction");
     g_object_set (G_OBJECT(action), "sensitive",
-                  sensitive && subaccounts, NULL);
+                  is_readwrite && sensitive && subaccounts, NULL);
 
-    gnc_plugin_update_actions (action_group, actions_requiring_account,
+    gnc_plugin_update_actions (action_group, actions_requiring_account_rw,
+                               "sensitive", is_readwrite && sensitive);
+    gnc_plugin_update_actions (action_group, actions_requiring_account_always,
                                "sensitive", sensitive);
 }
 
@@ -790,7 +903,7 @@ gnc_plugin_page_account_tree_cmd_new_account (GtkAction *action, GncPluginPageAc
 static void
 gnc_plugin_page_account_tree_cmd_file_new_hierarchy (GtkAction *action, GncPluginPageAccountTree *page)
 {
-    gnc_ui_hierarchy_druid(FALSE);
+    gnc_ui_hierarchy_assistant(FALSE);
 }
 
 static void
@@ -815,6 +928,33 @@ gnc_plugin_page_account_tree_cmd_open_subaccounts (GtkAction *action,
     gppat_open_account_common (page, account, TRUE);
 }
 
+
+/*################## Added for Reg2 #################*/
+/* Register Firing - Single Account to start with    */
+static void
+gnc_plugin_page_account_tree_cmd_open2_account (GtkAction *action,
+        GncPluginPageAccountTree *page)
+{
+    Account *account;
+
+    g_return_if_fail (GNC_IS_PLUGIN_PAGE_ACCOUNT_TREE (page));
+    account = gnc_plugin_page_account_tree_get_current_account (page);
+    gppat_open2_account_common (page, account, FALSE);
+}
+
+static void
+gnc_plugin_page_account_tree_cmd_open2_subaccounts (GtkAction *action,
+        GncPluginPageAccountTree *page)
+{
+    Account *account;
+
+    g_return_if_fail (GNC_IS_PLUGIN_PAGE_ACCOUNT_TREE (page));
+    account = gnc_plugin_page_account_tree_get_current_account (page);
+    gppat_open2_account_common (page, account, TRUE);
+}
+/*################## Added for Reg2 #################*/
+
+
 static void
 gnc_plugin_page_account_tree_cmd_edit_account (GtkAction *action, GncPluginPageAccountTree *page)
 {
@@ -875,21 +1015,21 @@ static void
 set_ok_sensitivity(GtkWidget *dialog)
 {
     GtkWidget *button;
-    gpointer dmas, tmas;
-    gint dmas_cnt, tmas_cnt;
+    GtkWidget *sa_mas, *trans_mas;
+    gint sa_mas_cnt, trans_mas_cnt;
     gboolean sensitive;
 
-    dmas = g_object_get_data(G_OBJECT(dialog), "dmas");
-    tmas = g_object_get_data(G_OBJECT(dialog), "tmas");
-    dmas_cnt = gnc_account_sel_get_num_account(GNC_ACCOUNT_SEL(dmas));
-    tmas_cnt = gnc_account_sel_get_num_account(GNC_ACCOUNT_SEL(tmas));
+    sa_mas = g_object_get_data(G_OBJECT(dialog), DELETE_DIALOG_SA_MAS);
+    trans_mas = g_object_get_data(G_OBJECT(dialog), DELETE_DIALOG_TRANS_MAS);
+    sa_mas_cnt = gnc_account_sel_get_num_account(GNC_ACCOUNT_SEL(sa_mas));
+    trans_mas_cnt = gnc_account_sel_get_num_account(GNC_ACCOUNT_SEL(trans_mas));
 
-    sensitive = (((NULL == dmas) ||
-                  (!GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(dmas)) || dmas_cnt)) &&
-                 ((NULL == tmas) ||
-                  (!GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(tmas)) || tmas_cnt)));
+    sensitive = (((NULL == sa_mas) ||
+                  (!gtk_widget_is_sensitive(sa_mas) || sa_mas_cnt)) &&
+                 ((NULL == trans_mas) ||
+                  (!gtk_widget_is_sensitive(trans_mas) || trans_mas_cnt)));
 
-    button = gnc_glade_lookup_widget(dialog, "deletebutton");
+    button = g_object_get_data(G_OBJECT(dialog), DELETE_DIALOG_OK_BUTTON);
     gtk_widget_set_sensitive(button, sensitive);
 }
 
@@ -914,22 +1054,29 @@ gppat_populate_gas_list(GtkWidget *dialog,
     gnc_account_sel_purge_account( gas, account, exclude_subaccounts);
 
     /* The sensitivity of the OK button needs to be reevaluated. */
-    set_ok_sensitivity(GTK_WIDGET(dialog));
+    set_ok_sensitivity(dialog);
 }
 
 void
-gppat_populate_tmas_list(GtkToggleButton *damrb,
-                         gpointer tmas)
+gppat_populate_trans_mas_list(GtkToggleButton *sa_mrb,
+                              GtkWidget *dialog)
 {
-    GtkWidget *dialog;
+    GtkWidget *trans_mas;
+
+    g_return_if_fail(GTK_IS_DIALOG(dialog));
 
     /* Cannot move transactions to subaccounts if they are to be deleted. */
-    dialog = gnc_glade_lookup_widget(GTK_WIDGET(damrb), "Delete Account");
-    gppat_populate_gas_list(dialog, tmas, !gtk_toggle_button_get_active(damrb));
+    trans_mas = g_object_get_data(G_OBJECT(dialog), DELETE_DIALOG_TRANS_MAS);
+    gppat_populate_gas_list(dialog, GNC_ACCOUNT_SEL(trans_mas), !gtk_toggle_button_get_active(sa_mrb));
 }
 
+/* Note that the emitting object (the toggle button) and the signal data
+ * are swapped in below callback function. This is a gtkbuilder feature:
+ * it swaps if you explicitly set an object for a signal handler in the
+ * gtkbuilder xml file.
+ */
 void
-gppat_set_insensitive_iff_rb_active(GtkToggleButton *b, GtkWidget *widget)
+gppat_set_insensitive_iff_rb_active(GtkWidget *widget, GtkToggleButton *b)
 {
     gtk_widget_set_sensitive(widget, !gtk_toggle_button_get_active(b));
     set_ok_sensitivity(gtk_widget_get_toplevel(widget));
@@ -940,19 +1087,17 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
 {
     Account *account = gnc_plugin_page_account_tree_get_current_account (page);
     gchar *acct_name;
-    GList *splits;
     delete_helper_t delete_res = { FALSE, FALSE };
-    GtkWidget *widget;
     GtkWidget *window;
-    GtkWidget *dialog = NULL;
-    GNCAccountSel *damas = NULL; /* descendant account move account selector */
-    GNCAccountSel *dtmas = NULL; /* descendant transaction move account selector */
-    GNCAccountSel *tmas = NULL; /* transaction move account selector */
-    gint response;
+    GtkWidget *trans_mas = NULL; /* transaction move to account selector */
+    GtkWidget *sa_mas = NULL;    /* subaccount move to account selector */
+    GtkWidget *sa_trans_mas = NULL; /* subaccount's transaction move to account selector */
     Account *ta = NULL; /* transaction adopter */
-    Account *daa = NULL; /* descendant account adopter */
-    Account *dta = NULL; /* descendant transaction adopter */
+    Account *saa = NULL; /* subaccount adopter */
+    Account *sta = NULL; /* subaccount transaction adopter */
+    GList *splits;
     GList* list;
+    gint response;
 
     if (NULL == account)
         return;
@@ -984,20 +1129,26 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
      */
     if ((NULL != splits) || (gnc_account_n_children(account) > 0))
     {
-        GList *filter;
-        GladeXML *xml;
-        GtkWidget *label;
-        gchar *message;
+        GList *filter = NULL;
+        GtkBuilder *builder = NULL;
+        GtkWidget *dialog = NULL;
+        GtkWidget *box = NULL;
+        GtkWidget *widget = NULL;
+        gchar *title = NULL;
 
-        xml = gnc_glade_xml_new ("account.glade", "Delete Account");
-        dialog = glade_xml_get_widget (xml, "Delete Account");
+        builder = gtk_builder_new();
+        gnc_builder_add_from_file (builder, "dialog-account.glade", "Delete Account");
+
+        dialog = GTK_WIDGET(gtk_builder_get_object (builder, "Delete Account"));
         gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(window));
-        glade_xml_signal_autoconnect_full(xml, gnc_glade_autoconnect_full_func, dialog);
 
-        label = glade_xml_get_widget (xml, "header");
-        message = g_strdup_printf(_("Deleting account %s"), acct_name);
-        gtk_label_set_text(GTK_LABEL(label), message);
-        g_free(message);
+        widget = GTK_WIDGET(gtk_builder_get_object (builder, "header"));
+        title = g_strdup_printf(_("Deleting account %s"), acct_name);
+        gtk_label_set_text(GTK_LABEL(widget), title);
+        g_free(title);
+
+        widget = GTK_WIDGET(gtk_builder_get_object (builder, DELETE_DIALOG_OK_BUTTON));
+        g_object_set_data(G_OBJECT(dialog), DELETE_DIALOG_OK_BUTTON, widget);
 
         /*
          * Reparent only to accounts of the same
@@ -1015,24 +1166,27 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
         {
             delete_helper_t delete_res2 = { FALSE, FALSE };
 
-            tmas = GNC_ACCOUNT_SEL(glade_xml_get_widget (xml, "tmas"));
-            gppat_populate_gas_list(dialog, tmas, FALSE);
+            trans_mas = gnc_account_sel_new();
+            box = GTK_WIDGET(gtk_builder_get_object (builder, "trans_mas_hbox"));
+            gtk_box_pack_start (GTK_BOX(box), trans_mas, TRUE, TRUE, 0);
+            g_object_set_data(G_OBJECT(dialog), DELETE_DIALOG_TRANS_MAS, trans_mas);
+            gppat_populate_gas_list(dialog, GNC_ACCOUNT_SEL(trans_mas), FALSE);
 
             delete_account_helper(account, &delete_res2);
             if (delete_res2.has_ro_splits)
             {
-                gtk_widget_destroy(glade_xml_get_widget (xml, "trans_rw"));
-                widget = glade_xml_get_widget (xml, "tdrb");
+                gtk_widget_destroy(GTK_WIDGET(gtk_builder_get_object (builder, "trans_rw")));
+                widget = GTK_WIDGET(gtk_builder_get_object (builder, "trans_drb"));
                 gtk_widget_set_sensitive(widget, FALSE);
             }
             else
             {
-                gtk_widget_destroy(glade_xml_get_widget (xml, "trans_ro"));
+                gtk_widget_destroy(GTK_WIDGET(gtk_builder_get_object (builder, "trans_ro")));
             }
         }
         else
         {
-            gtk_widget_destroy(glade_xml_get_widget (xml, "transactions"));
+            gtk_widget_destroy(GTK_WIDGET(gtk_builder_get_object (builder, "transactions")));
         }
 
         /*
@@ -1047,32 +1201,43 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
                                                  &delete_res);
             if (delete_res.has_ro_splits)
             {
-                gtk_widget_destroy(glade_xml_get_widget (xml, "sa_trans_rw"));
-                widget = glade_xml_get_widget (xml, "dtdrb");
+                gtk_widget_destroy(GTK_WIDGET(gtk_builder_get_object (builder, "sa_trans_rw")));
+                widget = GTK_WIDGET(gtk_builder_get_object (builder, "sa_trans_drb"));
                 gtk_widget_set_sensitive(widget, FALSE);
             }
             else if (delete_res.has_splits)
             {
-                gtk_widget_destroy(glade_xml_get_widget (xml, "sa_trans_ro"));
+                gtk_widget_destroy(GTK_WIDGET(gtk_builder_get_object (builder, "sa_trans_ro")));
             }
             else
             {
-                gtk_widget_destroy(glade_xml_get_widget (xml, "subaccount_trans"));
+                gtk_widget_destroy(GTK_WIDGET(gtk_builder_get_object (builder, "subaccount_trans")));
             }
-            damas = GNC_ACCOUNT_SEL(glade_xml_get_widget (xml, "damas"));
-            gppat_populate_gas_list(dialog, damas, TRUE);
-            dtmas = GNC_ACCOUNT_SEL(glade_xml_get_widget (xml, "dtmas"));
-            gppat_populate_gas_list(dialog, dtmas, TRUE);
+
+            sa_mas = gnc_account_sel_new();
+            box = GTK_WIDGET(gtk_builder_get_object (builder, "sa_mas_hbox"));
+            gtk_box_pack_start (GTK_BOX(box), sa_mas, TRUE, TRUE, 0);
+            g_object_set_data(G_OBJECT(dialog), DELETE_DIALOG_SA_MAS, sa_mas);
+            gppat_populate_gas_list(dialog, GNC_ACCOUNT_SEL(sa_mas), TRUE);
+
+            sa_trans_mas = gnc_account_sel_new();
+            box = GTK_WIDGET(gtk_builder_get_object (builder, "sa_trans_mas_hbox"));
+            gtk_box_pack_start (GTK_BOX(box), sa_trans_mas, TRUE, TRUE, 0);
+            g_object_set_data(G_OBJECT(dialog), DELETE_DIALOG_SA_TRANS_MAS, sa_trans_mas);
+            gppat_populate_gas_list(dialog, GNC_ACCOUNT_SEL(sa_trans_mas), TRUE);
         }
         else
         {
-            gtk_widget_destroy(glade_xml_get_widget (xml, "subaccounts"));
-            gtk_widget_destroy(glade_xml_get_widget (xml, "subaccount_trans"));
+            gtk_widget_destroy(GTK_WIDGET(gtk_builder_get_object (builder, "subaccounts")));
+            gtk_widget_destroy(GTK_WIDGET(gtk_builder_get_object (builder, "subaccount_trans")));
         }
 
         /* default to cancel */
         gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_CANCEL);
 
+        gtk_builder_connect_signals(builder, dialog);
+        g_object_unref(G_OBJECT(builder));
+
         /*
          * Note that one effect of the modal dialog is preventing
          * the account selectors from being repopulated.
@@ -1087,12 +1252,12 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
             g_free(acct_name);
             return;
         }
-        if (tmas && GTK_WIDGET_IS_SENSITIVE(tmas))
-            ta = gnc_account_sel_get_account(tmas);
-        if (damas && GTK_WIDGET_IS_SENSITIVE(damas))
-            daa = gnc_account_sel_get_account(damas);
-        if (dtmas && GTK_WIDGET_IS_SENSITIVE(dtmas))
-            dta = gnc_account_sel_get_account(dtmas);
+        if (trans_mas && gtk_widget_is_sensitive(trans_mas))
+            ta = gnc_account_sel_get_account(GNC_ACCOUNT_SEL(trans_mas));
+        if (sa_mas && gtk_widget_is_sensitive(sa_mas))
+            saa = gnc_account_sel_get_account(GNC_ACCOUNT_SEL(sa_mas));
+        if (sa_trans_mas && gtk_widget_is_sensitive(sa_trans_mas))
+            sta = gnc_account_sel_get_account(GNC_ACCOUNT_SEL(sa_trans_mas));
         gtk_widget_destroy(dialog);
         g_list_free(filter);
     } /* (NULL != splits) || (NULL != children) */
@@ -1107,6 +1272,7 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
         char *message;
         char *name;
         int i = 0;
+        GtkWidget *dialog;
 
         lines[0] = g_strdup_printf(format, acct_name);
         if (splits)
@@ -1126,9 +1292,9 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
         }
         if (gnc_account_n_children(account) > 0)
         {
-            if (daa)
+            if (saa)
             {
-                name = gnc_account_get_full_name(daa);
+                name = gnc_account_get_full_name(saa);
                 format = _("All of its sub-accounts will be moved to "
                            "the account %s.");
                 lines[++i] = g_strdup_printf(format, name);
@@ -1137,9 +1303,9 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
             {
                 format = _("All of its subaccounts will be deleted.");
                 lines[++i] = g_strdup_printf("%s", format);
-                if (dta)
+                if (sta)
                 {
-                    name = gnc_account_get_full_name(dta);
+                    name = gnc_account_get_full_name(sta);
                     format = _("All sub-account transactions will be moved to "
                                "the account %s.");
                     lines[++i] = g_strdup_printf(format, name);
@@ -1179,23 +1345,23 @@ gnc_plugin_page_account_tree_cmd_delete_account (GtkAction *action, GncPluginPag
             gnc_set_busy_cursor(NULL, TRUE);
             gnc_suspend_gui_refresh ();
             xaccAccountBeginEdit (account);
-            if (NULL != daa)
+            if (NULL != saa)
             {
                 GList *acct_list, *ptr;
 
-                xaccAccountBeginEdit (daa);
+                xaccAccountBeginEdit (saa);
                 acct_list = gnc_account_get_children(account);
                 for (ptr = acct_list; ptr; ptr = g_list_next(ptr))
-                    gnc_account_append_child (daa, ptr->data);
+                    gnc_account_append_child (saa, ptr->data);
                 g_list_free(acct_list);
-                xaccAccountCommitEdit (daa);
+                xaccAccountCommitEdit (saa);
             }
-            else if (NULL != dta)
+            else if (NULL != sta)
             {
                 /* Move the splits of its subaccounts, if any. */
                 gnc_account_foreach_descendant(account,
                                                (AccountCb)xaccAccountMoveAllSplits,
-                                               dta);
+                                               sta);
             }
             if (NULL != ta)
             {
