@@ -1,34 +1,37 @@
-/*
- * gnc-plugin-page-sx-list.c
- *
- * Copyright (C) 2006 Josh Sled <jsled@asynchronous.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 and/or version 3 of the GNU General Public
- * License as published by the Free Software Foundation.
- *
- * As a special exception, permission is granted to link the binary module
- * resultant from this code with the OpenSSL project's "OpenSSL" library (or
- * modified versions of it that use the same license as the "OpenSSL"
- * library), and distribute the linked executable.  You must obey the GNU
- * General Public License in all respects for all of the code used other than
- * "OpenSSL". If you modify this file, you may extend this exception to your
- * version of the file, but you are not obligated to do so. If you do not
- * wish to do so, delete this exception statement from your version of this
- * file.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, contact:
- *
- * Free Software Foundation           Voice:  +1-617-542-5942
- * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
- * Boston, MA  02110-1301,  USA       gnu@gnu.org
- */
+/********************************************************************\
+ * gnc-plugin-page-sx-list.c : scheduled transaction plugin         *
+ *                                                                  *
+ * Copyright (C) 2006 Joshua Sled <jsled@asynchronous.org>          *
+ * Copyright (C) 2011 Robert Fewell                                 *
+ *                                                                  *
+ * This program is free software; you can redistribute it and/or    *
+ * modify it under the terms of version 2 and/or version 3 of the   *
+ * GNU General Public License as published by the Free Software     *
+ * Foundation.                                                      *
+ *                                                                  *
+ * As a special exception, permission is granted to link the binary *
+ * module resultant from this code with the OpenSSL project's       *
+ * "OpenSSL" library (or modified versions of it that use the same  *
+ * license as the "OpenSSL" library), and distribute the linked     *
+ * executable.  You must obey the GNU General Public License in all *
+ * respects for all of the code used other than "OpenSSL". If you   *
+ * modify this file, you may extend this exception to your version  *
+ * of the file, but you are not obligated to do so. If you do not   *
+ * wish to do so, delete this exception statement from your version *
+ * of this file.                                                    *
+ *                                                                  *
+ * This program is distributed in the hope that it will be useful,  *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
+ * GNU General Public License for more details.                     *
+ *                                                                  *
+ * You should have received a copy of the GNU General Public License*
+ * along with this program; if not, contact:                        *
+ *                                                                  *
+ * Free Software Foundation           Voice:  +1-617-542-5942       *
+ * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
+ * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
+\********************************************************************/
 
 /** @addtogroup ContentPlugins
     @{ */
@@ -43,11 +46,15 @@
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <glade/glade-xml.h>
+
+#include <gnc-gdate-utils.h>
 #include "SX-book.h"
 #include "Split.h"
 #include "Transaction.h"
 #include "dialog-sx-editor.h"
+/*################## Added for Reg2 #################*/
+#include "dialog-sx-editor2.h"
+/*################## Added for Reg2 #################*/
 #include "dialog-utils.h"
 #include "gnc-commodity.h"
 #include "gnc-component-manager.h"
@@ -69,6 +76,8 @@
 #undef G_LOG_DOMAIN
 #define G_LOG_DOMAIN "gnc.gui.plugin-page.sx-list"
 
+G_GNUC_UNUSED static QofLogModule log_module = GNC_MOD_GUI_SX;
+
 #define PLUGIN_PAGE_SX_LIST_CM_CLASS "plugin-page-sx-list"
 #define GCONF_SECTION "window/pages/sx_list"
 
@@ -79,12 +88,12 @@ typedef struct GncPluginPageSxListPrivate
     GtkWidget* widget;
     gint gnc_component_id;
 
-    GladeXML* gxml;
     GncSxInstanceDenseCalAdapter *dense_cal_model;
     GncDenseCal* gdcal;
 
     GncSxInstanceModel* instances;
     GtkTreeView* tree_view;
+
 } GncPluginPageSxListPrivate;
 
 #define GNC_PLUGIN_PAGE_SX_LIST_GET_PRIVATE(o)  \
@@ -110,6 +119,10 @@ static void gppsl_row_activated_cb(GtkTreeView *tree_view, GtkTreePath *path, Gt
 
 static void gnc_plugin_page_sx_list_cmd_new(GtkAction *action, GncPluginPageSxList *page);
 static void gnc_plugin_page_sx_list_cmd_edit(GtkAction *action, GncPluginPageSxList *page);
+/*################## Added for Reg2 #################*/
+static void gnc_plugin_page_sx_list_cmd_new2(GtkAction *action, GncPluginPageSxList *page);
+static void gnc_plugin_page_sx_list_cmd_edit2(GtkAction *action, GncPluginPageSxList *page);
+/*################## Added for Reg2 #################*/
 static void gnc_plugin_page_sx_list_cmd_delete(GtkAction *action, GncPluginPageSxList *page);
 
 /* Command callbacks */
@@ -120,10 +133,22 @@ static GtkActionEntry gnc_plugin_page_sx_list_actions [] =
         "SxListNewAction", GNC_STOCK_NEW_ACCOUNT, N_("_New"), NULL,
         N_("Create a new scheduled transaction"), G_CALLBACK(gnc_plugin_page_sx_list_cmd_new)
     },
+/*################## Added for Reg2 #################*/
+    {
+        "SxListNewAction2", GNC_STOCK_NEW_ACCOUNT, N_("_New 2"), NULL,
+        N_("Create a new scheduled transaction 2"), G_CALLBACK(gnc_plugin_page_sx_list_cmd_new2)
+    },
+/*################## Added for Reg2 #################*/
     {
         "SxListEditAction", GNC_STOCK_EDIT_ACCOUNT, N_("_Edit"), NULL,
         N_("Edit the selected scheduled transaction"), G_CALLBACK(gnc_plugin_page_sx_list_cmd_edit)
     },
+/*################## Added for Reg2 #################*/
+    {
+        "SxListEditAction2", GNC_STOCK_EDIT_ACCOUNT, N_("_Edit 2"), NULL,
+        N_("Edit the selected scheduled transaction 2"), G_CALLBACK(gnc_plugin_page_sx_list_cmd_edit2)
+    },
+/*################## Added for Reg2 #################*/
     {
         "SxListDeleteAction", GNC_STOCK_DELETE_ACCOUNT, N_("_Delete"), NULL,
         N_("Delete the selected scheduled transaction"), G_CALLBACK(gnc_plugin_page_sx_list_cmd_delete)
@@ -132,6 +157,7 @@ static GtkActionEntry gnc_plugin_page_sx_list_actions [] =
 /** The number of actions provided by this plugin. */
 static guint gnc_plugin_page_sx_list_n_actions = G_N_ELEMENTS (gnc_plugin_page_sx_list_actions);
 
+
 GType
 gnc_plugin_page_sx_list_get_type (void)
 {
@@ -160,6 +186,7 @@ gnc_plugin_page_sx_list_get_type (void)
     return gnc_plugin_page_sx_list_type;
 }
 
+
 GncPluginPage *
 gnc_plugin_page_sx_list_new (void)
 {
@@ -168,6 +195,7 @@ gnc_plugin_page_sx_list_new (void)
     return GNC_PLUGIN_PAGE(plugin_page);
 }
 
+
 static void
 gnc_plugin_page_sx_list_class_init (GncPluginPageSxListClass *klass)
 {
@@ -189,15 +217,13 @@ gnc_plugin_page_sx_list_class_init (GncPluginPageSxListClass *klass)
     g_type_class_add_private(klass, sizeof(GncPluginPageSxListPrivate));
 }
 
+
 static void
 gnc_plugin_page_sx_list_init (GncPluginPageSxList *plugin_page)
 {
     GtkActionGroup *action_group;
-    GncPluginPageSxListPrivate *priv;
     GncPluginPage *parent;
 
-    priv = GNC_PLUGIN_PAGE_SX_LIST_GET_PRIVATE(plugin_page);
-
     /* Init parent declared variables */
     parent = GNC_PLUGIN_PAGE(plugin_page);
     g_object_set(G_OBJECT(plugin_page),
@@ -217,6 +243,7 @@ gnc_plugin_page_sx_list_init (GncPluginPageSxList *plugin_page)
     /* gnc_plugin_init_short_names (action_group, toolbar_labels); */
 }
 
+
 static void
 gnc_plugin_page_sx_list_dispose(GObject *object)
 {
@@ -233,7 +260,7 @@ gnc_plugin_page_sx_list_dispose(GObject *object)
 
     g_object_unref(G_OBJECT(priv->dense_cal_model));
     priv->dense_cal_model = NULL;
-    gtk_widget_unref(GTK_WIDGET(priv->gdcal));
+    g_object_unref(GTK_WIDGET(priv->gdcal));
     priv->gdcal = NULL;
     g_object_unref(G_OBJECT(priv->instances));
     priv->instances = NULL;
@@ -241,6 +268,7 @@ gnc_plugin_page_sx_list_dispose(GObject *object)
     G_OBJECT_CLASS (parent_class)->dispose(object);
 }
 
+
 static void
 gnc_plugin_page_sx_list_finalize (GObject *object)
 {
@@ -255,6 +283,7 @@ gnc_plugin_page_sx_list_finalize (GObject *object)
     G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
+
 /* Virtual Functions */
 static void
 gnc_plugin_page_sx_list_refresh_cb (GHashTable *changes, gpointer user_data)
@@ -272,17 +301,15 @@ gnc_plugin_page_sx_list_refresh_cb (GHashTable *changes, gpointer user_data)
     gtk_widget_queue_draw(priv->widget);
 }
 
+
 static void
 gnc_plugin_page_sx_list_close_cb (gpointer user_data)
 {
-    GncPluginPage *plugin_page;
-    GncPluginPageSxList *page;
-
-    plugin_page = GNC_PLUGIN_PAGE(user_data);
-    page = GNC_PLUGIN_PAGE_SX_LIST (plugin_page);
+    GncPluginPage *plugin_page = GNC_PLUGIN_PAGE(user_data);
     gnc_main_window_close_page(plugin_page);
 }
 
+
 static void
 gppsl_selection_changed_cb(GtkTreeSelection *selection, gpointer user_data)
 {
@@ -301,19 +328,51 @@ gppsl_selection_changed_cb(GtkTreeSelection *selection, gpointer user_data)
     gtk_action_set_sensitive(delete_action, selection_state);
 }
 
+
 static GtkWidget *
 gnc_plugin_page_sx_list_create_widget (GncPluginPage *plugin_page)
 {
     GncPluginPageSxList *page;
     GncPluginPageSxListPrivate *priv;
+    GtkWidget *widget;
+    GtkWidget *vbox;
+    GtkWidget *label;
+    GtkWidget *swin;
+    char *markup;
+    char *text;
 
     page = GNC_PLUGIN_PAGE_SX_LIST(plugin_page);
     priv = GNC_PLUGIN_PAGE_SX_LIST_GET_PRIVATE(page);
     if (priv->widget != NULL)
         return priv->widget;
 
-    priv->gxml = gnc_glade_xml_new("sched-xact.glade", "sx-list-vbox");
-    priv->widget = glade_xml_get_widget(priv->gxml, "sx-list-vbox");
+    /* Create Vpaned widget for top level */
+    widget = gtk_vpaned_new();
+    priv->widget = widget;
+    gtk_widget_show (priv->widget);
+
+    /* Add vbox and label */
+    vbox = gtk_vbox_new(FALSE, 0);
+    gtk_paned_pack1( GTK_PANED(widget), vbox, TRUE, FALSE);
+
+    label = gtk_label_new(NULL);
+    text = g_strdup_printf(_("Transactions"));
+    markup = g_markup_printf_escaped ("<b> %s</b>", text);
+    gtk_label_set_markup (GTK_LABEL (label), markup);
+    g_free (markup);
+    g_free (text);
+    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0);
+    gtk_widget_show (label);
+    gtk_box_pack_start ( GTK_BOX(vbox), label, FALSE, FALSE, 0);
+    gtk_widget_show (vbox);
+
+    /* Create scrolled window for top area */
+    swin = gtk_scrolled_window_new(NULL, NULL);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin),
+                                    GTK_POLICY_AUTOMATIC,
+                                    GTK_POLICY_AUTOMATIC);
+    gtk_box_pack_start ( GTK_BOX(vbox), swin, TRUE, TRUE, 5);
+    gtk_widget_show (swin);
 
     {
         // gint half_way;
@@ -325,7 +384,7 @@ gnc_plugin_page_sx_list_create_widget (GncPluginPage *plugin_page)
     {
         GDate end;
         g_date_clear(&end, 1);
-        g_date_set_time_t(&end, time(NULL));
+        gnc_gdate_set_today (&end);
         g_date_add_years(&end, 1);
         priv->instances = GNC_SX_INSTANCE_MODEL(gnc_sx_get_instances(&end, TRUE));
     }
@@ -339,16 +398,14 @@ gnc_plugin_page_sx_list_create_widget (GncPluginPage *plugin_page)
     }
 
     {
-        GtkContainer *tree_view_container;
         GtkTreeSelection *selection;
 
-        tree_view_container = GTK_CONTAINER(glade_xml_get_widget(priv->gxml, "sx-list-tree-view-container"));
         priv->tree_view = GTK_TREE_VIEW(gnc_tree_view_sx_list_new(priv->instances));
         g_object_set(G_OBJECT(priv->tree_view),
                      "gconf-section", GCONF_SECTION,
                      "show-column-menu", TRUE,
                      NULL);
-        gtk_container_add(tree_view_container, GTK_WIDGET(priv->tree_view));
+        gtk_container_add(GTK_CONTAINER( swin ), GTK_WIDGET(priv->tree_view));
 
         selection = gtk_tree_view_get_selection(priv->tree_view);
         gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
@@ -356,9 +413,31 @@ gnc_plugin_page_sx_list_create_widget (GncPluginPage *plugin_page)
         g_signal_connect(G_OBJECT(priv->tree_view), "row-activated", (GCallback)gppsl_row_activated_cb, (gpointer)page);
     }
 
-    {
-        GtkWidget *w;
+    /* Add vbox and label */
+    vbox = gtk_vbox_new(FALSE, 0);
+    gtk_paned_pack2( GTK_PANED(widget), vbox, TRUE, FALSE);
 
+    label = gtk_label_new(NULL);
+    text = g_strdup_printf(_("Upcoming Transactions"));
+    markup = g_markup_printf_escaped ("<b> %s</b>", text);
+    gtk_label_set_markup (GTK_LABEL (label), markup);
+    g_free (markup);
+    g_free (text);
+    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0);
+    gtk_widget_show (label);
+
+    gtk_box_pack_start ( GTK_BOX(vbox), label, FALSE, FALSE, 0);
+    gtk_widget_show (vbox);
+
+    /* Create scrolled window for bottom area */
+    swin = gtk_scrolled_window_new(NULL, NULL);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin),
+                                    GTK_POLICY_AUTOMATIC,
+                                    GTK_POLICY_AUTOMATIC);
+    gtk_box_pack_start ( GTK_BOX(vbox), swin, TRUE, TRUE, 5);
+    gtk_widget_show (swin);
+
+    {
         priv->dense_cal_model = gnc_sx_instance_dense_cal_adapter_new(GNC_SX_INSTANCE_MODEL(priv->instances));
         priv->gdcal = GNC_DENSE_CAL(gnc_dense_cal_new_with_model(GNC_DENSE_CAL_MODEL(priv->dense_cal_model)));
         g_object_ref_sink(priv->gdcal);
@@ -366,9 +445,7 @@ gnc_plugin_page_sx_list_create_widget (GncPluginPage *plugin_page)
         gnc_dense_cal_set_months_per_col(priv->gdcal, 4);
         gnc_dense_cal_set_num_months(priv->gdcal, 12);
 
-        w = glade_xml_get_widget(priv->gxml, "upcoming_cal_hbox");
-        gtk_container_add(GTK_CONTAINER(w), GTK_WIDGET(priv->gdcal));
-        gtk_widget_show_all(w);
+        gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(swin), GTK_WIDGET(priv->gdcal));
     }
 
     priv->gnc_component_id = gnc_register_gui_component("plugin-page-sx-list",
@@ -379,6 +456,7 @@ gnc_plugin_page_sx_list_create_widget (GncPluginPage *plugin_page)
     return priv->widget;
 }
 
+
 static void
 gnc_plugin_page_sx_list_destroy_widget (GncPluginPage *plugin_page)
 {
@@ -401,6 +479,7 @@ gnc_plugin_page_sx_list_destroy_widget (GncPluginPage *plugin_page)
     }
 }
 
+
 /** Save enough information about this page that it can be recreated next time
  * the user starts gnucash.
  * @param plugin_page The page to save.
@@ -430,6 +509,7 @@ gnc_plugin_page_sx_list_save_page (GncPluginPage *plugin_page,
                            gtk_paned_get_position(GTK_PANED(priv->widget)));
 }
 
+
 /**
  * Create a new sx list page based on the information saved during a previous
  * instantiation of gnucash.
@@ -478,6 +558,7 @@ gnc_plugin_page_sx_list_recreate_page (GtkWidget *window,
     return GNC_PLUGIN_PAGE(page);
 }
 
+
 static void
 gnc_plugin_page_sx_list_cmd_new(GtkAction *action, GncPluginPageSxList *page)
 {
@@ -491,7 +572,7 @@ gnc_plugin_page_sx_list_cmd_new(GtkAction *action, GncPluginPageSxList *page)
         GList *schedule;
 
         g_date_clear(&now, 1);
-        g_date_set_time_t(&now, time(NULL));
+        gnc_gdate_set_today (&now);
         recurrenceSet(r, 1, PERIOD_MONTH, &now, WEEKEND_ADJ_NONE);
         schedule = gnc_sx_get_schedule(new_sx);
         schedule = g_list_append(schedule, r);
@@ -500,18 +581,51 @@ gnc_plugin_page_sx_list_cmd_new(GtkAction *action, GncPluginPageSxList *page)
     gnc_ui_scheduled_xaction_editor_dialog_create(new_sx, new_sx_flag);
 }
 
+/*################## Added for Reg2 #################*/
+static void
+gnc_plugin_page_sx_list_cmd_new2 (GtkAction *action, GncPluginPageSxList *page)
+{
+    SchedXaction *new_sx;
+    gboolean new_sx_flag = TRUE;
+
+    new_sx = xaccSchedXactionMalloc (gnc_get_current_book());
+    {
+        GDate now;
+        Recurrence *r = g_new0 (Recurrence, 1);
+        GList *schedule;
+
+        g_date_clear (&now, 1);
+        gnc_gdate_set_today (&now);
+        recurrenceSet(r, 1, PERIOD_MONTH, &now, WEEKEND_ADJ_NONE);
+        schedule = gnc_sx_get_schedule (new_sx);
+        schedule = g_list_append (schedule, r);
+        gnc_sx_set_schedule (new_sx, schedule);
+    }
+    gnc_ui_scheduled_xaction_editor_dialog_create2 (new_sx, new_sx_flag);
+}
+/*################## Added for Reg2 #################*/
+
 static void
 _edit_sx(gpointer data, gpointer user_data)
 {
     gnc_ui_scheduled_xaction_editor_dialog_create((SchedXaction*)data, FALSE);
 }
 
+/*################## Added for Reg2 #################*/
+static void
+_edit_sx2 (gpointer data, gpointer user_data)
+{
+    gnc_ui_scheduled_xaction_editor_dialog_create2 ((SchedXaction*)data, FALSE);
+}
+/*################## Added for Reg2 #################*/
+
 static SchedXaction*
 _argument_reorder_fn(GtkTreePath* list_path_data, GncTreeViewSxList* user_tree_view)
 {
     return gnc_tree_view_sx_list_get_sx_from_path(user_tree_view, list_path_data);
 }
 
+
 static void
 gnc_plugin_page_sx_list_cmd_edit(GtkAction *action, GncPluginPageSxList *page)
 {
@@ -537,6 +651,34 @@ gnc_plugin_page_sx_list_cmd_edit(GtkAction *action, GncPluginPageSxList *page)
     g_list_free(selected_paths);
 }
 
+/*################## Added for Reg2 #################*/
+static void
+gnc_plugin_page_sx_list_cmd_edit2 (GtkAction *action, GncPluginPageSxList *page)
+{
+    GncPluginPageSxListPrivate *priv = GNC_PLUGIN_PAGE_SX_LIST_GET_PRIVATE (page);
+    GtkTreeSelection *selection;
+    GList *selected_paths, *to_edit;
+    GtkTreeModel *model;
+
+    selection = gtk_tree_view_get_selection (priv->tree_view);
+    selected_paths = gtk_tree_selection_get_selected_rows (selection, &model);
+    if (g_list_length (selected_paths) == 0)
+    {
+        g_warning ("no selection edit.");
+        return;
+    }
+
+    to_edit = gnc_g_list_map (selected_paths,
+                             (GncGMapFunc)_argument_reorder_fn,
+                             priv->tree_view);
+    g_list_foreach(to_edit, (GFunc)_edit_sx2, NULL);
+    g_list_free (to_edit);
+    g_list_foreach (selected_paths, (GFunc)gtk_tree_path_free, NULL);
+    g_list_free (selected_paths);
+}
+/*################## Added for Reg2 #################*/
+
+
 static void
 gppsl_row_activated_cb(GtkTreeView *tree_view,
                        GtkTreePath *path,
@@ -564,6 +706,7 @@ _destroy_sx(gpointer data, gpointer user_data)
     xaccSchedXactionDestroy(sx);
 }
 
+
 static void
 gnc_plugin_page_sx_list_cmd_delete(GtkAction *action, GncPluginPageSxList *page)
 {
