@@ -52,7 +52,6 @@
 #include "gnucash-sheet.h"
 #include "table-allgui.h"
 
-#include <libguile.h>
 #include "dialog-utils.h"
 
 // static QofLogModule log_module = GNC_MOD_SX;
@@ -88,7 +87,7 @@ static void gnc_split_reg_refresh_toolbar( GNCSplitReg *gsr );
 static void gnc_split_reg_ld_destroy( GNCLedgerDisplay *ledger );
 
 static Transaction* create_balancing_transaction(QofBook *book, Account *account,
-        time_t statement_date, gnc_numeric balancing_amount);
+        time64 statement_date, gnc_numeric balancing_amount);
 
 void gsr_default_enter_handler    ( GNCSplitReg *w, gpointer ud );
 void gsr_default_cancel_handler   ( GNCSplitReg *w, gpointer ud );
@@ -111,7 +110,7 @@ void gsr_default_reverse_txn_handler ( GNCSplitReg *w, gpointer ud );
 
 static void gsr_emit_simple_signal( GNCSplitReg *gsr, const char *sigName );
 static void gsr_emit_help_changed( GnucashRegister *reg, gpointer user_data );
-static void gsr_emit_include_date_signal( GNCSplitReg *gsr, time_t date );
+static void gsr_emit_include_date_signal( GNCSplitReg *gsr, time64 date );
 
 void gnc_split_reg_cut_cb(GtkWidget *w, gpointer data);
 void gnc_split_reg_copy_cb(GtkWidget *w, gpointer data);
@@ -153,6 +152,7 @@ void gnc_split_reg_sort_desc_cb (GtkWidget *w, gpointer data);
 void gnc_split_reg_sort_action_cb (GtkWidget *w, gpointer data);
 void gnc_split_reg_sort_notes_cb (GtkWidget *w, gpointer data);
 
+
 void gnc_split_reg_destroy_cb(GtkWidget *widget, gpointer data);
 void gnc_split_reg_size_allocate( GtkWidget *widget,
                                   GtkAllocation *allocation,
@@ -165,10 +165,6 @@ static void gnc_split_reg_class_init( GNCSplitRegClass *class );
 static void gnc_split_reg_init( GNCSplitReg *gsr );
 static void gnc_split_reg_init2( GNCSplitReg *gsr );
 
-void gnc_split_register_size_allocate (GtkWidget *widget,
-                                       GtkAllocation *allocation,
-                                       gpointer user_data);
-
 FROM_STRING_FUNC(SortType, ENUM_LIST_SORTTYPE)
 AS_STRING_FUNC(SortType, ENUM_LIST_SORTTYPE)
 
@@ -284,7 +280,7 @@ gnc_split_reg_class_init( GNCSplitRegClass *class )
                       G_SIGNAL_RUN_LAST,
                       signals[i++].defaultOffset,
                       NULL, NULL,
-                      g_cclosure_marshal_VOID__INT, /* time_t == int */
+                      g_cclosure_marshal_VOID__INT, /* time64 == int */
                       G_TYPE_NONE, 1, G_TYPE_INT );
 
     g_assert( i == LAST_SIGNAL );
@@ -388,6 +384,14 @@ gsr_create_table( GNCSplitReg *gsr )
     GtkWidget *register_widget;
     SplitRegister *sr;
 
+    gchar *gconf_key;
+    const GncGUID * guid;
+    Account * account;
+    
+    account = gnc_ledger_display_leader(gsr->ledger);
+    guid = xaccAccountGetGUID(account);
+    gconf_key = (gchar*)guid_to_string (guid);
+
     ENTER("gsr=%p", gsr);
 
     gnc_ledger_display_set_user_data( gsr->ledger, (gpointer)gsr );
@@ -399,10 +403,9 @@ gsr_create_table( GNCSplitReg *gsr )
     sr = gnc_ledger_display_get_split_register( gsr->ledger );
     register_widget = gnucash_register_new( sr->table );
     gsr->reg = GNUCASH_REGISTER( register_widget );
-    gnc_table_init_gui( GTK_WIDGET(gsr->reg), sr );
-
+    gnc_table_init_gui( GTK_WIDGET(gsr->reg), gconf_key );
     gtk_box_pack_start (GTK_BOX (gsr), GTK_WIDGET(gsr->reg), TRUE, TRUE, 0);
-    GNUCASH_SHEET(gsr->reg->sheet)->window = gsr->window;
+    gnucash_sheet_set_window (gnucash_register_get_sheet (gsr->reg), gsr->window);
     gtk_widget_show ( GTK_WIDGET(gsr->reg) );
     g_signal_connect (gsr->reg, "activate_cursor",
                       G_CALLBACK(gnc_split_reg_record_cb), gsr);
@@ -696,7 +699,16 @@ static void
 gnc_split_reg_ld_destroy( GNCLedgerDisplay *ledger )
 {
     GNCSplitReg *gsr = gnc_ledger_display_get_user_data( ledger );
-
+    
+    gchar *gconf_key;
+    const GncGUID * guid;
+    Account * account;
+    
+    account = gnc_ledger_display_leader(ledger);
+    guid = xaccAccountGetGUID(account);
+    gconf_key = (gchar*)guid_to_string (guid);
+    
+    
     if (gsr)
     {
         SplitRegister *reg;
@@ -704,7 +716,7 @@ gnc_split_reg_ld_destroy( GNCLedgerDisplay *ledger )
         reg = gnc_ledger_display_get_split_register (ledger);
 
         if (reg && reg->table)
-            gnc_table_save_state (reg->table);
+            gnc_table_save_state (reg->table, gconf_key);
 
         /*
          * Don't destroy the window here any more.  The register no longer
@@ -881,8 +893,8 @@ gsr_default_reverse_txn_handler (GNCSplitReg *gsr, gpointer data)
     new_trans = xaccTransReverse(trans);
 
     /* Clear transaction level info */
-    xaccTransSetDatePostedSecs(new_trans, time(NULL));
-    xaccTransSetDateEnteredSecs(new_trans, time(NULL));
+    xaccTransSetDatePostedSecsNormalized(new_trans, gnc_time (NULL));
+    xaccTransSetDateEnteredSecs(new_trans, gnc_time (NULL));
 
     /* Now jump to new trans */
     gnc_split_reg_jump_to_split(gsr, xaccTransGetSplit(new_trans, 0));
@@ -897,7 +909,7 @@ gnc_split_reg_reverse_trans_cb (GtkWidget *w, gpointer data)
 
 
 static gboolean
-xaccTransWarnReadOnly (const Transaction *trans)
+is_trans_readonly_and_warn (const Transaction *trans)
 {
     GtkWidget *dialog;
     const gchar *reason;
@@ -907,6 +919,21 @@ xaccTransWarnReadOnly (const Transaction *trans)
 
     if (!trans) return FALSE;
 
+    if (xaccTransIsReadonlyByPostedDate (trans))
+    {
+        dialog = gtk_message_dialog_new(NULL,
+                                        0,
+                                        GTK_MESSAGE_ERROR,
+                                        GTK_BUTTONS_OK,
+                                        "%s", title);
+        gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
+                "%s", _("The date of this transaction is older than the \"Read-Only Threshold\" set for this book. "
+                        "This setting can be changed in File -> Properties -> Accounts."));
+        gtk_dialog_run(GTK_DIALOG(dialog));
+        gtk_widget_destroy(dialog);
+        return TRUE;
+    }
+
     reason = xaccTransGetReadOnly (trans);
     if (reason)
     {
@@ -944,7 +971,7 @@ gsr_default_reinit_handler( GNCSplitReg *gsr, gpointer data )
     reg = gnc_ledger_display_get_split_register( gsr->ledger );
 
     trans = gnc_split_register_get_current_trans (reg);
-    if (xaccTransWarnReadOnly(trans))
+    if (is_trans_readonly_and_warn(trans))
         return;
     dialog = gtk_message_dialog_new(GTK_WINDOW(gsr->window),
                                     GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -996,7 +1023,6 @@ gnc_split_reg_reinitialize_trans_cb(GtkWidget *widget, gpointer data)
 void
 gsr_default_delete_handler( GNCSplitReg *gsr, gpointer data )
 {
-    SplitRegisterStyle style;
     CursorClass cursor_class;
     SplitRegister *reg;
     Transaction *trans;
@@ -1016,7 +1042,6 @@ gsr_default_delete_handler( GNCSplitReg *gsr, gpointer data )
     }
 
     trans = xaccSplitGetParent(split);
-    style = reg->style;
     cursor_class = gnc_split_register_get_current_cursor_class (reg);
 
     /* Deleting the blank split just cancels */
@@ -1033,7 +1058,7 @@ gsr_default_delete_handler( GNCSplitReg *gsr, gpointer data )
     if (cursor_class == CURSOR_CLASS_NONE)
         return;
 
-    if (xaccTransWarnReadOnly(trans))
+    if (is_trans_readonly_and_warn(trans))
         return;
 
     /* On a split cursor, just delete the one split. */
@@ -1046,7 +1071,7 @@ gsr_default_delete_handler( GNCSplitReg *gsr, gpointer data )
         const char *anchor_error = _("You cannot delete this split.");
         const char *anchor_split = _("This is the split anchoring this transaction "
                                      "to the register. You may not delete it from "
-                                     "this register window.  You may delete the "
+                                     "this register window. You may delete the "
                                      "entire transaction from this window, or you "
                                      "may navigate to a register that shows "
                                      "another side of this same transaction and "
@@ -1380,7 +1405,7 @@ gnc_split_reg_jump_to_blank (GNCSplitReg *gsr)
 
 void
 gnc_split_reg_balancing_entry(GNCSplitReg *gsr, Account *account,
-                              time_t statement_date, gnc_numeric balancing_amount)
+                              time64 statement_date, gnc_numeric balancing_amount)
 {
 
     Transaction *transaction;
@@ -1407,7 +1432,7 @@ gnc_split_reg_balancing_entry(GNCSplitReg *gsr, Account *account,
 
 static Transaction*
 create_balancing_transaction(QofBook *book, Account *account,
-                             time_t statement_date, gnc_numeric balancing_amount)
+                             time64 statement_date, gnc_numeric balancing_amount)
 {
 
     Transaction *trans;
@@ -1425,9 +1450,12 @@ create_balancing_transaction(QofBook *book, Account *account,
     xaccTransBeginEdit(trans);
 
     // fill Transaction
-    xaccTransSetCurrency(trans, xaccAccountGetCommodity(account));
-    xaccTransSetDatePostedSecs(trans, statement_date);
+    xaccTransSetCurrency(trans, gnc_account_or_default_currency(account, NULL));
+    xaccTransSetDatePostedSecsNormalized(trans, statement_date);
     xaccTransSetDescription(trans, _("Balancing entry from reconcilation"));
+    /* We also must set a new DateEntered on the new entry
+     * because otherwise the ordering is not deterministic */
+    xaccTransSetDateEnteredSecs(trans, gnc_time(NULL));
 
     // 1. Split
     split = xaccMallocSplit(book);
@@ -1546,14 +1574,14 @@ gnc_split_reg_double_line_cb (GtkWidget *w, gpointer data)
 }
 
 static void
-gnc_split_reg_sort( GNCSplitReg *gsr, SortType sort_code )
+gnc_split_reg_sort_force( GNCSplitReg *gsr, SortType sort_code, gboolean force )
 {
     Query *query = gnc_ledger_display_get_query( gsr->ledger );
     gboolean show_present_divider = FALSE;
     GSList *p1 = NULL, *p2 = NULL, *p3 = NULL, *standard;
     SplitRegister *reg;
 
-    if (gsr->sort_type == sort_code)
+    if ((gsr->sort_type == sort_code) && !force)
         return;
 
     standard = g_slist_prepend( NULL, QUERY_DEFAULT_SORT );
@@ -1610,6 +1638,7 @@ gnc_split_reg_sort( GNCSplitReg *gsr, SortType sort_code )
     default:
         g_slist_free (standard);
         g_return_if_fail (FALSE);
+        break;
     }
 
     qof_query_set_sort_order( query, p1, p2, p3 );
@@ -1619,6 +1648,12 @@ gnc_split_reg_sort( GNCSplitReg *gsr, SortType sort_code )
     gnc_ledger_display_refresh( gsr->ledger );
 }
 
+static void
+gnc_split_reg_sort( GNCSplitReg *gsr, SortType sort_code )
+{
+    gnc_split_reg_sort_force( gsr, sort_code, FALSE );
+}
+
 void
 gnc_split_reg_sort_standard_cb(GtkWidget *w, gpointer data)
 {
@@ -1689,6 +1724,15 @@ gnc_split_reg_sort_notes_cb(GtkWidget *w, gpointer data)
     gnc_split_reg_sort(gsr, BY_NOTES);
 }
 
+
+void 
+gnc_split_reg_set_sort_reversed(GNCSplitReg *gsr, gboolean rev)
+{
+  Query *query = gnc_ledger_display_get_query( gsr->ledger );
+  qof_query_set_sort_increasing (query, rev, rev, rev);
+  gnc_ledger_display_refresh( gsr->ledger );
+}
+
 void
 gnc_split_reg_handle_exchange_cb (GtkWidget *w, gpointer data)
 {
@@ -1975,6 +2019,13 @@ gnc_split_reg_determine_read_only( GNCSplitReg *gsr )
     dialog_args *args = g_malloc(sizeof(dialog_args));
     SplitRegister *reg;
 
+    if (qof_book_is_readonly(gnc_get_current_book()))
+    {
+        /* Is the book read-only? Then for sure also make this register
+        read-only. */
+        gsr->read_only = TRUE;
+    }
+
     if ( !gsr->read_only )
     {
 
@@ -1985,7 +2036,7 @@ gnc_split_reg_determine_read_only( GNCSplitReg *gsr )
             return;
 
         case PLACEHOLDER_THIS:
-            args->string = _("This account may not be edited.  If you want "
+            args->string = _("This account may not be edited. If you want "
                              "to edit transactions in this register, please "
                              "open the account options and turn off the "
                              "placeholder checkbox.");
@@ -1993,7 +2044,7 @@ gnc_split_reg_determine_read_only( GNCSplitReg *gsr )
 
         default:
             args->string = _("One of the sub-accounts selected may not be "
-                             "edited.  If you want to edit transactions in "
+                             "edited. If you want to edit transactions in "
                              "this register, please open the sub-account "
                              "options and turn off the placeholder checkbox. "
                              "You may also open an individual account instead "
@@ -2034,7 +2085,7 @@ gsr_emit_help_changed( GnucashRegister *reg, gpointer user_data )
 
 static
 void
-gsr_emit_include_date_signal( GNCSplitReg *gsr, time_t date )
+gsr_emit_include_date_signal( GNCSplitReg *gsr, time64 date )
 {
     g_signal_emit_by_name( gsr, "include-date", date, NULL );
 }
@@ -2068,6 +2119,13 @@ gnc_split_reg_set_sort_type( GNCSplitReg *gsr, SortType t )
     gnc_split_reg_sort( gsr, t );
 }
 
+void
+gnc_split_reg_set_sort_type_force( GNCSplitReg *gsr, SortType t, gboolean force )
+{
+    gnc_split_reg_sort_force( gsr, t, force );
+}
+
+
 GtkWidget*
 gnc_split_reg_get_summarybar( GNCSplitReg *gsr )
 {
