@@ -1,5 +1,5 @@
 /********************************************************************\
- * guile-mappings.h - Guile version compatability mappings          *
+ * guile-mappings.h - Guile version compatibility mappings          *
  * Copyright (C) 2003, David Hampton                                *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
@@ -19,33 +19,11 @@
 
 #include <libguile.h> /* for SCM_MAJOR_VERSION etc */
 
-/* Give Guile 1.6 and 1.8 a 2.0-like interface */
-#if (SCM_MAJOR_VERSION == 1) && (SCM_MINOR_VERSION <= 6)
-# define scm_is_bool SCM_BOOLP
-# define scm_is_false SCM_FALSEP
-# define scm_is_null SCM_NULLP
-# define scm_is_number SCM_NUMBERP
-# define scm_is_pair SCM_CONSP
-# define scm_is_string SCM_STRINGP
-# define scm_is_symbol SCM_SYMBOLP
-# define scm_is_true SCM_NFALSEP
-# define scm_is_vector SCM_VECTORP
-# define scm_c_string_length SCM_STRING_LENGTH
-#elif (SCM_MAJOR_VERSION == 1) && (SCM_MINOR_VERSION <= 8)
+/* Give Guile 1.8 a 2.0-like interface */
+#if (SCM_MAJOR_VERSION == 1) && (SCM_MINOR_VERSION <= 8)
 # define scm_c_string_length scm_i_string_length
 #endif
 
-/* The result of SCM_STRING_CHARS must not be free'd, but the result
- * of scm_to_locale_string must. That's bad. We define the macro
- * gnc_free_scm_locale_string to wrap around free() for that
- * reason. */
-#if (SCM_MAJOR_VERSION == 1) && (SCM_MINOR_VERSION <= 6)
-# define scm_to_locale_string SCM_STRING_CHARS
-# define gnc_free_scm_locale_string (void)
-#else
-# define gnc_free_scm_locale_string free
-#endif
-
 /* Convenience macros */
 
 #define scm_is_equal(obj1,obj2)	scm_is_true(scm_equal_p(obj1,obj2))
