@@ -55,6 +55,11 @@
 # define GNC_GWENHYWFAR_CB
 #endif
 
+#define GWEN_GUI_CM_CLASS "dialog-hbcilog"
+#define GCONF_SECTION_CONNECTION GCONF_SECTION_AQBANKING "/connection_dialog"
+#define KEY_CLOSE_ON_FINISH "close_on_finish"
+#define KEY_REMEMBER_PIN "remember_pin"
+
 #ifdef USING_GWENHYWFAR_GTK2_GUI
 # include <gwen-gui-gtk2/gtk2_gui.h>
 #endif
@@ -112,7 +117,7 @@ gnc_GWEN_Gui_get_close_flag()
 gboolean
 gnc_GWEN_Gui_show_dialog()
 {
-    return;
+    return TRUE;
 }
 
 void
@@ -150,11 +155,6 @@ GWEN_INHERIT(GWEN_GUI, GncGWENGui)
                                                         (gwen_gui), (gui), NULL)
 #define GETDATA_GUI(gwen_gui) GWEN_INHERIT_GETDATA(GWEN_GUI, GncGWENGui, (gwen_gui))
 
-#define GWEN_GUI_CM_CLASS "dialog-hbcilog"
-#define GCONF_SECTION_CONNECTION GCONF_SECTION_AQBANKING "/connection_dialog"
-#define KEY_CLOSE_ON_FINISH "close_on_finish"
-#define KEY_REMEMBER_PIN "remember_pin"
-
 #define OTHER_ENTRIES_ROW_OFFSET 3
 
 typedef struct _Progress Progress;
@@ -165,7 +165,6 @@ static void unregister_callbacks(GncGWENGui *gui);
 static void setup_dialog(GncGWENGui *gui);
 static void enable_password_cache(GncGWENGui *gui, gboolean enabled);
 static void reset_dialog(GncGWENGui *gui);
-static void set_runing(GncGWENGui *gui);
 static void set_finished(GncGWENGui *gui);
 static void set_aborted(GncGWENGui *gui);
 static void show_dialog(GncGWENGui *gui, gboolean clear_log);
@@ -516,33 +515,36 @@ unregister_callbacks(GncGWENGui *gui)
 static void
 setup_dialog(GncGWENGui *gui)
 {
-    GladeXML *xml;
+    GtkBuilder *builder;
     gint component_id;
 
     g_return_if_fail(gui);
 
     ENTER("gui=%p", gui);
 
-    xml = gnc_glade_xml_new("aqbanking.glade", "Connection Dialog");
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-ab.glade", "Connection Dialog");
 
-    gui->dialog = glade_xml_get_widget(xml, "Connection Dialog");
-    g_object_set_data_full(G_OBJECT(gui->dialog), "xml", xml, g_object_unref);
-    glade_xml_signal_autoconnect_full(xml, gnc_glade_autoconnect_full_func, gui);
-    gui->entries_table = glade_xml_get_widget(xml, "entries_table");
-    gui->top_entry = glade_xml_get_widget(xml, "top_entry");
-    gui->top_progress = glade_xml_get_widget(xml, "top_progress");
-    gui->second_entry = glade_xml_get_widget(xml, "second_entry");
+    gui->dialog = GTK_WIDGET(gtk_builder_get_object (builder, "Connection Dialog"));
+
+    gui->entries_table = GTK_WIDGET(gtk_builder_get_object (builder, "entries_table"));
+    gui->top_entry = GTK_WIDGET(gtk_builder_get_object (builder, "top_entry"));
+    gui->top_progress = GTK_WIDGET(gtk_builder_get_object (builder, "top_progress"));
+    gui->second_entry = GTK_WIDGET(gtk_builder_get_object (builder, "second_entry"));
     gui->other_entries_box = NULL;
     gui->progresses = NULL;
-    gui->log_text = glade_xml_get_widget(xml, "log_text");
-    gui->abort_button = glade_xml_get_widget(xml, "abort_button");
-    gui->close_button = glade_xml_get_widget(xml, "close_button");
-    gui->close_checkbutton = glade_xml_get_widget(xml, "close_checkbutton");
+    gui->log_text = GTK_WIDGET(gtk_builder_get_object (builder, "log_text"));
+    gui->abort_button = GTK_WIDGET(gtk_builder_get_object (builder, "abort_button"));
+    gui->close_button = GTK_WIDGET(gtk_builder_get_object (builder, "close_button"));
+    gui->close_checkbutton = GTK_WIDGET(gtk_builder_get_object (builder, "close_checkbutton"));
     gui->accepted_certs = NULL;
     gui->permanently_accepted_certs = NULL;
     gui->showbox_hash = NULL;
     gui->showbox_id = 1;
 
+    /* Connect the Signals */
+    gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, gui);
+
     gtk_toggle_button_set_active(
         GTK_TOGGLE_BUTTON(gui->close_checkbutton),
         gnc_gconf_get_bool(GCONF_SECTION_AQBANKING, KEY_CLOSE_ON_FINISH, NULL));
@@ -551,6 +553,10 @@ setup_dialog(GncGWENGui *gui)
                    cm_close_handler, gui);
     gnc_gui_component_set_session(component_id, gnc_get_current_session());
 
+
+
+    g_object_unref(G_OBJECT(builder));
+
     reset_dialog(gui);
 
     LEAVE(" ");
@@ -682,8 +688,6 @@ set_aborted(GncGWENGui *gui)
 static void
 show_dialog(GncGWENGui *gui, gboolean clear_log)
 {
-    gboolean cache_pin;
-
     g_return_if_fail(gui);
 
     ENTER("gui=%p, clear_log=%d", gui, clear_log);
@@ -734,8 +738,6 @@ static gboolean
 show_progress_cb(gpointer user_data)
 {
     Progress *progress = user_data;
-    GncGWENGui *gui;
-    GList *item;
 
     g_return_val_if_fail(progress, FALSE);
 
@@ -791,7 +793,7 @@ show_progress(GncGWENGui *gui, Progress *progress)
             gtk_entry_set_text(GTK_ENTRY(entry), current->title);
             if (new_box)
                 gui->other_entries_box = box = gtk_vbox_new(TRUE, 6);
-            gtk_box_pack_start_defaults(GTK_BOX(box), entry);
+            gtk_box_pack_start(GTK_BOX(box), entry, TRUE, TRUE, 0);
             gtk_widget_show(entry);
             if (new_box)
             {
@@ -972,7 +974,7 @@ static void
 get_input(GncGWENGui *gui, guint32 flags, const gchar *title, const gchar *text,
           gchar **input, gint min_len, gint max_len)
 {
-    GladeXML *xml;
+    GtkBuilder *builder;
     GtkWidget *dialog;
     GtkWidget *heading_label;
     GtkWidget *input_entry;
@@ -981,9 +983,7 @@ get_input(GncGWENGui *gui, guint32 flags, const gchar *title, const gchar *text,
     GtkWidget *remember_pin_checkbutton;
     const gchar *internal_input, *internal_confirmed;
     gboolean confirm = (flags & GWEN_GUI_INPUT_FLAGS_CONFIRM) != 0;
-    gboolean hidden = (flags & GWEN_GUI_INPUT_FLAGS_SHOW) == 0;
     gboolean is_tan = (flags & GWEN_GUI_INPUT_FLAGS_TAN) != 0;
-    gint retval;
 
     g_return_if_fail(input);
     g_return_if_fail(max_len >= min_len && max_len > 0);
@@ -991,15 +991,15 @@ get_input(GncGWENGui *gui, guint32 flags, const gchar *title, const gchar *text,
     ENTER(" ");
 
     /* Set up dialog */
-    xml = gnc_glade_xml_new("aqbanking.glade", "Password Dialog");
-    dialog = glade_xml_get_widget(xml, "Password Dialog");
-    g_object_set_data_full(G_OBJECT(dialog), "xml", xml, g_object_unref);
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-ab.glade", "Password Dialog");
+    dialog = GTK_WIDGET(gtk_builder_get_object (builder, "Password Dialog"));
 
-    heading_label = glade_xml_get_widget(xml, "heading_label");
-    input_entry = glade_xml_get_widget(xml, "input_entry");
-    confirm_entry = glade_xml_get_widget(xml, "confirm_entry");
-    confirm_label = glade_xml_get_widget(xml, "confirm_label");
-    remember_pin_checkbutton = glade_xml_get_widget(xml, "remember_pin");
+    heading_label = GTK_WIDGET(gtk_builder_get_object (builder, "heading_pw_label"));
+    input_entry = GTK_WIDGET(gtk_builder_get_object (builder, "input_entry"));
+    confirm_entry = GTK_WIDGET(gtk_builder_get_object (builder, "confirm_entry"));
+    confirm_label = GTK_WIDGET(gtk_builder_get_object (builder, "confirm_label"));
+    remember_pin_checkbutton = GTK_WIDGET(gtk_builder_get_object (builder, "remember_pin"));
     if (is_tan)
     {
         gtk_widget_hide(remember_pin_checkbutton);
@@ -1092,6 +1092,8 @@ get_input(GncGWENGui *gui, guint32 flags, const gchar *title, const gchar *text,
         }
     }
 
+    g_object_unref(G_OBJECT(builder));
+
     /* This trashes passwords in the entries' memory as well */
     gtk_widget_destroy(dialog);
 
@@ -1207,7 +1209,6 @@ static void
 hidebox_cb(GWEN_GUI *gwen_gui, guint32 id)
 {
     GncGWENGui *gui = GETDATA_GUI(gwen_gui);
-    GtkWidget *dialog;
 
     g_return_if_fail(gui && gui->showbox_hash);
 
