@@ -41,6 +41,7 @@
 #include "Account.h"
 #include "Query.h"
 #include "gnc-engine.h"
+#include "engine-helpers.h"
 #include "gnc-ui-util.h"
 
 #define GCONF_SECTION "dialogs/import/generic_matcher"
@@ -409,7 +410,7 @@ TransactionGetTokens(GNCImportTransInfo *info)
     Transaction* transaction;
     GList* tokens;
     const char* text;
-    time_t transtime;
+    time64 transtime;
     struct tm *tm_struct;
     char local_day_of_week[16];
     Split* split;
@@ -432,12 +433,12 @@ TransactionGetTokens(GNCImportTransInfo *info)
      * it to day of week as a token
      */
     transtime = xaccTransGetDate(transaction);
-    tm_struct = gmtime(&transtime);
+    tm_struct = gnc_gmtime(&transtime);
     if (!qof_strftime(local_day_of_week, sizeof(local_day_of_week), "%A", tm_struct))
     {
         PERR("TransactionGetTokens: error, strftime failed\n");
     }
-
+    gnc_tm_free (tm_struct);
     /* we cannot add a locally allocated string to this array, dup it so
      * it frees the same way the rest do
      */
@@ -599,7 +600,7 @@ static void split_find_match (GNCImportTransInfo * trans_info,
         gint prob = 0;
         gboolean update_proposed;
         double downloaded_split_amount, match_split_amount;
-        time_t match_time, download_time;
+        time64 match_time, download_time;
         int datediff_day;
         Transaction *new_trans = gnc_import_TransInfo_get_trans (trans_info);
         Split *new_trans_fsplit = gnc_import_TransInfo_get_fsplit (trans_info);
@@ -678,7 +679,7 @@ static void split_find_match (GNCImportTransInfo * trans_info,
 
         /* Check number heuristics */
         {
-            const char *new_trans_str = xaccTransGetNum(new_trans);
+            const char *new_trans_str = gnc_get_num_action(new_trans, new_trans_fsplit);
             if (new_trans_str && strlen(new_trans_str) != 0)
             {
                 long new_trans_number, split_number;
@@ -694,14 +695,14 @@ static void split_find_match (GNCImportTransInfo * trans_info,
                 if (errno || endptr == new_trans_str)
                     conversion_ok = FALSE;
 
-                split_str = xaccTransGetNum (xaccSplitGetParent (split));
+                split_str = gnc_get_num_action (xaccSplitGetParent (split), split);
                 errno = 0;
                 split_number = strtol(split_str, &endptr, 10);
                 if (errno || endptr == split_str)
                     conversion_ok = FALSE;
 
                 if ( (conversion_ok && (split_number == new_trans_number)) ||
-                        (safe_strcmp(new_trans_str, split_str) == 0) )
+                        (g_strcmp0(new_trans_str, split_str) == 0) )
                 {
                     /* An exact match of the Check number gives a +4 */
                     prob += 4;
@@ -721,14 +722,14 @@ static void split_find_match (GNCImportTransInfo * trans_info,
             const char *memo = xaccSplitGetMemo(new_trans_fsplit);
             if (memo && strlen(memo) != 0)
             {
-                if (safe_strcmp(memo, xaccSplitGetMemo(split)) == 0)
+                if (safe_strcasecmp(memo, xaccSplitGetMemo(split)) == 0)
                 {
                     /* An exact match of memo gives a +2 */
                     prob = prob + 2;
                     /* DEBUG("heuristics:  probability + 2 (memo)"); */
                 }
-                else if ((strncmp(memo, xaccSplitGetMemo(split),
-                                  strlen(xaccSplitGetMemo(split)) / 2)
+                else if ((strncasecmp(memo, xaccSplitGetMemo(split),
+                                      strlen(xaccSplitGetMemo(split)) / 2)
                           == 0))
                 {
                     /* Very primitive fuzzy match worth +1.  This matches the
@@ -746,17 +747,17 @@ static void split_find_match (GNCImportTransInfo * trans_info,
             const char *descr = xaccTransGetDescription(new_trans);
             if (descr && strlen(descr) != 0)
             {
-                if (safe_strcmp(descr,
-                                xaccTransGetDescription(xaccSplitGetParent(split)))
+                if (safe_strcasecmp(descr,
+                                    xaccTransGetDescription(xaccSplitGetParent(split)))
                         == 0)
                 {
                     /*An exact match of Description gives a +2 */
                     prob = prob + 2;
                     /*DEBUG("heuristics:  probability + 2 (description)");*/
                 }
-                else if ((strncmp(descr,
-                                  xaccTransGetDescription (xaccSplitGetParent(split)),
-                                  strlen(xaccTransGetDescription (new_trans)) / 2)
+                else if ((strncasecmp(descr,
+                                      xaccTransGetDescription (xaccSplitGetParent(split)),
+                                      strlen(xaccTransGetDescription (new_trans)) / 2)
                           == 0))
                 {
                     /* Very primitive fuzzy match worth +1.  This matches the
@@ -816,7 +817,7 @@ void gnc_import_find_split_matches(GNCImportTransInfo *trans_info,
         */
         Account *importaccount =
             xaccSplitGetAccount (gnc_import_TransInfo_get_fsplit (trans_info));
-        time_t download_time = xaccTransGetDate (gnc_import_TransInfo_get_trans (trans_info));
+        time64 download_time = xaccTransGetDate (gnc_import_TransInfo_get_trans (trans_info));
 
         qof_query_set_book (query, gnc_get_current_book());
         xaccQueryAddSingleAccountMatch (query, importaccount,
@@ -917,7 +918,7 @@ gnc_import_process_trans_item (GncImportMatchMap *matchmap,
         xaccSplitSetReconcile(gnc_import_TransInfo_get_fsplit (trans_info), CREC);
         /*Set reconcile date to today*/
         xaccSplitSetDateReconciledSecs(gnc_import_TransInfo_get_fsplit (trans_info),
-                                       time(NULL));
+                                       gnc_time (NULL));
         /* Done editing. */
         xaccTransCommitEdit(gnc_import_TransInfo_get_trans (trans_info));
         return TRUE;
@@ -945,7 +946,7 @@ gnc_import_process_trans_item (GncImportMatchMap *matchmap,
             /*DEBUG("BeginEdit selected_match")*/
             xaccTransBeginEdit(selected_match->trans);
 
-            xaccTransSetDatePostedSecs(selected_match->trans,
+            xaccTransSetDatePostedSecsNormalized(selected_match->trans,
                                        xaccTransGetDate(xaccSplitGetParent(
                                                    gnc_import_TransInfo_get_fsplit(trans_info))));
 
@@ -981,7 +982,7 @@ gnc_import_process_trans_item (GncImportMatchMap *matchmap,
             }
 
             /* Set reconcile date to today */
-            xaccSplitSetDateReconciledSecs(selected_match->split, time(NULL));
+            xaccSplitSetDateReconciledSecs(selected_match->split, gnc_time (NULL));
 
             /* Copy the online id to the reconciled transaction, so
                the match will be remembered */
@@ -1037,7 +1038,7 @@ gnc_import_process_trans_item (GncImportMatchMap *matchmap,
                 (selected_match->split, CREC);
             /* Set reconcile date to today */
             xaccSplitSetDateReconciledSecs
-            (selected_match->split, time(NULL));
+            (selected_match->split, gnc_time (NULL));
 
             /* Copy the online id to the reconciled transaction, so
             		 the match will be remembered */
@@ -1065,6 +1066,7 @@ gnc_import_process_trans_item (GncImportMatchMap *matchmap,
     return TRUE;
     default:
         DEBUG("Invalid GNCImportAction for this imported transaction.");
+        break;
     }
     /*DEBUG("End");*/
     return FALSE;
@@ -1117,7 +1119,6 @@ static gint check_trans_online_id(Transaction *trans1, void *user_data)
   its parent account. */
 gboolean gnc_import_exists_online_id (Transaction *trans)
 {
-    int i;
     gboolean online_id_exists = FALSE;
     Account *dest_acct;
     Split *source_split;
