@@ -1,4 +1,11 @@
 /********************************************************************\
+ * import-main-matcher.c - Transaction matcher main window          *
+ *                                                                  *
+ * Copyright (C) 2002 Benoit Grégoire <bock@step.polymtl.ca>        *
+ * Copyright (C) 2002 Christian Stimming                            *
+ * Copyright (c) 2006 David Hampton <hampton@employees.org>         *
+ * Copyright (C) 2012 Robert Fewell                                 *
+ *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
  * published by the Free Software Foundation; either version 2 of   *
@@ -41,12 +48,14 @@
 #include "import-match-picker.h"
 #include "import-backend.h"
 #include "import-account-matcher.h"
+#include "app-utils/gnc-component-manager.h"
 
 #define GCONF_SECTION "dialogs/import/generic_matcher/transaction_list"
 
 struct _main_matcher_info
 {
     GtkWidget *dialog;
+    GtkWidget *assistant;
     GtkTreeView *view;
     GNCImportSettings *user_settings;
     GdkColor color_back_red;
@@ -80,6 +89,11 @@ enum downloaded_cols
 
 static QofLogModule log_module = GNC_MOD_IMPORT;
 
+void on_matcher_ok_clicked (GtkButton *button, GNCImportMainMatcher *info);
+void on_matcher_cancel_clicked (GtkButton *button, gpointer user_data);
+void on_matcher_help_clicked (GtkButton *button, gpointer user_data);
+void on_matcher_help_close_clicked (GtkButton *button, gpointer user_data);
+
 /* Local prototypes */
 static void
 automatch_store_transactions(GNCImportMainMatcher *info,
@@ -120,13 +134,19 @@ void gnc_gen_trans_list_delete (GNCImportMainMatcher *info)
         while (gtk_tree_model_iter_next (model, &iter));
     }
 
-    gnc_save_window_size(GCONF_SECTION, GTK_WINDOW(info->dialog));
-    gnc_import_Settings_delete (info->user_settings);
-    gtk_widget_destroy (GTK_WIDGET (info->dialog));
+
+    if (!(info->dialog == NULL))
+    {
+        gnc_save_window_size(GCONF_SECTION, GTK_WINDOW(info->dialog));
+        gnc_import_Settings_delete (info->user_settings);
+        gtk_widget_destroy (GTK_WIDGET (info->dialog));
+    }
+    else
+        gnc_import_Settings_delete (info->user_settings);
     g_free (info);
 }
 
-static void
+void
 on_matcher_ok_clicked (GtkButton *button,
                        GNCImportMainMatcher *info)
 {
@@ -135,7 +155,7 @@ on_matcher_ok_clicked (GtkButton *button,
     GtkTreeRowReference *ref;
     GtkTreeIter iter;
     GNCImportTransInfo *trans_info;
-    GSList *refs_list = NULL, *item;
+    GSList *refs_list = NULL;
 
     g_assert (info);
 
@@ -145,6 +165,10 @@ on_matcher_ok_clicked (GtkButton *button,
     if (!gtk_tree_model_get_iter_first(model, &iter))
         return;
 
+    /* Don't run any queries and/or split sorts while processing the matcher
+    results. */
+    gnc_suspend_gui_refresh();
+
     do
     {
         gtk_tree_model_get(model, &iter,
@@ -165,78 +189,60 @@ on_matcher_ok_clicked (GtkButton *button,
                                                info->user_data);
             }
         }
-        else
-        {
-            /* transaction skipped -> destroy
-             * Otherwise temporary transactions remains visible if account is open
-             * (see gnc_import_process_trans_item() case GNCImport_CLEAR) */
-            xaccTransDestroy(gnc_import_TransInfo_get_trans(trans_info));
-            xaccTransCommitEdit(gnc_import_TransInfo_get_trans(trans_info));
-        }
-
     }
     while (gtk_tree_model_iter_next (model, &iter));
 
-    /* DEBUG ("Deleting") */
-    /* DRH: Is this necessary. Isn't the call to trans_list_delete at
-       the end of this routine going to destroy the entire list store
-       anyway? */
-    for (item = refs_list; item; item = g_slist_next(item))
-    {
-        ref = item->data;
-        path =  gtk_tree_row_reference_get_path(ref);
-        if (gtk_tree_model_get_iter(model, &iter, path))
-            gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
-        gtk_tree_path_free(path);
-        gtk_tree_row_reference_free(ref);
-    }
-    g_slist_free(refs_list);
+    /* Allow GUI refresh again. */
+    gnc_resume_gui_refresh();
 
     gnc_gen_trans_list_delete (info);
     /* DEBUG ("End") */
 }
 
-static void
-on_matcher_cancel_clicked (GtkButton *button,
-                           gpointer user_data)
+void
+on_matcher_cancel_clicked (GtkButton *button, gpointer user_data)
 {
     GNCImportMainMatcher *info = user_data;
     gnc_gen_trans_list_delete (info);
 }
 
-static void
-on_matcher_help_close_clicked (GtkButton *button,
-                               gpointer user_data)
+void
+on_matcher_help_close_clicked (GtkButton *button, gpointer user_data)
 {
     GtkWidget *help_dialog = user_data;
 
     gtk_widget_destroy(help_dialog);
 }
 
-static void
-on_matcher_help_clicked (GtkButton *button,
-                         gpointer user_data)
+void
+on_matcher_help_clicked (GtkButton *button, gpointer user_data)
 {
     GNCImportMainMatcher *info = user_data;
-    GladeXML *xml;
+    GtkBuilder *builder;
     GtkWidget *help_dialog, *box;
 
-    xml = gnc_glade_xml_new ("generic-import.glade", "matcher_help");
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-import.glade", "textbuffer2");
+    gnc_builder_add_from_file (builder, "dialog-import.glade", "textbuffer3");
+    gnc_builder_add_from_file (builder, "dialog-import.glade", "textbuffer4");
+    gnc_builder_add_from_file (builder, "dialog-import.glade", "textbuffer5");
+    gnc_builder_add_from_file (builder, "dialog-import.glade", "matcher_help");
 
-    box = glade_xml_get_widget (xml, "red");
+    box = GTK_WIDGET(gtk_builder_get_object (builder, "red"));
     gtk_widget_modify_bg(box, GTK_STATE_NORMAL, &info->color_back_red);
-    box = glade_xml_get_widget (xml, "yellow");
+    box = GTK_WIDGET(gtk_builder_get_object (builder, "yellow"));
     gtk_widget_modify_bg(box, GTK_STATE_NORMAL, &info->color_back_yellow);
-    box = glade_xml_get_widget (xml, "green");
+    box = GTK_WIDGET(gtk_builder_get_object (builder, "green"));
     gtk_widget_modify_bg(box, GTK_STATE_NORMAL, &info->color_back_green);
 
-    help_dialog = glade_xml_get_widget (xml, "matcher_help");
+    help_dialog = GTK_WIDGET(gtk_builder_get_object (builder, "matcher_help"));
     gtk_window_set_transient_for(GTK_WINDOW(help_dialog),
                                  GTK_WINDOW(info->dialog));
 
-    glade_xml_signal_connect_data(xml, "on_matcher_help_close_clicked",
-                                  G_CALLBACK(on_matcher_help_close_clicked),
-                                  help_dialog);
+    /* Connect the signals */
+    gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, help_dialog);
+
+    g_object_unref(G_OBJECT(builder));
 
     gtk_widget_show(help_dialog);
 }
@@ -387,6 +393,7 @@ gnc_gen_trans_row_activated_cb (GtkTreeView           *view,
         break;
     default:
         PERR("I don't know what to do! (Yet...)");
+        break;
     }
     refresh_model_row(gui, model, &iter, trans_info);
 }
@@ -523,8 +530,9 @@ GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
         gint match_date_hardlimit)
 {
     GNCImportMainMatcher *info;
-    GladeXML *xml;
+    GtkBuilder *builder;
     GtkWidget *heading_label;
+    GtkWidget *box, *pbox;
     gboolean show_update;
 
     info = g_new0 (GNCImportMainMatcher, 1);
@@ -534,33 +542,30 @@ GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
     gnc_import_Settings_set_match_date_hardlimit (info->user_settings, match_date_hardlimit);
 
     /* Initialize the GtkDialog. */
-    xml = gnc_glade_xml_new ("generic-import.glade", "transaction_matcher");
-
-    info->dialog = glade_xml_get_widget (xml, "transaction_matcher");
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-import.glade", "transaction_matcher");
+    gnc_builder_add_from_file (builder, "dialog-import.glade", "transaction_matcher_content");
+    info->dialog = GTK_WIDGET(gtk_builder_get_object (builder, "transaction_matcher"));
     g_assert (info->dialog != NULL);
-    info->view = GTK_TREE_VIEW(glade_xml_get_widget (xml, "downloaded_view"));
+
+    /* Pack the content into the dialog vbox */
+    pbox = GTK_WIDGET(gtk_builder_get_object (builder, "transaction_matcher_vbox"));
+    box = GTK_WIDGET(gtk_builder_get_object (builder, "transaction_matcher_content"));
+    gtk_box_pack_start( GTK_BOX(pbox), box, TRUE, TRUE, 0);
+
+    /* Get the view */
+    info->view = GTK_TREE_VIEW(gtk_builder_get_object (builder, "downloaded_view"));
     g_assert (info->view != NULL);
 
     show_update = gnc_import_Settings_get_action_update_enabled(info->user_settings);
     gnc_gen_trans_init_view(info, all_from_same_account, show_update);
-    heading_label = glade_xml_get_widget (xml, "heading_label");
+    heading_label = GTK_WIDGET(gtk_builder_get_object (builder, "heading_label"));
     g_assert (heading_label != NULL);
 
     /* if (parent)
       gtk_window_set_transient_for (GTK_WINDOW (info->dialog),
     			  GTK_WINDOW (parent));*/
 
-    /* Connect signals */
-    glade_xml_signal_connect_data(xml, "on_matcher_ok_clicked",
-                                  G_CALLBACK(on_matcher_ok_clicked),
-                                  info);
-    glade_xml_signal_connect_data(xml, "on_matcher_cancel_clicked",
-                                  G_CALLBACK(on_matcher_cancel_clicked),
-                                  info);
-    glade_xml_signal_connect_data(xml, "on_matcher_help_clicked",
-                                  G_CALLBACK(on_matcher_help_clicked),
-                                  info);
-
     /*Initialise the colors */
     gdk_color_parse(COLOR_RED,    &info->color_back_red);
     gdk_color_parse(COLOR_YELLOW, &info->color_back_yellow);
@@ -574,9 +579,82 @@ GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
 
     info->transaction_processed_cb = NULL;
 
+    /* Connect the signals */
+    gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, info);
+
+    g_object_unref(G_OBJECT(builder));
+
     return info;
 }
 
+/*****************************************************************
+ *                 Assistant routines Start                      *
+ *****************************************************************/
+
+GNCImportMainMatcher * gnc_gen_trans_assist_new (GtkWidget *parent,
+        const gchar* heading,
+        gboolean all_from_same_account,
+        gint match_date_hardlimit)
+{
+    GNCImportMainMatcher *info;
+    GtkBuilder *builder;
+    GtkWidget *heading_label;
+    GtkWidget *box;
+    gboolean show_update;
+
+    info = g_new0 (GNCImportMainMatcher, 1);
+
+    /* Initialize user Settings. */
+    info->user_settings = gnc_import_Settings_new ();
+    gnc_import_Settings_set_match_date_hardlimit (info->user_settings, match_date_hardlimit);
+
+    /* load the interface */
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-import.glade", "transaction_matcher_content");
+    if (builder == NULL)
+    {
+        PERR("Error opening the glade builder interface");
+    }
+    /* Pack content into Assistant page widget */
+    box = GTK_WIDGET(gtk_builder_get_object (builder, "transaction_matcher_content"));
+    gtk_box_pack_start( GTK_BOX(parent), box, TRUE, TRUE, 6);
+
+    /* Get the view */
+    info->view = GTK_TREE_VIEW(gtk_builder_get_object (builder, "downloaded_view"));
+    g_assert (info->view != NULL);
+
+    show_update = gnc_import_Settings_get_action_update_enabled(info->user_settings);
+    gnc_gen_trans_init_view(info, all_from_same_account, show_update);
+    heading_label = GTK_WIDGET(gtk_builder_get_object (builder, "heading_label"));
+    g_assert (heading_label != NULL);
+
+    /*Initialise the colors */
+    gdk_color_parse(COLOR_RED,    &info->color_back_red);
+    gdk_color_parse(COLOR_YELLOW, &info->color_back_yellow);
+    gdk_color_parse(COLOR_GREEN,  &info->color_back_green);
+
+    if (heading)
+        gtk_label_set_text (GTK_LABEL (heading_label), heading);
+
+    info->transaction_processed_cb = NULL;
+
+    /* Connect the signals */
+    gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, info);
+
+    g_object_unref(G_OBJECT(builder));
+
+    return info;
+}
+
+void gnc_gen_trans_assist_start (GNCImportMainMatcher *info)
+{
+    on_matcher_ok_clicked (NULL, info);
+}
+
+/*****************************************************************
+ *                   Assistant routines End                      *
+ *****************************************************************/
+
 void gnc_gen_trans_list_add_tp_cb(GNCImportMainMatcher *info,
                                   GNCTransactionProcessedCB trans_processed_cb,
                                   gpointer user_data)
@@ -585,7 +663,6 @@ void gnc_gen_trans_list_add_tp_cb(GNCImportMainMatcher *info,
     info->transaction_processed_cb = trans_processed_cb;
 }
 
-
 gboolean gnc_gen_trans_list_run (GNCImportMainMatcher *info)
 {
     gboolean result;
@@ -600,7 +677,6 @@ gboolean gnc_gen_trans_list_run (GNCImportMainMatcher *info)
     return result;
 }
 
-
 static void
 refresh_model_row (GNCImportMainMatcher *gui,
                    GtkTreeModel *model,
@@ -627,9 +703,7 @@ refresh_model_row (GNCImportMainMatcher *gui,
     gtk_list_store_set(store, iter, DOWNLOADED_COL_ACCOUNT, ro_text, -1);
 
     /*Date*/
-
-    text =
-        qof_print_date ( xaccTransGetDate( gnc_import_TransInfo_get_trans(info) ) );
+    text = qof_print_date ( xaccTransGetDate( gnc_import_TransInfo_get_trans(info) ) );
     gtk_list_store_set(store, iter, DOWNLOADED_COL_DATE, text, -1);
     g_free(text);
 
@@ -753,6 +827,7 @@ refresh_model_row (GNCImportMainMatcher *gui,
     default:
         color = "white";
         ro_text = "WRITEME, this is an unknown action";
+        break;
     }
 
     gtk_list_store_set(store, iter,
@@ -815,7 +890,6 @@ refresh_model_row (GNCImportMainMatcher *gui,
     gtk_tree_selection_unselect_all(selection);
 }
 
-
 void gnc_gen_trans_list_add_trans(GNCImportMainMatcher *gui, Transaction *trans)
 {
     gnc_gen_trans_list_add_trans_with_ref_id(gui, trans, 0);
