@@ -30,7 +30,6 @@
 #include <glib/gstdio.h>
 #include <string.h>
 #include <sys/time.h>
-#include <libguile.h>
 #include <errno.h>
 
 #include "Account.h"
@@ -480,6 +479,10 @@ static void  process_trans_record(  FILE *log_file)
                         {
                             acct = xaccAccountLookupDirect(record.acc_guid, book);
                             xaccAccountInsertSplit(acct, split);
+
+                            // No currency in the txn yet? Set one now.
+                            if (!xaccTransGetCurrency(trans))
+                                xaccTransSetCurrency(trans, gnc_account_or_default_currency(acct, NULL));
                         }
                         if (is_new_split)
                             xaccTransAppendSplit(trans, split);
@@ -619,7 +622,7 @@ void gnc_file_log_replay (void)
                         PERR("File header not recognised:\n%s", read_buf);
                         PERR("Expected:\n%s", expected_header);
                         gnc_error_dialog(NULL, "%s",
-                                         _("The log file you selected cannot be read.  "
+                                         _("The log file you selected cannot be read. "
                                            "The file header was not recognized."));
                     }
                     else
