@@ -31,10 +31,11 @@
 
 #include "dialog-account-picker.h"
 #include "dialog-utils.h"
-#include "druid-qif-import.h"
+#include "assistant-qif-import.h"
 #include "gnc-gui-query.h"
 #include "gnc-ui-util.h"
 #include "guile-mappings.h"
+#include "gnc-guile-utils.h"
 #include "gnc-ui.h" /* for GNC_RESPONSE_NEW */
 
 enum account_cols
@@ -54,6 +55,7 @@ struct _accountpickerdialog
     gchar           * selected_name;
 };
 
+void gnc_ui_qif_account_picker_new_cb (GtkButton * w, gpointer user_data);
 
 /****************************************************************
  * acct_tree_add_accts
@@ -64,7 +66,6 @@ struct _accountpickerdialog
  * name matches search_name, then a GtkTreeRowReference* will be
  * returned in the reference parameter.
  ****************************************************************/
-
 static void
 acct_tree_add_accts(SCM accts,
                     GtkTreeStore *store,
@@ -74,7 +75,7 @@ acct_tree_add_accts(SCM accts,
                     GtkTreeRowReference **reference)
 {
     GtkTreeIter  iter;
-    const char   * compname;
+    char         * compname;
     char         * acctname;
     gboolean     leafnode;
     SCM          current;
@@ -92,9 +93,9 @@ acct_tree_add_accts(SCM accts,
         }
 
         if (scm_is_string(SCM_CAR(current)))
-            compname = scm_to_locale_string(SCM_CAR(current));
+            compname = gnc_scm_to_locale_string (SCM_CAR(current));
         else
-            compname = "";
+            compname = g_strdup("");
 
         if (!scm_is_null(SCM_CADDR(current)))
         {
@@ -140,6 +141,7 @@ acct_tree_add_accts(SCM accts,
         }
 
         g_free(acctname);
+        g_free(compname);
 
         accts = SCM_CDR(accts);
     }
@@ -151,7 +153,6 @@ acct_tree_add_accts(SCM accts,
  *
  * This function refreshes the contents of the account tree.
  ****************************************************************/
-
 static void
 build_acct_tree(QIFAccountPickerDialog * picker, QIFImportWindow * import)
 {
@@ -167,7 +168,7 @@ build_acct_tree(QIFAccountPickerDialog * picker, QIFImportWindow * import)
 
     /* Get an account tree with all existing and to-be-imported accounts. */
     acct_tree = scm_call_1(get_accts,
-                           gnc_ui_qif_import_druid_get_mappings(import));
+                           gnc_ui_qif_import_assistant_get_mappings(import));
 
     /* Rebuild the store.
      * NOTE: It is necessary to save a copy of the name to select, because
@@ -200,8 +201,7 @@ build_acct_tree(QIFAccountPickerDialog * picker, QIFImportWindow * import)
  * This handler is invoked when the user wishes to create a new
  * account.
  ****************************************************************/
-
-static void
+void
 gnc_ui_qif_account_picker_new_cb(GtkButton * w, gpointer user_data)
 {
     QIFAccountPickerDialog * wind = user_data;
@@ -242,7 +242,7 @@ gnc_ui_qif_account_picker_new_cb(GtkButton * w, gpointer user_data)
         /* Save the full name and update the map entry. */
         g_free(wind->selected_name);
         wind->selected_name = fullname;
-        scm_call_2(name_setter, wind->map_entry, scm_makfrom0str(fullname));
+        scm_call_2(name_setter, wind->map_entry, scm_from_locale_string(fullname));
     }
     gtk_widget_destroy(dlg);
 
@@ -251,6 +251,11 @@ gnc_ui_qif_account_picker_new_cb(GtkButton * w, gpointer user_data)
     gtk_widget_grab_focus(GTK_WIDGET(wind->treeview));
 }
 
+
+/****************************************************************
+ * gnc_ui_qif_account_picker_changed_cb
+ *
+ ****************************************************************/
 static void
 gnc_ui_qif_account_picker_changed_cb(GtkTreeSelection *selection,
                                      gpointer          user_data)
@@ -267,7 +272,7 @@ gnc_ui_qif_account_picker_changed_cb(GtkTreeSelection *selection,
                            ACCOUNT_COL_FULLNAME, &wind->selected_name,
                            -1);
         scm_call_2(name_setter, wind->map_entry,
-                   scm_makfrom0str(wind->selected_name));
+                   wind->selected_name ? scm_from_locale_string(wind->selected_name) : SCM_BOOL_F);
     }
     else
     {
@@ -275,6 +280,11 @@ gnc_ui_qif_account_picker_changed_cb(GtkTreeSelection *selection,
     }
 }
 
+
+/****************************************************************
+ * gnc_ui_qif_account_picker_row_activated_cb
+ *
+ ****************************************************************/
 static void
 gnc_ui_qif_account_picker_row_activated_cb(GtkTreeView *view,
         GtkTreePath *path,
@@ -287,6 +297,11 @@ gnc_ui_qif_account_picker_row_activated_cb(GtkTreeView *view,
     gtk_dialog_response(GTK_DIALOG(wind->dialog), GTK_RESPONSE_OK);
 }
 
+
+/****************************************************************
+ * gnc_ui_qif_account_picker_map_cb
+ *
+ ****************************************************************/
 static int
 gnc_ui_qif_account_picker_map_cb(GtkWidget * w, gpointer user_data)
 {
@@ -308,7 +323,6 @@ gnc_ui_qif_account_picker_map_cb(GtkWidget * w, gpointer user_data)
  * user clicks OK, map_entry is changed and TRUE is returned.
  * If the clicks Cancel instead, FALSE is returned. Modal.
  ****************************************************************/
-
 gboolean
 qif_account_picker_dialog(QIFImportWindow * qif_wind, SCM map_entry)
 {
@@ -317,7 +331,7 @@ qif_account_picker_dialog(QIFImportWindow * qif_wind, SCM map_entry)
     SCM set_gnc_name = scm_c_eval_string("qif-map-entry:set-gnc-name!");
     SCM orig_acct    = scm_call_1(gnc_name, map_entry);
     int response;
-    GladeXML *xml;
+    GtkBuilder *builder;
     GtkWidget *button;
 
     wind = g_new0(QIFAccountPickerDialog, 1);
@@ -327,21 +341,19 @@ qif_account_picker_dialog(QIFImportWindow * qif_wind, SCM map_entry)
     scm_gc_protect_object(wind->map_entry);
 
     /* Set the initial account to be selected. */
-    wind->selected_name = g_strdup(scm_to_locale_string(orig_acct));
+    if (scm_is_string(orig_acct))
+        wind->selected_name = gnc_scm_to_locale_string (orig_acct);
 
+    builder = gtk_builder_new();
+    gnc_builder_add_from_file (builder, "dialog-account-picker.glade", "QIF Import Account Picker");
 
-    xml = gnc_glade_xml_new("qif.glade", "QIF Import Account Picker");
+    /* Connect all the signals */
+    gtk_builder_connect_signals (builder, wind);
 
-    glade_xml_signal_connect_data(xml,
-                                  "gnc_ui_qif_account_picker_new_cb",
-                                  G_CALLBACK(gnc_ui_qif_account_picker_new_cb),
-                                  wind);
-
-    wind->dialog     = glade_xml_get_widget(xml, "QIF Import Account Picker");
-    wind->treeview   = GTK_TREE_VIEW(glade_xml_get_widget(xml, "account_tree"));
+    wind->dialog     = GTK_WIDGET(gtk_builder_get_object (builder, "QIF Import Account Picker"));
+    wind->treeview   = GTK_TREE_VIEW(gtk_builder_get_object (builder, "account_tree"));
     wind->qif_wind   = qif_wind;
 
-
     {
         GtkTreeStore *store;
         GtkCellRenderer *renderer;
@@ -383,7 +395,7 @@ qif_account_picker_dialog(QIFImportWindow * qif_wind, SCM map_entry)
                            G_CALLBACK(gnc_ui_qif_account_picker_map_cb),
                            wind);
 
-    button = glade_xml_get_widget(xml, "newbutton");
+    button =  GTK_WIDGET(gtk_builder_get_object (builder, "newbutton"));
     gtk_button_set_use_stock(GTK_BUTTON(button), TRUE);
 
     /* this is to get the checkmarks set up right.. it will get called
@@ -396,6 +408,7 @@ qif_account_picker_dialog(QIFImportWindow * qif_wind, SCM map_entry)
     }
     while (response == GNC_RESPONSE_NEW);
     gtk_widget_destroy(wind->dialog);
+    g_object_unref(G_OBJECT(builder));
 
     scm_gc_unprotect_object(wind->map_entry);
     g_free(wind->selected_name);
