@@ -297,7 +297,7 @@ qof_instance_init_data (QofInstance *inst, QofIdType type, QofBook *book)
      * OK, it might eliminate programming errors. */
 
     col_type = qof_collection_get_type(col);
-    if (safe_strcmp(col_type, type))
+    if (g_strcmp0(col_type, type))
     {
         PERR ("attempt to insert \"%s\" into \"%s\"", type, col_type);
         return;
@@ -418,13 +418,11 @@ qof_instance_set_property (GObject         *object,
                            GParamSpec      *pspec)
 {
     QofInstance *inst;
-    QofInstancePrivate *priv;
     Timespec *ts;
 
     g_return_if_fail(QOF_IS_INSTANCE(object));
 
     inst = QOF_INSTANCE(object);
-    priv = GET_PRIVATE(inst);
 
     switch (prop_id)
     {
@@ -602,17 +600,6 @@ qof_instance_set_slots (QofInstance *inst, KvpFrame *frm)
     inst->kvp_data = frm;
 }
 
-Timespec
-qof_instance_get_last_update (const QofInstance *inst)
-{
-    if (!inst)
-    {
-        Timespec ts = {0, -1};
-        return ts;
-    }
-    return GET_PRIVATE(inst)->last_update;
-}
-
 void
 qof_instance_set_last_update (QofInstance *inst, Timespec ts)
 {
@@ -645,13 +632,6 @@ void qof_instance_reset_editlevel (gpointer ptr)
     GET_PRIVATE(ptr)->editlevel = 0;
 }
 
-gboolean
-qof_instance_check_edit(const QofInstance *inst)
-{
-    g_return_val_if_fail(QOF_IS_INSTANCE(inst), FALSE);
-    return (GET_PRIVATE(inst)->editlevel > 0);
-}
-
 int
 qof_instance_version_cmp (const QofInstance *left, const QofInstance *right)
 {
@@ -770,14 +750,6 @@ qof_instance_get_version (gconstpointer inst)
     return GET_PRIVATE(inst)->version;
 }
 
-gint
-qof_instance_compare_version (gconstpointer inst1, gconstpointer inst2)
-{
-    g_return_val_if_fail(QOF_IS_INSTANCE(inst1), 1);
-    g_return_val_if_fail(QOF_IS_INSTANCE(inst2), -1);
-    return GET_PRIVATE(inst2)->version - GET_PRIVATE(inst1)->version;
-}
-
 void
 qof_instance_set_version (gpointer inst, gint32 vers)
 {
@@ -793,18 +765,6 @@ qof_instance_copy_version (gpointer to, gconstpointer from)
     GET_PRIVATE(to)->version = GET_PRIVATE(from)->version;
 }
 
-void
-qof_instance_increment_version (gpointer inst, guint32 new_check)
-{
-    QofInstancePrivate *priv;
-
-    g_return_if_fail(QOF_IS_INSTANCE(inst));
-
-    priv = GET_PRIVATE(inst);
-    priv->version++;
-    priv->version_check = new_check;
-}
-
 guint32
 qof_instance_get_version_check (gconstpointer inst)
 {
@@ -853,64 +813,6 @@ void qof_instance_set_idata(gpointer inst, guint32 idata)
 
 /* ========================================================== */
 
-void
-qof_instance_gemini (QofInstance *to, const QofInstance *from)
-{
-    QofInstancePrivate *from_priv, *to_priv, *fb_priv, *tb_priv;
-    time_t now;
-
-    g_return_if_fail(QOF_IS_INSTANCE(to));
-    g_return_if_fail(QOF_IS_INSTANCE(from));
-
-    from_priv = GET_PRIVATE(from);
-    to_priv = GET_PRIVATE(to);
-    fb_priv = GET_PRIVATE(from_priv->book);
-    tb_priv = GET_PRIVATE(to_priv->book);
-
-    /* Books must differ for a gemini to be meaningful */
-    if (from_priv->book == to_priv->book)
-        return;
-
-    now = time(0);
-
-    /* Make a note of where the copy came from */
-    gnc_kvp_bag_add (to->kvp_data, "gemini", now,
-                     "inst_guid", &from_priv->guid,
-                     "book_guid", &fb_priv->guid,
-                     NULL);
-    gnc_kvp_bag_add (from->kvp_data, "gemini", now,
-                     "inst_guid", &to_priv->guid,
-                     "book_guid", &tb_priv->guid,
-                     NULL);
-
-    to_priv->dirty = TRUE;
-}
-
-QofInstance *
-qof_instance_lookup_twin (const QofInstance *src, QofBook *target_book)
-{
-    QofCollection *col;
-    KvpFrame *fr;
-    GncGUID * twin_guid;
-    QofInstance * twin;
-    QofInstancePrivate *bpriv;
-
-    if (!src || !target_book) return NULL;
-    ENTER (" ");
-
-    bpriv = GET_PRIVATE(QOF_INSTANCE(target_book));
-    fr = gnc_kvp_bag_find_by_guid (src->kvp_data, "gemini",
-                                   "book_guid", &bpriv->guid);
-
-    twin_guid = kvp_frame_get_guid (fr, "inst_guid");
-
-    col = qof_book_get_collection (target_book, src->e_type);
-    twin = (QofInstance *) qof_collection_lookup_entity (col, twin_guid);
-
-    LEAVE (" found twin=%p", twin);
-    return twin;
-}
-
 /* Returns a displayable name to represent this object */
 gchar* qof_instance_get_display_name(const QofInstance* inst)
 {
@@ -1105,10 +1007,8 @@ qof_commit_edit_part2(QofInstance *inst,
 {
     QofInstancePrivate *priv;
     QofBackend * be;
-    gboolean dirty;
 
     priv = GET_PRIVATE(inst);
-    dirty = priv->dirty;
 
     /* See if there's a backend.  If there is, invoke it. */
     be = qof_book_get_backend(priv->book);
@@ -1160,9 +1060,3 @@ qof_commit_edit_part2(QofInstance *inst,
 
 /* ========================== END OF FILE ======================= */
 
-// Local Variables:
-// mode: c
-// indent-tabs-mode: nil
-// c-block-comment-prefix: "* "
-// eval: (c-add-style "gnc" '("k&r" (c-basic-offset . 4) (c-offsets-alist (case-label . +))) t)
-// End:
