@@ -207,9 +207,9 @@ gnc_get_default_register_style (GNCAccountType type)
     default:
         style_string = gnc_gconf_get_string(GCONF_GENERAL_REGISTER,
                                             "default_style", NULL);
-        if (safe_strcmp(style_string, "journal") == 0)
+        if (g_strcmp0(style_string, "journal") == 0)
             new_style = REG_STYLE_JOURNAL;
-        else if (safe_strcmp(style_string, "auto_ledger") == 0)
+        else if (g_strcmp0(style_string, "auto_ledger") == 0)
             new_style = REG_STYLE_AUTO_LEDGER;
         else
             new_style = REG_STYLE_LEDGER;
@@ -406,7 +406,7 @@ GNCLedgerDisplay *
 gnc_ledger_display_gl (void)
 {
     Query *query;
-    time_t start;
+    time64 start;
     struct tm tm;
     GNCLedgerDisplay *ld;
 
@@ -436,7 +436,7 @@ gnc_ledger_display_gl (void)
 
     gnc_tm_get_today_start(&tm);
     tm.tm_mon--; /* Default the register to the last month's worth of transactions. */
-    start = mktime (&tm);
+    start = gnc_mktime (&tm);
     xaccQueryAddDateMatchTT (query,
                              TRUE, start,
                              FALSE, 0,
