@@ -28,6 +28,7 @@
 #include "SchedXaction.h"
 #include "datecell.h"
 #include "gnc-engine.h"
+#include "engine-helpers.h"
 #include "numcell.h"
 #include "pricecell.h"
 #include "recncell.h"
@@ -126,20 +127,40 @@ gnc_split_register_save_num_cell (BasicCell * cell,
 
     DEBUG ("NUM: %s\n", value ? value : "(null)");
 
-    xaccTransSetNum (sd->trans, value);
+    /* set per book option */
+    gnc_set_num_action (sd->trans, sd->split, value, NULL);
 
     if (gnc_num_cell_set_last_num ((NumCell *) cell, value))
     {
         SRInfo *info = gnc_split_register_get_info (reg);
         Split *blank_split = xaccSplitLookup (&info->blank_split_guid,
-                                              gnc_get_current_book ());
+                                                  gnc_get_current_book ());
         Transaction *blank_trans = xaccSplitGetParent (blank_split);
 
         if (sd->trans == blank_trans)
-            gnc_split_register_set_last_num (reg, gnc_basic_cell_get_value (cell));
+           gnc_split_register_set_last_num (reg, gnc_basic_cell_get_value (cell));
     }
 }
 
+static void
+gnc_split_register_save_tnum_cell (BasicCell * cell,
+                                  gpointer save_data,
+                                  gpointer user_data)
+{
+    SRSaveData *sd = save_data;
+    SplitRegister *reg = user_data;
+    const char *value;
+
+    g_return_if_fail (gnc_basic_cell_has_name (cell, TNUM_CELL));
+
+    value = gnc_basic_cell_get_value (cell);
+
+    DEBUG ("TNUM: %s\n", value ? value : "(null)");
+
+    /* set tran-num using utility function */
+    gnc_set_num_action (sd->trans, NULL, value, NULL);
+}
+
 static void
 gnc_split_register_save_desc_cell (BasicCell * cell,
                                    gpointer save_data,
@@ -203,7 +224,9 @@ gnc_split_register_save_actn_cell (BasicCell * cell,
 
     DEBUG ("ACTN: %s", value ? value : "(null)");
 
-    xaccSplitSetAction (sd->split, value);
+    /* Set split-action with gnc_set_num_action which is the same as
+     * xaccSplitSetAction with these arguments */
+    gnc_set_num_action (NULL, sd->split, NULL, value);
 }
 
 static void
@@ -794,6 +817,10 @@ gnc_split_register_model_add_save_handlers (TableModel *model)
                                       gnc_split_register_save_num_cell,
                                       NUM_CELL);
 
+    gnc_table_model_set_save_handler (model,
+                                      gnc_split_register_save_tnum_cell,
+                                      TNUM_CELL);
+
     gnc_table_model_set_save_handler (model,
                                       gnc_split_register_save_desc_cell,
                                       DESC_CELL);
