@@ -28,6 +28,7 @@
 #include <glib/gi18n.h>
 #include <libguile.h>
 
+#include <gnc-gdate-utils.h>
 #include "combocell.h"
 #include "datecell.h"
 #include "dialog-utils.h"
@@ -48,6 +49,9 @@
 #include "split-register-model-save.h"
 #include "table-allgui.h"
 #include "dialog-account.h"
+#include "dialog-dup-trans.h"
+#include "engine-helpers.h"
+#include "qofbookslots.h"
 
 
 /** static variables ******************************************************/
@@ -182,6 +186,7 @@ gnc_split_register_begin_edit_or_warn(SRInfo *info, Transaction *trans)
         }
     }
     LEAVE(" ");
+    return FALSE;  /* to satisfy static code analysis */
 }
 
 void
@@ -483,21 +488,74 @@ gnc_split_register_duplicate_current (SplitRegister *reg)
     if (cursor_class == CURSOR_CLASS_SPLIT)
     {
         Split *new_split;
+        char *out_num;
+        gboolean new_act_num = FALSE;
 
         /* We are on a split in an expanded transaction.
-         * Just copy the split and add it to the transaction. */
+         * Just copy the split and add it to the transaction.
+         * However, if the split-action field is being used as the register 
+         * number, and the action field is a number, request a new value or
+         * cancel. Need to get next number and update account last num from
+         * split account not register account, which may be the same or not */
+
+        if (!reg->use_tran_num_for_num_field
+            && gnc_strisnum (gnc_get_num_action (NULL, split)))
+        {
+            Account *account = xaccSplitGetAccount (split);
+            const char *in_num = NULL;
+            const char* title = _("New Split Information");
+            time64 date = info->last_date_entered;
+
+            if (account)
+                in_num = xaccAccountGetLastNum (account);
+            else
+                in_num = gnc_get_num_action (NULL, split);
+            if (!gnc_dup_trans_dialog (gnc_split_register_get_parent (reg),
+                                   title, FALSE, &date, in_num, &out_num, NULL, NULL))
+            {
+                gnc_resume_gui_refresh ();
+                LEAVE("dup cancelled");
+                return NULL;
+            }
+            new_act_num = TRUE;
+        }
 
         new_split = xaccMallocSplit (gnc_get_current_book ());
 
         xaccTransBeginEdit (trans);
         xaccSplitSetParent (new_split, trans);
         gnc_copy_split_onto_split (split, new_split, FALSE);
+        if (new_act_num) /* if new number supplied by user dialog */
+            gnc_set_num_action (NULL, new_split, out_num, NULL);
         xaccTransCommitEdit (trans);
 
+        if (new_act_num && gnc_strisnum (out_num))
+        {
+            Account *account = xaccSplitGetAccount (new_split);
+
+            /* If current register is for account, set last num */
+            if (xaccAccountEqual(account,
+                                    gnc_split_register_get_default_account(reg),
+                                    TRUE))
+            {
+                NumCell *num_cell;
+                num_cell = (NumCell *) gnc_table_layout_get_cell (reg->table->layout,
+                       NUM_CELL);
+                if (gnc_num_cell_set_last_num (num_cell, out_num))
+                    gnc_split_register_set_last_num (reg, out_num);
+            }
+            else
+            {
+                xaccAccountSetLastNum (account, out_num);
+            }
+        }
+
         return_split = new_split;
 
         info->cursor_hint_split = new_split;
         info->cursor_hint_cursor_class = CURSOR_CLASS_SPLIT;
+        if (new_act_num)
+            g_free (out_num);
     }
     else
     {
@@ -506,30 +564,60 @@ gnc_split_register_duplicate_current (SplitRegister *reg)
         int trans_split_index;
         int split_index;
         const char *in_num = NULL;
+        const char *in_tnum = NULL;
         char *out_num;
-        time_t date;
+        char *out_tnum;
+        time64 date;
+        gboolean use_autoreadonly = qof_book_uses_autoreadonly(gnc_get_current_book());
 
         /* We are on a transaction row. Copy the whole transaction. */
 
         date = info->last_date_entered;
-        if (gnc_strisnum (xaccTransGetNum (trans)))
+        if (gnc_strisnum (gnc_get_num_action (trans, trans_split)))
         {
             Account *account = gnc_split_register_get_default_account (reg);
 
             if (account)
                 in_num = xaccAccountGetLastNum (account);
             else
-                in_num = xaccTransGetNum (trans);
+                in_num = gnc_get_num_action (trans, trans_split);
+            in_tnum = (reg->use_tran_num_for_num_field
+                                        ? NULL
+                                        : gnc_get_num_action (trans, NULL));
         }
 
-        if (!gnc_dup_trans_dialog (gnc_split_register_get_parent (reg),
-                                   &date, in_num, &out_num))
+        if (!gnc_dup_trans_dialog (gnc_split_register_get_parent (reg), NULL,
+                                   TRUE, &date, in_num, &out_num, in_tnum, &out_tnum))
         {
             gnc_resume_gui_refresh ();
             LEAVE("dup cancelled");
             return NULL;
         }
 
+        if (use_autoreadonly)
+        {
+            GDate d;
+            GDate *readonly_threshold = qof_book_get_autoreadonly_gdate(gnc_get_current_book());
+            gnc_gdate_set_time64 (&d, date);
+            if (g_date_compare(&d, readonly_threshold) < 0)
+            {
+                GtkWidget *dialog = gtk_message_dialog_new(NULL,
+                                    0,
+                                    GTK_MESSAGE_ERROR,
+                                    GTK_BUTTONS_OK,
+                                    "%s", _("Cannot store a transaction at this date"));
+                gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
+                        "%s", _("The entered date of the duplicated transaction is older than the \"Read-Only Threshold\" set for this book. "
+                                "This setting can be changed in File -> Properties -> Accounts."));
+                gtk_dialog_run(GTK_DIALOG(dialog));
+                gtk_widget_destroy(dialog);
+
+                g_date_free(readonly_threshold);
+                return NULL;
+            }
+            g_date_free(readonly_threshold);
+        }
+
         split_index = xaccTransGetSplitIndex(trans, split);
         trans_split_index = xaccTransGetSplitIndex(trans, trans_split);
 
@@ -545,8 +633,24 @@ gnc_split_register_duplicate_current (SplitRegister *reg)
 
         xaccTransBeginEdit (new_trans);
         gnc_copy_trans_onto_trans (trans, new_trans, FALSE, FALSE);
-        xaccTransSetDatePostedSecs (new_trans, date);
-        xaccTransSetNum (new_trans, out_num);
+        xaccTransSetDatePostedSecsNormalized (new_trans, date);
+        /* We also must set a new DateEntered on the new entry
+         * because otherwise the ordering is not deterministic */
+        xaccTransSetDateEnteredSecs(new_trans, gnc_time(NULL));
+
+        /* set per book option */
+        gnc_set_num_action (new_trans, NULL, out_num, out_tnum);
+        if (!reg->use_tran_num_for_num_field)
+        {
+            /* find split in new_trans that equals trans_split and set
+             * split_action to out_num */
+            gnc_set_num_action (NULL,
+                                xaccTransGetSplit (new_trans, trans_split_index),
+                                out_num, NULL);
+            /* note that if the transaction has multiple splits to the register
+             * account, only the anchor split will be set with user input. The
+             * user will have to adjust other splits manually. */
+        }
         xaccTransCommitEdit (new_trans);
 
         num_cell = (NumCell *) gnc_table_layout_get_cell (reg->table->layout,
@@ -555,6 +659,8 @@ gnc_split_register_duplicate_current (SplitRegister *reg)
             gnc_split_register_set_last_num (reg, out_num);
 
         g_free (out_num);
+        if (!reg->use_tran_num_for_num_field)
+            g_free (out_tnum);
 
         /* This shouldn't happen, but be paranoid. */
         if (split_index >= xaccTransCountSplits (new_trans))
@@ -898,6 +1004,7 @@ gnc_split_register_paste_current (SplitRegister *reg)
             blank_split = xaccTransGetSplit(trans, 0);
             info->blank_split_guid = *xaccSplitGetGUID (blank_split);
             info->blank_split_edited = TRUE;
+            info->auto_complete = FALSE;
             DEBUG("replacement blank_split=%p", blank_split);
 
             /* NOTE: At this point, the blank transaction virtual cell is still
@@ -1012,6 +1119,7 @@ gnc_split_register_delete_current_trans (SplitRegister *reg)
     {
         DEBUG("deleting blank split");
         info->blank_split_guid = *guid_null();
+        info->auto_complete = FALSE;
     }
     else
     {
@@ -1285,7 +1393,21 @@ gnc_split_register_save_to_scm (SplitRegister *reg,
         const char *value;
 
         value = gnc_table_layout_get_cell_value (reg->table->layout, NUM_CELL);
-        gnc_trans_scm_set_num (trans_scm, value);
+        if (reg->use_tran_num_for_num_field)
+            gnc_trans_scm_set_num (trans_scm, value);
+     /* else this contains the same as ACTN_CELL which is already handled below *
+      * and the TNUM_CELL contains transaction number which is handled in next  *
+      * if statement. */
+    }
+
+    if (gnc_table_layout_get_cell_changed (reg->table->layout, TNUM_CELL, TRUE))
+    {
+        const char *value;
+
+        value = gnc_table_layout_get_cell_value (reg->table->layout, TNUM_CELL);
+        if (!reg->use_tran_num_for_num_field)
+            gnc_trans_scm_set_num (trans_scm, value);
+     /* else this cell is not used */
     }
 
     if (gnc_table_layout_get_cell_changed (reg->table->layout, DESC_CELL, TRUE))
@@ -1504,6 +1626,7 @@ gnc_split_register_save (SplitRegister *reg, gboolean do_commit)
                 info->last_date_entered = xaccTransGetDate (trans);
                 info->blank_split_guid = *guid_null ();
                 info->blank_split_edited = FALSE;
+                info->auto_complete = FALSE;
             }
 
             /* We have to clear the pending guid *before* committing the
@@ -1607,7 +1730,7 @@ gnc_split_register_save (SplitRegister *reg, gboolean do_commit)
         account = gnc_split_register_get_default_account(reg);
         if (account)
             xaccSplitSetAccount(blank_split, account);
-        xaccTransSetDateEnteredSecs(trans, time(NULL));
+        xaccTransSetDateEnteredSecs(trans, gnc_time (NULL));
     }
 
     if (split == NULL)
@@ -1668,6 +1791,7 @@ gnc_split_register_save (SplitRegister *reg, gboolean do_commit)
         if (do_commit)
         {
             info->blank_split_guid = *guid_null ();
+            info->auto_complete = FALSE;
             blank_split = NULL;
             info->last_date_entered = xaccTransGetDate (trans);
         }
@@ -1731,7 +1855,7 @@ gnc_split_register_get_account_by_name (SplitRegister *reg, BasicCell * bcell,
 
     /* Now have the account. */
     account_name = gnc_get_account_name_for_register (account);
-    if (safe_strcmp(account_name, gnc_basic_cell_get_value(bcell)))
+    if (g_strcmp0(account_name, gnc_basic_cell_get_value(bcell)))
     {
         /* The name has changed. Update the cell. */
         gnc_combo_cell_set_value (cell, account_name);
@@ -2439,6 +2563,18 @@ split_register_gconf_changed (GConfEntry *entry, gpointer user_data)
     }
 }
 
+static void
+split_register_book_option_changed (gpointer new_val, gpointer user_data)
+{
+    SplitRegister * reg = user_data;
+    gboolean *new_data = (gboolean*)new_val;
+
+    if (reg == NULL)
+        return;
+
+    reg->use_tran_num_for_num_field = (*new_data ? FALSE : TRUE);
+}
+
 static void
 gnc_split_register_init (SplitRegister *reg,
                          SplitRegisterType type,
@@ -2458,6 +2594,9 @@ gnc_split_register_init (SplitRegister *reg,
     gnc_gconf_general_register_cb(KEY_ACCOUNT_SEPARATOR,
                                   split_register_gconf_changed,
                                   reg);
+    gnc_book_option_register_cb(OPTION_NAME_NUM_FIELD_SOURCE,
+                                split_register_book_option_changed,
+                                reg);
 
     reg->sr_info = NULL;
 
@@ -2466,6 +2605,9 @@ gnc_split_register_init (SplitRegister *reg,
     reg->use_double_line = use_double_line;
     reg->do_auto_complete = do_auto_complete;
     reg->is_template = is_template;
+    reg->use_tran_num_for_num_field =
+                (qof_book_use_split_action_for_num_field(gnc_get_current_book())
+                    ? FALSE : TRUE);
 
     layout = gnc_split_register_layout_new (reg);
 
@@ -2672,6 +2814,7 @@ gnc_split_register_cleanup (SplitRegister *reg)
             pending_trans = NULL;
         }
         info->blank_split_guid = *guid_null ();
+        info->auto_complete = FALSE;
         blank_split = NULL;
     }
 
@@ -2712,6 +2855,9 @@ gnc_split_register_destroy (SplitRegister *reg)
     gnc_gconf_general_remove_cb(KEY_ACCOUNT_SEPARATOR,
                                 split_register_gconf_changed,
                                 reg);
+    gnc_book_option_remove_cb(OPTION_NAME_NUM_FIELD_SOURCE,
+                                split_register_book_option_changed,
+                                reg);
     gnc_split_register_cleanup (reg);
 
     gnc_table_destroy (reg->table);
