@@ -35,8 +35,8 @@
 
 #include "config.h"
 
-#include <gnome.h>
 #include <string.h>
+#include <gdk/gdkkeysyms.h>
 
 #include "QuickFill.h"
 #include "combocell.h"
@@ -44,6 +44,7 @@
 #include "gnucash-item-edit.h"
 #include "gnucash-item-list.h"
 #include "gnucash-sheet.h"
+#include "gnucash-sheetP.h"
 #include "table-allgui.h"
 
 #define KEY_AUTO_RAISE_LISTS	"auto_raise_lists"
@@ -205,7 +206,7 @@ key_press_item_cb (GncItemList *item_list, GdkEventKey *event, gpointer data)
 
     switch (event->keyval)
     {
-    case GDK_Escape:
+    case GDK_KEY_Escape:
         gnc_item_edit_hide_popup (box->item_edit);
         box->list_popped = FALSE;
         break;
@@ -605,7 +606,7 @@ gnc_combo_cell_direct_update (BasicCell *bcell,
     unicode_value = gdk_keyval_to_unicode(event->keyval);
     switch (event->keyval)
     {
-    case GDK_slash:
+    case GDK_KEY_slash:
         if (!(event->state & GDK_MOD1_MASK))
         {
             if (unicode_value == box->complete_char)
@@ -614,9 +615,9 @@ gnc_combo_cell_direct_update (BasicCell *bcell,
             return FALSE;
         }
         keep_on_going = TRUE;
-        /* Fall through */
-    case GDK_Tab:
-    case GDK_ISO_Left_Tab:
+        /* fall through */
+    case GDK_KEY_Tab:
+    case GDK_KEY_ISO_Left_Tab:
         if (!(event->state & GDK_CONTROL_MASK) &&
                 !keep_on_going)
             return FALSE;
@@ -746,8 +747,7 @@ static void
 gnc_combo_cell_gui_realize (BasicCell *bcell, gpointer data)
 {
     GnucashSheet *sheet = data;
-    GnomeCanvasItem *item = sheet->item_editor;
-    GncItemEdit *item_edit = GNC_ITEM_EDIT (item);
+    GncItemEdit *item_edit = gnucash_sheet_get_item_edit (sheet);
     ComboCell *cell = (ComboCell *) bcell;
     PopBox *box = cell->cell.gui_private;
 
@@ -961,8 +961,3 @@ gnc_combo_cell_set_autosize (ComboCell *cell, gboolean autosize)
     box->autosize = autosize;
 }
 
-/*
-  Local Variables:
-  c-basic-offset: 8
-  End:
-*/
