@@ -29,8 +29,13 @@
  */
 
 #include "config.h"
+#include <glib.h>
+#include <glib/gprintf.h>
+#include <gdk/gdkkeysyms.h>
+#include <libgnomecanvas/libgnomecanvas.h>
 
 #include "gnucash-sheet.h"
+#include "gnucash-sheetP.h"
 
 #include "dialog-utils.h"
 #include "gnc-gconf-utils.h"
@@ -43,6 +48,10 @@
 #include "split-register.h"
 #include "gnc-engine.h"		// For debugging, e.g. ENTER(), LEAVE()
 
+#ifdef G_OS_WIN32
+# include <gdk/gdkwin32.h>
+#endif
+
 #define DEFAULT_REGISTER_HEIGHT 400
 #define DEFAULT_REGISTER_WIDTH  400
 /* Used to calculate the minimum preferred height of the register window: */
@@ -375,7 +384,6 @@ gnucash_sheet_y_pixel_to_block (GnucashSheet *sheet, int y)
 void
 gnucash_sheet_compute_visible_range (GnucashSheet *sheet)
 {
-    Table *table;
     VirtualCellLocation vcell_loc;
     gint height;
     gint cy;
@@ -384,7 +392,6 @@ gnucash_sheet_compute_visible_range (GnucashSheet *sheet)
     g_return_if_fail (sheet != NULL);
     g_return_if_fail (GNUCASH_IS_SHEET (sheet));
 
-    table = sheet->table;
     height = GTK_WIDGET(sheet)->allocation.height;
 
     gnome_canvas_get_scroll_offsets (GNOME_CANVAS(sheet), NULL, &cy);
@@ -859,7 +866,6 @@ gnucash_sheet_insert_cb (GtkWidget *widget,
     GString *change_text_gs;
 
     int new_text_len;
-    int old_text_len;
     int change_text_len;
 
     const char *old_text;
@@ -896,7 +902,6 @@ gnucash_sheet_insert_cb (GtkWidget *widget,
     old_text = gtk_entry_get_text (GTK_ENTRY(sheet->entry));
     if (old_text == NULL)
         old_text = "";
-    old_text_len = strlen (old_text);
 
     old_position = *position;
 
@@ -983,7 +988,7 @@ gnucash_sheet_insert_cb (GtkWidget *widget,
         *position = g_utf8_strlen(retval, -1);
 
     if (start_sel != end_sel)
-	gtk_editable_select_region(editable, start_sel, end_sel);
+        gtk_editable_select_region(editable, start_sel, end_sel);
 
     g_string_free (new_text_gs, TRUE);
     g_string_free (change_text_gs, TRUE);
@@ -1199,15 +1204,12 @@ gnucash_sheet_check_direct_update_cell(GnucashSheet *sheet,
 static void
 gnucash_sheet_start_editing_at_cursor (GnucashSheet *sheet)
 {
-    GnomeCanvas *canvas;
     const char *text;
     VirtualLocation virt_loc;
 
     g_return_if_fail (sheet != NULL);
     g_return_if_fail (GNUCASH_IS_SHEET (sheet));
 
-    canvas = GNOME_CANVAS(sheet);
-
     gnucash_cursor_get_virt (GNUCASH_CURSOR(sheet->cursor), &virt_loc);
 
     text = gnc_table_get_entry (sheet->table, virt_loc);
@@ -1392,7 +1394,7 @@ gnucash_button_press_event (GtkWidget *widget, GdkEventButton *event)
     if (sheet->button == 3)
         sheet->button = 0;
 
-    if (!GTK_WIDGET_HAS_FOCUS(widget))
+    if (!gtk_widget_has_focus(widget))
         gtk_widget_grab_focus(widget);
 
     button_1 = FALSE;
@@ -1406,8 +1408,9 @@ gnucash_button_press_event (GtkWidget *widget, GdkEventButton *event)
     case 2:
         if (event->type != GDK_BUTTON_PRESS)
             return FALSE;
-        gnc_item_edit_paste_primary(GNC_ITEM_EDIT(sheet->item_editor),
-                                    event->time);
+        gnc_item_edit_paste_selection (GNC_ITEM_EDIT(sheet->item_editor),
+                                       GDK_SELECTION_PRIMARY,
+                                       event->time);
         return TRUE;
     case 3:
         do_popup = (sheet->popup != NULL);
@@ -1445,8 +1448,8 @@ gnucash_button_press_event (GtkWidget *widget, GdkEventButton *event)
     {
         gtk_grab_add(widget);
         sheet->grabbed = TRUE;
-        gnc_item_edit_set_has_selection
-        (GNC_ITEM_EDIT(sheet->item_editor), TRUE);
+        gnc_item_edit_set_has_selection (GNC_ITEM_EDIT(sheet->item_editor),
+                                         TRUE);
     }
 
     if (virt_loc_equal (new_virt_loc, cur_virt_loc) && sheet->editing)
@@ -1549,7 +1552,8 @@ gnucash_register_paste_clipboard (GnucashRegister *reg)
     sheet = GNUCASH_SHEET(reg->sheet);
     item_edit = GNC_ITEM_EDIT(sheet->item_editor);
 
-    gnc_item_edit_paste_clipboard(item_edit, GDK_CURRENT_TIME);
+    gnc_item_edit_paste_selection (item_edit, GDK_SELECTION_CLIPBOARD,
+                                   GDK_CURRENT_TIME);
 }
 
 static void
@@ -1590,34 +1594,36 @@ gnucash_sheet_clipboard_event (GnucashSheet *sheet, GdkEventKey *event)
 
     switch (event->keyval)
     {
-    case GDK_C:
-    case GDK_c:
+    case GDK_KEY_C:
+    case GDK_KEY_c:
         if (event->state & GDK_CONTROL_MASK)
         {
             gnc_item_edit_copy_clipboard(item_edit, time);
             handled = TRUE;
         }
         break;
-    case GDK_X:
-    case GDK_x:
+    case GDK_KEY_X:
+    case GDK_KEY_x:
         if (event->state & GDK_CONTROL_MASK)
         {
             gnc_item_edit_cut_clipboard(item_edit, time);
             handled = TRUE;
         }
         break;
-    case GDK_V:
-    case GDK_v:
+    case GDK_KEY_V:
+    case GDK_KEY_v:
         if (event->state & GDK_CONTROL_MASK)
         {
-            gnc_item_edit_paste_clipboard(item_edit, time);
+            gnc_item_edit_paste_selection (item_edit, GDK_SELECTION_CLIPBOARD,
+                                           time);
             handled = TRUE;
         }
         break;
-    case GDK_Insert:
+    case GDK_KEY_Insert:
         if (event->state & GDK_SHIFT_MASK)
         {
-            gnc_item_edit_paste_clipboard(item_edit, time);
+            gnc_item_edit_paste_selection (item_edit, GDK_SELECTION_CLIPBOARD,
+                                           time);
             handled = TRUE;
         }
         else if (event->state & GDK_CONTROL_MASK)
@@ -1710,7 +1716,6 @@ gnucash_sheet_key_press_event_internal (GtkWidget *widget, GdkEventKey *event)
 {
     Table *table;
     GnucashSheet *sheet;
-    CellBlock *header;
     gboolean pass_on = FALSE;
     gboolean abort_move;
     VirtualLocation cur_virt_loc;
@@ -1724,7 +1729,6 @@ gnucash_sheet_key_press_event_internal (GtkWidget *widget, GdkEventKey *event)
 
     sheet = GNUCASH_SHEET (widget);
     table = sheet->table;
-    header = gnc_table_get_header_cell(table)->cellblock;
 
     if (gnucash_sheet_direct_event(sheet, (GdkEvent *) event))
         return TRUE;
@@ -1744,13 +1748,13 @@ gnucash_sheet_key_press_event_internal (GtkWidget *widget, GdkEventKey *event)
     {
         switch (event->keyval)
         {
-        case GDK_Return:
-        case GDK_KP_Enter:
+        case GDK_KEY_Return:
+        case GDK_KEY_KP_Enter:
             g_signal_emit_by_name(sheet->reg, "activate_cursor");
             return TRUE;
             break;
-        case GDK_Tab:
-        case GDK_ISO_Left_Tab:
+        case GDK_KEY_Tab:
+        case GDK_KEY_ISO_Left_Tab:
             if (event->state & GDK_SHIFT_MASK)
             {
                 direction = GNC_TABLE_TRAVERSE_LEFT;
@@ -1764,8 +1768,8 @@ gnucash_sheet_key_press_event_internal (GtkWidget *widget, GdkEventKey *event)
                                     TRUE);
             }
             break;
-        case GDK_KP_Page_Up:
-        case GDK_Page_Up:
+        case GDK_KEY_KP_Page_Up:
+        case GDK_KEY_Page_Up:
             direction = GNC_TABLE_TRAVERSE_UP;
             new_virt_loc.phys_col_offset = 0;
             if (event->state & GDK_SHIFT_MASK)
@@ -1777,8 +1781,8 @@ gnucash_sheet_key_press_event_internal (GtkWidget *widget, GdkEventKey *event)
                 (table, &new_virt_loc, -distance);
             }
             break;
-        case GDK_KP_Page_Down:
-        case GDK_Page_Down:
+        case GDK_KEY_KP_Page_Down:
+        case GDK_KEY_Page_Down:
             direction = GNC_TABLE_TRAVERSE_DOWN;
             new_virt_loc.phys_col_offset = 0;
             if (event->state & GDK_SHIFT_MASK)
@@ -1791,17 +1795,17 @@ gnucash_sheet_key_press_event_internal (GtkWidget *widget, GdkEventKey *event)
                 (table, &new_virt_loc, distance);
             }
             break;
-        case GDK_KP_Up:
-        case GDK_Up:
+        case GDK_KEY_KP_Up:
+        case GDK_KEY_Up:
             direction = GNC_TABLE_TRAVERSE_UP;
             gnc_table_move_vertical_position (table,
                                               &new_virt_loc, -1);
             break;
-        case GDK_KP_Down:
-        case GDK_Down:
-        case GDK_Menu:
+        case GDK_KEY_KP_Down:
+        case GDK_KEY_Down:
+        case GDK_KEY_Menu:
             if (event->keyval == GDK_Menu ||
-                    event->state & GDK_CONTROL_MASK)
+                    (event->state & GDK_CONTROL_MASK))
             {
                 GncItemEdit *item_edit;
 
@@ -1818,12 +1822,12 @@ gnucash_sheet_key_press_event_internal (GtkWidget *widget, GdkEventKey *event)
             gnc_table_move_vertical_position (table,
                                               &new_virt_loc, 1);
             break;
-        case GDK_Control_L:
-        case GDK_Control_R:
-        case GDK_Shift_L:
-        case GDK_Shift_R:
-        case GDK_Alt_L:
-        case GDK_Alt_R:
+        case GDK_KEY_Control_L:
+        case GDK_KEY_Control_R:
+        case GDK_KEY_Shift_L:
+        case GDK_KEY_Shift_R:
+        case GDK_KEY_Alt_L:
+        case GDK_KEY_Alt_R:
             pass_on = TRUE;
             break;
         default:
@@ -1866,7 +1870,6 @@ static gint
 gnucash_sheet_key_press_event (GtkWidget *widget, GdkEventKey *event)
 {
     GnucashSheet *sheet;
-    gint result;
 
     g_return_val_if_fail(widget != NULL, TRUE);
     g_return_val_if_fail(GNUCASH_IS_SHEET(widget), TRUE);
@@ -1879,6 +1882,11 @@ gnucash_sheet_key_press_event (GtkWidget *widget, GdkEventKey *event)
        bug#618434
            save keyval to handle GDK_KP_Decimal event
      */
+#ifdef G_OS_WIN32
+    /* gdk never sends GDK_KP_Decimal on win32. See #486658 */
+    if (event->hardware_keycode == VK_DECIMAL)
+        event->keyval = GDK_KP_Decimal;
+#endif
     if (sheet->preedit_length)
     {
         sheet->shift_state = 0;
@@ -1887,7 +1895,7 @@ gnucash_sheet_key_press_event (GtkWidget *widget, GdkEventKey *event)
     else
     {
         sheet->shift_state = event->state & GDK_SHIFT_MASK;
-        sheet->keyval_state = (event->keyval == GDK_KP_Decimal) ? GDK_KP_Decimal : 0;
+        sheet->keyval_state = (event->keyval == GDK_KEY_KP_Decimal) ? GDK_KEY_KP_Decimal : 0;
     }
     if (gtk_im_context_filter_keypress (sheet->im_context, event))
     {
@@ -1949,7 +1957,7 @@ gnucash_sheet_commit_cb (GtkIMContext *context, const gchar *str,
                          GnucashSheet *sheet)
 {
     GtkEditable *editable;
-    gint tmp_pos, length, sel_start, sel_end;
+    gint tmp_pos, sel_start, sel_end;
 
     g_return_if_fail(strlen(str) > 0);
     g_return_if_fail(sheet->editing == TRUE);
@@ -2010,7 +2018,7 @@ gnucash_sheet_commit_cb (GtkIMContext *context, const gchar *str,
     gtk_editable_get_selection_bounds (editable, &sel_start, &sel_end);
     gtk_editable_set_position (editable, tmp_pos);
     if (sel_start != sel_end)
-	gtk_editable_select_region (editable, sel_start, sel_end);
+        gtk_editable_select_region (editable, sel_start, sel_end);
 
     gnucash_sheet_im_context_reset_flags(sheet);
 }
@@ -2278,6 +2286,29 @@ gnucash_sheet_get_block (GnucashSheet *sheet, VirtualCellLocation vcell_loc)
                           vcell_loc.virt_col);
 }
 
+GncItemEdit *gnucash_sheet_get_item_edit (GnucashSheet *sheet)
+{
+    g_return_val_if_fail (sheet != NULL, NULL);
+    g_return_val_if_fail (GNUCASH_IS_SHEET(sheet), NULL);
+
+    if (sheet->item_editor == NULL)
+        return NULL;
+    else
+        return GNC_ITEM_EDIT (sheet->item_editor);
+}
+
+
+void gnucash_sheet_set_window (GnucashSheet *sheet, GtkWidget *window)
+{
+    g_return_if_fail (sheet != NULL);
+    g_return_if_fail (GNUCASH_IS_SHEET(sheet));
+
+    if (window)
+        g_return_if_fail (GTK_IS_WIDGET(window));
+
+    sheet->window = window;
+}
+
 
 /* This fills up a block from the table; it sets the style and returns
  * true if the style changed. */
@@ -2544,53 +2575,6 @@ gnucash_sheet_table_load (GnucashSheet *sheet, gboolean do_scroll)
     gnucash_sheet_activate_cursor_cell (sheet, TRUE);
 }
 
-static gboolean
-gnucash_sheet_selection_clear (GtkWidget          *widget,
-                               GdkEventSelection  *event)
-{
-    GnucashSheet *sheet;
-
-    g_return_val_if_fail(widget != NULL, FALSE);
-    g_return_val_if_fail(GNUCASH_IS_SHEET(widget), FALSE);
-
-    sheet = GNUCASH_SHEET(widget);
-
-    return gnc_item_edit_selection_clear(GNC_ITEM_EDIT(sheet->item_editor), event);
-}
-
-static void
-gnucash_sheet_selection_get (GtkWidget         *widget,
-                             GtkSelectionData  *selection_data,
-                             guint              info,
-                             guint              time)
-{
-    GnucashSheet *sheet;
-
-    g_return_if_fail(widget != NULL);
-    g_return_if_fail(GNUCASH_IS_SHEET(widget));
-
-    sheet = GNUCASH_SHEET(widget);
-
-    gnc_item_edit_selection_get(GNC_ITEM_EDIT(sheet->item_editor),
-                                selection_data, info, time);
-}
-
-static void
-gnucash_sheet_selection_received (GtkWidget          *widget,
-                                  GtkSelectionData   *selection_data,
-                                  guint               time)
-{
-    GnucashSheet *sheet;
-
-    g_return_if_fail(widget != NULL);
-    g_return_if_fail(GNUCASH_IS_SHEET(widget));
-
-    sheet = GNUCASH_SHEET(widget);
-
-    gnc_item_edit_selection_received(GNC_ITEM_EDIT(sheet->item_editor),
-                                     selection_data, time);
-}
-
 static void
 gnucash_sheet_realize_entry (GnucashSheet *sheet, GtkWidget *entry)
 {
@@ -2712,11 +2696,9 @@ gnucash_sheet_class_init (GnucashSheetClass *class)
 {
     GObjectClass *gobject_class;
     GtkWidgetClass *widget_class;
-    GnomeCanvasClass *canvas_class;
 
     gobject_class = G_OBJECT_CLASS (class);
     widget_class = GTK_WIDGET_CLASS (class);
-    canvas_class = GNOME_CANVAS_CLASS (class);
 
     sheet_parent_class = g_type_class_peek_parent (class);
 
@@ -2738,9 +2720,6 @@ gnucash_sheet_class_init (GnucashSheetClass *class)
     widget_class->motion_notify_event = gnucash_motion_event;
     widget_class->scroll_event = gnucash_scroll_event;
 
-    widget_class->selection_clear_event = gnucash_sheet_selection_clear;
-    widget_class->selection_received = gnucash_sheet_selection_received;
-    widget_class->selection_get = gnucash_sheet_selection_get;
 }
 
 
@@ -2749,8 +2728,8 @@ gnucash_sheet_init (GnucashSheet *sheet)
 {
     GnomeCanvas *canvas = GNOME_CANVAS (sheet);
 
-    GTK_WIDGET_SET_FLAGS (canvas, GTK_CAN_FOCUS);
-    GTK_WIDGET_SET_FLAGS (canvas, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_focus (GTK_WIDGET(canvas), TRUE);
+    gtk_widget_set_can_default (GTK_WIDGET(canvas), TRUE);
 
     sheet->top_block = 1;
     sheet->bottom_block = 1;
@@ -2830,7 +2809,6 @@ GtkWidget *
 gnucash_sheet_new (Table *table)
 {
     GnucashSheet *sheet;
-    GnomeCanvas *sheet_canvas;
     GnomeCanvasItem *item;
     GnomeCanvasGroup *sheet_group;
 
@@ -2839,7 +2817,6 @@ gnucash_sheet_new (Table *table)
     sheet = gnucash_sheet_create (table);
 
     /* handy shortcuts */
-    sheet_canvas = GNOME_CANVAS (sheet);
     sheet_group = gnome_canvas_root (GNOME_CANVAS(sheet));
 
     /* The grid */
@@ -2891,12 +2868,8 @@ static void
 gnucash_register_class_init (GnucashRegisterClass *class)
 {
     GObjectClass *gobject_class;
-    GtkWidgetClass *widget_class;
-    GtkTableClass *table_class;
 
     gobject_class = G_OBJECT_CLASS (class);
-    widget_class = (GtkWidgetClass *) class;
-    table_class = (GtkTableClass *) class;
 
     register_parent_class = g_type_class_peek_parent (class);
 
@@ -2941,8 +2914,8 @@ gnucash_register_init (GnucashRegister *g_reg)
 {
     GtkTable *table = GTK_TABLE(g_reg);
 
-    GTK_WIDGET_UNSET_FLAGS (table, GTK_CAN_FOCUS);
-    GTK_WIDGET_UNSET_FLAGS (table, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_focus (GTK_WIDGET(table), FALSE);
+    gtk_widget_set_can_default (GTK_WIDGET(table), FALSE);
 
     gtk_table_set_homogeneous (table, FALSE);
     gtk_table_resize (table, 3, 2);
@@ -3060,14 +3033,14 @@ gnucash_register_new (Table *table)
      * user. */
     box = gtk_hbox_new(FALSE, 0);
     gtk_widget_set_no_show_all(GTK_WIDGET(box), TRUE);
-    gtk_box_pack_start_defaults(GTK_BOX(box),
-                                GNUCASH_SHEET(sheet)->header_color);
-    gtk_box_pack_start_defaults(GTK_BOX(box),
-                                GNUCASH_SHEET(sheet)->primary_color);
-    gtk_box_pack_start_defaults(GTK_BOX(box),
-                                GNUCASH_SHEET(sheet)->secondary_color);
-    gtk_box_pack_start_defaults(GTK_BOX(box),
-                                GNUCASH_SHEET(sheet)->split_color);
+    gtk_box_pack_start(GTK_BOX(box),
+                                GNUCASH_SHEET(sheet)->header_color, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box),
+                                GNUCASH_SHEET(sheet)->primary_color, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box),
+                                GNUCASH_SHEET(sheet)->secondary_color, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box),
+                                GNUCASH_SHEET(sheet)->split_color, TRUE, TRUE, 0);
 
     gtk_table_attach (GTK_TABLE(widget), box,
                       0, 1, 4, 5,
@@ -3092,8 +3065,11 @@ void gnucash_register_set_moved_cb (GnucashRegister *reg,
 }
 
 
-/*
-  Local Variables:
-  c-basic-offset: 4
-  End:
-*/
+GnucashSheet *gnucash_register_get_sheet (GnucashRegister *reg)
+{
+    g_return_val_if_fail (reg != NULL, NULL);
+    g_return_val_if_fail (GNUCASH_IS_REGISTER(reg), NULL);
+
+    return GNUCASH_SHEET(reg->sheet);
+}
+
