@@ -26,14 +26,21 @@
 (define-module (gnucash report business-reports))
 (use-modules (gnucash gnc-module))
 (gnc:module-load "gnucash/report/standard-reports" 0)
-(gnc:module-load "gnucash/business-utils" 0)
+(gnc:module-load "gnucash/app-utils" 0)
 
 ;; to define gnc-build-url
 (gnc:module-load "gnucash/html" 0)
-;; this defines URL-TYPE-OWNERREPORT
-(gnc:module-load "gnucash/business-gnome" 0)
 
-(define gnc:menuname-business-reports (N_ "_Business"))
+;; Guile 2 needs to find this macro at compile time already
+(cond-expand
+  (guile-2
+    (eval-when
+      (compile load eval) 
+      (define gnc:menuname-business-reports (N_ "_Business"))))
+  (else
+    (define gnc:menuname-business-reports (N_ "_Business"))))
+
+(define gnc:optname-invoice-number (N_ "Invoice Number"))
 
 (define (guid-ref idstr type guid)
   (gnc-build-url type (string-append idstr guid) ""))
@@ -97,7 +104,23 @@
 	  (gnc-build-url URL-TYPE-OWNERREPORT ref ""))
 	ref)))
 
-(export gnc:menuname-business-reports)
+;; Creates a new report instance for the given invoice. The given
+;; report-template-id must refer to an existing report template, which
+;; is then used to instantiate the new report instance.
+(define (gnc:invoice-report-create invoice report-template-id)
+    (if (gnc:find-report-template report-template-id)
+        ;; We found the report template id, so instantiate a report
+        ;; and set the invoice option accordingly.
+        (let* ((options (gnc:make-report-options report-template-id))
+               (invoice-op (gnc:lookup-option options gnc:pagename-general gnc:optname-invoice-number)))
+
+          (gnc:option-set-value invoice-op invoice)
+          (gnc:make-report report-template-id options))
+        ;; Invalid report-template-id, so let's return zero as an invalid report id.
+        0
+        ))
+
+(export gnc:menuname-business-reports gnc:optname-invoice-number)
 
 (use-modules (gnucash report fancy-invoice))
 (use-modules (gnucash report invoice))
@@ -108,10 +131,16 @@
 (use-modules (gnucash report payables))
 (use-modules (gnucash report receivables))
 (use-modules (gnucash report customer-summary))
+(use-modules (gnucash report balsheet-eg))
 
-(define gnc:invoice-report-create gnc:invoice-report-create-internal)
+(define (gnc:payables-report-create account title show-zeros?)
+  (payables-report-create-internal account title show-zeros?))
+
+(define (gnc:receivables-report-create account title show-zeros?)
+  (receivables-report-create-internal account title show-zeros?))
 
 (export gnc:invoice-report-create
 	gnc:customer-anchor-text gnc:job-anchor-text gnc:vendor-anchor-text
-	gnc:invoice-anchor-text gnc:owner-anchor-text gnc:owner-report-text)
+	gnc:invoice-anchor-text gnc:owner-anchor-text gnc:owner-report-text
+	gnc:payables-report-create gnc:receivables-report-create)
 (re-export gnc:owner-report-create)
