@@ -29,14 +29,14 @@
 (define (gnc:options-add-report-date!
 	 options pagename optname sort-tag)
   (gnc:options-make-end-date! options pagename optname sort-tag
-			      (N_ "Select a date to report on")))
+			      (N_ "Select a date to report on.")))
 
 ;; This is a date-interval for a report.
 (define (gnc:options-add-date-interval!
 	 options pagename name-from name-to sort-tag)
   (gnc:options-make-date-interval! options pagename
-				   name-from (N_ "Start of reporting period")
-				   name-to (N_ "End of reporting period")
+				   name-from (N_ "Start of reporting period.")
+				   name-to (N_ "End of reporting period.")
 				   sort-tag))
 
 ;; A date interval multichoice option.
@@ -46,14 +46,14 @@
    options
    (gnc:make-multichoice-option
     pagename optname
-    sort-tag (N_ "The amount of time between data points") default
-    (list (vector 'DayDelta (N_ "Day") (N_ "Day"))
-	  (vector 'WeekDelta (N_ "Week") (N_ "Week"))
-	  (vector 'TwoWeekDelta (N_ "2Week") (N_ "Two Weeks"))
-	  (vector 'MonthDelta (N_ "Month") (N_ "Month"))
-	  (vector 'QuarterDelta (N_ "Quarter") (N_ "Quarter"))
-	  (vector 'HalfYearDelta (N_ "Half Year") (N_ "Half Year"))
-	  (vector 'YearDelta (N_ "Year") (N_ "Year"))
+    sort-tag (N_ "The amount of time between data points.") default
+    (list (vector 'DayDelta (N_ "Day") (N_ "One Day."))
+	  (vector 'WeekDelta (N_ "Week") (N_ "One Week."))
+	  (vector 'TwoWeekDelta (N_ "2Week") (N_ "Two Weeks."))
+	  (vector 'MonthDelta (N_ "Month") (N_ "One Month."))
+	  (vector 'QuarterDelta (N_ "Quarter") (N_ "One Quarter."))
+	  (vector 'HalfYearDelta (N_ "Half Year") (N_ "Half Year."))
+	  (vector 'YearDelta (N_ "Year") (N_ "One Year."))
 	  ))))
 
 ;; A multichoice option intended to chose the account level. Different
@@ -70,19 +70,19 @@
     help-string
     default-depth
     (list (list->vector
-	   (list 'all (N_ "All") (N_ "All accounts")))
+	   (list 'all (N_ "All") (N_ "All accounts.")))
 	  (list->vector
-	   (list 1 "1" (N_ "Top-level")))
+	   (list 1 "1" (N_ "Top-level.")))
 	  (list->vector
-	   (list 2 "2" (N_ "Second-level")))
+	   (list 2 "2" (N_ "Second-level.")))
 	  (list->vector
-	   (list 3 "3" (N_ "Third-level")))
+	   (list 3 "3" (N_ "Third-level.")))
 	  (list->vector
-	   (list 4 "4" (N_ "Fourth-level")))
+	   (list 4 "4" (N_ "Fourth-level.")))
 	  (list->vector
-	   (list 5 "5" (N_ "Fifth-level")))
+	   (list 5 "5" (N_ "Fifth-level.")))
 	  (list->vector
-	   (list 6 "6" (N_ "Sixth-level")))))))
+	   (list 6 "6" (N_ "Sixth-level.")))))))
 
 ;; These help for selecting a bunch of accounts.
 (define (gnc:options-add-account-selection! 
@@ -170,19 +170,19 @@
    options
    (gnc:make-multichoice-option
     pagename optname
-    sort-tag (N_ "The source of price information") default
+    sort-tag (N_ "The source of price information.") default
     (list (vector 'average-cost
 		  (N_ "Average Cost")
-		  (N_ "The volume-weighted average cost of purchases"))
+		  (N_ "The volume-weighted average cost of purchases."))
           (vector 'weighted-average 
 		  (N_ "Weighted Average")
-		  (N_ "The weighted average of all currency transactions of the past"))
+		  (N_ "The weighted average of all currency transactions of the past."))
 	  (vector 'pricedb-latest 
 		  (N_ "Most recent")
-		  (N_ "The most recent recorded price"))
+		  (N_ "The most recent recorded price."))
 	  (vector 'pricedb-nearest
 		  (N_ "Nearest in time")
-		  (N_ "The price recorded nearest in time to the report date"))
+		  (N_ "The price recorded nearest in time to the report date."))
 	  ))))
 
 ;; The width- and height- options for charts
@@ -217,12 +217,15 @@
     (N_ "Choose the marker for each data point.")
     default
     (list
-     (vector 'circle (N_ "Circle") (N_ "Circle"))
-     (vector 'cross (N_ "Cross") (N_ "Cross"))
-     (vector 'square (N_ "Square") (N_ "Square"))
-     (vector 'asterisk (N_ "Asterisk") (N_ "Asterisk"))
-     (vector 'filledcircle (N_ "Filled circle") (N_ "Circle filled with color"))
-     (vector 'filledsquare (N_ "Filled square") (N_ "Square filled with color"))))))
+     (vector 'diamond (N_ "Diamond") (N_ "Hollow diamond."))
+     (vector 'circle (N_ "Circle") (N_ "Hollow circle."))
+     (vector 'square (N_ "Square") (N_ "Hollow square."))
+     (vector 'cross (N_ "Cross") (N_ "Cross."))
+     (vector 'plus (N_ "Plus") (N_ "Plus."))
+     (vector 'dash (N_ "Dash") (N_ "Dash."))
+     (vector 'filleddiamond (N_ "Filled diamond") (N_ "Diamond filled with color."))
+     (vector 'filledcircle (N_ "Filled circle") (N_ "Circle filled with color."))
+     (vector 'filledsquare (N_ "Filled square") (N_ "Square filled with color."))))))
 
 
 (define (gnc:options-add-sort-method!
@@ -235,9 +238,9 @@
     (N_ "Choose the method for sorting accounts.")
     default
     (list
-     (vector 'acct-code (N_ "Account Code") (N_ "Alphabetical by account code"))
-     (vector 'alphabetical (N_ "Alphabetical") (N_ "Alphabetical by account name"))
-     (vector 'amount (N_ "Amount") (N_ "By amount, largest to smallest"))))))
+     (vector 'acct-code (N_ "Account Code") (N_ "Alphabetical by account code."))
+     (vector 'alphabetical (N_ "Alphabetical") (N_ "Alphabetical by account name."))
+     (vector 'amount (N_ "Amount") (N_ "By amount, largest to smallest."))))))
 
 
 ;; These control the calculation and view mode of subtotal balances
@@ -253,17 +256,17 @@
     ;; usually the option name is: (N_ "Parent account balances")
     optname-parent-balance-mode
     (string-append sort-tag "a")
-    (N_ "How to show the balances of parent accounts")
+    (N_ "How to show the balances of parent accounts.")
     'immediate-bal
     (list (vector 'immediate-bal
 		  (N_ "Account Balance")
-		  (N_ "Show only the balance in the parent account, excluding any subaccounts"))
+		  (N_ "Show only the balance in the parent account, excluding any subaccounts."))
 	  (vector 'recursive-bal
 		  (N_ "Subtotal")
-		  (N_ "Calculate the subtotal for this parent account and all of its subaccounts, and show this as the parent account balance"))
+		  (N_ "Calculate the subtotal for this parent account and all of its subaccounts, and show this as the parent account balance."))
 	  (vector 'omit-bal
 		  (N_ "Do not show")
-		  (N_ "Do not show any balances of parent accounts")))))
+		  (N_ "Do not show any balances of parent accounts.")))))
   (gnc:register-option
    options
    (gnc:make-multichoice-option
@@ -271,15 +274,15 @@
     ;; usually the option name is: (N_ "Parent account subtotals")
     optname-parent-total-mode
     (string-append sort-tag "b")
-    (N_ "How to show account subtotals for parent accounts")
+    (N_ "How to show account subtotals for parent accounts.")
     'f
     (list (vector 't
 		  (N_ "Show subtotals")
-		  (N_ "Show subtotals for selected parent accounts which have subaccounts"))
+		  (N_ "Show subtotals for selected parent accounts which have subaccounts."))
 	  (vector 'f
 		  (N_ "Do not show")
-		  (N_ "Do not show any subtotals for parent accounts"))
+		  (N_ "Do not show any subtotals for parent accounts."))
 	  (vector 'canonically-tabbed
 		  ;;(N_ "Subtotals indented text book style")
 		  (N_ "Text book style (experimental)")
-		  (N_ "Show parent account subtotals, indented per accounting text book practice (experimental)"))))))
+		  (N_ "Show parent account subtotals, indented per accounting text book practice (experimental)."))))))
