@@ -69,13 +69,14 @@ balance at a given time"))
 
 (define optname-fullname (N_ "Show long account names"))
 (define optname-show-total (N_ "Show Totals"))
+(define optname-show-percent (N_ "Show Percents"))
 (define optname-slices (N_ "Maximum Slices"))
 (define optname-plot-width (N_ "Plot Width"))
 (define optname-plot-height (N_ "Plot Height"))
 (define optname-sort-method (N_ "Sort Method"))
 
 (define optname-averaging (N_ "Show Average"))
-(define opthelp-averaging (N_ "Select whether the amounts should be shown over the full time period or rather as the average e.g. per month"))
+(define opthelp-averaging (N_ "Select whether the amounts should be shown over the full time period or rather as the average e.g. per month."))
 
 ;; The option-generator. The only dependance on the type of piechart
 ;; is the list of account types that the account selection option
@@ -104,12 +105,7 @@ balance at a given time"))
      options gnc:pagename-general
      optname-price-source "c" 'average-cost)
 
-    (if #f
-;; Option deactivated before 2.4.0 is out in order not to have
-;; untranslated strings show up for the user (string freeze). Will be
-;; activated in 2.4.1 or so by un-commenting the line below and
-;; removing the line above, and changing line 217 accordingly.
-    ;;(if do-intervals?
+    (if do-intervals?
         (add-option
          (gnc:make-multichoice-option
           gnc:pagename-general optname-averaging
@@ -117,16 +113,16 @@ balance at a given time"))
           'None
           (list (vector 'None
                         (N_ "No Averaging")
-                        (N_ "Just show the amounts, without any averaging"))
+                        (N_ "Just show the amounts, without any averaging."))
                 (vector 'YearDelta
                         (N_ "Yearly")
-                        (N_ "Show the average yearly amount during the reporting period"))
+                        (N_ "Show the average yearly amount during the reporting period."))
                 (vector 'MonthDelta
                         (N_ "Monthly")
-                        (N_ "Show the average monthly amount during the reporting period"))
+                        (N_ "Show the average monthly amount during the reporting period."))
                 (vector 'WeekDelta
                         (N_ "Weekly")
-                        (N_ "Show the average weekly amount during the reporting period"))
+                        (N_ "Show the average weekly amount during the reporting period."))
                 )
           ))
         )
@@ -149,7 +145,7 @@ balance at a given time"))
 
     (gnc:options-add-account-levels! 
      options gnc:pagename-accounts optname-levels "b" 
-     (N_ "Show accounts to this depth and not further") 
+     (N_ "Show accounts to this depth and not further.") 
      2)
 
     (add-option
@@ -162,10 +158,17 @@ balance at a given time"))
       gnc:pagename-display optname-show-total
       "b" (N_ "Show the total balance in legend?") #t))
 
+
+     (add-option
+      (gnc:make-simple-boolean-option
+       gnc:pagename-display optname-show-percent
+       "b" (N_ "Show the percentage in legend?") #t))
+
+
     (add-option
      (gnc:make-number-range-option
       gnc:pagename-display optname-slices
-      "c" (N_ "Maximum number of slices in pie") 7
+      "c" (N_ "Maximum number of slices in pie.") 7
       2 24 0 1))
 
     (gnc:options-add-plot-size!
@@ -214,13 +217,14 @@ balance at a given time"))
                                   optname-price-source))
         (report-title (get-option gnc:pagename-general 
 				  gnc:optname-reportname))
-        (averaging-selection (if #f ;;do-intervals?
+        (averaging-selection (if do-intervals?
                                  (get-option gnc:pagename-general
                                              optname-averaging)
                                  'None))
 
         (show-fullname? (get-option gnc:pagename-display optname-fullname))
         (show-total? (get-option gnc:pagename-display optname-show-total))
+        (show-percent? (get-option gnc:pagename-display optname-show-percent))
         (max-slices (inexact->exact
 		     (get-option gnc:pagename-display optname-slices)))
         (height (get-option gnc:pagename-display optname-plot-height))
@@ -499,8 +503,15 @@ balance at a given time"))
 				  (car pair)
 				  (gnc-commodity-get-fraction report-currency)
 				  GNC-RND-ROUND)
-				 print-info))
-			       "")))
+ 				 print-info)
+ 				 )
+ 			       "")
+ 			   (if show-percent?
+ 				(sprintf
+ 				 #f "   (%2.2f %%)"
+ 				 (* 100.0 (/ (car pair) (apply + (unzip1 combined)))))
+ 			       "")
+ 			       ))
                        combined)))
                  (gnc:html-piechart-set-labels! chart legend-labels))
 
