@@ -48,6 +48,7 @@
 (define-module (gnucash report standard-reports equity-statement))
 (use-modules (gnucash main)) ;; FIXME: delete after we finish modularizing.
 (use-modules (gnucash gnc-module))
+(use-modules (gnucash app-utils))
 
 (use-modules (gnucash printf))
 
@@ -58,43 +59,43 @@
 ;; define all option's names and help text so that they are properly
 ;; defined in *one* place.
 (define optname-report-title (N_ "Report Title"))
-(define opthelp-report-title (N_ "Title for this report"))
+(define opthelp-report-title (N_ "Title for this report."))
 
 (define optname-party-name (N_ "Company name"))
-(define opthelp-party-name (N_ "Name of company/individual"))
+(define opthelp-party-name (N_ "Name of company/individual."))
 
 (define optname-start-date (N_ "Start Date"))
 (define optname-end-date (N_ "End Date"))
 
 (define optname-accounts (N_ "Accounts"))
 (define opthelp-accounts
-  (N_ "Report only on these accounts"))
+  (N_ "Report only on these accounts."))
 
 (define optname-use-rules (N_ "Show accounting-style rules"))
 (define opthelp-use-rules
-  (N_ "Use rules beneath columns of added numbers like accountants do"))
+  (N_ "Use rules beneath columns of added numbers like accountants do."))
 
 (define pagename-commodities (N_ "Commodities"))
 (define optname-report-commodity (N_ "Report's currency"))
 (define optname-price-source (N_ "Price Source"))
 (define optname-show-foreign (N_ "Show Foreign Currencies"))
 (define opthelp-show-foreign
-  (N_ "Display any foreign currency amount in an account"))
+  (N_ "Display any foreign currency amount in an account."))
 (define optname-show-rates (N_ "Show Exchange Rates"))
-(define opthelp-show-rates (N_ "Show the exchange rates used"))
+(define opthelp-show-rates (N_ "Show the exchange rates used."))
 
 (define pagename-entries (N_ "Entries"))
 (define optname-closing-pattern (N_ "Closing Entries pattern"))
 (define opthelp-closing-pattern
-  (N_ "Any text in the Description column which identifies closing entries"))
+  (N_ "Any text in the Description column which identifies closing entries."))
 (define optname-closing-casing
   (N_ "Closing Entries pattern is case-sensitive"))
 (define opthelp-closing-casing
-  (N_ "Causes the Closing Entries Pattern match to be case-sensitive"))
+  (N_ "Causes the Closing Entries Pattern match to be case-sensitive."))
 (define optname-closing-regexp
   (N_ "Closing Entries Pattern is regular expression"))
 (define opthelp-closing-regexp
-  (N_ "Causes the Closing Entries Pattern to be treated as a regular expression"))
+  (N_ "Causes the Closing Entries Pattern to be treated as a regular expression."))
 
 ;; options generator
 (define (equity-statement-options-generator)
@@ -110,10 +111,7 @@
     (add-option
       (gnc:make-string-option
       (N_ "General") optname-party-name
-      "b" opthelp-party-name ""))
-    ;; this should default to company name in (gnc-get-current-book)
-    ;; does anyone know the function to get the company name??
-    ;; (GnuCash is *so* well documented... sigh)
+      "b" opthelp-party-name (or (gnc:company-info gnc:*company-name*) "")))
     
     ;; date at which to report balance
     (gnc:options-add-date-interval!
@@ -169,7 +167,7 @@
     (add-option
       (gnc:make-string-option
       pagename-entries optname-closing-pattern
-      "a" opthelp-closing-pattern (N_ "Closing Entries")))
+      "a" opthelp-closing-pattern (_ "Closing Entries")))
     (add-option
      (gnc:make-simple-boolean-option
       pagename-entries optname-closing-casing
@@ -444,10 +442,10 @@
 	  
 	  ;; start and end retained earnings (income - expenses)
 	  (set! neg-pre-start-retained-earnings
-		(gnc:accountlist-get-comm-balance-at-date
+		(gnc:accountlist-get-comm-balance-at-date-with-closing
 		 income-expense-accounts start-date-tp)) ; OK
 	  (set! neg-pre-end-retained-earnings
-		(gnc:accountlist-get-comm-balance-at-date
+		(gnc:accountlist-get-comm-balance-at-date-with-closing
 		 income-expense-accounts end-date-tp)) ; OK
 	  ;; neg-pre-end-retained-earnings is not used to calculate
 	  ;; profit but is used to calculate unrealized gains
@@ -455,13 +453,13 @@
 	  ;; calculate net income
 	  ;; first, ask out how much profit/loss was closed
 	  (set! income-expense-closing
-		(gnc:account-get-trans-type-balance-interval
+		(gnc:account-get-trans-type-balance-interval-with-closing
 		 income-expense-accounts closing-pattern
 		 start-date-tp end-date-tp)
 		)
 	  ;; find retained earnings for the period
 	  (set! neg-net-income
-		(gnc:accountlist-get-comm-balance-interval
+		(gnc:accountlist-get-comm-balance-interval-with-closing
 		 income-expense-accounts
 		 start-date-tp end-date-tp)) ; OK
 	  ;; revert the income/expense to its pre-closing balance
@@ -532,7 +530,7 @@
 	  ;; 
 	  
 	  (set! equity-closing 
-		(gnc:account-get-trans-type-balance-interval
+		(gnc:account-get-trans-type-balance-interval-with-closing
 		 equity-accounts closing-pattern
 		 start-date-tp end-date-tp)
 		)
@@ -543,12 +541,9 @@
 	  (set! net-investment (gnc:make-commodity-collector))  ;; 0
 	  (net-investment 'minusmerge neg-pre-closing-equity #f);; > 0
 	  (net-investment 'merge neg-start-equity-balance #f)   ;; net increase
-	  
-	  (set! withdrawals (gnc:make-commodity-collector))
-	  (withdrawals 'merge (gnc:account-get-pos-trans-total-interval
-				    equity-accounts closing-pattern
-				    start-date-tp end-date-tp)
-		       #f)
+
+	  (set! withdrawals (gnc:account-get-total-flow 'in  equity-accounts start-date-tp end-date-tp))
+
 	  (set! investments (gnc:make-commodity-collector))
 	  (investments 'merge net-investment #f)
 	  (investments 'merge withdrawals #f)
