@@ -31,6 +31,8 @@
 (use-modules (gnucash gnc-module))
 
 (use-modules (gnucash printf))
+(use-modules (gnucash report report-system report-collectors))
+(use-modules (gnucash report report-system collectors))
 
 (gnc:module-load "gnucash/report/report-system" 0)
 
@@ -200,6 +202,8 @@
     ;; 'report-currency' according to the exchange-fn. Returns a
     ;; double.
     (define (collector->double c date)
+      (if (not (gnc:timepair? date))
+	  (throw 'wrong))
       (gnc-numeric-to-double
        (gnc:gnc-monetary-amount
         (gnc:sum-collector-commodity
@@ -250,6 +254,7 @@
      (let* ((assets-list #f)
             (liability-list #f)
             (net-list #f)
+	    (progress-range (cons 50 80))
             (date-string-list (map
                                (if inc-exp?
                                    (lambda (date-list-item)
@@ -257,20 +262,46 @@
                                       (car date-list-item)))
                                    gnc-print-date)
                                dates-list)))
+       (let* ((the-acount-destination-alist
+	       (if inc-exp?
+		   (append (map (lambda (account) (cons account 'asset))
+				 (assoc-ref classified-accounts ACCT-TYPE-INCOME))
+			   (map (lambda (account) (cons account 'liability))
+				 (assoc-ref classified-accounts ACCT-TYPE-EXPENSE)))
+		   (append  (map (lambda (account) (cons account 'asset))
+				 (assoc-ref classified-accounts ACCT-TYPE-ASSET))
+			    (map (lambda (account) (cons account 'liability))
+				 (assoc-ref classified-accounts ACCT-TYPE-LIABILITY)))))
+	      (account-reformat (if inc-exp?
+				    (lambda (account result)
+				      (map (lambda (collector date-interval)
+					     (- (collector->double collector (second date-interval))))
+					   result dates-list))
+				    (lambda (account result)
+				      (let ((commodity-collector (gnc:make-commodity-collector)))
+					(collector-end (fold (lambda (next date list-collector)
+							       (commodity-collector 'merge next #f)
+							       (collector-add list-collector
+									      (collector->double
+									       commodity-collector date)))
+							     (collector-into-list)
+							     result
+							     dates-list))))))
+	      (work (category-by-account-report-work inc-exp?
+					  dates-list
+					  the-acount-destination-alist
+					  (lambda (account date)
+					    (make-gnc-collector-collector))
+					  account-reformat))
+	      (rpt (category-by-account-report-do-work work progress-range))
+	      (assets (assoc-ref rpt 'asset))
+	      (liabilities (assoc-ref rpt 'liability)))
+	 (set! assets-list (if assets (car assets)
+			       (map (lambda (d) 0) dates-list)))
+	 (set! liability-list (if liabilities (car liabilities)
+				  (map (lambda (d) 0) dates-list)))
+	 )
 
-       (set! assets-list
-             (process-datelist
-              (if inc-exp?
-                  accounts
-                  (assoc-ref classified-accounts ACCT-TYPE-ASSET))
-              dates-list #t))
-       (gnc:report-percent-done 70)
-       (set! liability-list
-             (process-datelist
-              (if inc-exp?
-                  accounts
-                  (assoc-ref classified-accounts ACCT-TYPE-LIABILITY))
-              dates-list #f))
        (gnc:report-percent-done 80)
        (set! net-list
              (map + assets-list liability-list))
@@ -416,11 +447,19 @@
     (gnc:report-finished)
     document))
 
+;; Export reports
+
+(export net-worth-barchart-uuid)
+(export income-expense-barchart-uuid)
+
+(define net-worth-barchart-uuid "cbba1696c8c24744848062c7f1cf4a72")
+(define income-expense-barchart-uuid "80769921e87943adade887b9835a7685")
+
 ;; Here we define the actual report
 (gnc:define-report
  'version 1
  'name (N_ "Net Worth Barchart")
- 'report-guid "cbba1696c8c24744848062c7f1cf4a72"
+ 'report-guid net-worth-barchart-uuid
  'menu-path (list gnc:menuname-asset-liability)
  'options-generator (lambda () (options-generator #f))
  'renderer (lambda (report-obj) (net-renderer report-obj #f)))
@@ -428,7 +467,7 @@
 (gnc:define-report
  'version 1
  'name reportname
- 'report-guid "80769921e87943adade887b9835a7685"
+ 'report-guid income-expense-barchart-uuid
  'menu-name (N_ "Income & Expense Chart")
  'menu-path (list gnc:menuname-income-expense)
  'options-generator (lambda () (options-generator #t))
