@@ -32,6 +32,8 @@
 (use-modules (gnucash gnc-module))
 
 (use-modules (gnucash printf))
+(use-modules (gnucash report report-system report-collectors))
+(use-modules (gnucash report report-system collectors))
 
 (gnc:module-load "gnucash/report/report-system" 0)
 
@@ -55,12 +57,12 @@
 (define optname-plot-height (N_ "Plot Height"))
 
 (define optname-line-width (N_ "Line Width"))
-(define opthelp-line-width (N_ "Set line width in pixels"))
+(define opthelp-line-width (N_ "Set line width in pixels."))
 
 (define optname-markers (N_ "Data markers?"))
 
 ;;(define optname-x-grid (N_ "X grid"))
-(define optname-y-grid (N_ "Y Grid"))
+(define optname-y-grid (N_ "Grid"))
 
 
 
@@ -152,7 +154,7 @@
     (add-option
      (gnc:make-simple-boolean-option
       gnc:pagename-display optname-y-grid
-      "f" (N_ "Add horizontal grid lines.")
+      "f" (N_ "Add grid lines.")
       #f))
 
     ;(add-option
@@ -242,6 +244,8 @@
     ;; 'report-currency' according to the exchange-fn. Returns a
     ;; double.
     (define (collector->double c date)
+      (if (not (gnc:timepair? date))
+	  (throw 'wrong))
       (gnc-numeric-to-double
        (gnc:gnc-monetary-amount
         (gnc:sum-collector-commodity
@@ -292,6 +296,7 @@
      (let* ((assets-list #f)
             (liability-list #f)
             (net-list #f)
+	    (progress-range (cons 50 80))
             (date-string-list (map
                                (if inc-exp?
                                    (lambda (date-list-item)
@@ -299,20 +304,46 @@
                                       (car date-list-item)))
                                    gnc-print-date)
                                dates-list)))
+       (let* ((the-acount-destination-alist
+	       (if inc-exp?
+		   (append (map (lambda (account) (cons account 'asset))
+				 (assoc-ref classified-accounts ACCT-TYPE-INCOME))
+			   (map (lambda (account) (cons account 'liability))
+				 (assoc-ref classified-accounts ACCT-TYPE-EXPENSE)))
+		   (append  (map (lambda (account) (cons account 'asset))
+				 (assoc-ref classified-accounts ACCT-TYPE-ASSET))
+			    (map (lambda (account) (cons account 'liability))
+				 (assoc-ref classified-accounts ACCT-TYPE-LIABILITY)))))
+	      (account-reformat (if inc-exp?
+				    (lambda (account result)
+				      (map (lambda (collector date-interval)
+					     (- (collector->double collector (second date-interval))))
+					   result dates-list))
+				    (lambda (account result)
+				      (let ((commodity-collector (gnc:make-commodity-collector)))
+					(collector-end (fold (lambda (next date list-collector)
+							       (commodity-collector 'merge next #f)
+							       (collector-add list-collector
+									      (collector->double
+									       commodity-collector date)))
+							     (collector-into-list)
+							     result
+							     dates-list))))))
+	      (work (category-by-account-report-work inc-exp?
+					  dates-list
+					  the-acount-destination-alist
+					  (lambda (account date)
+					    (make-gnc-collector-collector))
+					  account-reformat))
+	      (rpt (category-by-account-report-do-work work progress-range))
+	      (assets (assoc-ref rpt 'asset))
+	      (liabilities (assoc-ref rpt 'liability)))
+	 (set! assets-list (if assets (car assets)
+			       (map (lambda (d) 0) dates-list)))
+	 (set! liability-list (if liabilities (car liabilities)
+				  (map (lambda (d) 0) dates-list)))
+	 )
 
-       (set! assets-list
-             (process-datelist
-              (if inc-exp?
-                  accounts
-                  (assoc-ref classified-accounts ACCT-TYPE-ASSET))
-              dates-list #t))
-       (gnc:report-percent-done 70)
-       (set! liability-list
-             (process-datelist
-              (if inc-exp?
-                  accounts
-                  (assoc-ref classified-accounts ACCT-TYPE-LIABILITY))
-              dates-list #f))
        (gnc:report-percent-done 80)
        (set! net-list
              (map + assets-list liability-list))
@@ -416,6 +447,11 @@
            (gnc:html-document-add-object! document chart)
              (if show-table?
              (let ((table (gnc:make-html-table)))
+                (gnc:html-table-set-style!
+                  table "table"
+                  'attribute (list "border" 0)
+                  'attribute (list "cellspacing" 0)
+                  'attribute (list "cellpadding" 4))
                 (gnc:html-table-set-col-headers!
                  table
                  (append
@@ -465,11 +501,16 @@
     (gnc:report-finished)
     document))
 
+;; Export reports
+
+(export net-worth-linechart-uuid)
+(define net-worth-linechart-uuid "d8b63264186b11e19038001558291366")
+
 ;; Here we define the actual report
 (gnc:define-report
  'version 1
  'name (N_ "Net Worth Linechart")
- 'report-guid "d8b63264186b11e19038001558291366"
+ 'report-guid net-worth-linechart-uuid
  'menu-path (list gnc:menuname-asset-liability)
  'options-generator (lambda () (options-generator #f))
  'renderer (lambda (report-obj) (net-renderer report-obj #f)))
